# Copyright (c) 2015, Scott J Maddox. All rights reserved.
# Use of this source code is governed by the BSD-3-Clause
# license that can be found in the LICENSE file.

# This file was generated by `scripts/gen_test_gfd.py`.
# Do not edit this file directly, or your changes will be lost.
'''
Tests the `gfd` module.
'''
# Make sure we import the local package
import os
import sys
sys.path.insert(0,
    os.path.abspath(os.path.join(os.path.dirname(__file__), '../..')))
from fdint import gfd
import unittest
import numpy
import warnings

class Test_GFD(unittest.TestCase):

    def assertRTOL(self, a, b, RTOL):
        assert RTOL >= 0
        rerr = abs(a-b)/a
        if rerr > RTOL:
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(RTOL, rerr))

    def assert_all_rtol(self, a, b, rtol):
        a = numpy.array(a)
        b = numpy.array(b)
        rtol = numpy.array(rtol)
        for rtol_ in rtol:
            assert rtol_ >= 0
        rerr = abs(a-b)/a
        if (rerr > rtol).all():
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(rtol, rerr))

    def test_gfdm1h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-50.0, 0.0),
                            3.41862030057428093e-22,
                            1e-07)

    def test_vgfdm1h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-50.0,)),
                                           numpy.array((0.0,))),
                                 (3.41862030057428093e-22,),
                                 (1e-07,))

    def test_gfdm1h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-3.0, 0.0),
                            8.52597063488509527e-02,
                            1e-07)

    def test_vgfdm1h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-3.0,)),
                                           numpy.array((0.0,))),
                                 (8.52597063488509527e-02,),
                                 (1e-07,))

    def test_gfdm1h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-2.0, 0.0),
                            2.19191620737676202e-01,
                            1e-07)

    def test_vgfdm1h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-2.0,)),
                                           numpy.array((0.0,))),
                                 (2.19191620737676202e-01,),
                                 (1e-07,))

    def test_gfdm1h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-1.0, 0.0),
                            5.21150414377014259e-01,
                            1e-07)

    def test_vgfdm1h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-1.0,)),
                                           numpy.array((0.0,))),
                                 (5.21150414377014259e-01,),
                                 (1e-07,))

    def test_gfdm1h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(0.0, 0.0),
                            1.07215499426948724e+00,
                            1e-07)

    def test_vgfdm1h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((0.0,)),
                                           numpy.array((0.0,))),
                                 (1.07215499426948724e+00,),
                                 (1e-07,))

    def test_gfdm1h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(1.0, 0.0),
                            1.82041146637164375e+00,
                            1e-07)

    def test_vgfdm1h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((1.0,)),
                                           numpy.array((0.0,))),
                                 (1.82041146637164375e+00,),
                                 (1e-07,))

    def test_gfdm1h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(4.0, 0.0),
                            3.87435338318501366e+00,
                            1e-07)

    def test_vgfdm1h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((4.0,)),
                                           numpy.array((0.0,))),
                                 (3.87435338318501366e+00,),
                                 (1e-07,))

    def test_gfdm1h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(5.0, 0.0),
                            4.38325669770695736e+00,
                            1e-07)

    def test_vgfdm1h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((5.0,)),
                                           numpy.array((0.0,))),
                                 (4.38325669770695736e+00,),
                                 (1e-07,))

    def test_gfdm1h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(7.0, 0.0),
                            5.24155545558703384e+00,
                            1e-07)

    def test_vgfdm1h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((7.0,)),
                                           numpy.array((0.0,))),
                                 (5.24155545558703384e+00,),
                                 (1e-07,))

    def test_gfdm1h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(10.0, 0.0),
                            6.29713762236208385e+00,
                            1e-07)

    def test_vgfdm1h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((10.0,)),
                                           numpy.array((0.0,))),
                                 (6.29713762236208385e+00,),
                                 (1e-07,))

    def test_gfdm1h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(15.0, 0.0),
                            7.73151352106451295e+00,
                            1e-07)

    def test_vgfdm1h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((15.0,)),
                                           numpy.array((0.0,))),
                                 (7.73151352106451295e+00,),
                                 (1e-07,))

    def test_gfdm1h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(20.0, 0.0),
                            8.93497320226533098e+00,
                            1e-07)

    def test_vgfdm1h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((20.0,)),
                                           numpy.array((0.0,))),
                                 (8.93497320226533098e+00,),
                                 (1e-07,))

    def test_gfdm1h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(30.0, 0.0),
                            1.09494219613718897e+01,
                            1e-07)

    def test_vgfdm1h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((30.0,)),
                                           numpy.array((0.0,))),
                                 (1.09494219613718897e+01,),
                                 (1e-07,))

    def test_gfdm1h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(40.0, 0.0),
                            1.26458514472489920e+01,
                            1e-07)

    def test_vgfdm1h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((40.0,)),
                                           numpy.array((0.0,))),
                                 (1.26458514472489920e+01,),
                                 (1e-07,))

    def test_gfdm1h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(50.0, 0.0),
                            1.41398061393993402e+01,
                            1e-07)

    def test_vgfdm1h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((50.0,)),
                                           numpy.array((0.0,))),
                                 (1.41398061393993402e+01,),
                                 (1e-07,))

    def test_gfdm1h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-50.0, 0.075),
                            3.45023869035781114e-22,
                            9e-08)

    def test_vgfdm1h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-50.0,)),
                                           numpy.array((0.075,))),
                                 (3.45023869035781114e-22,),
                                 (9e-08,))

    def test_gfdm1h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-3.0, 0.075),
                            8.60617942686103948e-02,
                            9e-08)

    def test_vgfdm1h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-3.0,)),
                                           numpy.array((0.075,))),
                                 (8.60617942686103948e-02,),
                                 (9e-08,))

    def test_gfdm1h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-2.0, 0.075),
                            2.21310594441572001e-01,
                            1e-07)

    def test_vgfdm1h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-2.0,)),
                                           numpy.array((0.075,))),
                                 (2.21310594441572001e-01,),
                                 (1e-07,))

    def test_gfdm1h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-1.0, 0.075),
                            5.26519912692117509e-01,
                            1e-07)

    def test_vgfdm1h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-1.0,)),
                                           numpy.array((0.075,))),
                                 (5.26519912692117509e-01,),
                                 (1e-07,))

    def test_gfdm1h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(0.0, 0.075),
                            1.08467593486047531e+00,
                            1e-09)

    def test_vgfdm1h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((0.0,)),
                                           numpy.array((0.075,))),
                                 (1.08467593486047531e+00,),
                                 (1e-09,))

    def test_gfdm1h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(1.0, 0.075),
                            1.84614866407679723e+00,
                            3e-09)

    def test_vgfdm1h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((1.0,)),
                                           numpy.array((0.075,))),
                                 (1.84614866407679723e+00,),
                                 (3e-09,))

    def test_gfdm1h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(4.0, 0.075),
                            3.97966737443307395e+00,
                            5e-09)

    def test_vgfdm1h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((4.0,)),
                                           numpy.array((0.075,))),
                                 (3.97966737443307395e+00,),
                                 (5e-09,))

    def test_gfdm1h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(5.0, 0.075),
                            4.52570562678987720e+00,
                            6e-09)

    def test_vgfdm1h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((5.0,)),
                                           numpy.array((0.075,))),
                                 (4.52570562678987720e+00,),
                                 (6e-09,))

    def test_gfdm1h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(7.0, 0.075),
                            5.46972697064253399e+00,
                            9e-10)

    def test_vgfdm1h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((7.0,)),
                                           numpy.array((0.075,))),
                                 (5.46972697064253399e+00,),
                                 (9e-10,))

    def test_gfdm1h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(10.0, 0.075),
                            6.67659724958244460e+00,
                            4e-09)

    def test_vgfdm1h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((10.0,)),
                                           numpy.array((0.075,))),
                                 (6.67659724958244460e+00,),
                                 (4e-09,))

    def test_gfdm1h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(15.0, 0.075),
                            8.40902185520310397e+00,
                            5e-09)

    def test_vgfdm1h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((15.0,)),
                                           numpy.array((0.075,))),
                                 (8.40902185520310397e+00,),
                                 (5e-09,))

    def test_gfdm1h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(20.0, 0.075),
                            9.95449196388720381e+00,
                            7e-09)

    def test_vgfdm1h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((20.0,)),
                                           numpy.array((0.075,))),
                                 (9.95449196388720381e+00,),
                                 (7e-09,))

    def test_gfdm1h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(30.0, 0.075),
                            1.27504736062638031e+01,
                            3e-09)

    def test_vgfdm1h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((30.0,)),
                                           numpy.array((0.075,))),
                                 (1.27504736062638031e+01,),
                                 (3e-09,))

    def test_gfdm1h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(40.0, 0.075),
                            1.53257081165839342e+01,
                            6e-09)

    def test_vgfdm1h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((40.0,)),
                                           numpy.array((0.075,))),
                                 (1.53257081165839342e+01,),
                                 (6e-09,))

    def test_gfdm1h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(50.0, 0.075),
                            1.77719171979791852e+01,
                            6e-11)

    def test_vgfdm1h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((50.0,)),
                                           numpy.array((0.075,))),
                                 (1.77719171979791852e+01,),
                                 (6e-11,))

    def test_gfdm1h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-50.0, 0.15),
                            3.48106251908235795e-22,
                            2e-07)

    def test_vgfdm1h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-50.0,)),
                                           numpy.array((0.15,))),
                                 (3.48106251908235795e-22,),
                                 (2e-07,))

    def test_gfdm1h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-3.0, 0.15),
                            8.68435600907420391e-02,
                            2e-07)

    def test_vgfdm1h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-3.0,)),
                                           numpy.array((0.15,))),
                                 (8.68435600907420391e-02,),
                                 (2e-07,))

    def test_gfdm1h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-2.0, 0.15),
                            2.23375183085195328e-01,
                            5e-09)

    def test_vgfdm1h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-2.0,)),
                                           numpy.array((0.15,))),
                                 (2.23375183085195328e-01,),
                                 (5e-09,))

    def test_gfdm1h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-1.0, 0.15),
                            5.31747154463234506e-01,
                            5e-09)

    def test_vgfdm1h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-1.0,)),
                                           numpy.array((0.15,))),
                                 (5.31747154463234506e-01,),
                                 (5e-09,))

    def test_gfdm1h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(0.0, 0.15),
                            1.09684291233822795e+00,
                            6e-09)

    def test_vgfdm1h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((0.0,)),
                                           numpy.array((0.15,))),
                                 (1.09684291233822795e+00,),
                                 (6e-09,))

    def test_gfdm1h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(1.0, 0.15),
                            1.87107615391477422e+00,
                            9e-09)

    def test_vgfdm1h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((1.0,)),
                                           numpy.array((0.15,))),
                                 (1.87107615391477422e+00,),
                                 (9e-09,))

    def test_gfdm1h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(4.0, 0.15),
                            4.07990784552398189e+00,
                            8e-08)

    def test_vgfdm1h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((4.0,)),
                                           numpy.array((0.15,))),
                                 (4.07990784552398189e+00,),
                                 (8e-08,))

    def test_gfdm1h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(5.0, 0.15),
                            4.66034331354291353e+00,
                            3e-09)

    def test_vgfdm1h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((5.0,)),
                                           numpy.array((0.15,))),
                                 (4.66034331354291353e+00,),
                                 (3e-09,))

    def test_gfdm1h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(7.0, 0.15),
                            5.68232613899786987e+00,
                            1e-08)

    def test_vgfdm1h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((7.0,)),
                                           numpy.array((0.15,))),
                                 (5.68232613899786987e+00,),
                                 (1e-08,))

    def test_gfdm1h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(10.0, 0.15),
                            7.02291019121403437e+00,
                            4e-09)

    def test_vgfdm1h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((10.0,)),
                                           numpy.array((0.15,))),
                                 (7.02291019121403437e+00,),
                                 (4e-09,))

    def test_gfdm1h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(15.0, 0.15),
                            9.00841827043538323e+00,
                            2e-09)

    def test_vgfdm1h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((15.0,)),
                                           numpy.array((0.15,))),
                                 (9.00841827043538323e+00,),
                                 (2e-09,))

    def test_gfdm1h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(20.0, 0.15),
                            1.08324690858367116e+01,
                            4e-09)

    def test_vgfdm1h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((20.0,)),
                                           numpy.array((0.15,))),
                                 (1.08324690858367116e+01,),
                                 (4e-09,))

    def test_gfdm1h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(30.0, 0.15),
                            1.42340752123558119e+01,
                            4e-07)

    def test_vgfdm1h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((30.0,)),
                                           numpy.array((0.15,))),
                                 (1.42340752123558119e+01,),
                                 (4e-07,))

    def test_gfdm1h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(40.0, 0.15),
                            1.74579864824527320e+01,
                            2e-04)

    def test_vgfdm1h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((40.0,)),
                                           numpy.array((0.15,))),
                                 (1.74579864824527320e+01,),
                                 (2e-04,))

    def test_gfdm1h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(50.0, 0.15),
                            2.06418432701824841e+01,
                            6e-03)

    def test_vgfdm1h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((50.0,)),
                                           numpy.array((0.15,))),
                                 (2.06418432701824841e+01,),
                                 (6e-03,))

    def test_gfdm1h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-50.0, 0.225),
                            3.51117756491165601e-22,
                            2e-07)

    def test_vgfdm1h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-50.0,)),
                                           numpy.array((0.225,))),
                                 (3.51117756491165601e-22,),
                                 (2e-07,))

    def test_gfdm1h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-3.0, 0.225),
                            8.76072067647288427e-02,
                            2e-07)

    def test_vgfdm1h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-3.0,)),
                                           numpy.array((0.225,))),
                                 (8.76072067647288427e-02,),
                                 (2e-07,))

    def test_gfdm1h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-2.0, 0.225),
                            2.25391246283487862e-01,
                            7e-09)

    def test_vgfdm1h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-2.0,)),
                                           numpy.array((0.225,))),
                                 (2.25391246283487862e-01,),
                                 (7e-09,))

    def test_gfdm1h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-1.0, 0.225),
                            5.36847718624313019e-01,
                            8e-09)

    def test_vgfdm1h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-1.0,)),
                                           numpy.array((0.225,))),
                                 (5.36847718624313019e-01,),
                                 (8e-09,))

    def test_gfdm1h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(0.0, 0.225),
                            1.10869585877475774e+00,
                            1e-08)

    def test_vgfdm1h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((0.0,)),
                                           numpy.array((0.225,))),
                                 (1.10869585877475774e+00,),
                                 (1e-08,))

    def test_gfdm1h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(1.0, 0.225),
                            1.89529108118685441e+00,
                            2e-08)

    def test_vgfdm1h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((1.0,)),
                                           numpy.array((0.225,))),
                                 (1.89529108118685441e+00,),
                                 (2e-08,))

    def test_gfdm1h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(4.0, 0.225),
                            4.17588519952772597e+00,
                            4e-09)

    def test_vgfdm1h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((4.0,)),
                                           numpy.array((0.225,))),
                                 (4.17588519952772597e+00,),
                                 (4e-09,))

    def test_gfdm1h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(5.0, 0.225),
                            4.78854351316443871e+00,
                            4e-10)

    def test_vgfdm1h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((5.0,)),
                                           numpy.array((0.225,))),
                                 (4.78854351316443871e+00,),
                                 (4e-10,))

    def test_gfdm1h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(7.0, 0.225),
                            5.88258669200485862e+00,
                            1e-09)

    def test_vgfdm1h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((7.0,)),
                                           numpy.array((0.225,))),
                                 (5.88258669200485862e+00,),
                                 (1e-09,))

    def test_gfdm1h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(10.0, 0.225),
                            7.34439766989452103e+00,
                            6e-10)

    def test_vgfdm1h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((10.0,)),
                                           numpy.array((0.225,))),
                                 (7.34439766989452103e+00,),
                                 (6e-10,))

    def test_gfdm1h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(15.0, 0.225),
                            9.55390506670982376e+00,
                            3e-09)

    def test_vgfdm1h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((15.0,)),
                                           numpy.array((0.225,))),
                                 (9.55390506670982376e+00,),
                                 (3e-09,))

    def test_gfdm1h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(20.0, 0.225),
                            1.16191847019764545e+01,
                            2e-06)

    def test_vgfdm1h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((20.0,)),
                                           numpy.array((0.225,))),
                                 (1.16191847019764545e+01,),
                                 (2e-06,))

    def test_gfdm1h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(30.0, 0.225),
                            1.55466689055292804e+01,
                            2e-03)

    def test_vgfdm1h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((30.0,)),
                                           numpy.array((0.225,))),
                                 (1.55466689055292804e+01,),
                                 (2e-03,))

    def test_gfdm1h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(40.0, 0.225),
                            2.01017376048420005e+01,
                            8e-02)

    def test_vgfdm1h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((40.0,)),
                                           numpy.array((0.225,))),
                                 (2.01017376048420005e+01,),
                                 (8e-02,))

    def test_gfdm1h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(50.0, 0.225),
                            3.72959709474892236e+01,
                            1e+00)

    def test_vgfdm1h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((50.0,)),
                                           numpy.array((0.225,))),
                                 (3.72959709474892236e+01,),
                                 (1e+00,))

    def test_gfdm1h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-50.0, 0.3),
                            3.54064902642658540e-22,
                            2e-07)

    def test_vgfdm1h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-50.0,)),
                                           numpy.array((0.3,))),
                                 (3.54064902642658540e-22,),
                                 (2e-07,))

    def test_gfdm1h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-3.0, 0.3),
                            8.83544073023509180e-02,
                            2e-07)

    def test_vgfdm1h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-3.0,)),
                                           numpy.array((0.3,))),
                                 (8.83544073023509180e-02,),
                                 (2e-07,))

    def test_gfdm1h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-2.0, 0.3),
                            2.27363426531536572e-01,
                            1e-08)

    def test_vgfdm1h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-2.0,)),
                                           numpy.array((0.3,))),
                                 (2.27363426531536572e-01,),
                                 (1e-08,))

    def test_gfdm1h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(-1.0, 0.3),
                            5.41833916844009611e-01,
                            1e-08)

    def test_vgfdm1h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((-1.0,)),
                                           numpy.array((0.3,))),
                                 (5.41833916844009611e-01,),
                                 (1e-08,))

    def test_gfdm1h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(0.0, 0.3),
                            1.12026641774436864e+00,
                            2e-08)

    def test_vgfdm1h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((0.0,)),
                                           numpy.array((0.3,))),
                                 (1.12026641774436864e+00,),
                                 (2e-08,))

    def test_gfdm1h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(1.0, 0.3),
                            1.91886965841472179e+00,
                            3e-08)

    def test_vgfdm1h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((1.0,)),
                                           numpy.array((0.3,))),
                                 (1.91886965841472179e+00,),
                                 (3e-08,))

    def test_gfdm1h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(4.0, 0.3),
                            4.26819597451099764e+00,
                            1e-08)

    def test_vgfdm1h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((4.0,)),
                                           numpy.array((0.3,))),
                                 (4.26819597451099764e+00,),
                                 (1e-08,))

    def test_gfdm1h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(5.0, 0.3),
                            4.91128862748422979e+00,
                            3e-09)

    def test_vgfdm1h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((5.0,)),
                                           numpy.array((0.3,))),
                                 (4.91128862748422979e+00,),
                                 (3e-09,))

    def test_gfdm1h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(7.0, 0.3),
                            6.07269354910286019e+00,
                            5e-09)

    def test_vgfdm1h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((7.0,)),
                                           numpy.array((0.3,))),
                                 (6.07269354910286019e+00,),
                                 (5e-09,))

    def test_gfdm1h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(10.0, 0.3),
                            7.64624379698125711e+00,
                            7e-08)

    def test_vgfdm1h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((10.0,)),
                                           numpy.array((0.3,))),
                                 (7.64624379698125711e+00,),
                                 (7e-08,))

    def test_gfdm1h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(15.0, 0.3),
                            1.00589425324919723e+01,
                            8e-06)

    def test_vgfdm1h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((15.0,)),
                                           numpy.array((0.3,))),
                                 (1.00589425324919723e+01,),
                                 (8e-06,))

    def test_gfdm1h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(20.0, 0.3),
                            1.23427708786633286e+01,
                            5e-04)

    def test_vgfdm1h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((20.0,)),
                                           numpy.array((0.3,))),
                                 (1.23427708786633286e+01,),
                                 (5e-04,))

    def test_gfdm1h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(30.0, 0.3),
                            1.75069361023896022e+01,
                            1e-01)

    def test_vgfdm1h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((30.0,)),
                                           numpy.array((0.3,))),
                                 (1.75069361023896022e+01,),
                                 (1e-01,))

    def test_gfdm1h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(40.0, 0.3),
                            5.00973909081849911e+01,
                            3e+00)

    def test_vgfdm1h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((40.0,)),
                                           numpy.array((0.3,))),
                                 (5.00973909081849911e+01,),
                                 (3e+00,))

    def test_gfdm1h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfdm1h(50.0, 0.3),
                            4.24788289017311456e+02,
                            3e+01)

    def test_vgfdm1h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfdm1h(numpy.array((50.0,)),
                                           numpy.array((0.3,))),
                                 (4.24788289017311456e+02,),
                                 (3e+01,))

    def test_gfd1h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-50.0, 0.0),
                            1.70931015028714046e-22,
                            1e-07)

    def test_vgfd1h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-50.0,)),
                                           numpy.array((0.0,))),
                                 (1.70931015028714046e-22,),
                                 (1e-07,))

    def test_gfd1h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-3.0, 0.0),
                            4.33663701523976236e-02,
                            1e-07)

    def test_vgfd1h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-3.0,)),
                                           numpy.array((0.0,))),
                                 (4.33663701523976236e-02,),
                                 (1e-07,))

    def test_gfd1h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-2.0, 0.0),
                            1.14587830800532503e-01,
                            1e-07)

    def test_vgfd1h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-2.0,)),
                                           numpy.array((0.0,))),
                                 (1.14587830800532503e-01,),
                                 (1e-07,))

    def test_gfd1h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-1.0, 0.0),
                            2.90500913599971378e-01,
                            1e-07)

    def test_vgfd1h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-1.0,)),
                                           numpy.array((0.0,))),
                                 (2.90500913599971378e-01,),
                                 (1e-07,))

    def test_gfd1h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(0.0, 0.0),
                            6.78093935838734674e-01,
                            1e-07)

    def test_vgfd1h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((0.0,)),
                                           numpy.array((0.0,))),
                                 (6.78093935838734674e-01,),
                                 (1e-07,))

    def test_gfd1h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(1.0, 0.0),
                            1.39637536444908084e+00,
                            1e-07)

    def test_vgfd1h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((1.0,)),
                                           numpy.array((0.0,))),
                                 (1.39637536444908084e+00,),
                                 (1e-07,))

    def test_gfd1h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(4.0, 0.0),
                            5.77072687384848759e+00,
                            1e-07)

    def test_vgfd1h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((4.0,)),
                                           numpy.array((0.0,))),
                                 (5.77072687384848759e+00,),
                                 (1e-07,))

    def test_gfd1h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(5.0, 0.0),
                            7.83797652757165952e+00,
                            1e-07)

    def test_vgfd1h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((5.0,)),
                                           numpy.array((0.0,))),
                                 (7.83797652757165952e+00,),
                                 (1e-07,))

    def test_gfd1h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(7.0, 0.0),
                            1.26646383321303588e+01,
                            1e-07)

    def test_vgfd1h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((7.0,)),
                                           numpy.array((0.0,))),
                                 (1.26646383321303588e+01,),
                                 (1e-07,))

    def test_gfd1h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(10.0, 0.0),
                            2.13444727730234760e+01,
                            1e-07)

    def test_vgfd1h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((10.0,)),
                                           numpy.array((0.0,))),
                                 (2.13444727730234760e+01,),
                                 (1e-07,))

    def test_gfd1h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(15.0, 0.0),
                            3.89430489375154991e+01,
                            1e-07)

    def test_vgfd1h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((15.0,)),
                                           numpy.array((0.0,))),
                                 (3.89430489375154991e+01,),
                                 (1e-07,))

    def test_gfd1h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(20.0, 0.0),
                            5.98127989591257574e+01,
                            1e-07)

    def test_vgfd1h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((20.0,)),
                                           numpy.array((0.0,))),
                                 (5.98127989591257574e+01,),
                                 (1e-07,))

    def test_gfd1h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(30.0, 0.0),
                            1.09694824918955632e+02,
                            1e-07)

    def test_vgfd1h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((30.0,)),
                                           numpy.array((0.0,))),
                                 (1.09694824918955632e+02,),
                                 (1e-07,))

    def test_gfd1h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(40.0, 0.0),
                            1.68784932721796395e+02,
                            1e-07)

    def test_vgfd1h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((40.0,)),
                                           numpy.array((0.0,))),
                                 (1.68784932721796395e+02,),
                                 (1e-07,))

    def test_gfd1h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(50.0, 0.0),
                            2.35818629275001257e+02,
                            1e-07)

    def test_vgfd1h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((50.0,)),
                                           numpy.array((0.0,))),
                                 (2.35818629275001257e+02,),
                                 (1e-07,))

    def test_gfd1h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-50.0, 0.075),
                            1.75632472638411867e-22,
                            3e-08)

    def test_vgfd1h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-50.0,)),
                                           numpy.array((0.075,))),
                                 (1.75632472638411867e-22,),
                                 (3e-08,))

    def test_gfd1h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-3.0, 0.075),
                            4.45693568806805954e-02,
                            3e-08)

    def test_vgfd1h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-3.0,)),
                                           numpy.array((0.075,))),
                                 (4.45693568806805954e-02,),
                                 (3e-08,))

    def test_gfd1h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-2.0, 0.075),
                            1.17810625935642538e-01,
                            3e-08)

    def test_vgfd1h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-2.0,)),
                                           numpy.array((0.075,))),
                                 (1.17810625935642538e-01,),
                                 (3e-08,))

    def test_gfd1h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-1.0, 0.075),
                            2.98945928877046907e-01,
                            3e-08)

    def test_vgfd1h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-1.0,)),
                                           numpy.array((0.075,))),
                                 (2.98945928877046907e-01,),
                                 (3e-08,))

    def test_gfd1h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(0.0, 0.075),
                            6.99200487338112686e-01,
                            2e-08)

    def test_vgfd1h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((0.0,)),
                                           numpy.array((0.075,))),
                                 (6.99200487338112686e-01,),
                                 (2e-08,))

    def test_gfd1h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(1.0, 0.075),
                            1.44502709099618265e+00,
                            2e-08)

    def test_vgfd1h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((1.0,)),
                                           numpy.array((0.075,))),
                                 (1.44502709099618265e+00,),
                                 (2e-08,))

    def test_gfd1h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(4.0, 0.075),
                            6.08971762438002084e+00,
                            5e-08)

    def test_vgfd1h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((4.0,)),
                                           numpy.array((0.075,))),
                                 (6.08971762438002084e+00,),
                                 (5e-08,))

    def test_gfd1h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(5.0, 0.075),
                            8.33885063738478394e+00,
                            1e-08)

    def test_vgfd1h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((5.0,)),
                                           numpy.array((0.075,))),
                                 (8.33885063738478394e+00,),
                                 (1e-08,))

    def test_gfd1h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(7.0, 0.075),
                            1.37056355584969562e+01,
                            5e-09)

    def test_vgfd1h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((7.0,)),
                                           numpy.array((0.075,))),
                                 (1.37056355584969562e+01,),
                                 (5e-09,))

    def test_gfd1h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(10.0, 0.075),
                            2.37044470618182537e+01,
                            2e-08)

    def test_vgfd1h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((10.0,)),
                                           numpy.array((0.075,))),
                                 (2.37044470618182537e+01,),
                                 (2e-08,))

    def test_gfd1h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(15.0, 0.075),
                            4.50830486391759422e+01,
                            1e-08)

    def test_vgfd1h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((15.0,)),
                                           numpy.array((0.075,))),
                                 (4.50830486391759422e+01,),
                                 (1e-08,))

    def test_gfd1h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(20.0, 0.075),
                            7.19794174887380933e+01,
                            2e-08)

    def test_vgfd1h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((20.0,)),
                                           numpy.array((0.075,))),
                                 (7.19794174887380933e+01,),
                                 (2e-08,))

    def test_gfd1h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(30.0, 0.075),
                            1.41532187835316762e+02,
                            9e-09)

    def test_vgfd1h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((30.0,)),
                                           numpy.array((0.075,))),
                                 (1.41532187835316762e+02,),
                                 (9e-09,))

    def test_gfd1h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(40.0, 0.075),
                            2.31477206375404734e+02,
                            1e-08)

    def test_vgfd1h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((40.0,)),
                                           numpy.array((0.075,))),
                                 (2.31477206375404734e+02,),
                                 (1e-08,))

    def test_gfd1h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(50.0, 0.075),
                            3.41437761287440139e+02,
                            2e-09)

    def test_vgfd1h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((50.0,)),
                                           numpy.array((0.075,))),
                                 (3.41437761287440139e+02,),
                                 (2e-09,))

    def test_gfd1h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-50.0, 0.15),
                            1.80144534348771730e-22,
                            7e-08)

    def test_vgfd1h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-50.0,)),
                                           numpy.array((0.15,))),
                                 (1.80144534348771730e-22,),
                                 (7e-08,))

    def test_gfd1h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-3.0, 0.15),
                            4.57236851642160644e-02,
                            7e-08)

    def test_vgfd1h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-3.0,)),
                                           numpy.array((0.15,))),
                                 (4.57236851642160644e-02,),
                                 (7e-08,))

    def test_gfd1h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-2.0, 0.15),
                            1.20902196226494160e-01,
                            7e-08)

    def test_vgfd1h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-2.0,)),
                                           numpy.array((0.15,))),
                                 (1.20902196226494160e-01,),
                                 (7e-08,))

    def test_gfd1h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-1.0, 0.15),
                            3.07041412974718042e-01,
                            8e-08)

    def test_vgfd1h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-1.0,)),
                                           numpy.array((0.15,))),
                                 (3.07041412974718042e-01,),
                                 (8e-08,))

    def test_gfd1h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(0.0, 0.15),
                            7.19401826377869313e-01,
                            9e-08)

    def test_vgfd1h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((0.0,)),
                                           numpy.array((0.15,))),
                                 (7.19401826377869313e-01,),
                                 (9e-08,))

    def test_gfd1h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(1.0, 0.15),
                            1.49145549474437922e+00,
                            1e-07)

    def test_vgfd1h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((1.0,)),
                                           numpy.array((0.15,))),
                                 (1.49145549474437922e+00,),
                                 (1e-07,))

    def test_gfd1h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(4.0, 0.15),
                            6.38891646674312330e+00,
                            1e-08)

    def test_vgfd1h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((4.0,)),
                                           numpy.array((0.15,))),
                                 (6.38891646674312330e+00,),
                                 (1e-08,))

    def test_gfd1h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(5.0, 0.15),
                            8.80517851626515480e+00,
                            7e-09)

    def test_vgfd1h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((5.0,)),
                                           numpy.array((0.15,))),
                                 (8.80517851626515480e+00,),
                                 (7e-09,))

    def test_gfd1h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(7.0, 0.15),
                            1.46599411190672146e+01,
                            4e-10)

    def test_vgfd1h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((7.0,)),
                                           numpy.array((0.15,))),
                                 (1.46599411190672146e+01,),
                                 (4e-10,))

    def test_gfd1h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(10.0, 0.15),
                            2.58187406970339026e+01,
                            1e-08)

    def test_vgfd1h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((10.0,)),
                                           numpy.array((0.15,))),
                                 (2.58187406970339026e+01,),
                                 (1e-08,))

    def test_gfd1h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(15.0, 0.15),
                            5.03946789953786265e+01,
                            6e-09)

    def test_vgfd1h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((15.0,)),
                                           numpy.array((0.15,))),
                                 (5.03946789953786265e+01,),
                                 (6e-09,))

    def test_gfd1h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(20.0, 0.15),
                            8.21886508630633870e+01,
                            9e-09)

    def test_vgfd1h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((20.0,)),
                                           numpy.array((0.15,))),
                                 (8.21886508630633870e+01,),
                                 (9e-09,))

    def test_gfd1h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(30.0, 0.15),
                            1.66943232233332822e+02,
                            1e-06)

    def test_vgfd1h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((30.0,)),
                                           numpy.array((0.15,))),
                                 (1.66943232233332822e+02,),
                                 (1e-06,))

    def test_gfd1h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(40.0, 0.15),
                            2.79637310890885772e+02,
                            5e-04)

    def test_vgfd1h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((40.0,)),
                                           numpy.array((0.15,))),
                                 (2.79637310890885772e+02,),
                                 (5e-04,))

    def test_gfd1h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(50.0, 0.15),
                            4.23027005180958383e+02,
                            1e-02)

    def test_vgfd1h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((50.0,)),
                                           numpy.array((0.15,))),
                                 (4.23027005180958383e+02,),
                                 (1e-02,))

    def test_gfd1h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-50.0, 0.225),
                            1.84493804131964310e-22,
                            2e-07)

    def test_vgfd1h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-50.0,)),
                                           numpy.array((0.225,))),
                                 (1.84493804131964310e-22,),
                                 (2e-07,))

    def test_gfd1h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-3.0, 0.225),
                            4.68362035160664325e-02,
                            2e-07)

    def test_vgfd1h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-3.0,)),
                                           numpy.array((0.225,))),
                                 (4.68362035160664325e-02,),
                                 (2e-07,))

    def test_gfd1h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-2.0, 0.225),
                            1.23881072020770297e-01,
                            2e-07)

    def test_vgfd1h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-2.0,)),
                                           numpy.array((0.225,))),
                                 (1.23881072020770297e-01,),
                                 (2e-07,))

    def test_gfd1h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-1.0, 0.225),
                            3.14837133747599474e-01,
                            2e-07)

    def test_vgfd1h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-1.0,)),
                                           numpy.array((0.225,))),
                                 (3.14837133747599474e-01,),
                                 (2e-07,))

    def test_gfd1h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(0.0, 0.225),
                            7.38829369987956230e-01,
                            1e-08)

    def test_vgfd1h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((0.0,)),
                                           numpy.array((0.225,))),
                                 (7.38829369987956230e-01,),
                                 (1e-08,))

    def test_gfd1h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(1.0, 0.225),
                            1.53599522382729647e+00,
                            1e-08)

    def test_vgfd1h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((1.0,)),
                                           numpy.array((0.225,))),
                                 (1.53599522382729647e+00,),
                                 (1e-08,))

    def test_gfd1h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(4.0, 0.225),
                            6.67198092070039817e+00,
                            4e-08)

    def test_vgfd1h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((4.0,)),
                                           numpy.array((0.225,))),
                                 (6.67198092070039817e+00,),
                                 (4e-08,))

    def test_gfd1h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(5.0, 0.225),
                            9.24386249954516259e+00,
                            1e-09)

    def test_vgfd1h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((5.0,)),
                                           numpy.array((0.225,))),
                                 (9.24386249954516259e+00,),
                                 (1e-09,))

    def test_gfd1h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(7.0, 0.225),
                            1.55475406671984615e+01,
                            4e-09)

    def test_vgfd1h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((7.0,)),
                                           numpy.array((0.225,))),
                                 (1.55475406671984615e+01,),
                                 (4e-09,))

    def test_gfd1h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(10.0, 0.225),
                            2.77546203959929692e+01,
                            5e-09)

    def test_vgfd1h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((10.0,)),
                                           numpy.array((0.225,))),
                                 (2.77546203959929692e+01,),
                                 (5e-09,))

    def test_gfd1h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(15.0, 0.225),
                            5.51542415233834475e+01,
                            5e-09)

    def test_vgfd1h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((15.0,)),
                                           numpy.array((0.225,))),
                                 (5.51542415233834475e+01,),
                                 (5e-09,))

    def test_gfd1h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(20.0, 0.225),
                            9.11844155758273871e+01,
                            6e-06)

    def test_vgfd1h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((20.0,)),
                                           numpy.array((0.225,))),
                                 (9.11844155758273871e+01,),
                                 (6e-06,))

    def test_gfd1h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(30.0, 0.225),
                            1.89190523435314418e+02,
                            4e-03)

    def test_vgfd1h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((30.0,)),
                                           numpy.array((0.225,))),
                                 (1.89190523435314418e+02,),
                                 (4e-03,))

    def test_gfd1h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(40.0, 0.225),
                            3.51352594869688005e+02,
                            2e-01)

    def test_vgfd1h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((40.0,)),
                                           numpy.array((0.225,))),
                                 (3.51352594869688005e+02,),
                                 (2e-01,))

    def test_gfd1h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(50.0, 0.225),
                            1.16174735294552215e+03,
                            3e+00)

    def test_vgfd1h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((50.0,)),
                                           numpy.array((0.225,))),
                                 (1.16174735294552215e+03,),
                                 (3e+00,))

    def test_gfd1h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-50.0, 0.3),
                            1.88700467882265615e-22,
                            1e-08)

    def test_vgfd1h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-50.0,)),
                                           numpy.array((0.3,))),
                                 (1.88700467882265615e-22,),
                                 (1e-08,))

    def test_gfd1h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-3.0, 0.3),
                            4.79121065683675990e-02,
                            1e-08)

    def test_vgfd1h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-3.0,)),
                                           numpy.array((0.3,))),
                                 (4.79121065683675990e-02,),
                                 (1e-08,))

    def test_gfd1h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-2.0, 0.3),
                            1.26761300940476579e-01,
                            1e-08)

    def test_vgfd1h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-2.0,)),
                                           numpy.array((0.3,))),
                                 (1.26761300940476579e-01,),
                                 (1e-08,))

    def test_gfd1h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(-1.0, 0.3),
                            3.22370766316044888e-01,
                            1e-08)

    def test_vgfd1h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((-1.0,)),
                                           numpy.array((0.3,))),
                                 (3.22370766316044888e-01,),
                                 (1e-08,))

    def test_gfd1h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(0.0, 0.3),
                            7.57581974572145267e-01,
                            2e-08)

    def test_vgfd1h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((0.0,)),
                                           numpy.array((0.3,))),
                                 (7.57581974572145267e-01,),
                                 (2e-08,))

    def test_gfd1h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(1.0, 0.3),
                            1.57889622462815948e+00,
                            2e-08)

    def test_vgfd1h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((1.0,)),
                                           numpy.array((0.3,))),
                                 (1.57889622462815948e+00,),
                                 (2e-08,))

    def test_gfd1h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(4.0, 0.3),
                            6.94149732106426764e+00,
                            1e-07)

    def test_vgfd1h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((4.0,)),
                                           numpy.array((0.3,))),
                                 (6.94149732106426764e+00,),
                                 (1e-07,))

    def test_gfd1h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(5.0, 0.3),
                            9.65966213111688532e+00,
                            5e-09)

    def test_vgfd1h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((5.0,)),
                                           numpy.array((0.3,))),
                                 (9.65966213111688532e+00,),
                                 (5e-09,))

    def test_gfd1h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(7.0, 0.3),
                            1.63814857356260859e+01,
                            2e-09)

    def test_vgfd1h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((7.0,)),
                                           numpy.array((0.3,))),
                                 (1.63814857356260859e+01,),
                                 (2e-09,))

    def test_gfd1h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(10.0, 0.3),
                            2.95526013663800313e+01,
                            4e-07)

    def test_vgfd1h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((10.0,)),
                                           numpy.array((0.3,))),
                                 (2.95526013663800313e+01,),
                                 (4e-07,))

    def test_gfd1h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(15.0, 0.3),
                            5.95102317520063906e+01,
                            3e-05)

    def test_vgfd1h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((15.0,)),
                                           numpy.array((0.3,))),
                                 (5.95102317520063906e+01,),
                                 (3e-05,))

    def test_gfd1h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(20.0, 0.3),
                            9.93880241203347907e+01,
                            1e-03)

    def test_vgfd1h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((20.0,)),
                                           numpy.array((0.3,))),
                                 (9.93880241203347907e+01,),
                                 (1e-03,))

    def test_gfd1h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(30.0, 0.3),
                            2.31853742532847605e+02,
                            2e-01)

    def test_vgfd1h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((30.0,)),
                                           numpy.array((0.3,))),
                                 (2.31853742532847605e+02,),
                                 (2e-01,))

    def test_gfd1h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(40.0, 0.3),
                            1.46480797069886626e+03,
                            6e+00)

    def test_vgfd1h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((40.0,)),
                                           numpy.array((0.3,))),
                                 (1.46480797069886626e+03,),
                                 (6e+00,))

    def test_gfd1h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd1h(50.0, 0.3),
                            1.92572027975448000e+04,
                            7e+01)

    def test_vgfd1h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd1h(numpy.array((50.0,)),
                                           numpy.array((0.3,))),
                                 (1.92572027975448000e+04,),
                                 (7e+01,))

    def test_gfd3h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-50.0, 0.0),
                            2.56396522543071034e-22,
                            1e-07)

    def test_vgfd3h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-50.0,)),
                                           numpy.array((0.0,))),
                                 (2.56396522543071034e-22,),
                                 (1e-07,))

    def test_gfd3h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-3.0, 0.0),
                            6.56117427430797789e-02,
                            1e-07)

    def test_vgfd3h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-3.0,)),
                                           numpy.array((0.0,))),
                                 (6.56117427430797789e-02,),
                                 (1e-07,))

    def test_gfd3h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-2.0, 0.0),
                            1.75800999402072250e-01,
                            1e-07)

    def test_vgfd3h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-2.0,)),
                                           numpy.array((0.0,))),
                                 (1.75800999402072250e-01,),
                                 (1e-07,))

    def test_gfd3h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-1.0, 0.0),
                            4.60848833941030100e-01,
                            1e-07)

    def test_vgfd3h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-1.0,)),
                                           numpy.array((0.0,))),
                                 (4.60848833941030100e-01,),
                                 (1e-07,))

    def test_gfd3h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(0.0, 0.0),
                            1.15280390625659157e+00,
                            1e-07)

    def test_vgfd3h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((0.0,)),
                                           numpy.array((0.0,))),
                                 (1.15280390625659157e+00,),
                                 (1e-07,))

    def test_gfd3h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(1.0, 0.0),
                            2.66168278443296202e+00,
                            1e-07)

    def test_vgfd3h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((1.0,)),
                                           numpy.array((0.0,))),
                                 (2.66168278443296202e+00,),
                                 (1e-07,))

    def test_gfd3h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(4.0, 0.0),
                            1.76277035587071147e+01,
                            1e-07)

    def test_vgfd3h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((4.0,)),
                                           numpy.array((0.0,))),
                                 (1.76277035587071147e+01,),
                                 (1e-07,))

    def test_gfd3h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(5.0, 0.0),
                            2.78024478838951552e+01,
                            1e-07)

    def test_vgfd3h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((5.0,)),
                                           numpy.array((0.0,))),
                                 (2.78024478838951552e+01,),
                                 (1e-07,))

    def test_gfd3h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(7.0, 0.0),
                            5.83422205422022486e+01,
                            1e-07)

    def test_vgfd3h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((7.0,)),
                                           numpy.array((0.0,))),
                                 (5.83422205422022486e+01,),
                                 (1e-07,))

    def test_gfd3h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(10.0, 0.0),
                            1.34270168019349427e+02,
                            1e-07)

    def test_vgfd3h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((10.0,)),
                                           numpy.array((0.0,))),
                                 (1.34270168019349427e+02,),
                                 (1e-07,))

    def test_gfd3h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(15.0, 0.0),
                            3.58112269195261376e+02,
                            1e-07)

    def test_vgfd3h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((15.0,)),
                                           numpy.array((0.0,))),
                                 (3.58112269195261376e+02,),
                                 (1e-07,))

    def test_gfd3h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(20.0, 0.0),
                            7.26568327559272234e+02,
                            1e-07)

    def test_vgfd3h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((20.0,)),
                                           numpy.array((0.0,))),
                                 (7.26568327559272234e+02,),
                                 (1e-07,))

    def test_gfd3h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(30.0, 0.0),
                            1.98531149686472122e+03,
                            1e-07)

    def test_vgfd3h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((30.0,)),
                                           numpy.array((0.0,))),
                                 (1.98531149686472122e+03,),
                                 (1e-07,))

    def test_gfd3h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(40.0, 0.0),
                            4.06331804904606452e+03,
                            1e-07)

    def test_vgfd3h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((40.0,)),
                                           numpy.array((0.0,))),
                                 (4.06331804904606452e+03,),
                                 (1e-07,))

    def test_gfd3h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(50.0, 0.0),
                            7.08851338555907569e+03,
                            1e-07)

    def test_vgfd3h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((50.0,)),
                                           numpy.array((0.0,))),
                                 (7.08851338555907569e+03,),
                                 (1e-07,))

    def test_gfd3h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-50.0, 0.075),
                            2.68050319568913796e-22,
                            5e-08)

    def test_vgfd3h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-50.0,)),
                                           numpy.array((0.075,))),
                                 (2.68050319568913796e-22,),
                                 (5e-08,))

    def test_gfd3h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-3.0, 0.075),
                            6.86066750207212639e-02,
                            5e-08)

    def test_vgfd3h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-3.0,)),
                                           numpy.array((0.075,))),
                                 (6.86066750207212639e-02,),
                                 (5e-08,))

    def test_gfd3h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-2.0, 0.075),
                            1.83881988194320833e-01,
                            5e-08)

    def test_vgfd3h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-2.0,)),
                                           numpy.array((0.075,))),
                                 (1.83881988194320833e-01,),
                                 (5e-08,))

    def test_gfd3h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-1.0, 0.075),
                            4.82401060953742189e-01,
                            5e-08)

    def test_vgfd3h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-1.0,)),
                                           numpy.array((0.075,))),
                                 (4.82401060953742189e-01,),
                                 (5e-08,))

    def test_gfd3h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(0.0, 0.075),
                            1.20878657947807766e+00,
                            5e-08)

    def test_vgfd3h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((0.0,)),
                                           numpy.array((0.075,))),
                                 (1.20878657947807766e+00,),
                                 (5e-08,))

    def test_gfd3h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(1.0, 0.075),
                            2.80000794588478330e+00,
                            6e-08)

    def test_vgfd3h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((1.0,)),
                                           numpy.array((0.075,))),
                                 (2.80000794588478330e+00,),
                                 (6e-08,))

    def test_gfd3h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(4.0, 0.075),
                            1.89101326780703793e+01,
                            3e-08)

    def test_vgfd3h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((4.0,)),
                                           numpy.array((0.075,))),
                                 (1.89101326780703793e+01,),
                                 (3e-08,))

    def test_gfd3h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(5.0, 0.075),
                            3.00840492504489951e+01,
                            1e-08)

    def test_vgfd3h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((5.0,)),
                                           numpy.array((0.075,))),
                                 (3.00840492504489951e+01,),
                                 (1e-08,))

    def test_gfd3h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(7.0, 0.075),
                            6.43119244745047070e+01,
                            1e-08)

    def test_vgfd3h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((7.0,)),
                                           numpy.array((0.075,))),
                                 (6.43119244745047070e+01,),
                                 (1e-08,))

    def test_gfd3h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(10.0, 0.075),
                            1.52325523752477324e+02,
                            3e-08)

    def test_vgfd3h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((10.0,)),
                                           numpy.array((0.075,))),
                                 (1.52325523752477324e+02,),
                                 (3e-08,))

    def test_gfd3h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(15.0, 0.075),
                            4.25678129558724834e+02,
                            2e-08)

    def test_vgfd3h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((15.0,)),
                                           numpy.array((0.075,))),
                                 (4.25678129558724834e+02,),
                                 (2e-08,))

    def test_gfd3h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(20.0, 0.075),
                            9.02150729494757911e+02,
                            3e-08)

    def test_vgfd3h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((20.0,)),
                                           numpy.array((0.075,))),
                                 (9.02150729494757911e+02,),
                                 (3e-08,))

    def test_gfd3h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(30.0, 0.075),
                            2.66501589243813351e+03,
                            1e-08)

    def test_vgfd3h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((30.0,)),
                                           numpy.array((0.075,))),
                                 (2.66501589243813351e+03,),
                                 (1e-08,))

    def test_gfd3h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(40.0, 0.075),
                            5.83652161907989921e+03,
                            2e-08)

    def test_vgfd3h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((40.0,)),
                                           numpy.array((0.075,))),
                                 (5.83652161907989921e+03,),
                                 (2e-08,))

    def test_gfd3h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(50.0, 0.075),
                            1.08078726745106324e+04,
                            4e-09)

    def test_vgfd3h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((50.0,)),
                                           numpy.array((0.075,))),
                                 (1.08078726745106324e+04,),
                                 (4e-09,))

    def test_gfd3h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-50.0, 0.15),
                            2.79070532998296774e-22,
                            5e-10)

    def test_vgfd3h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-50.0,)),
                                           numpy.array((0.15,))),
                                 (2.79070532998296774e-22,),
                                 (5e-10,))

    def test_gfd3h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-3.0, 0.15),
                            7.14384547295619787e-02,
                            5e-10)

    def test_vgfd3h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-3.0,)),
                                           numpy.array((0.15,))),
                                 (7.14384547295619787e-02,),
                                 (5e-10,))

    def test_gfd3h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-2.0, 0.15),
                            1.91521288044533333e-01,
                            6e-10)

    def test_vgfd3h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-2.0,)),
                                           numpy.array((0.15,))),
                                 (1.91521288044533333e-01,),
                                 (6e-10,))

    def test_gfd3h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-1.0, 0.15),
                            5.02765361586696824e-01,
                            5e-10)

    def test_vgfd3h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-1.0,)),
                                           numpy.array((0.15,))),
                                 (5.02765361586696824e-01,),
                                 (5e-10,))

    def test_gfd3h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(0.0, 0.15),
                            1.26162371655850070e+00,
                            2e-10)

    def test_vgfd3h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((0.0,)),
                                           numpy.array((0.15,))),
                                 (1.26162371655850070e+00,),
                                 (2e-10,))

    def test_gfd3h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(1.0, 0.15),
                            2.93026606807198586e+00,
                            4e-09)

    def test_vgfd3h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((1.0,)),
                                           numpy.array((0.15,))),
                                 (2.93026606807198586e+00,),
                                 (4e-09,))

    def test_gfd3h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(4.0, 0.15),
                            2.00994854317833500e+01,
                            5e-08)

    def test_vgfd3h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((4.0,)),
                                           numpy.array((0.15,))),
                                 (2.00994854317833500e+01,),
                                 (5e-08,))

    def test_gfd3h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(5.0, 0.15),
                            3.21851009539578143e+01,
                            1e-08)

    def test_vgfd3h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((5.0,)),
                                           numpy.array((0.15,))),
                                 (3.21851009539578143e+01,),
                                 (1e-08,))

    def test_gfd3h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(7.0, 0.15),
                            6.97256534740510574e+01,
                            7e-09)

    def test_vgfd3h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((7.0,)),
                                           numpy.array((0.15,))),
                                 (6.97256534740510574e+01,),
                                 (7e-09,))

    def test_gfd3h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(10.0, 0.15),
                            1.68320698038579991e+02,
                            1e-08)

    def test_vgfd3h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((10.0,)),
                                           numpy.array((0.15,))),
                                 (1.68320698038579991e+02,),
                                 (1e-08,))

    def test_gfd3h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(15.0, 0.15),
                            4.83402429203509769e+02,
                            9e-09)

    def test_vgfd3h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((15.0,)),
                                           numpy.array((0.15,))),
                                 (4.83402429203509769e+02,),
                                 (9e-09,))

    def test_gfd3h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(20.0, 0.15),
                            1.04746266604618586e+03,
                            1e-08)

    def test_vgfd3h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((20.0,)),
                                           numpy.array((0.15,))),
                                 (1.04746266604618586e+03,),
                                 (1e-08,))

    def test_gfd3h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(30.0, 0.15),
                            3.19891327460370758e+03,
                            2e-06)

    def test_vgfd3h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((30.0,)),
                                           numpy.array((0.15,))),
                                 (3.19891327460370758e+03,),
                                 (2e-06,))

    def test_gfd3h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(40.0, 0.15),
                            7.17577763915706964e+03,
                            7e-04)

    def test_vgfd3h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((40.0,)),
                                           numpy.array((0.15,))),
                                 (7.17577763915706964e+03,),
                                 (7e-04,))

    def test_gfd3h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(50.0, 0.15),
                            1.36710648966167355e+04,
                            2e-02)

    def test_vgfd3h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((50.0,)),
                                           numpy.array((0.15,))),
                                 (1.36710648966167355e+04,),
                                 (2e-02,))

    def test_gfd3h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-50.0, 0.225),
                            2.89565826333962415e-22,
                            6e-08)

    def test_vgfd3h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-50.0,)),
                                           numpy.array((0.225,))),
                                 (2.89565826333962415e-22,),
                                 (6e-08,))

    def test_gfd3h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-3.0, 0.225),
                            7.41350911550967828e-02,
                            6e-08)

    def test_vgfd3h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-3.0,)),
                                           numpy.array((0.225,))),
                                 (7.41350911550967828e-02,),
                                 (6e-08,))

    def test_gfd3h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-2.0, 0.225),
                            1.98794851403979123e-01,
                            6e-08)

    def test_vgfd3h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-2.0,)),
                                           numpy.array((0.225,))),
                                 (1.98794851403979123e-01,),
                                 (6e-08,))

    def test_gfd3h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-1.0, 0.225),
                            5.22146878499213152e-01,
                            6e-08)

    def test_vgfd3h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-1.0,)),
                                           numpy.array((0.225,))),
                                 (5.22146878499213152e-01,),
                                 (6e-08,))

    def test_gfd3h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(0.0, 0.225),
                            1.31186401823519261e+00,
                            7e-08)

    def test_vgfd3h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((0.0,)),
                                           numpy.array((0.225,))),
                                 (1.31186401823519261e+00,),
                                 (7e-08,))

    def test_gfd3h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(1.0, 0.225),
                            3.05389390748236655e+00,
                            7e-08)

    def test_vgfd3h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((1.0,)),
                                           numpy.array((0.225,))),
                                 (3.05389390748236655e+00,),
                                 (7e-08,))

    def test_gfd3h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(4.0, 0.225),
                            2.12149012797099559e+01,
                            8e-09)

    def test_vgfd3h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((4.0,)),
                                           numpy.array((0.225,))),
                                 (2.12149012797099559e+01,),
                                 (8e-09,))

    def test_gfd3h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(5.0, 0.225),
                            3.41451325993784280e+01,
                            4e-09)

    def test_vgfd3h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((5.0,)),
                                           numpy.array((0.225,))),
                                 (3.41451325993784280e+01,),
                                 (4e-09,))

    def test_gfd3h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(7.0, 0.225),
                            7.47210028844568797e+01,
                            1e-08)

    def test_vgfd3h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((7.0,)),
                                           numpy.array((0.225,))),
                                 (7.47210028844568797e+01,),
                                 (1e-08,))

    def test_gfd3h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(10.0, 0.225),
                            1.82851523256851323e+02,
                            3e-09)

    def test_vgfd3h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((10.0,)),
                                           numpy.array((0.225,))),
                                 (1.82851523256851323e+02,),
                                 (3e-09,))

    def test_gfd3h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(15.0, 0.225),
                            5.34712394088538190e+02,
                            2e-07)

    def test_vgfd3h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((15.0,)),
                                           numpy.array((0.225,))),
                                 (5.34712394088538190e+02,),
                                 (2e-07,))

    def test_gfd3h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(20.0, 0.225),
                            1.17445243366865725e+03,
                            1e-05)

    def test_vgfd3h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((20.0,)),
                                           numpy.array((0.225,))),
                                 (1.17445243366865725e+03,),
                                 (1e-05,))

    def test_gfd3h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(30.0, 0.225),
                            3.66617542497532895e+03,
                            7e-03)

    def test_vgfd3h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((30.0,)),
                                           numpy.array((0.225,))),
                                 (3.66617542497532895e+03,),
                                 (7e-03,))

    def test_gfd3h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(40.0, 0.225),
                            9.49800336542126570e+03,
                            3e-01)

    def test_vgfd3h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((40.0,)),
                                           numpy.array((0.225,))),
                                 (9.49800336542126570e+03,),
                                 (3e-01,))

    def test_gfd3h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(50.0, 0.225),
                            4.78840107064072945e+04,
                            4e+00)

    def test_vgfd3h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((50.0,)),
                                           numpy.array((0.225,))),
                                 (4.78840107064072945e+04,),
                                 (4e+00,))

    def test_gfd3h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-50.0, 0.3),
                            2.99614222780075374e-22,
                            1e-07)

    def test_vgfd3h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-50.0,)),
                                           numpy.array((0.3,))),
                                 (2.99614222780075374e-22,),
                                 (1e-07,))

    def test_gfd3h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-3.0, 0.3),
                            7.67166915520561821e-02,
                            1e-07)

    def test_vgfd3h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-3.0,)),
                                           numpy.array((0.3,))),
                                 (7.67166915520561821e-02,),
                                 (1e-07,))

    def test_gfd3h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-2.0, 0.3),
                            2.05757183974466101e-01,
                            2e-07)

    def test_vgfd3h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-2.0,)),
                                           numpy.array((0.3,))),
                                 (2.05757183974466101e-01,),
                                 (2e-07,))

    def test_gfd3h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(-1.0, 0.3),
                            5.40692695085241315e-01,
                            2e-07)

    def test_vgfd3h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((-1.0,)),
                                           numpy.array((0.3,))),
                                 (5.40692695085241315e-01,),
                                 (2e-07,))

    def test_gfd3h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(0.0, 0.3),
                            1.35990014077538435e+00,
                            8e-09)

    def test_vgfd3h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((0.0,)),
                                           numpy.array((0.3,))),
                                 (1.35990014077538435e+00,),
                                 (8e-09,))

    def test_gfd3h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(1.0, 0.3),
                            3.17191463518228423e+00,
                            8e-09)

    def test_vgfd3h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((1.0,)),
                                           numpy.array((0.3,))),
                                 (3.17191463518228423e+00,),
                                 (8e-09,))

    def test_gfd3h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(4.0, 0.3),
                            2.22694509399631286e+01,
                            3e-08)

    def test_vgfd3h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((4.0,)),
                                           numpy.array((0.3,))),
                                 (2.22694509399631286e+01,),
                                 (3e-08,))

    def test_gfd3h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(5.0, 0.3),
                            3.59905469435718572e+01,
                            5e-08)

    def test_vgfd3h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((5.0,)),
                                           numpy.array((0.3,))),
                                 (3.59905469435718572e+01,),
                                 (5e-08,))

    def test_gfd3h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(7.0, 0.3),
                            7.93853531162478987e+01,
                            1e-07)

    def test_vgfd3h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((7.0,)),
                                           numpy.array((0.3,))),
                                 (7.93853531162478987e+01,),
                                 (1e-07,))

    def test_gfd3h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(10.0, 0.3),
                            1.96267893099285288e+02,
                            1e-06)

    def test_vgfd3h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((10.0,)),
                                           numpy.array((0.3,))),
                                 (1.96267893099285288e+02,),
                                 (1e-06,))

    def test_gfd3h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(15.0, 0.3),
                            5.81410456309328310e+02,
                            5e-05)

    def test_vgfd3h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((15.0,)),
                                           numpy.array((0.3,))),
                                 (5.81410456309328310e+02,),
                                 (5e-05,))

    def test_gfd3h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(20.0, 0.3),
                            1.29011458309667273e+03,
                            2e-03)

    def test_vgfd3h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((20.0,)),
                                           numpy.array((0.3,))),
                                 (1.29011458309667273e+03,),
                                 (2e-03,))

    def test_gfd3h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(30.0, 0.3),
                            4.75831799589709590e+03,
                            3e-01)

    def test_vgfd3h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((30.0,)),
                                           numpy.array((0.3,))),
                                 (4.75831799589709590e+03,),
                                 (3e-01,))

    def test_gfd3h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(40.0, 0.3),
                            5.17342847313166931e+04,
                            9e+00)

    def test_vgfd3h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((40.0,)),
                                           numpy.array((0.3,))),
                                 (5.17342847313166931e+04,),
                                 (9e+00,))

    def test_gfd3h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd3h(50.0, 0.3),
                            9.00261010849752696e+05,
                            1e+02)

    def test_vgfd3h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd3h(numpy.array((50.0,)),
                                           numpy.array((0.3,))),
                                 (9.00261010849752696e+05,),
                                 (1e+02,))

    def test_gfd5h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-50.0, 0.0),
                            6.40991306357677657e-22,
                            1e-07)

    def test_vgfd5h_1(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-50.0,)),
                                           numpy.array((0.0,))),
                                 (6.40991306357677657e-22,),
                                 (1e-07,))

    def test_gfd5h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-3.0, 0.0),
                            1.64740403616628783e-01,
                            1e-07)

    def test_vgfd5h_2(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-3.0,)),
                                           numpy.array((0.0,))),
                                 (1.64740403616628783e-01,),
                                 (1e-07,))

    def test_gfd5h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-2.0, 0.0),
                            4.44554480132030305e-01,
                            1e-07)

    def test_vgfd5h_3(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-2.0,)),
                                           numpy.array((0.0,))),
                                 (4.44554480132030305e-01,),
                                 (1e-07,))

    def test_gfd5h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-1.0, 0.0),
                            1.18596824660155797e+00,
                            1e-07)

    def test_vgfd5h_4(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-1.0,)),
                                           numpy.array((0.0,))),
                                 (1.18596824660155797e+00,),
                                 (1e-07,))

    def test_gfd5h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(0.0, 0.0),
                            3.08258626779258371e+00,
                            1e-07)

    def test_vgfd5h_5(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((0.0,)),
                                           numpy.array((0.0,))),
                                 (3.08258626779258371e+00,),
                                 (1e-07,))

    def test_gfd5h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(1.0, 0.0),
                            7.62653581259771762e+00,
                            1e-07)

    def test_vgfd5h_6(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((1.0,)),
                                           numpy.array((0.0,))),
                                 (7.62653581259771762e+00,),
                                 (1e-07,))

    def test_gfd5h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(4.0, 0.0),
                            7.13480566047064997e+01,
                            1e-07)

    def test_vgfd5h_7(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((4.0,)),
                                           numpy.array((0.0,))),
                                 (7.13480566047064997e+01,),
                                 (1e-07,))

    def test_gfd5h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(5.0, 0.0),
                            1.27489552562595904e+02,
                            1e-07)

    def test_vgfd5h_8(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((5.0,)),
                                           numpy.array((0.0,))),
                                 (1.27489552562595904e+02,),
                                 (1e-07,))

    def test_gfd5h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(7.0, 0.0),
                            3.36814345132562380e+02,
                            1e-07)

    def test_vgfd5h_9(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((7.0,)),
                                           numpy.array((0.0,))),
                                 (3.36814345132562380e+02,),
                                 (1e-07,))

    def test_gfd5h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(10.0, 0.0),
                            1.03468431626258916e+03,
                            1e-07)

    def test_vgfd5h_10(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((10.0,)),
                                           numpy.array((0.0,))),
                                 (1.03468431626258916e+03,),
                                 (1e-07,))

    def test_gfd5h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(15.0, 0.0),
                            3.97448812041092924e+03,
                            1e-07)

    def test_vgfd5h_11(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((15.0,)),
                                           numpy.array((0.0,))),
                                 (3.97448812041092924e+03,),
                                 (1e-07,))

    def test_gfd5h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(20.0, 0.0),
                            1.05906398120527356e+04,
                            1e-07)

    def test_vgfd5h_12(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((20.0,)),
                                           numpy.array((0.0,))),
                                 (1.05906398120527356e+04,),
                                 (1e-07,))

    def test_gfd5h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(30.0, 0.0),
                            4.29292601608553960e+04,
                            1e-07)

    def test_vgfd5h_13(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((30.0,)),
                                           numpy.array((0.0,))),
                                 (4.29292601608553960e+04,),
                                 (1e-07,))

    def test_gfd5h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(40.0, 0.0),
                            1.16689928020525942e+05,
                            1e-07)

    def test_vgfd5h_14(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((40.0,)),
                                           numpy.array((0.0,))),
                                 (1.16689928020525942e+05,),
                                 (1e-07,))

    def test_gfd5h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(50.0, 0.0),
                            2.53992583816560684e+05,
                            1e-07)

    def test_vgfd5h_15(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((50.0,)),
                                           numpy.array((0.0,))),
                                 (2.53992583816560684e+05,),
                                 (1e-07,))

    def test_gfd5h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-50.0, 0.075),
                            6.81441293231909427e-22,
                            2e-08)

    def test_vgfd5h_16(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-50.0,)),
                                           numpy.array((0.075,))),
                                 (6.81441293231909427e-22,),
                                 (2e-08,))

    def test_gfd5h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-3.0, 0.075),
                            1.75158585864029048e-01,
                            2e-08)

    def test_vgfd5h_17(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-3.0,)),
                                           numpy.array((0.075,))),
                                 (1.75158585864029048e-01,),
                                 (2e-08,))

    def test_gfd5h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-2.0, 0.075),
                            4.72767843554117995e-01,
                            2e-08)

    def test_vgfd5h_18(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-2.0,)),
                                           numpy.array((0.075,))),
                                 (4.72767843554117995e-01,),
                                 (2e-08,))

    def test_gfd5h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-1.0, 0.075),
                            1.26191167665433168e+00,
                            3e-08)

    def test_vgfd5h_19(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-1.0,)),
                                           numpy.array((0.075,))),
                                 (1.26191167665433168e+00,),
                                 (3e-08,))

    def test_gfd5h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(0.0, 0.075),
                            3.28408317536401162e+00,
                            3e-08)

    def test_vgfd5h_20(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((0.0,)),
                                           numpy.array((0.075,))),
                                 (3.28408317536401162e+00,),
                                 (3e-08,))

    def test_gfd5h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(1.0, 0.075),
                            8.14550605882054413e+00,
                            3e-08)

    def test_vgfd5h_21(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((1.0,)),
                                           numpy.array((0.075,))),
                                 (8.14550605882054413e+00,),
                                 (3e-08,))

    def test_gfd5h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(4.0, 0.075),
                            7.75426595369294631e+01,
                            1e-08)

    def test_vgfd5h_22(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((4.0,)),
                                           numpy.array((0.075,))),
                                 (7.75426595369294631e+01,),
                                 (1e-08,))

    def test_gfd5h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(5.0, 0.075),
                            1.39718804751399517e+02,
                            2e-09)

    def test_vgfd5h_23(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((5.0,)),
                                           numpy.array((0.075,))),
                                 (1.39718804751399517e+02,),
                                 (2e-09,))

    def test_gfd5h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(7.0, 0.075),
                            3.76009161636877081e+02,
                            2e-08)

    def test_vgfd5h_24(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((7.0,)),
                                           numpy.array((0.075,))),
                                 (3.76009161636877081e+02,),
                                 (2e-08,))

    def test_gfd5h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(10.0, 0.075),
                            1.18961530804305448e+03,
                            3e-08)

    def test_vgfd5h_25(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((10.0,)),
                                           numpy.array((0.075,))),
                                 (1.18961530804305448e+03,),
                                 (3e-08,))

    def test_gfd5h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(15.0, 0.075),
                            4.79728462444000888e+03,
                            3e-08)

    def test_vgfd5h_26(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((15.0,)),
                                           numpy.array((0.075,))),
                                 (4.79728462444000888e+03,),
                                 (3e-08,))

    def test_gfd5h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(20.0, 0.075),
                            1.33810484383240291e+04,
                            4e-08)

    def test_vgfd5h_27(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((20.0,)),
                                           numpy.array((0.075,))),
                                 (1.33810484383240291e+04,),
                                 (4e-08,))

    def test_gfd5h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(30.0, 0.075),
                            5.88614674968122199e+04,
                            1e-08)

    def test_vgfd5h_28(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((30.0,)),
                                           numpy.array((0.075,))),
                                 (5.88614674968122199e+04,),
                                 (1e-08,))

    def test_gfd5h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(40.0, 0.075),
                            1.71730807793203887e+05,
                            2e-05)

    def test_vgfd5h_29(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((40.0,)),
                                           numpy.array((0.075,))),
                                 (1.71730807793203887e+05,),
                                 (2e-05,))

    def test_gfd5h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(50.0, 0.075),
                            3.97844914563980128e+05,
                            4e-04)

    def test_vgfd5h_30(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((50.0,)),
                                           numpy.array((0.075,))),
                                 (3.97844914563980128e+05,),
                                 (4e-04,))

    def test_gfd5h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-50.0, 0.15),
                            7.19161706636993687e-22,
                            6e-08)

    def test_vgfd5h_31(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-50.0,)),
                                           numpy.array((0.15,))),
                                 (7.19161706636993687e-22,),
                                 (6e-08,))

    def test_gfd5h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-3.0, 0.15),
                            1.84873049884995505e-01,
                            6e-08)

    def test_vgfd5h_32(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-3.0,)),
                                           numpy.array((0.15,))),
                                 (1.84873049884995505e-01,),
                                 (6e-08,))

    def test_gfd5h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-2.0, 0.15),
                            4.99072306661250686e-01,
                            6e-08)

    def test_vgfd5h_33(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-2.0,)),
                                           numpy.array((0.15,))),
                                 (4.99072306661250686e-01,),
                                 (6e-08,))

    def test_gfd5h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-1.0, 0.15),
                            1.33269479686240855e+00,
                            6e-08)

    def test_vgfd5h_34(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-1.0,)),
                                           numpy.array((0.15,))),
                                 (1.33269479686240855e+00,),
                                 (6e-08,))

    def test_gfd5h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(0.0, 0.15),
                            3.47174786148591163e+00,
                            7e-08)

    def test_vgfd5h_35(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((0.0,)),
                                           numpy.array((0.15,))),
                                 (3.47174786148591163e+00,),
                                 (7e-08,))

    def test_gfd5h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(1.0, 0.15),
                            8.62808262870235154e+00,
                            7e-08)

    def test_vgfd5h_36(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((1.0,)),
                                           numpy.array((0.15,))),
                                 (8.62808262870235154e+00,),
                                 (7e-08,))

    def test_gfd5h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(4.0, 0.15),
                            8.32308639722571826e+01,
                            2e-07)

    def test_vgfd5h_37(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((4.0,)),
                                           numpy.array((0.15,))),
                                 (8.32308639722571826e+01,),
                                 (2e-07,))

    def test_gfd5h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(5.0, 0.15),
                            1.50876251223504482e+02,
                            1e-08)

    def test_vgfd5h_38(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((5.0,)),
                                           numpy.array((0.15,))),
                                 (1.50876251223504482e+02,),
                                 (1e-08,))

    def test_gfd5h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(7.0, 0.15),
                            4.11253503283934208e+02,
                            2e-08)

    def test_vgfd5h_39(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((7.0,)),
                                           numpy.array((0.15,))),
                                 (4.11253503283934208e+02,),
                                 (2e-08,))

    def test_gfd5h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(10.0, 0.15),
                            1.32576412217039683e+03,
                            5e-08)

    def test_vgfd5h_40(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((10.0,)),
                                           numpy.array((0.15,))),
                                 (1.32576412217039683e+03,),
                                 (5e-08,))

    def test_gfd5h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(15.0, 0.15),
                            5.49445385756848918e+03,
                            2e-06)

    def test_vgfd5h_41(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((15.0,)),
                                           numpy.array((0.15,))),
                                 (5.49445385756848918e+03,),
                                 (2e-06,))

    def test_gfd5h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(20.0, 0.15),
                            1.56707076932394375e+04,
                            5e-05)

    def test_vgfd5h_42(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((20.0,)),
                                           numpy.array((0.15,))),
                                 (1.56707076932394375e+04,),
                                 (5e-05,))

    def test_gfd5h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(30.0, 0.15),
                            7.14251358747767226e+04,
                            5e-03)

    def test_vgfd5h_43(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((30.0,)),
                                           numpy.array((0.15,))),
                                 (7.14251358747767226e+04,),
                                 (5e-03,))

    def test_gfd5h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(40.0, 0.15),
                            2.20891583722858282e+05,
                            8e-02)

    def test_vgfd5h_44(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((40.0,)),
                                           numpy.array((0.15,))),
                                 (2.20891583722858282e+05,),
                                 (8e-02,))

    def test_gfd5h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(50.0, 0.15),
                            6.38673363837586949e+05,
                            5e-01)

    def test_vgfd5h_45(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((50.0,)),
                                           numpy.array((0.15,))),
                                 (6.38673363837586949e+05,),
                                 (5e-01,))

    def test_gfd5h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-50.0, 0.225),
                            7.54696653284489481e-22,
                            1e-08)

    def test_vgfd5h_46(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-50.0,)),
                                           numpy.array((0.225,))),
                                 (7.54696653284489481e-22,),
                                 (1e-08,))

    def test_gfd5h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-3.0, 0.225),
                            1.94024141918108045e-01,
                            1e-08)

    def test_vgfd5h_47(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-3.0,)),
                                           numpy.array((0.225,))),
                                 (1.94024141918108045e-01,),
                                 (1e-08,))

    def test_gfd5h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-2.0, 0.225),
                            5.23848886120844015e-01,
                            1e-08)

    def test_vgfd5h_48(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-2.0,)),
                                           numpy.array((0.225,))),
                                 (5.23848886120844015e-01,),
                                 (1e-08,))

    def test_gfd5h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-1.0, 0.225),
                            1.39934982722688672e+00,
                            1e-08)

    def test_vgfd5h_49(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-1.0,)),
                                           numpy.array((0.225,))),
                                 (1.39934982722688672e+00,),
                                 (1e-08,))

    def test_gfd5h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(0.0, 0.225),
                            3.64836190286121509e+00,
                            2e-08)

    def test_vgfd5h_50(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((0.0,)),
                                           numpy.array((0.225,))),
                                 (3.64836190286121509e+00,),
                                 (2e-08,))

    def test_gfd5h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(1.0, 0.225),
                            9.08166989206396202e+00,
                            2e-08)

    def test_vgfd5h_51(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((1.0,)),
                                           numpy.array((0.225,))),
                                 (9.08166989206396202e+00,),
                                 (2e-08,))

    def test_gfd5h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(4.0, 0.225),
                            8.85263311960657404e+01,
                            2e-08)

    def test_vgfd5h_52(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((4.0,)),
                                           numpy.array((0.225,))),
                                 (8.85263311960657404e+01,),
                                 (2e-08,))

    def test_gfd5h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(5.0, 0.225),
                            1.61214719508784299e+02,
                            1e-06)

    def test_vgfd5h_53(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((5.0,)),
                                           numpy.array((0.225,))),
                                 (1.61214719508784299e+02,),
                                 (1e-06,))

    def test_gfd5h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(7.0, 0.225),
                            4.43581322643197154e+02,
                            3e-06)

    def test_vgfd5h_54(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((7.0,)),
                                           numpy.array((0.225,))),
                                 (4.43581322643197154e+02,),
                                 (3e-06,))

    def test_gfd5h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(10.0, 0.225),
                            1.44879933670252876e+03,
                            2e-05)

    def test_vgfd5h_55(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((10.0,)),
                                           numpy.array((0.225,))),
                                 (1.44879933670252876e+03,),
                                 (2e-05,))

    def test_gfd5h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(15.0, 0.225),
                            6.11260123899200516e+03,
                            5e-04)

    def test_vgfd5h_56(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((15.0,)),
                                           numpy.array((0.225,))),
                                 (6.11260123899200516e+03,),
                                 (5e-04,))

    def test_gfd5h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(20.0, 0.225),
                            1.77237353014303735e+04,
                            7e-03)

    def test_vgfd5h_57(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((20.0,)),
                                           numpy.array((0.225,))),
                                 (1.77237353014303735e+04,),
                                 (7e-03,))

    def test_gfd5h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(30.0, 0.225),
                            9.20765192192947143e+04,
                            3e-01)

    def test_vgfd5h_58(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((30.0,)),
                                           numpy.array((0.225,))),
                                 (9.20765192192947143e+04,),
                                 (3e-01,))

    def test_gfd5h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(40.0, 0.225),
                            5.80758419784098049e+05,
                            3e+00)

    def test_vgfd5h_59(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((40.0,)),
                                           numpy.array((0.225,))),
                                 (5.80758419784098049e+05,),
                                 (3e+00,))

    def test_gfd5h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(50.0, 0.225),
                            5.19088362398220226e+06,
                            2e+01)

    def test_vgfd5h_60(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((50.0,)),
                                           numpy.array((0.225,))),
                                 (5.19088362398220226e+06,),
                                 (2e+01,))

    def test_gfd5h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-50.0, 0.3),
                            7.88423967604413785e-22,
                            1e-05)

    def test_vgfd5h_61(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-50.0,)),
                                           numpy.array((0.3,))),
                                 (7.88423967604413785e-22,),
                                 (1e-05,))

    def test_gfd5h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-3.0, 0.3),
                            2.02709309484947309e-01,
                            1e-05)

    def test_vgfd5h_62(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-3.0,)),
                                           numpy.array((0.3,))),
                                 (2.02709309484947309e-01,),
                                 (1e-05,))

    def test_gfd5h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-2.0, 0.3),
                            5.47362086788045543e-01,
                            1e-05)

    def test_vgfd5h_63(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-2.0,)),
                                           numpy.array((0.3,))),
                                 (5.47362086788045543e-01,),
                                 (1e-05,))

    def test_gfd5h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(-1.0, 0.3),
                            1.46259299424101075e+00,
                            1e-05)

    def test_vgfd5h_64(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((-1.0,)),
                                           numpy.array((0.3,))),
                                 (1.46259299424101075e+00,),
                                 (1e-05,))

    def test_gfd5h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(0.0, 0.3),
                            3.81585298984370835e+00,
                            1e-05)

    def test_vgfd5h_65(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((0.0,)),
                                           numpy.array((0.3,))),
                                 (3.81585298984370835e+00,),
                                 (1e-05,))

    def test_gfd5h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(1.0, 0.3),
                            9.51138485803959099e+00,
                            1e-05)

    def test_vgfd5h_66(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((1.0,)),
                                           numpy.array((0.3,))),
                                 (9.51138485803959099e+00,),
                                 (1e-05,))

    def test_gfd5h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(4.0, 0.3),
                            9.35055036426053192e+01,
                            3e-05)

    def test_vgfd5h_67(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((4.0,)),
                                           numpy.array((0.3,))),
                                 (9.35055036426053192e+01,),
                                 (3e-05,))

    def test_gfd5h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(5.0, 0.3),
                            1.70901471558054510e+02,
                            4e-05)

    def test_vgfd5h_68(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((5.0,)),
                                           numpy.array((0.3,))),
                                 (1.70901471558054510e+02,),
                                 (4e-05,))

    def test_gfd5h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(7.0, 0.3),
                            4.73657769681105947e+02,
                            1e-04)

    def test_vgfd5h_69(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((7.0,)),
                                           numpy.array((0.3,))),
                                 (4.73657769681105947e+02,),
                                 (1e-04,))

    def test_gfd5h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(10.0, 0.3),
                            1.56244525749910190e+03,
                            7e-04)

    def test_vgfd5h_70(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((10.0,)),
                                           numpy.array((0.3,))),
                                 (1.56244525749910190e+03,),
                                 (7e-04,))

    def test_gfd5h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(15.0, 0.3),
                            6.70965549483038922e+03,
                            1e-02)

    def test_vgfd5h_71(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((15.0,)),
                                           numpy.array((0.3,))),
                                 (6.70965549483038922e+03,),
                                 (1e-02,))

    def test_gfd5h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(20.0, 0.3),
                            2.05967064205203205e+04,
                            1e-01)

    def test_vgfd5h_72(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((20.0,)),
                                           numpy.array((0.3,))),
                                 (2.05967064205203205e+04,),
                                 (1e-01,))

    def test_gfd5h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(30.0, 0.3),
                            2.26561193608227069e+05,
                            3e+00)

    def test_vgfd5h_73(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((30.0,)),
                                           numpy.array((0.3,))),
                                 (2.26561193608227069e+05,),
                                 (3e+00,))

    def test_gfd5h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(40.0, 0.3),
                            4.03591059130166192e+06,
                            3e+01)

    def test_vgfd5h_74(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((40.0,)),
                                           numpy.array((0.3,))),
                                 (4.03591059130166192e+06,),
                                 (3e+01,))

    def test_gfd5h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assertRTOL(gfd.gfd5h(50.0, 0.3),
                            4.81487891604254469e+07,
                            1e+02)

    def test_vgfd5h_75(self):
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            self.assert_all_rtol(gfd.gfd5h(numpy.array((50.0,)),
                                           numpy.array((0.3,))),
                                 (4.81487891604254469e+07,),
                                 (1e+02,))

if __name__ == "__main__":
    unittest.main()
