# Copyright (c) 2015, Scott J Maddox. All rights reserved.
# Use of this source code is governed by the BSD-3-Clause
# license that can be found in the LICENSE file.

# This file was generated by `scripts/gen_test_fd.py`.
# Do not edit this file directly, or your changes will be lost.
'''
Tests the `fd` module.
'''
# Make sure we import the local package
import os
import sys
sys.path.insert(0,
    os.path.abspath(os.path.join(os.path.dirname(__file__), '../..')))
from fdint import fd
import unittest
import numpy

RTOL = 1.11e-16*12

class Test_FD(unittest.TestCase):

    def assert_rtol(self, a, b, rtol):
        assert rtol >= 0
        rerr = abs(a-b)/a
        if rerr > rtol:
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(rtol, rerr))

    def assert_all_rtol(self, a, b, rtol):
        a = numpy.array(a)
        b = numpy.array(b)
        rtol = numpy.array(rtol)
        for rtol_ in rtol:
            assert rtol_ >= 0
        rerr = abs(a-b)/a
        if (rerr > rtol).all():
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(rtol, rerr))

    def test_1_fdm9h(self):
        phi = -50.0
        nu = fd.fdm9h(phi)
        true_nu = 5.20932585974411373038525771005e-23
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2_fdm9h(self):
        phi = -49.0
        nu = fd.fdm9h(phi)
        true_nu = 1.41604158230642172985731113260e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_3_fdm9h(self):
        phi = -48.0
        nu = fd.fdm9h(phi)
        true_nu = 3.84920010152593965736602714797e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_4_fdm9h(self):
        phi = -47.0
        nu = fd.fdm9h(phi)
        true_nu = 1.04632106900806738075065480195e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_5_fdm9h(self):
        phi = -46.0
        nu = fd.fdm9h(phi)
        true_nu = 2.84419554861847224766509845914e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_6_fdm9h(self):
        phi = -45.0
        nu = fd.fdm9h(phi)
        true_nu = 7.73132507639369802939386996559e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_7_fdm9h(self):
        phi = -44.0
        nu = fd.fdm9h(phi)
        true_nu = 2.10159204650707290546659149793e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_8_fdm9h(self):
        phi = -43.0
        nu = fd.fdm9h(phi)
        true_nu = 5.71271947085423295937972576675e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_9_fdm9h(self):
        phi = -42.0
        nu = fd.fdm9h(phi)
        true_nu = 1.55287815287072336805542173004e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_10_fdm9h(self):
        phi = -41.0
        nu = fd.fdm9h(phi)
        true_nu = 4.22116046475953463458984774440e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_11_fdm9h(self):
        phi = -40.0
        nu = fd.fdm9h(phi)
        true_nu = 1.14743037863655806373615498304e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_12_fdm9h(self):
        phi = -39.0
        nu = fd.fdm9h(phi)
        true_nu = 3.11903914766963739174454086324e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_13_fdm9h(self):
        phi = -38.0
        nu = fd.fdm9h(phi)
        true_nu = 8.47842743736276202556920461849e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_14_fdm9h(self):
        phi = -37.0
        nu = fd.fdm9h(phi)
        true_nu = 2.30467552368917719121386585487e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_15_fdm9h(self):
        phi = -36.0
        nu = fd.fdm9h(phi)
        true_nu = 6.26475759653861380514190343170e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_16_fdm9h(self):
        phi = -35.0
        nu = fd.fdm9h(phi)
        true_nu = 1.70293767343715999435988010057e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_17_fdm9h(self):
        phi = -34.0
        nu = fd.fdm9h(phi)
        true_nu = 4.62906453270249899817172460039e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_18_fdm9h(self):
        phi = -33.0
        nu = fd.fdm9h(phi)
        true_nu = 1.25831020020090455232444662277e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_19_fdm9h(self):
        phi = -32.0
        nu = fd.fdm9h(phi)
        true_nu = 3.42044175177047230840440781756e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_20_fdm9h(self):
        phi = -31.0
        nu = fd.fdm9h(phi)
        true_nu = 9.29772465913801015578941405472e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_21_fdm9h(self):
        phi = -30.0
        nu = fd.fdm9h(phi)
        true_nu = 2.52738359869335095388672495651e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_22_fdm9h(self):
        phi = -29.0
        nu = fd.fdm9h(phi)
        true_nu = 6.87014090986106612763660860474e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_23_fdm9h(self):
        phi = -28.0
        nu = fd.fdm9h(phi)
        true_nu = 1.86749791941360812031327653581e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_24_fdm9h(self):
        phi = -27.0
        nu = fd.fdm9h(phi)
        true_nu = 5.07638565895885018683069788108e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_25_fdm9h(self):
        phi = -26.0
        nu = fd.fdm9h(phi)
        true_nu = 1.37990468904937447584009724331e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_26_fdm9h(self):
        phi = -25.0
        nu = fd.fdm9h(phi)
        true_nu = 3.75096984087579231204182266846e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_27_fdm9h(self):
        phi = -24.0
        nu = fd.fdm9h(phi)
        true_nu = 1.01961931547977780591200477062e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_28_fdm9h(self):
        phi = -23.0
        nu = fd.fdm9h(phi)
        true_nu = 2.77161265518046772311322710203e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_29_fdm9h(self):
        phi = -22.0
        nu = fd.fdm9h(phi)
        true_nu = 7.53402430107438710416428992891e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_30_fdm9h(self):
        phi = -21.0
        nu = fd.fdm9h(phi)
        true_nu = 2.04796012417233010456206444094e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_31_fdm9h(self):
        phi = -20.0
        nu = fd.fdm9h(phi)
        true_nu = 5.56693270888642651518100469545e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_32_fdm9h(self):
        phi = -19.0
        nu = fd.fdm9h(phi)
        true_nu = 1.51324914164747120315020857540e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_33_fdm9h(self):
        phi = -18.0
        nu = fd.fdm9h(phi)
        true_nu = 4.11343719563946530052041090117e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_34_fdm9h(self):
        phi = -17.0
        nu = fd.fdm9h(phi)
        true_nu = 1.11814782708804363577919412020e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_35_fdm9h(self):
        phi = -16.0
        nu = fd.fdm9h(phi)
        true_nu = 3.03943847373334098776232978990e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_36_fdm9h(self):
        phi = -15.0
        nu = fd.fdm9h(phi)
        true_nu = 8.26203229699324748848652797796e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_37_fdm9h(self):
        phi = -14.0
        nu = fd.fdm9h(phi)
        true_nu = 2.24583987031871888128382992811e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_38_fdm9h(self):
        phi = -13.0
        nu = fd.fdm9h(phi)
        true_nu = 6.10472702473089295188156601861e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_39_fdm9h(self):
        phi = -12.0
        nu = fd.fdm9h(phi)
        true_nu = 1.65936393705825025492561920033e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_40_fdm9h(self):
        phi = -11.0
        nu = fd.fdm9h(phi)
        true_nu = 4.51008008241117343272886353632e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_41_fdm9h(self):
        phi = -10.0
        nu = fd.fdm9h(phi)
        true_nu = 0.0000122556884916249963490362136512
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_42_fdm9h(self):
        phi = -9.0
        nu = fd.fdm9h(phi)
        true_nu = 0.0000332850180648616198198840492034
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_43_fdm9h(self):
        phi = -8.0
        nu = fd.fdm9h(phi)
        true_nu = 0.0000902611020452042958610760155711
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_44_fdm9h(self):
        phi = -7.0
        nu = fd.fdm9h(phi)
        true_nu = 0.000243757215864240419416209902718
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_45_fdm9h(self):
        phi = -6.0
        nu = fd.fdm9h(phi)
        true_nu = 0.000650897931562555934509052611071
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_46_fdm9h(self):
        phi = -5.0
        nu = fd.fdm9h(phi)
        true_nu = 0.00168490504765497031692362084332
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_47_fdm9h(self):
        phi = -4.0
        nu = fd.fdm9h(phi)
        true_nu = 0.00399563120300788457312763076721
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_48_fdm9h(self):
        phi = -3.0
        nu = fd.fdm9h(phi)
        true_nu = 0.00724001592165083792325213387796
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_49_fdm9h(self):
        phi = -2.0
        nu = fd.fdm9h(phi)
        true_nu = 0.00301319276611412691730413082569
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_50_fdm9h(self):
        phi = -1.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0244214561800243297102406789346
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_51_fdm9h(self):
        phi = 0.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0259413250529564669430694911920
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_52_fdm9h(self):
        phi = 1.0
        nu = fd.fdm9h(phi)
        true_nu = 0.0164758658827442915780716118767
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_53_fdm9h(self):
        phi = 2.0
        nu = fd.fdm9h(phi)
        true_nu = 0.0166320842515577800843310127715
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_54_fdm9h(self):
        phi = 3.0
        nu = fd.fdm9h(phi)
        true_nu = 0.00415001083950159313506971113541
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_55_fdm9h(self):
        phi = 4.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000444893985485837147429978113715
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_56_fdm9h(self):
        phi = 5.0
        nu = fd.fdm9h(phi)
        true_nu = -0.00107154288219387690258405455444
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_57_fdm9h(self):
        phi = 6.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000812360478522440677989328359939
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_58_fdm9h(self):
        phi = 7.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000517377107434319195823100168354
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_59_fdm9h(self):
        phi = 8.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000318632295443972394839025631130
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_60_fdm9h(self):
        phi = 9.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000199119274033918617816212215397
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_61_fdm9h(self):
        phi = 10.0
        nu = fd.fdm9h(phi)
        true_nu = -0.000128714522364631047428122908872
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_62_fdm9h(self):
        phi = 11.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000865868096572271904564914133948
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_63_fdm9h(self):
        phi = 12.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000605673218760340034267680052162
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_64_fdm9h(self):
        phi = 13.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000438782090643792258478645754119
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_65_fdm9h(self):
        phi = 14.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000327580118759536311776331686979
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_66_fdm9h(self):
        phi = 15.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000250823217652556724136291865099
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_67_fdm9h(self):
        phi = 16.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000196165003046843463253251817054
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_68_fdm9h(self):
        phi = 17.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000156183994551180905396570756803
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_69_fdm9h(self):
        phi = 18.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000126260555260089419687046660745
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_70_fdm9h(self):
        phi = 19.0
        nu = fd.fdm9h(phi)
        true_nu = -0.0000103420942739672676150322484182
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_71_fdm9h(self):
        phi = 20.0
        nu = fd.fdm9h(phi)
        true_nu = -8.56910234913257024637297308787e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_72_fdm9h(self):
        phi = 21.0
        nu = fd.fdm9h(phi)
        true_nu = -7.17237298560803276175057669402e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_73_fdm9h(self):
        phi = 22.0
        nu = fd.fdm9h(phi)
        true_nu = -6.05773686346994536210226068736e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_74_fdm9h(self):
        phi = 23.0
        nu = fd.fdm9h(phi)
        true_nu = -5.15795264246408986999574565056e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_75_fdm9h(self):
        phi = 24.0
        nu = fd.fdm9h(phi)
        true_nu = -4.42410461418140267735810691376e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_76_fdm9h(self):
        phi = 25.0
        nu = fd.fdm9h(phi)
        true_nu = -3.82001834116665385529210913330e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_77_fdm9h(self):
        phi = 26.0
        nu = fd.fdm9h(phi)
        true_nu = -3.31854753974978872243844893471e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_78_fdm9h(self):
        phi = 27.0
        nu = fd.fdm9h(phi)
        true_nu = -2.89905179585589198509556996515e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_79_fdm9h(self):
        phi = 28.0
        nu = fd.fdm9h(phi)
        true_nu = -2.54565020166470768952291717546e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_80_fdm9h(self):
        phi = 29.0
        nu = fd.fdm9h(phi)
        true_nu = -2.24599140557493329568272694047e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_81_fdm9h(self):
        phi = 30.0
        nu = fd.fdm9h(phi)
        true_nu = -1.99037396849151603848781897147e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_82_fdm9h(self):
        phi = 31.0
        nu = fd.fdm9h(phi)
        true_nu = -1.77110845481891334998473261209e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_83_fdm9h(self):
        phi = 32.0
        nu = fd.fdm9h(phi)
        true_nu = -1.58204893912778194295202806350e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_84_fdm9h(self):
        phi = 33.0
        nu = fd.fdm9h(phi)
        true_nu = -1.41824492685996853811107489632e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_85_fdm9h(self):
        phi = 34.0
        nu = fd.fdm9h(phi)
        true_nu = -1.27567996775943790662764015845e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_86_fdm9h(self):
        phi = 35.0
        nu = fd.fdm9h(phi)
        true_nu = -1.15107342553614917397806130141e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_87_fdm9h(self):
        phi = 36.0
        nu = fd.fdm9h(phi)
        true_nu = -1.04172876154716432076015151226e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_88_fdm9h(self):
        phi = 37.0
        nu = fd.fdm9h(phi)
        true_nu = -9.45416423641472419495686515646e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_89_fdm9h(self):
        phi = 38.0
        nu = fd.fdm9h(phi)
        true_nu = -8.60282723637679540307980360644e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_90_fdm9h(self):
        phi = 39.0
        nu = fd.fdm9h(phi)
        true_nu = -7.84778404602439856740906680524e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_91_fdm9h(self):
        phi = 40.0
        nu = fd.fdm9h(phi)
        true_nu = -7.17602248997501669485360431808e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_92_fdm9h(self):
        phi = 41.0
        nu = fd.fdm9h(phi)
        true_nu = -6.57656265551585791529720349809e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_93_fdm9h(self):
        phi = 42.0
        nu = fd.fdm9h(phi)
        true_nu = -6.04009854719290103936736557719e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_94_fdm9h(self):
        phi = 43.0
        nu = fd.fdm9h(phi)
        true_nu = -5.55870984428052756726412754537e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_95_fdm9h(self):
        phi = 44.0
        nu = fd.fdm9h(phi)
        true_nu = -5.12562874931085797255163141999e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_96_fdm9h(self):
        phi = 45.0
        nu = fd.fdm9h(phi)
        true_nu = -4.73505039724857490800399353060e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_97_fdm9h(self):
        phi = 46.0
        nu = fd.fdm9h(phi)
        true_nu = -4.38197790946596706161479154225e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_98_fdm9h(self):
        phi = 47.0
        nu = fd.fdm9h(phi)
        true_nu = -4.06209515448338424829570730165e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_99_fdm9h(self):
        phi = 48.0
        nu = fd.fdm9h(phi)
        true_nu = -3.77166178386115572715270051709e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_100_fdm9h(self):
        phi = 49.0
        nu = fd.fdm9h(phi)
        true_nu = -3.50742626650658064719523742367e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_101_fdm9h(self):
        phi = 50.0
        nu = fd.fdm9h(phi)
        true_nu = -3.26655353553295305905817034584e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_102_fdm7h(self):
        phi = -50.0
        nu = fd.fdm7h(phi)
        true_nu = -1.82326405091043980563682949934e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_103_fdm7h(self):
        phi = -49.0
        nu = fd.fdm7h(phi)
        true_nu = -4.95614553807247605451528801952e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_104_fdm7h(self):
        phi = -48.0
        nu = fd.fdm7h(phi)
        true_nu = -1.34722003553407888008897071629e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_105_fdm7h(self):
        phi = -47.0
        nu = fd.fdm7h(phi)
        true_nu = -3.66212374152823583270754593006e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_106_fdm7h(self):
        phi = -46.0
        nu = fd.fdm7h(phi)
        true_nu = -9.95468442016465286742084682580e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_107_fdm7h(self):
        phi = -45.0
        nu = fd.fdm7h(phi)
        true_nu = -2.70596377673779431072602715411e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_108_fdm7h(self):
        phi = -44.0
        nu = fd.fdm7h(phi)
        true_nu = -7.35557216277475517237075265400e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_109_fdm7h(self):
        phi = -43.0
        nu = fd.fdm7h(phi)
        true_nu = -1.99945181479898153817524571507e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_110_fdm7h(self):
        phi = -42.0
        nu = fd.fdm7h(phi)
        true_nu = -5.43507353504753180587112305995e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_111_fdm7h(self):
        phi = -41.0
        nu = fd.fdm7h(phi)
        true_nu = -1.47740616266583713516818979930e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_112_fdm7h(self):
        phi = -40.0
        nu = fd.fdm7h(phi)
        true_nu = -4.01600632522795331959049487330e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_113_fdm7h(self):
        phi = -39.0
        nu = fd.fdm7h(phi)
        true_nu = -1.09166370168437315842529018757e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_114_fdm7h(self):
        phi = -38.0
        nu = fd.fdm7h(phi)
        true_nu = -2.96744960307696723589754713741e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_115_fdm7h(self):
        phi = -37.0
        nu = fd.fdm7h(phi)
        true_nu = -8.06636433291212406289926900385e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_116_fdm7h(self):
        phi = -36.0
        nu = fd.fdm7h(phi)
        true_nu = -2.19266515878851770884003985173e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_117_fdm7h(self):
        phi = -35.0
        nu = fd.fdm7h(phi)
        true_nu = -5.96028185703008123887230014491e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_118_fdm7h(self):
        phi = -34.0
        nu = fd.fdm7h(phi)
        true_nu = -1.62017258644589035746830080909e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_119_fdm7h(self):
        phi = -33.0
        nu = fd.fdm7h(phi)
        true_nu = -4.40408570070328200122824035326e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_120_fdm7h(self):
        phi = -32.0
        nu = fd.fdm7h(phi)
        true_nu = -1.19715461311975107130635148409e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_121_fdm7h(self):
        phi = -31.0
        nu = fd.fdm7h(phi)
        true_nu = -3.25420363069893726484009973645e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_122_fdm7h(self):
        phi = -30.0
        nu = fd.fdm7h(phi)
        true_nu = -8.84584259543141085966271056275e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_123_fdm7h(self):
        phi = -29.0
        nu = fd.fdm7h(phi)
        true_nu = -2.40454931845483308575187545076e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_124_fdm7h(self):
        phi = -28.0
        nu = fd.fdm7h(phi)
        true_nu = -6.53624271797319411982859330174e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_125_fdm7h(self):
        phi = -27.0
        nu = fd.fdm7h(phi)
        true_nu = -1.77673498065448820360462406033e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_126_fdm7h(self):
        phi = -26.0
        nu = fd.fdm7h(phi)
        true_nu = -4.82966641181239465094481681790e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_127_fdm7h(self):
        phi = -25.0
        nu = fd.fdm7h(phi)
        true_nu = -1.31283944440966669915013763464e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_128_fdm7h(self):
        phi = -24.0
        nu = fd.fdm7h(phi)
        true_nu = -3.56866760494132505883467583339e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_129_fdm7h(self):
        phi = -23.0
        nu = fd.fdm7h(phi)
        true_nu = -9.70064429876285691416785613005e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_130_fdm7h(self):
        phi = -22.0
        nu = fd.fdm7h(phi)
        true_nu = -2.63690850953697544470460357512e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_131_fdm7h(self):
        phi = -21.0
        nu = fd.fdm7h(phi)
        true_nu = -7.16786046534857406051883516473e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_132_fdm7h(self):
        phi = -20.0
        nu = fd.fdm7h(phi)
        true_nu = -1.94842647082821146909716507675e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_133_fdm7h(self):
        phi = -19.0
        nu = fd.fdm7h(phi)
        true_nu = -5.29637216363044300075121995096e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_134_fdm7h(self):
        phi = -18.0
        nu = fd.fdm7h(phi)
        true_nu = -1.43970314250967465595438323971e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_135_fdm7h(self):
        phi = -17.0
        nu = fd.fdm7h(phi)
        true_nu = -3.91351831131596166355166463809e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_136_fdm7h(self):
        phi = -16.0
        nu = fd.fdm7h(phi)
        true_nu = -1.06380414301916537685880373528e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_137_fdm7h(self):
        phi = -15.0
        nu = fd.fdm7h(phi)
        true_nu = -2.89171630790342790211328465001e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_138_fdm7h(self):
        phi = -14.0
        nu = fd.fdm7h(phi)
        true_nu = -7.86047652051846272016622515245e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_139_fdm7h(self):
        phi = -13.0
        nu = fd.fdm7h(phi)
        true_nu = -2.13668177903443392383439697201e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_140_fdm7h(self):
        phi = -12.0
        nu = fd.fdm7h(phi)
        true_nu = -5.80797564719305528963233585689e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_141_fdm7h(self):
        phi = -11.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000157867718118534880569281831224
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_142_fdm7h(self):
        phi = -10.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000429059289279020372845492329599
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_143_fdm7h(self):
        phi = -9.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000116578949770358221728286407111
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_144_fdm7h(self):
        phi = -8.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000316514524587932452753656235786
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_145_fdm7h(self):
        phi = -7.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000857574548879067182237417161939
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_146_fdm7h(self):
        phi = -6.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00231055332532428193792934545222
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_147_fdm7h(self):
        phi = -5.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00613111125209306588209575531206
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_148_fdm7h(self):
        phi = -4.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0156072978063010906062172485284
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_149_fdm7h(self):
        phi = -3.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0354567638886152226776579043698
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_150_fdm7h(self):
        phi = -2.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0583427556416170463004861312037
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_151_fdm7h(self):
        phi = -1.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0265713647055185825936681669573
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_152_fdm7h(self):
        phi = 0.0
        nu = fd.fdm7h(phi)
        true_nu = 0.0830369774348991412903467726450
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_153_fdm7h(self):
        phi = 1.0
        nu = fd.fdm7h(phi)
        true_nu = 0.0951750895435129298328932106519
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_154_fdm7h(self):
        phi = 2.0
        nu = fd.fdm7h(phi)
        true_nu = 0.0257588999174738610205193762949
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_155_fdm7h(self):
        phi = 3.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00870938745806989986867527364981
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_156_fdm7h(self):
        phi = 4.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0132731636546082138704489715635
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_157_fdm7h(self):
        phi = 5.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0100856583481774060972873690785
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_158_fdm7h(self):
        phi = 6.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00672099125563970565214857873451
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_159_fdm7h(self):
        phi = 7.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00441818757547429559888072549078
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_160_fdm7h(self):
        phi = 8.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00298291956411399481617326217030
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_161_fdm7h(self):
        phi = 9.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00209519878636038922725366561782
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_162_fdm7h(self):
        phi = 10.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00153222291513933401495961318817
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_163_fdm7h(self):
        phi = 11.0
        nu = fd.fdm7h(phi)
        true_nu = -0.00116154807615950879231135538465
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_164_fdm7h(self):
        phi = 12.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000907526271808176572224426341982
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_165_fdm7h(self):
        phi = 13.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000726803955956152578531844060741
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_166_fdm7h(self):
        phi = 14.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000593942573519429101258482288925
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_167_fdm7h(self):
        phi = 15.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000493512350171966847164549438249
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_168_fdm7h(self):
        phi = 16.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000415806489804211871436895618876
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_169_fdm7h(self):
        phi = 17.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000354494983989978702731436697447
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_170_fdm7h(self):
        phi = 18.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000305310489879728738959071854369
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_171_fdm7h(self):
        phi = 19.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000265289916899523124049537085008
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_172_fdm7h(self):
        phi = 20.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000232322071610921814874272944701
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_173_fdm7h(self):
        phi = 21.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000204868766250550025895972728755
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_174_fdm7h(self):
        phi = 22.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000181787376980646072880983474891
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_175_fdm7h(self):
        phi = 23.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000162214646905419322557385695628
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_176_fdm7h(self):
        phi = 24.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000145488603400516495000503594231
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_177_fdm7h(self):
        phi = 25.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000131094871651603536674783049316
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_178_fdm7h(self):
        phi = 26.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000118629006480800245144850171270
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_179_fdm7h(self):
        phi = 27.0
        nu = fd.fdm7h(phi)
        true_nu = -0.000107769584070657679075429971554
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_180_fdm7h(self):
        phi = 28.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000982586697463815121990338412605
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_181_fdm7h(self):
        phi = 29.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000898874346856642722685986331682
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_182_fdm7h(self):
        phi = 30.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000824854257980800329523253397127
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_183_fdm7h(self):
        phi = 31.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000759124658073368633723635268392
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_184_fdm7h(self):
        phi = 32.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000700524723780102431729523391339
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_185_fdm7h(self):
        phi = 33.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000648086945157645171098852855114
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_186_fdm7h(self):
        phi = 34.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000601000073975484805531504996639
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_187_fdm7h(self):
        phi = 35.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000558580058120728979146850118349
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_188_fdm7h(self):
        phi = 36.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000520247059360655994355969944547
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_189_fdm7h(self):
        phi = 37.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000485507146277347411018003308403
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_190_fdm7h(self):
        phi = 38.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000453937609965416967721335098979
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_191_fdm7h(self):
        phi = 39.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000425175108774462088740688982371
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_192_fdm7h(self):
        phi = 40.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000398906038357728034458960546933
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_193_fdm7h(self):
        phi = 41.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000374858664111608030605919556315
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_194_fdm7h(self):
        phi = 42.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000352796658390023383959223685581
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_195_fdm7h(self):
        phi = 43.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000332513764262119648626359675448
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_196_fdm7h(self):
        phi = 44.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000313829367892490409850475649816
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_197_fdm7h(self):
        phi = 45.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000296584807778028186409095817764
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_198_fdm7h(self):
        phi = 46.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000280640284641274524681647079530
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_199_fdm7h(self):
        phi = 47.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000265872263365694355800682359899
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_200_fdm7h(self):
        phi = 48.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000252171279887201503766339206537
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_201_fdm7h(self):
        phi = 49.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000239440082857553713947709053495
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_202_fdm7h(self):
        phi = 50.0
        nu = fd.fdm7h(phi)
        true_nu = -0.0000227592053238217028632158155504
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_203_fdm5h(self):
        phi = -50.0
        nu = fd.fdm5h(phi)
        true_nu = 4.55816012727609951409456037439e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_204_fdm5h(self):
        phi = -49.0
        nu = fd.fdm5h(phi)
        true_nu = 1.23903638451811901363065938681e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_205_fdm5h(self):
        phi = -48.0
        nu = fd.fdm5h(phi)
        true_nu = 3.36805008883519720023600330885e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_206_fdm5h(self):
        phi = -47.0
        nu = fd.fdm5h(phi)
        true_nu = 9.15530935382058958186918247921e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_207_fdm5h(self):
        phi = -46.0
        nu = fd.fdm5h(phi)
        true_nu = 2.48867110504116321692933698380e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_208_fdm5h(self):
        phi = -45.0
        nu = fd.fdm5h(phi)
        true_nu = 6.76490944184448577736278371797e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_209_fdm5h(self):
        phi = -44.0
        nu = fd.fdm5h(phi)
        true_nu = 1.83889304069368879349739846490e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_210_fdm5h(self):
        phi = -43.0
        nu = fd.fdm5h(phi)
        true_nu = 4.99862953699745384842854140858e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_211_fdm5h(self):
        phi = -42.0
        nu = fd.fdm5h(phi)
        true_nu = 1.35876838376188295367742414059e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_212_fdm5h(self):
        phi = -41.0
        nu = fd.fdm5h(phi)
        true_nu = 3.69351540666459285424765335919e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_213_fdm5h(self):
        phi = -40.0
        nu = fd.fdm5h(phi)
        true_nu = 1.00400158130698834196186777240e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_214_fdm5h(self):
        phi = -39.0
        nu = fd.fdm5h(phi)
        true_nu = 2.72915925421093298520660157572e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_215_fdm5h(self):
        phi = -38.0
        nu = fd.fdm5h(phi)
        true_nu = 7.41862400769241874842927474470e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_216_fdm5h(self):
        phi = -37.0
        nu = fd.fdm5h(phi)
        true_nu = 2.01659108322803150243115956494e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_217_fdm5h(self):
        phi = -36.0
        nu = fd.fdm5h(phi)
        true_nu = 5.48166289697129786840056669263e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_218_fdm5h(self):
        phi = -35.0
        nu = fd.fdm5h(phi)
        true_nu = 1.49007046425752296704466501034e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_219_fdm5h(self):
        phi = -34.0
        nu = fd.fdm5h(phi)
        true_nu = 4.05043146611474552880599852147e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_220_fdm5h(self):
        phi = -33.0
        nu = fd.fdm5h(phi)
        true_nu = 1.10102142517583500881864473514e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_221_fdm5h(self):
        phi = -32.0
        nu = fd.fdm5h(phi)
        true_nu = 2.99288653279948488247188964765e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_222_fdm5h(self):
        phi = -31.0
        nu = fd.fdm5h(phi)
        true_nu = 8.13550907674813529999250541284e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_223_fdm5h(self):
        phi = -30.0
        nu = fd.fdm5h(phi)
        true_nu = 2.21146064885843803004807439318e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_224_fdm5h(self):
        phi = -29.0
        nu = fd.fdm5h(phi)
        true_nu = 6.01137329614140764072851869683e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_225_fdm5h(self):
        phi = -28.0
        nu = fd.fdm5h(phi)
        true_nu = 1.63406067949649424229866806311e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_226_fdm5h(self):
        phi = -27.0
        nu = fd.fdm5h(phi)
        true_nu = 4.44183745165983380677899143796e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_227_fdm5h(self):
        phi = -26.0
        nu = fd.fdm5h(phi)
        true_nu = 1.20741660297054666092442752960e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_228_fdm5h(self):
        phi = -25.0
        nu = fd.fdm5h(phi)
        true_nu = 3.28209861115309098529800805735e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_229_fdm5h(self):
        phi = -24.0
        nu = fd.fdm5h(phi)
        true_nu = 8.92166901330594106983108176206e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_230_fdm5h(self):
        phi = -23.0
        nu = fd.fdm5h(phi)
        true_nu = 2.42516107539461671408361083571e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_231_fdm5h(self):
        phi = -22.0
        nu = fd.fdm5h(phi)
        true_nu = 6.59227127904361356223577033259e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_232_fdm5h(self):
        phi = -21.0
        nu = fd.fdm5h(phi)
        true_nu = 1.79196512018032085730222639427e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_233_fdm5h(self):
        phi = -20.0
        nu = fd.fdm5h(phi)
        true_nu = 4.87106620546798151625193444254e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_234_fdm5h(self):
        phi = -19.0
        nu = fd.fdm5h(phi)
        true_nu = 1.32409306189064768988176977700e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_235_fdm5h(self):
        phi = -18.0
        nu = fd.fdm5h(phi)
        true_nu = 3.59925801131901822889075284900e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_236_fdm5h(self):
        phi = -17.0
        nu = fd.fdm5h(phi)
        true_nu = 9.78379692392475246362669687626e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_237_fdm5h(self):
        phi = -16.0
        nu = fd.fdm5h(phi)
        true_nu = 2.65951120406370848999981795056e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_238_fdm5h(self):
        phi = -15.0
        nu = fd.fdm5h(phi)
        true_nu = 7.22929702470682400180396522209e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_239_fdm5h(self):
        phi = -14.0
        nu = fd.fdm5h(phi)
        true_nu = 1.96512375193704435001338493620e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_240_fdm5h(self):
        phi = -13.0
        nu = fd.fdm5h(phi)
        true_nu = 5.34173859820117134213562023622e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_241_fdm5h(self):
        phi = -12.0
        nu = fd.fdm5h(phi)
        true_nu = 0.0000145201914551923872332635696891
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_242_fdm5h(self):
        phi = -11.0
        nu = fd.fdm5h(phi)
        true_nu = 0.0000394687939911080347668073576227
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_243_fdm5h(self):
        phi = -10.0
        nu = fd.fdm5h(phi)
        true_nu = 0.000107278597477641011813458505636
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_244_fdm5h(self):
        phi = -9.0
        nu = fd.fdm5h(phi)
        true_nu = 0.000291549130672386726462861082874
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_245_fdm5h(self):
        phi = -8.0
        nu = fd.fdm5h(phi)
        true_nu = 0.000792037608622878775874688036120
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_246_fdm5h(self):
        phi = -7.0
        nu = fd.fdm5h(phi)
        true_nu = 0.00214947601109667200274233168530
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_247_fdm5h(self):
        phi = -6.0
        nu = fd.fdm5h(phi)
        true_nu = 0.00581708141587446384942226352746
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_248_fdm5h(self):
        phi = -5.0
        nu = fd.fdm5h(phi)
        true_nu = 0.0156238493320502043249764414033
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_249_fdm5h(self):
        phi = -4.0
        nu = fd.fdm5h(phi)
        true_nu = 0.0411158619598184975775620356840
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_250_fdm5h(self):
        phi = -3.0
        nu = fd.fdm5h(phi)
        true_nu = 0.102498431234088010828774863805
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_251_fdm5h(self):
        phi = -2.0
        nu = fd.fdm5h(phi)
        true_nu = 0.222520002435615052491755212174
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_252_fdm5h(self):
        phi = -1.0
        nu = fd.fdm5h(phi)
        true_nu = 0.349279717735501919593155793041
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_253_fdm5h(self):
        phi = 0.0
        nu = fd.fdm5h(phi)
        true_nu = 0.280475155114933981056012994771
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_254_fdm5h(self):
        phi = 1.0
        nu = fd.fdm5h(phi)
        true_nu = 0.0250242025344388467504496112308
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_255_fdm5h(self):
        phi = 2.0
        nu = fd.fdm5h(phi)
        true_nu = -0.125465627510238414578372938795
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_256_fdm5h(self):
        phi = 3.0
        nu = fd.fdm5h(phi)
        true_nu = -0.137496395012719460070448472108
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_257_fdm5h(self):
        phi = 4.0
        nu = fd.fdm5h(phi)
        true_nu = -0.106743563532976189704703072882
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_258_fdm5h(self):
        phi = 5.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0771231004324749149953476212534
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_259_fdm5h(self):
        phi = 6.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0563120465601988563508611889254
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_260_fdm5h(self):
        phi = 7.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0426041763114455977533692002952
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_261_fdm5h(self):
        phi = 8.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0334973774614568179277128851056
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_262_fdm5h(self):
        phi = 9.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0272364917391627042842560261505
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_263_fdm5h(self):
        phi = 10.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0227533016902179866911652659840
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_264_fdm5h(self):
        phi = 11.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0194166628248026931164419857951
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_265_fdm5h(self):
        phi = 12.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0168492131112003673070296077907
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_266_fdm5h(self):
        phi = 13.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0148184254761504545678327843035
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_267_fdm5h(self):
        phi = 14.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0131755758937396741892952999510
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_268_fdm5h(self):
        phi = 15.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0118218395796356917819019667574
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_269_fdm5h(self):
        phi = 16.0
        nu = fd.fdm5h(phi)
        true_nu = -0.0106891677660482352316340584787
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_270_fdm5h(self):
        phi = 17.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00972920073395366549031631150258
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_271_fdm5h(self):
        phi = 18.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00890662227512296634942370531250
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_272_fdm5h(self):
        phi = 19.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00819503480227223293065552800056
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_273_fdm5h(self):
        phi = 20.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00757431101388989581866039061905
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_274_fdm5h(self):
        phi = 21.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00702883978772397589820176424661
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_275_fdm5h(self):
        phi = 22.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00654633155786503572395993022402
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_276_fdm5h(self):
        phi = 23.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00611698453327090604768741218995
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_277_fdm5h(self):
        phi = 24.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00573289013300038664408766138632
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_278_fdm5h(self):
        phi = 25.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00538760094206505274630636077287
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_279_fdm5h(self):
        phi = 26.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00507581150158023304194843903796
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_280_fdm5h(self):
        phi = 27.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00479311895427796831443039528674
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_281_fdm5h(self):
        phi = 28.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00453584117669120653231654566137
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_282_fdm5h(self):
        phi = 29.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00430087693027442929326611703632
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_283_fdm5h(self):
        phi = 30.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00408559714953721735140003994501
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_284_fdm5h(self):
        phi = 31.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00388775959189106194897811196769
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_285_fdm5h(self):
        phi = 32.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00370544121522994152050490984860
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_286_fdm5h(self):
        phi = 33.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00353698414848231698119827052447
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_287_fdm5h(self):
        phi = 34.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00338095218503316638669689799127
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_288_fdm5h(self):
        phi = 35.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00323609549483862011856955344875
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_289_fdm5h(self):
        phi = 36.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00310132180865982392967456100607
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_290_fdm5h(self):
        phi = 37.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00297567273826614281889140842690
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_291_fdm5h(self):
        phi = 38.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00285830420163705238118880330468
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_292_fdm5h(self):
        phi = 39.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00274847015127165213512971066471
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_293_fdm5h(self):
        phi = 40.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00264550897719623617996517535596
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_294_fdm5h(self):
        phi = 41.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00254883208872837837550460303531
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_295_fdm5h(self):
        phi = 42.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00245791428099499124732333208284
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_296_fdm5h(self):
        phi = 43.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00237228557122282533798461862555
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_297_fdm5h(self):
        phi = 44.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00229152425149886172825958956046
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_298_fdm5h(self):
        phi = 45.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00221525095315542114682181976118
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_299_fdm5h(self):
        phi = 46.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00214312355624019701893387910825
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_300_fdm5h(self):
        phi = 47.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00207483280798924084134267992153
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_301_fdm5h(self):
        phi = 48.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00201009853857376004954360166702
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_302_fdm5h(self):
        phi = 49.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00194866638196624077638255002765
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_303_fdm5h(self):
        phi = 50.0
        nu = fd.fdm5h(phi)
        true_nu = -0.00189030492558474857504944971322
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_304_fdm3h(self):
        phi = -50.0
        nu = fd.fdm3h(phi)
        true_nu = -6.83724019091414927114370553111e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_305_fdm3h(self):
        phi = -49.0
        nu = fd.fdm3h(phi)
        true_nu = -1.85855457677717852044736711665e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_306_fdm3h(self):
        phi = -48.0
        nu = fd.fdm3h(phi)
        true_nu = -5.05207513325279580036418735187e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_307_fdm3h(self):
        phi = -47.0
        nu = fd.fdm3h(phi)
        true_nu = -1.37329640307308843728790119594e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_308_fdm3h(self):
        phi = -46.0
        nu = fd.fdm3h(phi)
        true_nu = -3.73300665756174482544959943371e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_309_fdm3h(self):
        phi = -45.0
        nu = fd.fdm3h(phi)
        true_nu = -1.01473641627667286664549624515e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_310_fdm3h(self):
        phi = -44.0
        nu = fd.fdm3h(phi)
        true_nu = -2.75833956104053319054963042341e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_311_fdm3h(self):
        phi = -43.0
        nu = fd.fdm3h(phi)
        true_nu = -7.49794430549618077488563245353e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_312_fdm3h(self):
        phi = -42.0
        nu = fd.fdm3h(phi)
        true_nu = -2.03815257564282443217336874258e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_313_fdm3h(self):
        phi = -41.0
        nu = fd.fdm3h(phi)
        true_nu = -5.54027310999688929361686418449e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_314_fdm3h(self):
        phi = -40.0
        nu = fd.fdm3h(phi)
        true_nu = -1.50600237196048252199098469917e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_315_fdm3h(self):
        phi = -39.0
        nu = fd.fdm3h(phi)
        true_nu = -4.09373888131639954466743444367e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_316_fdm3h(self):
        phi = -38.0
        nu = fd.fdm3h(phi)
        true_nu = -1.11279360115386286166579672929e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_317_fdm3h(self):
        phi = -37.0
        nu = fd.fdm3h(phi)
        true_nu = -3.02488662484204761867649608288e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_318_fdm3h(self):
        phi = -36.0
        nu = fd.fdm3h(phi)
        true_nu = -8.22249434545694949982620033642e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_319_fdm3h(self):
        phi = -35.0
        nu = fd.fdm3h(phi)
        true_nu = -2.23510569638628644356193999610e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_320_fdm3h(self):
        phi = -34.0
        nu = fd.fdm3h(phi)
        true_nu = -6.07564719917213301956043265630e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_321_fdm3h(self):
        phi = -33.0
        nu = fd.fdm3h(phi)
        true_nu = -1.65153213776376339461165558788e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_322_fdm3h(self):
        phi = -32.0
        nu = fd.fdm3h(phi)
        true_nu = -4.48932979919930772686234267579e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_323_fdm3h(self):
        phi = -31.0
        nu = fd.fdm3h(phi)
        true_nu = -1.22032636151227970534079501981e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_324_fdm3h(self):
        phi = -30.0
        nu = fd.fdm3h(phi)
        true_nu = -3.31719097328809603142140920445e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_325_fdm3h(self):
        phi = -29.0
        nu = fd.fdm3h(phi)
        true_nu = -9.01705994421535515585440160822e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_326_fdm3h(self):
        phi = -28.0
        nu = fd.fdm3h(phi)
        true_nu = -2.45109101924713814770414392761e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_327_fdm3h(self):
        phi = -27.0
        nu = fd.fdm3h(phi)
        true_nu = -6.66275617750746068349410138965e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_328_fdm3h(self):
        phi = -26.0
        nu = fd.fdm3h(phi)
        true_nu = -1.81112490446890599002789067167e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_329_fdm3h(self):
        phi = -25.0
        nu = fd.fdm3h(phi)
        true_nu = -4.92314791682632965601565473652e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_330_fdm3h(self):
        phi = -24.0
        nu = fd.fdm3h(phi)
        true_nu = -1.33825035206733829218379509062e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_331_fdm3h(self):
        phi = -23.0
        nu = fd.fdm3h(phi)
        true_nu = -3.63774161361985193534800217802e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_332_fdm3h(self):
        phi = -22.0
        nu = fd.fdm3h(phi)
        true_nu = -9.88840692246630155754204343031e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_333_fdm3h(self):
        phi = -21.0
        nu = fd.fdm3h(phi)
        true_nu = -2.68794768315286429525951099626e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_334_fdm3h(self):
        phi = -20.0
        nu = fd.fdm3h(phi)
        true_nu = -7.30659932950006196077429558425e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_335_fdm3h(self):
        phi = -19.0
        nu = fd.fdm3h(phi)
        true_nu = -1.98613960857324934758226822966e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_336_fdm3h(self):
        phi = -18.0
        nu = fd.fdm3h(phi)
        true_nu = -5.39888713326215320410951121499e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_337_fdm3h(self):
        phi = -17.0
        nu = fd.fdm3h(phi)
        true_nu = -1.46756962451133084899237437750e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_338_fdm3h(self):
        phi = -16.0
        nu = fd.fdm3h(phi)
        true_nu = -3.98926744098249652536336571570e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_339_fdm3h(self):
        phi = -15.0
        nu = fd.fdm3h(phi)
        true_nu = -1.08439502282731842607633345179e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_340_fdm3h(self):
        phi = -14.0
        nu = fd.fdm3h(phi)
        true_nu = -2.94768909426466820114486413550e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_341_fdm3h(self):
        phi = -13.0
        nu = fd.fdm3h(phi)
        true_nu = -8.01263351033397699478015642238e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_342_fdm3h(self):
        phi = -12.0
        nu = fd.fdm3h(phi)
        true_nu = -0.0000217804764371200400918759810147
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_343_fdm3h(self):
        phi = -11.0
        nu = fd.fdm3h(phi)
        true_nu = -0.0000592045893613715089060426961912
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_344_fdm3h(self):
        phi = -10.0
        nu = fd.fdm3h(phi)
        true_nu = -0.000160928228159339936116253927858
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_345_fdm3h(self):
        phi = -9.0
        nu = fd.fdm3h(phi)
        true_nu = -0.000437400024728748551215703261447
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_346_fdm3h(self):
        phi = -8.0
        nu = fd.fdm3h(phi)
        true_nu = -0.00118862011732170635172259256105
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_347_fdm3h(self):
        phi = -7.0
        nu = fd.fdm3h(phi)
        true_nu = -0.00322837338680461246318739393130
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_348_fdm3h(self):
        phi = -6.0
        nu = fd.fdm3h(phi)
        true_nu = -0.00875623841368492761361968108034
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_349_fdm3h(self):
        phi = -5.0
        nu = fd.fdm3h(phi)
        true_nu = -0.0236596624404019063652532289573
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_350_fdm3h(self):
        phi = -4.0
        nu = fd.fdm3h(phi)
        true_nu = -0.0632824325264962996019492406674
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_351_fdm3h(self):
        phi = -3.0
        nu = fd.fdm3h(phi)
        true_nu = -0.164780410773006737177575133665
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_352_fdm3h(self):
        phi = -2.0
        nu = fd.fdm3h(phi)
        true_nu = -0.401084493286448276217180581178
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_353_fdm3h(self):
        phi = -1.0
        nu = fd.fdm3h(phi)
        true_nu = -0.839484415293234290324555865828
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_354_fdm3h(self):
        phi = 0.0
        nu = fd.fdm3h(phi)
        true_nu = -1.34743647771550796538410931379
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_355_fdm3h(self):
        phi = 1.0
        nu = fd.fdm3h(phi)
        true_nu = -1.58005377344713770465285571534
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_356_fdm3h(self):
        phi = 2.0
        nu = fd.fdm3h(phi)
        true_nu = -1.48230795438838082427017210327
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_357_fdm3h(self):
        phi = 3.0
        nu = fd.fdm3h(phi)
        true_nu = -1.27444096895633085460822779065
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_358_fdm3h(self):
        phi = 4.0
        nu = fd.fdm3h(phi)
        true_nu = -1.08995479991472073564128149257
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_359_fdm3h(self):
        phi = 5.0
        nu = fd.fdm3h(phi)
        true_nu = -0.953083801509991994450938546442
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_360_fdm3h(self):
        phi = 6.0
        nu = fd.fdm3h(phi)
        true_nu = -0.854062992536782746291556461534
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_361_fdm3h(self):
        phi = 7.0
        nu = fd.fdm3h(phi)
        true_nu = -0.780593905021640473356343282384
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_362_fdm3h(self):
        phi = 8.0
        nu = fd.fdm3h(phi)
        true_nu = -0.723964522891245587376729195575
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_363_fdm3h(self):
        phi = 9.0
        nu = fd.fdm3h(phi)
        true_nu = -0.678690388411845529169278845259
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_364_fdm3h(self):
        phi = 10.0
        nu = fd.fdm3h(phi)
        true_nu = -0.641373303852461319464203229317
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_365_fdm3h(self):
        phi = 11.0
        nu = fd.fdm3h(phi)
        true_nu = -0.609861285840441241029592962846
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_366_fdm3h(self):
        phi = 12.0
        nu = fd.fdm3h(phi)
        true_nu = -0.582741042586422953940080581659
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_367_fdm3h(self):
        phi = 13.0
        nu = fd.fdm3h(phi)
        true_nu = -0.559046661058127748601874061841
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_368_fdm3h(self):
        phi = 14.0
        nu = fd.fdm3h(phi)
        true_nu = -0.538092601110412072107759617247
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_369_fdm3h(self):
        phi = 15.0
        nu = fd.fdm3h(phi)
        true_nu = -0.519375874633831446993409157351
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_370_fdm3h(self):
        phi = 16.0
        nu = fd.fdm3h(phi)
        true_nu = -0.502516869934249968532572988472
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_371_fdm3h(self):
        phi = 17.0
        nu = fd.fdm3h(phi)
        true_nu = -0.487222231583315442598746708231
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_372_fdm3h(self):
        phi = 18.0
        nu = fd.fdm3h(phi)
        true_nu = -0.473260719290476199569323766604
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_373_fdm3h(self):
        phi = 19.0
        nu = fd.fdm3h(phi)
        true_nu = -0.460446972065803545424988620634
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_374_fdm3h(self):
        phi = 20.0
        nu = fd.fdm3h(phi)
        true_nu = -0.448630257239863434083344394960
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_375_fdm3h(self):
        phi = 21.0
        nu = fd.fdm3h(phi)
        true_nu = -0.437686467408463568648796103139
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_376_fdm3h(self):
        phi = 22.0
        nu = fd.fdm3h(phi)
        true_nu = -0.427512297379794065660428765048
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_377_fdm3h(self):
        phi = 23.0
        nu = fd.fdm3h(phi)
        true_nu = -0.418020923371120097226902105164
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_378_fdm3h(self):
        phi = 24.0
        nu = fd.fdm3h(phi)
        true_nu = -0.409138741601583424399778992365
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_379_fdm3h(self):
        phi = 25.0
        nu = fd.fdm3h(phi)
        true_nu = -0.400802869244719445802458350498
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_380_fdm3h(self):
        phi = 26.0
        nu = fd.fdm3h(phi)
        true_nu = -0.392959203831492393514879162972
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_381_fdm3h(self):
        phi = 27.0
        nu = fd.fdm3h(phi)
        true_nu = -0.385560898223599823794944146601
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_382_fdm3h(self):
        phi = 28.0
        nu = fd.fdm3h(phi)
        true_nu = -0.378567149204355564299996803367
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_383_fdm3h(self):
        phi = 29.0
        nu = fd.fdm3h(phi)
        true_nu = -0.371942225751774641048385608467
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_384_fdm3h(self):
        phi = 30.0
        nu = fd.fdm3h(phi)
        true_nu = -0.365654682593012362794192270126
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_385_fdm3h(self):
        phi = 31.0
        nu = fd.fdm3h(phi)
        true_nu = -0.359676718484972311967310912823
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_386_fdm3h(self):
        phi = 32.0
        nu = fd.fdm3h(phi)
        true_nu = -0.353983648625713594686965345721
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_387_fdm3h(self):
        phi = 33.0
        nu = fd.fdm3h(phi)
        true_nu = -0.348553467862592931785259157837
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_388_fdm3h(self):
        phi = 34.0
        nu = fd.fdm3h(phi)
        true_nu = -0.343366486722174800507740187586
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_389_fdm3h(self):
        phi = 35.0
        nu = fd.fdm3h(phi)
        true_nu = -0.338405026286780480576532524494
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_390_fdm3h(self):
        phi = 36.0
        nu = fd.fdm3h(phi)
        true_nu = -0.333653160958925002166906772370
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_391_fdm3h(self):
        phi = 37.0
        nu = fd.fdm3h(phi)
        true_nu = -0.329096500451510195400384207696
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_392_fdm3h(self):
        phi = 38.0
        nu = fd.fdm3h(phi)
        true_nu = -0.324722004105885758345573496587
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_393_fdm3h(self):
        phi = 39.0
        nu = fd.fdm3h(phi)
        true_nu = -0.320517822006467003488052968039
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_394_fdm3h(self):
        phi = 40.0
        nu = fd.fdm3h(phi)
        true_nu = -0.316473158427396571682522857523
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_395_fdm3h(self):
        phi = 41.0
        nu = fd.fdm3h(phi)
        true_nu = -0.312578153985607007816300863967
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_396_fdm3h(self):
        phi = 42.0
        nu = fd.fdm3h(phi)
        true_nu = -0.308823783538813484369959297776
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_397_fdm3h(self):
        phi = 43.0
        nu = fd.fdm3h(phi)
        true_nu = -0.305201767396226769649125198691
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_398_fdm3h(self):
        phi = 44.0
        nu = fd.fdm3h(phi)
        true_nu = -0.301704493834107416219880987975
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_399_fdm3h(self):
        phi = 45.0
        nu = fd.fdm3h(phi)
        true_nu = -0.298324951250452433951102990330
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_400_fdm3h(self):
        phi = 46.0
        nu = fd.fdm3h(phi)
        true_nu = -0.295056668570534352495134808318
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_401_fdm3h(self):
        phi = 47.0
        nu = fd.fdm3h(phi)
        true_nu = -0.291893662741117844118978176039
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_402_fdm3h(self):
        phi = 48.0
        nu = fd.fdm3h(phi)
        true_nu = -0.288830392336365370108984365150
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_403_fdm3h(self):
        phi = 49.0
        nu = fd.fdm3h(phi)
        true_nu = -0.285861716450828420850390380827
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_404_fdm3h(self):
        phi = 50.0
        nu = fd.fdm3h(phi)
        true_nu = -0.282982858180876093204611395539
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_405_fdm1h(self):
        phi = -50.0
        nu = fd.fdm1h(phi)
        true_nu = 3.41862009545707463557231900794e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_406_fdm1h(self):
        phi = -49.0
        nu = fd.fdm1h(phi)
        true_nu = 9.29277288388589260224028067438e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_407_fdm1h(self):
        phi = -48.0
        nu = fd.fdm1h(phi)
        true_nu = 2.52603756662639790018463927308e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_408_fdm1h(self):
        phi = -47.0
        nu = fd.fdm1h(phi)
        true_nu = 6.86648201536544218645831553981e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_409_fdm1h(self):
        phi = -46.0
        nu = fd.fdm1h(phi)
        true_nu = 1.86650332878087241273869820636e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_410_fdm1h(self):
        phi = -45.0
        nu = fd.fdm1h(phi)
        true_nu = 5.07368208138336433333017794436e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_411_fdm1h(self):
        phi = -44.0
        nu = fd.fdm1h(phi)
        true_nu = 1.37916978052026659535069839322e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_412_fdm1h(self):
        phi = -43.0
        nu = fd.fdm1h(phi)
        true_nu = 3.74897215274809038800352131193e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_413_fdm1h(self):
        phi = -42.0
        nu = fd.fdm1h(phi)
        true_nu = 1.01907628782141221650099250422e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_414_fdm1h(self):
        phi = -41.0
        nu = fd.fdm1h(phi)
        true_nu = 2.77013655499844464986977812867e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_415_fdm1h(self):
        phi = -40.0
        nu = fd.fdm1h(phi)
        true_nu = 7.53001185980241263257538109724e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_416_fdm1h(self):
        phi = -39.0
        nu = fd.fdm1h(phi)
        true_nu = 2.04686944065819978904810024186e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_417_fdm1h(self):
        phi = -38.0
        nu = fd.fdm1h(phi)
        true_nu = 5.56396800576931443183249744044e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_418_fdm1h(self):
        phi = -37.0
        nu = fd.fdm1h(phi)
        true_nu = 1.51244331242102390059568722531e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_419_fdm1h(self):
        phi = -36.0
        nu = fd.fdm1h(phi)
        true_nu = 4.11124717272847542421943774258e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_420_fdm1h(self):
        phi = -35.0
        nu = fd.fdm1h(phi)
        true_nu = 1.11755284819314372002970561820e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_421_fdm1h(self):
        phi = -34.0
        nu = fd.fdm1h(phi)
        true_nu = 3.03782359958607019136807504668e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_422_fdm1h(self):
        phi = -33.0
        nu = fd.fdm1h(phi)
        true_nu = 8.25766068881884417651749915244e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_423_fdm1h(self):
        phi = -32.0
        nu = fd.fdm1h(phi)
        true_nu = 2.24466489959967396421979838918e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_424_fdm1h(self):
        phi = -31.0
        nu = fd.fdm1h(phi)
        true_nu = 6.10163180756154705255877312293e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_425_fdm1h(self):
        phi = -30.0
        nu = fd.fdm1h(phi)
        true_nu = 1.65859548664415776229802901428e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_426_fdm1h(self):
        phi = -29.0
        nu = fd.fdm1h(phi)
        true_nu = 4.50852997210848850161760686327e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_427_fdm1h(self):
        phi = -28.0
        nu = fd.fdm1h(phi)
        true_nu = 1.22554550962416826991610776032e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_428_fdm1h(self):
        phi = -27.0
        nu = fd.fdm1h(phi)
        true_nu = 3.33137808875815783507846104756e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_429_fdm1h(self):
        phi = -26.0
        nu = fd.fdm1h(phi)
        true_nu = 9.05562452237724494674271327389e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_430_fdm1h(self):
        phi = -25.0
        nu = fd.fdm1h(phi)
        true_nu = 2.46157395843733812252526214296e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_431_fdm1h(self):
        phi = -24.0
        nu = fd.fdm1h(phi)
        true_nu = 6.69125176051530929019731320705e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_432_fdm1h(self):
        phi = -23.0
        nu = fd.fdm1h(phi)
        true_nu = 1.81887080694190768374070604046e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_433_fdm1h(self):
        phi = -22.0
        nu = fd.fdm1h(phi)
        true_nu = 4.94420346220837108254023401228e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_434_fdm1h(self):
        phi = -21.0
        nu = fd.fdm1h(phi)
        true_nu = 1.34397384229702790040242888340e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_435_fdm1h(self):
        phi = -20.0
        nu = fd.fdm1h(phi)
        true_nu = 3.65329967007455341094701755614e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_436_fdm1h(self):
        phi = -19.0
        nu = fd.fdm1h(phi)
        true_nu = 9.93069808220944144979227588565e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_437_fdm1h(self):
        phi = -18.0
        nu = fd.fdm1h(phi)
        true_nu = 2.69944359570198342875140350747e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_438_fdm1h(self):
        phi = -17.0
        nu = fd.fdm1h(phi)
        true_nu = 7.33784833736320645457023133018e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_439_fdm1h(self):
        phi = -16.0
        nu = fd.fdm1h(phi)
        true_nu = 1.99463387921299629435301928357e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_440_fdm1h(self):
        phi = -15.0
        nu = fd.fdm1h(phi)
        true_nu = 5.42197628694012212383475331585e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_441_fdm1h(self):
        phi = -14.0
        nu = fd.fdm1h(phi)
        true_nu = 1.47384541372269788230164229773e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_442_fdm1h(self):
        phi = -13.0
        nu = fd.fdm1h(phi)
        true_nu = 4.00632315843686102961115280433e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_443_fdm1h(self):
        phi = -12.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0000108902855323802440336064300532
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_444_fdm1h(self):
        phi = -11.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0000296026442791304743942589936886
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_445_fdm1h(self):
        phi = -10.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0000804666971611373336256790942292
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_446_fdm1h(self):
        phi = -9.0
        nu = fd.fdm1h(phi)
        true_nu = 0.000218719096467171876347413499926
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_447_fdm1h(self):
        phi = -8.0
        nu = fd.fdm1h(phi)
        true_nu = 0.000594451023356010496701267635684
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_448_fdm1h(self):
        phi = -7.0
        nu = fd.fdm1h(phi)
        true_nu = 0.00161522731005054368583098463785
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_449_fdm1h(self):
        phi = -6.0
        nu = fd.fdm1h(phi)
        true_nu = 0.00438578876463040482467797554867
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_450_fdm1h(self):
        phi = -5.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0118861109542278045309180778348
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_451_fdm1h(self):
        phi = -4.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0320493740378828291545290243537
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_452_fdm1h(self):
        phi = -3.0
        nu = fd.fdm1h(phi)
        true_nu = 0.0852597012332688621959556550085
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_453_fdm1h(self):
        phi = -2.0
        nu = fd.fdm1h(phi)
        true_nu = 0.219191607586179700098313426290
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_454_fdm1h(self):
        phi = -1.0
        nu = fd.fdm1h(phi)
        true_nu = 0.521150383107991239577682961624
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_455_fdm1h(self):
        phi = 0.0
        nu = fd.fdm1h(phi)
        true_nu = 1.07215492994019133953089744658
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_456_fdm1h(self):
        phi = 1.0
        nu = fd.fdm1h(phi)
        true_nu = 1.82041135714696264304151633669
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_457_fdm1h(self):
        phi = 2.0
        nu = fd.fdm1h(phi)
        true_nu = 2.59539458328847844069515636675
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_458_fdm1h(self):
        phi = 3.0
        nu = fd.fdm1h(phi)
        true_nu = 3.28521678288771168459684252576
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_459_fdm1h(self):
        phi = 4.0
        nu = fd.fdm1h(phi)
        true_nu = 3.87435315072382442298325102143
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_460_fdm1h(self):
        phi = 5.0
        nu = fd.fdm1h(phi)
        true_nu = 4.38325643471157061978169469654
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_461_fdm1h(self):
        phi = 6.0
        nu = fd.fdm1h(phi)
        true_nu = 4.83374495199356395814444081449
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_462_fdm1h(self):
        phi = 7.0
        nu = fd.fdm1h(phi)
        true_nu = 5.24155514109372470704104967391
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_463_fdm1h(self):
        phi = 8.0
        nu = fd.fdm1h(phi)
        true_nu = 5.61712737865121816864687501268
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_464_fdm1h(self):
        phi = 9.0
        nu = fd.fdm1h(phi)
        true_nu = 5.96740088359431652007197983329
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_465_fdm1h(self):
        phi = 10.0
        nu = fd.fdm1h(phi)
        true_nu = 6.29713724453384784416409684372
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_466_fdm1h(self):
        phi = 11.0
        nu = fd.fdm1h(phi)
        true_nu = 6.60973773344743211430490673081
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_467_fdm1h(self):
        phi = 12.0
        nu = fd.fdm1h(phi)
        true_nu = 6.90772808568797675175826936224
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_468_fdm1h(self):
        phi = 13.0
        nu = fd.fdm1h(phi)
        true_nu = 7.19304823870094149754964249970
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_469_fdm1h(self):
        phi = 14.0
        nu = fd.fdm1h(phi)
        true_nu = 7.46723047705571713581367910216
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_470_fdm1h(self):
        phi = 15.0
        nu = fd.fdm1h(phi)
        true_nu = 7.73151305717372870732801898619
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_471_fdm1h(self):
        phi = 16.0
        nu = fd.fdm1h(phi)
        true_nu = 7.98691550098973514673968307299
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_472_fdm1h(self):
        phi = 17.0
        nu = fd.fdm1h(phi)
        true_nu = 8.23429031477296237091303153176
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_473_fdm1h(self):
        phi = 18.0
        nu = fd.fdm1h(phi)
        true_nu = 8.47435966854861095510313314435
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_474_fdm1h(self):
        phi = 19.0
        nu = fd.fdm1h(phi)
        true_nu = 8.70774213794597783047991209375
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_475_fdm1h(self):
        phi = 20.0
        nu = fd.fdm1h(phi)
        true_nu = 8.93497266616697024502981566672
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_476_fdm1h(self):
        phi = 21.0
        nu = fd.fdm1h(phi)
        true_nu = 9.15651776808789519928875248177
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_477_fdm1h(self):
        phi = 22.0
        nu = fd.fdm1h(phi)
        true_nu = 9.37278731266564070058093678070
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_478_fdm1h(self):
        phi = 23.0
        nu = fd.fdm1h(phi)
        true_nu = 9.58414379185500251568638076215
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_479_fdm1h(self):
        phi = 24.0
        nu = fd.fdm1h(phi)
        true_nu = 9.79090970887911519569054801761
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_480_fdm1h(self):
        phi = 25.0
        nu = fd.fdm1h(phi)
        true_nu = 9.99337353651641893628040870787
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_481_fdm1h(self):
        phi = 26.0
        nu = fd.fdm1h(phi)
        true_nu = 10.1917945725116999418921972084
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_482_fdm1h(self):
        phi = 27.0
        nu = fd.fdm1h(phi)
        true_nu = 10.3864069335613775050366828873
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_483_fdm1h(self):
        phi = 28.0
        nu = fd.fdm1h(phi)
        true_nu = 10.5774228687757153622305186346
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_484_fdm1h(self):
        phi = 29.0
        nu = fd.fdm1h(phi)
        true_nu = 10.7650355299785213411501477872
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_485_fdm1h(self):
        phi = 30.0
        nu = fd.fdm1h(phi)
        true_nu = 10.9494213044066105833098545852
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_486_fdm1h(self):
        phi = 31.0
        nu = fd.fdm1h(phi)
        true_nu = 11.1307417918259419823280125784
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_487_fdm1h(self):
        phi = 32.0
        nu = fd.fdm1h(phi)
        true_nu = 11.3091454904272025893630493122
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_488_fdm1h(self):
        phi = 33.0
        nu = fd.fdm1h(phi)
        true_nu = 11.4847692424747457932322176448
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_489_fdm1h(self):
        phi = 34.0
        nu = fd.fdm1h(phi)
        true_nu = 11.6577394804219339374147741201
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_490_fdm1h(self):
        phi = 35.0
        nu = fd.fdm1h(phi)
        true_nu = 11.8281733062661898492474017317
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_491_fdm1h(self):
        phi = 36.0
        nu = fd.fdm1h(phi)
        true_nu = 11.9961794307183793742798217353
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_492_fdm1h(self):
        phi = 37.0
        nu = fd.fdm1h(phi)
        true_nu = 12.1618589938815347859754538725
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_493_fdm1h(self):
        phi = 38.0
        nu = fd.fdm1h(phi)
        true_nu = 12.3253062852629677631424478454
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_494_fdm1h(self):
        phi = 39.0
        nu = fd.fdm1h(phi)
        true_nu = 12.4866093778508171863841873648
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_495_fdm1h(self):
        phi = 40.0
        nu = fd.fdm1h(phi)
        true_nu = 12.6458506884979485913608471549
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_496_fdm1h(self):
        phi = 41.0
        nu = fd.fdm1h(phi)
        true_nu = 12.8031074748418516262515683541
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_497_fdm1h(self):
        phi = 42.0
        nu = fd.fdm1h(phi)
        true_nu = 12.9584522773487667569116993684
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_498_fdm1h(self):
        phi = 43.0
        nu = fd.fdm1h(phi)
        true_nu = 13.1119533137267853769676195166
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_499_fdm1h(self):
        phi = 44.0
        nu = fd.fdm1h(phi)
        true_nu = 13.2636748318464959370021859581
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_500_fdm1h(self):
        phi = 45.0
        nu = fd.fdm1h(phi)
        true_nu = 13.4136774263923771863913805171
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_501_fdm1h(self):
        phi = 46.0
        nu = fd.fdm1h(phi)
        true_nu = 13.5620183237070341220149400591
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_502_fdm1h(self):
        phi = 47.0
        nu = fd.fdm1h(phi)
        true_nu = 13.7087516386546603216672384252
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_503_fdm1h(self):
        phi = 48.0
        nu = fd.fdm1h(phi)
        true_nu = 13.8539286067968401800452278331
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_504_fdm1h(self):
        phi = 49.0
        nu = fd.fdm1h(phi)
        true_nu = 13.9975977947246289385416584753
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_505_fdm1h(self):
        phi = 50.0
        nu = fd.fdm1h(phi)
        true_nu = 14.1398052910110230016841699268
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fdm1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fdm1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_506_fd0h(self):
        phi = -50.0
        nu = fd.fd0h(phi)
        true_nu = 1.92874984796391778301715681273e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_507_fd0h(self):
        phi = -49.0
        nu = fd.fd0h(phi)
        true_nu = 5.24288566336346393717043091033e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_508_fd0h(self):
        phi = -48.0
        nu = fd.fd0h(phi)
        true_nu = 1.42516408274093510628430548170e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_509_fd0h(self):
        phi = -47.0
        nu = fd.fd0h(phi)
        true_nu = 3.87399762868718711292397356846e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_510_fd0h(self):
        phi = -46.0
        nu = fd.fd0h(phi)
        true_nu = 1.05306173575538123787078774985e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_511_fd0h(self):
        phi = -45.0
        nu = fd.fd0h(phi)
        true_nu = 2.86251858054939364442915156606e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_512_fd0h(self):
        phi = -44.0
        nu = fd.fd0h(phi)
        true_nu = 7.78113224113379651541058663451e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_513_fd0h(self):
        phi = -43.0
        nu = fd.fd0h(phi)
        true_nu = 2.11513103759108048640771204171e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_514_fd0h(self):
        phi = -42.0
        nu = fd.fd0h(phi)
        true_nu = 5.74952226429355980501153056719e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_515_fd0h(self):
        phi = -41.0
        nu = fd.fd0h(phi)
        true_nu = 1.56288218933498876686958262624e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_516_fd0h(self):
        phi = -40.0
        nu = fd.fd0h(phi)
        true_nu = 4.24835425529158898630497784363e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_517_fd0h(self):
        phi = -39.0
        nu = fd.fd0h(phi)
        true_nu = 1.15482241730157859195817012882e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_518_fd0h(self):
        phi = -38.0
        nu = fd.fd0h(phi)
        true_nu = 3.13913279204802957943819122168e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_519_fd0h(self):
        phi = -37.0
        nu = fd.fd0h(phi)
        true_nu = 8.53304762574406543021354090686e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_520_fd0h(self):
        phi = -36.0
        nu = fd.fd0h(phi)
        true_nu = 2.31952283024356911930295560868e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_521_fd0h(self):
        phi = -35.0
        nu = fd.fd0h(phi)
        true_nu = 6.30511676014698739791415323792e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_522_fd0h(self):
        phi = -34.0
        nu = fd.fd0h(phi)
        true_nu = 1.71390843154201149756166448718e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_523_fd0h(self):
        phi = -33.0
        nu = fd.fd0h(phi)
        true_nu = 4.65888614510338651157418902545e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_524_fd0h(self):
        phi = -32.0
        nu = fd.fd0h(phi)
        true_nu = 1.26641655490940955325763767247e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_525_fd0h(self):
        phi = -31.0
        nu = fd.fd0h(phi)
        true_nu = 3.44247710846991720514917763516e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_526_fd0h(self):
        phi = -30.0
        nu = fd.fd0h(phi)
        true_nu = 9.35762296883973677937769742468e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_527_fd0h(self):
        phi = -29.0
        nu = fd.fd0h(phi)
        true_nu = 2.54366564737659939855710339670e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_528_fd0h(self):
        phi = -28.0
        nu = fd.fd0h(phi)
        true_nu = 6.91440010693781256297064302610e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_529_fd0h(self):
        phi = -27.0
        nu = fd.fd0h(phi)
        true_nu = 1.87952881653731698047217222813e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_530_fd0h(self):
        phi = -26.0
        nu = fd.fd0h(phi)
        true_nu = 5.10908902805027332452610612328e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_531_fd0h(self):
        phi = -25.0
        nu = fd.fd0h(phi)
        true_nu = 1.38879438648675831022644607359e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_532_fd0h(self):
        phi = -24.0
        nu = fd.fd0h(phi)
        true_nu = 3.77513454420783954750971618760e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_533_fd0h(self):
        phi = -23.0
        nu = fd.fd0h(phi)
        true_nu = 1.02618796311753594360858585309e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_534_fd0h(self):
        phi = -22.0
        nu = fd.fd0h(phi)
        true_nu = 2.78946809247986819573457393855e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_535_fd0h(self):
        phi = -21.0
        nu = fd.fd0h(phi)
        true_nu = 7.58256042503714559724816667046e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_536_fd0h(self):
        phi = -20.0
        nu = fd.fd0h(phi)
        true_nu = 2.06115362031438070323898279888e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_537_fd0h(self):
        phi = -19.0
        nu = fd.fd0h(phi)
        true_nu = 5.60279642184160363839924117378e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_538_fd0h(self):
        phi = -18.0
        nu = fd.fd0h(phi)
        true_nu = 1.52299796287364881015010037677e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_539_fd0h(self):
        phi = -17.0
        nu = fd.fd0h(phi)
        true_nu = 4.13993763308974744770836006167e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_540_fd0h(self):
        phi = -16.0
        nu = fd.fd0h(phi)
        true_nu = 1.12535168387176815021341469209e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_541_fd0h(self):
        phi = -15.0
        nu = fd.fd0h(phi)
        true_nu = 3.05902273713720485897019177280e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_542_fd0h(self):
        phi = -14.0
        nu = fd.fd0h(phi)
        true_nu = 8.31528373383754187676455548008e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_543_fd0h(self):
        phi = -13.0
        nu = fd.fd0h(phi)
        true_nu = 2.26032685244038969565490340799e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_544_fd0h(self):
        phi = -12.0
        nu = fd.fd0h(phi)
        true_nu = 6.14419347773280543457906620819e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_545_fd0h(self):
        phi = -11.0
        nu = fd.fd0h(phi)
        true_nu = 0.0000167015613183939584621922403693
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_546_fd0h(self):
        phi = -10.0
        nu = fd.fd0h(phi)
        true_nu = 0.0000453988992168646467694878293071
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_547_fd0h(self):
        phi = -9.0
        nu = fd.fd0h(phi)
        true_nu = 0.000123402189723258816350138750044
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_548_fd0h(self):
        phi = -8.0
        nu = fd.fd0h(phi)
        true_nu = 0.000335406372895768831573909856033
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_549_fd0h(self):
        phi = -7.0
        nu = fd.fd0h(phi)
        true_nu = 0.000911466453774244691702493803415
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_550_fd0h(self):
        phi = -6.0
        nu = fd.fd0h(phi)
        true_nu = 0.00247568513773044953085968204352
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_551_fd0h(self):
        phi = -5.0
        nu = fd.fd0h(phi)
        true_nu = 0.00671534848911806861641668773264
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_552_fd0h(self):
        phi = -4.0
        nu = fd.fd0h(phi)
        true_nu = 0.0181499279178097403549833182878
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_553_fd0h(self):
        phi = -3.0
        nu = fd.fd0h(phi)
        true_nu = 0.0485873515737420587589259198547
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_554_fd0h(self):
        phi = -2.0
        nu = fd.fd0h(phi)
        true_nu = 0.126928011042972496443726806358
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_555_fd0h(self):
        phi = -1.0
        nu = fd.fd0h(phi)
        true_nu = 0.313261687518222834048995494968
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_556_fd0h(self):
        phi = 0.0
        nu = fd.fd0h(phi)
        true_nu = 0.693147180559945309417232121458
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_557_fd0h(self):
        phi = 1.0
        nu = fd.fd0h(phi)
        true_nu = 1.31326168751822283404899549497
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_558_fd0h(self):
        phi = 2.0
        nu = fd.fd0h(phi)
        true_nu = 2.12692801104297249644372680636
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_559_fd0h(self):
        phi = 3.0
        nu = fd.fd0h(phi)
        true_nu = 3.04858735157374205875892591985
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_560_fd0h(self):
        phi = 4.0
        nu = fd.fd0h(phi)
        true_nu = 4.01814992791780974035498331829
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_561_fd0h(self):
        phi = 5.0
        nu = fd.fd0h(phi)
        true_nu = 5.00671534848911806861641668773
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_562_fd0h(self):
        phi = 6.0
        nu = fd.fd0h(phi)
        true_nu = 6.00247568513773044953085968204
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_563_fd0h(self):
        phi = 7.0
        nu = fd.fd0h(phi)
        true_nu = 7.00091146645377424469170249380
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_564_fd0h(self):
        phi = 8.0
        nu = fd.fd0h(phi)
        true_nu = 8.00033540637289576883157390986
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_565_fd0h(self):
        phi = 9.0
        nu = fd.fd0h(phi)
        true_nu = 9.00012340218972325881635013875
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_566_fd0h(self):
        phi = 10.0
        nu = fd.fd0h(phi)
        true_nu = 10.0000453988992168646467694878
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_567_fd0h(self):
        phi = 11.0
        nu = fd.fd0h(phi)
        true_nu = 11.0000167015613183939584621922
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_568_fd0h(self):
        phi = 12.0
        nu = fd.fd0h(phi)
        true_nu = 12.0000061441934777328054345791
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_569_fd0h(self):
        phi = 13.0
        nu = fd.fd0h(phi)
        true_nu = 13.0000022603268524403896956549
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_570_fd0h(self):
        phi = 14.0
        nu = fd.fd0h(phi)
        true_nu = 14.0000008315283733837541876765
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_571_fd0h(self):
        phi = 15.0
        nu = fd.fd0h(phi)
        true_nu = 15.0000003059022737137204858970
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_572_fd0h(self):
        phi = 16.0
        nu = fd.fd0h(phi)
        true_nu = 16.0000001125351683871768150213
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_573_fd0h(self):
        phi = 17.0
        nu = fd.fd0h(phi)
        true_nu = 17.0000000413993763308974744771
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_574_fd0h(self):
        phi = 18.0
        nu = fd.fd0h(phi)
        true_nu = 18.0000000152299796287364881015
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_575_fd0h(self):
        phi = 19.0
        nu = fd.fd0h(phi)
        true_nu = 19.0000000056027964218416036384
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_576_fd0h(self):
        phi = 20.0
        nu = fd.fd0h(phi)
        true_nu = 20.0000000020611536203143807032
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_577_fd0h(self):
        phi = 21.0
        nu = fd.fd0h(phi)
        true_nu = 21.0000000007582560425037145597
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_578_fd0h(self):
        phi = 22.0
        nu = fd.fd0h(phi)
        true_nu = 22.0000000002789468092479868196
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_579_fd0h(self):
        phi = 23.0
        nu = fd.fd0h(phi)
        true_nu = 23.0000000001026187963117535944
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_580_fd0h(self):
        phi = 24.0
        nu = fd.fd0h(phi)
        true_nu = 24.0000000000377513454420783955
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_581_fd0h(self):
        phi = 25.0
        nu = fd.fd0h(phi)
        true_nu = 25.0000000000138879438648675831
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_582_fd0h(self):
        phi = 26.0
        nu = fd.fd0h(phi)
        true_nu = 26.0000000000051090890280502733
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_583_fd0h(self):
        phi = 27.0
        nu = fd.fd0h(phi)
        true_nu = 27.0000000000018795288165373170
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_584_fd0h(self):
        phi = 28.0
        nu = fd.fd0h(phi)
        true_nu = 28.0000000000006914400106937813
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_585_fd0h(self):
        phi = 29.0
        nu = fd.fd0h(phi)
        true_nu = 29.0000000000002543665647376599
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_586_fd0h(self):
        phi = 30.0
        nu = fd.fd0h(phi)
        true_nu = 30.0000000000000935762296883974
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_587_fd0h(self):
        phi = 31.0
        nu = fd.fd0h(phi)
        true_nu = 31.0000000000000344247710846992
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_588_fd0h(self):
        phi = 32.0
        nu = fd.fd0h(phi)
        true_nu = 32.0000000000000126641655490941
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_589_fd0h(self):
        phi = 33.0
        nu = fd.fd0h(phi)
        true_nu = 33.0000000000000046588861451034
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_590_fd0h(self):
        phi = 34.0
        nu = fd.fd0h(phi)
        true_nu = 34.0000000000000017139084315420
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_591_fd0h(self):
        phi = 35.0
        nu = fd.fd0h(phi)
        true_nu = 35.0000000000000006305116760147
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_592_fd0h(self):
        phi = 36.0
        nu = fd.fd0h(phi)
        true_nu = 36.0000000000000002319522830244
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_593_fd0h(self):
        phi = 37.0
        nu = fd.fd0h(phi)
        true_nu = 37.0000000000000000853304762574
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_594_fd0h(self):
        phi = 38.0
        nu = fd.fd0h(phi)
        true_nu = 38.0000000000000000313913279205
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_595_fd0h(self):
        phi = 39.0
        nu = fd.fd0h(phi)
        true_nu = 39.0000000000000000115482241730
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_596_fd0h(self):
        phi = 40.0
        nu = fd.fd0h(phi)
        true_nu = 40.0000000000000000042483542553
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_597_fd0h(self):
        phi = 41.0
        nu = fd.fd0h(phi)
        true_nu = 41.0000000000000000015628821893
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_598_fd0h(self):
        phi = 42.0
        nu = fd.fd0h(phi)
        true_nu = 42.0000000000000000005749522264
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_599_fd0h(self):
        phi = 43.0
        nu = fd.fd0h(phi)
        true_nu = 43.0000000000000000002115131038
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_600_fd0h(self):
        phi = 44.0
        nu = fd.fd0h(phi)
        true_nu = 44.0000000000000000000778113224
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_601_fd0h(self):
        phi = 45.0
        nu = fd.fd0h(phi)
        true_nu = 45.0000000000000000000286251858
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_602_fd0h(self):
        phi = 46.0
        nu = fd.fd0h(phi)
        true_nu = 46.0000000000000000000105306174
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_603_fd0h(self):
        phi = 47.0
        nu = fd.fd0h(phi)
        true_nu = 47.0000000000000000000038739976
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_604_fd0h(self):
        phi = 48.0
        nu = fd.fd0h(phi)
        true_nu = 48.0000000000000000000014251641
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_605_fd0h(self):
        phi = 49.0
        nu = fd.fd0h(phi)
        true_nu = 49.0000000000000000000005242886
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_606_fd0h(self):
        phi = 50.0
        nu = fd.fd0h(phi)
        true_nu = 50.0000000000000000000001928750
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd0h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd0h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_607_fd1h(self):
        phi = -50.0
        nu = fd.fd1h(phi)
        true_nu = 1.70931004772853731778627606456e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_608_fd1h(self):
        phi = -49.0
        nu = fd.fd1h(phi)
        true_nu = 4.64638644194294630112100160997e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_609_fd1h(self):
        phi = -48.0
        nu = fd.fd1h(phi)
        true_nu = 1.26301878331319895009295603583e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_610_fd1h(self):
        phi = -47.0
        nu = fd.fd1h(phi)
        true_nu = 3.43324100768272109323386015994e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_611_fd1h(self):
        phi = -46.0
        nu = fd.fd1h(phi)
        true_nu = 9.33251664390436206372823725556e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_612_fd1h(self):
        phi = -45.0
        nu = fd.fd1h(phi)
        true_nu = 2.53684104069168216669076315184e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_613_fd1h(self):
        phi = -44.0
        nu = fd.fd1h(phi)
        true_nu = 6.89584890260133297694319991987e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_614_fd1h(self):
        phi = -43.0
        nu = fd.fd1h(phi)
        true_nu = 1.87448607637404519414193692726e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_615_fd1h(self):
        phi = -42.0
        nu = fd.fd1h(phi)
        true_nu = 5.09538143910706108354073285339e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_616_fd1h(self):
        phi = -41.0
        nu = fd.fd1h(phi)
        true_nu = 1.38506827749922232570022557344e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_617_fd1h(self):
        phi = -40.0
        nu = fd.fd1h(phi)
        true_nu = 3.76500592990120632194280494897e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_618_fd1h(self):
        phi = -39.0
        nu = fd.fd1h(phi)
        true_nu = 1.02343472032909989870264587594e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_619_fd1h(self):
        phi = -38.0
        nu = fd.fd1h(phi)
        true_nu = 2.78198400288465724679212716871e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_620_fd1h(self):
        phi = -37.0
        nu = fd.fd1h(phi)
        true_nu = 7.56221656210511973112203408624e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_621_fd1h(self):
        phi = -36.0
        nu = fd.fd1h(phi)
        true_nu = 2.05562358636423788068630326488e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_622_fd1h(self):
        phi = -35.0
        nu = fd.fd1h(phi)
        true_nu = 5.58776424096571984577036714137e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_623_fd1h(self):
        phi = -34.0
        nu = fd.fd1h(phi)
        true_nu = 1.51891179979303601608100220297e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_624_fd1h(self):
        phi = -33.0
        nu = fd.fd1h(phi)
        true_nu = 4.12883034440942888912355487950e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_625_fd1h(self):
        phi = -32.0
        nu = fd.fd1h(phi)
        true_nu = 1.12233244979984200730705595745e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_626_fd1h(self):
        phi = -31.0
        nu = fd.fd1h(phi)
        true_nu = 3.05081590378081065774308606813e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_627_fd1h(self):
        phi = -30.0
        nu = fd.fd1h(phi)
        true_nu = 8.29297743322106317795845611550e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_628_fd1h(self):
        phi = -29.0
        nu = fd.fd1h(phi)
        true_nu = 2.25426498605444698173140497450e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_629_fd1h(self):
        phi = -28.0
        nu = fd.fd1h(phi)
        true_nu = 6.12772754812233933974062885670e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_630_fd1h(self):
        phi = -27.0
        nu = fd.fd1h(phi)
        true_nu = 1.66568904438018579087208424439e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_631_fd1h(self):
        phi = -26.0
        nu = fd.fd1h(phi)
        true_nu = 4.52781226119680122252219436122e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_632_fd1h(self):
        phi = -25.0
        nu = fd.fd1h(phi)
        true_nu = 1.23078697922471238489203545050e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_633_fd1h(self):
        phi = -24.0
        nu = fd.fd1h(phi)
        true_nu = 3.34562588030230910241915865671e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_634_fd1h(self):
        phi = -23.0
        nu = fd.fd1h(phi)
        true_nu = 9.09435403503949270888872336486e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_635_fd1h(self):
        phi = -22.0
        nu = fd.fd1h(phi)
        true_nu = 2.47210173134799061724943929948e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_636_fd1h(self):
        phi = -21.0
        nu = fd.fd1h(phi)
        true_nu = 6.71986921328662888468737877059e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_637_fd1h(self):
        phi = -20.0
        nu = fd.fd1h(phi)
        true_nu = 1.82664983636840731460693810172e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_638_fd1h(self):
        phi = -19.0
        nu = fd.fd1h(phi)
        true_nu = 4.96534905094051943286335520749e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_639_fd1h(self):
        phi = -18.0
        nu = fd.fd1h(phi)
        true_nu = 1.34972180511871848130041472717e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_640_fd1h(self):
        phi = -17.0
        nu = fd.fd1h(phi)
        true_nu = 3.66892422238324248985181053795e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_641_fd1h(self):
        phi = -16.0
        nu = fd.fd1h(phi)
        true_nu = 9.97316979286937585774592537083e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_642_fd1h(self):
        phi = -15.0
        nu = fd.fd1h(phi)
        true_nu = 2.71098843667099238178013838078e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_643_fd1h(self):
        phi = -14.0
        nu = fd.fd1h(phi)
        true_nu = 7.36922923509037947085754454864e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_644_fd1h(self):
        phi = -13.0
        nu = fd.fd1h(phi)
        true_nu = 2.00316318003786824022359968247e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_645_fd1h(self):
        phi = -12.0
        nu = fd.fd1h(phi)
        true_nu = 5.44515459468473803445711028716e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_646_fd1h(self):
        phi = -11.0
        nu = fd.fd1h(phi)
        true_nu = 0.0000148014095399709850938846180348
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_647_fd1h(self):
        phi = -10.0
        nu = fd.fd1h(phi)
        true_nu = 0.0000402339943668939389307425597552
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_648_fd1h(self):
        phi = -9.0
        nu = fd.fd1h(phi)
        true_nu = 0.000109364319579770272139346267635
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_649_fd1h(self):
        phi = -8.0
        nu = fd.fd1h(phi)
        true_nu = 0.000297260759286247860282711915036
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_650_fd1h(self):
        phi = -7.0
        nu = fd.fd1h(phi)
        true_nu = 0.000807873938281784289669222756434
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_651_fd1h(self):
        phi = -6.0
        nu = fd.fd1h(phi)
        true_nu = 0.00219481435680129498803017955103
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_652_fd1h(self):
        phi = -5.0
        nu = fd.fd1h(phi)
        true_nu = 0.00595717690517847659661550122039
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_653_fd1h(self):
        phi = -4.0
        nu = fd.fd1h(phi)
        true_nu = 0.0161277379439837770554415365725
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_654_fd1h(self):
        phi = -3.0
        nu = fd.fd1h(phi)
        true_nu = 0.0433663675504155648413078321338
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_655_fd1h(self):
        phi = -2.0
        nu = fd.fd1h(phi)
        true_nu = 0.114587823925263069890484669463
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_656_fd1h(self):
        phi = -1.0
        nu = fd.fd1h(phi)
        true_nu = 0.290500896169917553439244221222
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_657_fd1h(self):
        phi = 0.0
        nu = fd.fd1h(phi)
        true_nu = 0.678093895153101007312308851917
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_658_fd1h(self):
        phi = 1.0
        nu = fd.fd1h(phi)
        true_nu = 1.39637528066656412631963412190
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_659_fd1h(self):
        phi = 2.0
        nu = fd.fd1h(phi)
        true_nu = 2.50245782600714033355122597532
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_660_fd1h(self):
        phi = 3.0
        nu = fd.fd1h(phi)
        true_nu = 3.97698535404797741785584973778
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_661_fd1h(self):
        phi = 4.0
        nu = fd.fd1h(phi)
        true_nu = 5.77072652760489548384515986214
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_662_fd1h(self):
        phi = 5.0
        nu = fd.fd1h(phi)
        true_nu = 7.83797605729309660900568156345
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_663_fd1h(self):
        phi = 6.0
        nu = fd.fd1h(phi)
        true_nu = 10.1442849321960072250591438618
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_664_fd1h(self):
        phi = 7.0
        nu = fd.fd1h(phi)
        true_nu = 12.6646375722521062877858940135
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_665_fd1h(self):
        phi = 8.0
        nu = fd.fd1h(phi)
        true_nu = 15.3804861224934281628441983252
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_666_fd1h(self):
        phi = 9.0
        nu = fd.fd1h(phi)
        true_nu = 18.2775602501195553687531002737
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_667_fd1h(self):
        phi = 10.0
        nu = fd.fd1h(phi)
        true_nu = 21.3444714923551829494152168465
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_668_fd1h(self):
        phi = 11.0
        nu = fd.fd1h(phi)
        true_nu = 24.5718462568402960191700198756
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_669_fd1h(self):
        phi = 12.0
        nu = fd.fd1h(phi)
        true_nu = 27.9517773872321912421682767762
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_670_fd1h(self):
        phi = 13.0
        nu = fd.fd1h(phi)
        true_nu = 31.4774648667258990785138629280
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_671_fd1h(self):
        phi = 14.0
        nu = fd.fd1h(phi)
        true_nu = 35.1429709160487974962850434792
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_672_fd1h(self):
        phi = 15.0
        nu = fd.fd1h(phi)
        true_nu = 38.9430466009327036091558812945
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_673_fd1h(self):
        phi = 16.0
        nu = fd.fd1h(phi)
        true_nu = 42.8730048687506865482112321699
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_674_fd1h(self):
        phi = 17.0
        nu = fd.fd1h(phi)
        true_nu = 46.9286248812875124327544482699
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_675_fd1h(self):
        phi = 18.0
        nu = fd.fd1h(phi)
        true_nu = 51.1060781780054333658402610727
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_676_fd1h(self):
        phi = 19.0
        nu = fd.fd1h(phi)
        true_nu = 55.4018705306506880028811719769
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_677_fd1h(self):
        phi = 20.0
        nu = fd.fd1h(phi)
        true_nu = 59.8127953703580265126110372609
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_678_fd1h(self):
        phi = 21.0
        nu = fd.fd1h(phi)
        true_nu = 64.3358959388317831871889262327
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_679_fd1h(self):
        phi = 22.0
        nu = fd.fd1h(phi)
        true_nu = 68.9684341408683790478261894290
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_680_fd1h(self):
        phi = 23.0
        nu = fd.fd1h(phi)
        true_nu = 73.7078646284920743895601586403
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_681_fd1h(self):
        phi = 24.0
        nu = fd.fd1h(phi)
        true_nu = 78.5518130273662559765480881920
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_682_fd1h(self):
        phi = 25.0
        nu = fd.fd1h(phi)
        true_nu = 83.4980574839931858036964071073
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_683_fd1h(self):
        phi = 26.0
        nu = fd.fd1h(phi)
        true_nu = 88.5445129047246293866474790204
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_684_fd1h(self):
        phi = 27.0
        nu = fd.fd1h(phi)
        true_nu = 93.6892173984778058105879167290
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_685_fd1h(self):
        phi = 28.0
        nu = fd.fd1h(phi)
        true_nu = 98.9303205397890821516309722830
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_686_fd1h(self):
        phi = 29.0
        nu = fd.fd1h(phi)
        true_nu = 104.266073147821448633981857231
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_687_fd1h(self):
        phi = 30.0
        nu = fd.fd1h(phi)
        true_nu = 109.694818337266498680586337213
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_688_fd1h(self):
        phi = 31.0
        nu = fd.fd1h(phi)
        true_nu = 115.214983643688595625826721410
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_689_fd1h(self):
        phi = 32.0
        nu = fd.fd1h(phi)
        true_nu = 120.825074062246737035485676154
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_690_fd1h(self):
        phi = 33.0
        nu = fd.fd1h(phi)
        true_nu = 126.523665867412792081019843688
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_691_fd1h(self):
        phi = 34.0
        nu = fd.fd1h(phi)
        true_nu = 132.309401104115064086478713991
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_692_fd1h(self):
        phi = 35.0
        nu = fd.fd1h(phi)
        true_nu = 138.180982659024517699890500597
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_693_fd1h(self):
        phi = 36.0
        nu = fd.fd1h(phi)
        true_nu = 144.137169835475240840212882793
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_694_fd1h(self):
        phi = 37.0
        nu = fd.fd1h(phi)
        true_nu = 150.176774367530337535236771459
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_695_fd1h(self):
        phi = 38.0
        nu = fd.fd1h(phi)
        true_nu = 156.298656818547503527155942564
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_696_fd1h(self):
        phi = 39.0
        nu = fd.fd1h(phi)
        true_nu = 162.501723317708873256790924156
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_697_fd1h(self):
        phi = 40.0
        nu = fd.fd1h(phi)
        true_nu = 168.784922594701017065573203667
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_698_fd1h(self):
        phi = 41.0
        nu = fd.fd1h(phi)
        true_nu = 175.147243278331400095282649296
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_699_fd1h(self):
        phi = 42.0
        nu = fd.fd1h(phi)
        true_nu = 181.587711429558010519904316890
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_700_fd1h(self):
        phi = 43.0
        nu = fd.fd1h(phi)
        true_nu = 188.105388283356092642843991704
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_701_fd1h(self):
        phi = 44.0
        nu = fd.fd1h(phi)
        true_nu = 194.699368177182917196857535380
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_702_fd1h(self):
        phi = 45.0
        nu = fd.fd1h(phi)
        true_nu = 201.368776646634842062115229917
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_703_fd1h(self):
        phi = 46.0
        nu = fd.fd1h(phi)
        true_nu = 208.112768671306465649387457339
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_704_fd1h(self):
        phi = 47.0
        nu = fd.fd1h(phi)
        true_nu = 214.930527055929088072941918189
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_705_fd1h(self):
        phi = 48.0
        nu = fd.fd1h(phi)
        true_nu = 221.821260933641714287768440574
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_706_fd1h(self):
        phi = 49.0
        nu = fd.fd1h(phi)
        true_nu = 228.784204379778923725702700308
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_707_fd1h(self):
        phi = 50.0
        nu = fd.fd1h(phi)
        true_nu = 235.818615125884321229814992440
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd1h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd1h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_708_fd2h(self):
        phi = -50.0
        nu = fd.fd2h(phi)
        true_nu = 1.92874984796391778301724981463e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_709_fd2h(self):
        phi = -49.0
        nu = fd.fd2h(phi)
        true_nu = 5.24288566336346393717111810658e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_710_fd2h(self):
        phi = -48.0
        nu = fd.fd2h(phi)
        true_nu = 1.42516408274093510628481325487e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_711_fd2h(self):
        phi = -47.0
        nu = fd.fd2h(phi)
        true_nu = 3.87399762868718711292772553286e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_712_fd2h(self):
        phi = -46.0
        nu = fd.fd2h(phi)
        true_nu = 1.05306173575538123787356009739e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_713_fd2h(self):
        phi = -45.0
        nu = fd.fd2h(phi)
        true_nu = 2.86251858054939364444963659762e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_714_fd2h(self):
        phi = -44.0
        nu = fd.fd2h(phi)
        true_nu = 7.78113224113379651556195168189e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_715_fd2h(self):
        phi = -43.0
        nu = fd.fd2h(phi)
        true_nu = 2.11513103759108048651955652437e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_716_fd2h(self):
        phi = -42.0
        nu = fd.fd2h(phi)
        true_nu = 5.74952226429355980583795572388e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_717_fd2h(self):
        phi = -41.0
        nu = fd.fd2h(phi)
        true_nu = 1.56288218933498876748023281067e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_718_fd2h(self):
        phi = -40.0
        nu = fd.fd2h(phi)
        true_nu = 4.24835425529158899081710631325e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_719_fd2h(self):
        phi = -39.0
        nu = fd.fd2h(phi)
        true_nu = 1.15482241730157859529220716758e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_720_fd2h(self):
        phi = -38.0
        nu = fd.fd2h(phi)
        true_nu = 3.13913279204802960407357793695e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_721_fd2h(self):
        phi = -37.0
        nu = fd.fd2h(phi)
        true_nu = 8.53304762574406561224579536490e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_722_fd2h(self):
        phi = -36.0
        nu = fd.fd2h(phi)
        true_nu = 2.31952283024356925380760960921e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_723_fd2h(self):
        phi = -35.0
        nu = fd.fd2h(phi)
        true_nu = 6.30511676014698839177658721509e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_724_fd2h(self):
        phi = -34.0
        nu = fd.fd2h(phi)
        true_nu = 1.71390843154201223193219241488e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_725_fd2h(self):
        phi = -33.0
        nu = fd.fd2h(phi)
        true_nu = 4.65888614510339193787921728452e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_726_fd2h(self):
        phi = -32.0
        nu = fd.fd2h(phi)
        true_nu = 1.26641655490941356278486404402e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_727_fd2h(self):
        phi = -31.0
        nu = fd.fd2h(phi)
        true_nu = 3.44247710846994683177078348378e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_728_fd2h(self):
        phi = -30.0
        nu = fd.fd2h(phi)
        true_nu = 9.35762296883995569214676481947e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_729_fd2h(self):
        phi = -29.0
        nu = fd.fd2h(phi)
        true_nu = 2.54366564737676115443024449664e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_730_fd2h(self):
        phi = -28.0
        nu = fd.fd2h(phi)
        true_nu = 6.91440010693900778619161365877e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_731_fd2h(self):
        phi = -27.0
        nu = fd.fd2h(phi)
        true_nu = 1.87952881653820013761522095441e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_732_fd2h(self):
        phi = -26.0
        nu = fd.fd2h(phi)
        true_nu = 5.10908902805679902220024574941e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_733_fd2h(self):
        phi = -25.0
        nu = fd.fd2h(phi)
        true_nu = 1.38879438649158018484629634278e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_734_fd2h(self):
        phi = -24.0
        nu = fd.fd2h(phi)
        true_nu = 3.77513454424346864957704396833e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_735_fd2h(self):
        phi = -23.0
        nu = fd.fd2h(phi)
        true_nu = 1.02618796314386248700006896342e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_736_fd2h(self):
        phi = -22.0
        nu = fd.fd2h(phi)
        true_nu = 2.78946809267439650171468502898e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_737_fd2h(self):
        phi = -21.0
        nu = fd.fd2h(phi)
        true_nu = 7.58256042647452616235275440051e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_738_fd2h(self):
        phi = -20.0
        nu = fd.fd2h(phi)
        true_nu = 2.06115362137646926511598877050e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_739_fd2h(self):
        phi = -19.0
        nu = fd.fd2h(phi)
        true_nu = 5.60279642968943557943504426534e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_740_fd2h(self):
        phi = -18.0
        nu = fd.fd2h(phi)
        true_nu = 1.52299796867245580725616769632e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_741_fd2h(self):
        phi = -17.0
        nu = fd.fd2h(phi)
        true_nu = 4.13993767593745665948670323376e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_742_fd2h(self):
        phi = -16.0
        nu = fd.fd2h(phi)
        true_nu = 1.12535171553217885591785973455e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_743_fd2h(self):
        phi = -15.0
        nu = fd.fd2h(phi)
        true_nu = 3.05902297107771546846696314035e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_744_fd2h(self):
        phi = -14.0
        nu = fd.fd2h(phi)
        true_nu = 8.31528546243629094109743715515e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_745_fd2h(self):
        phi = -13.0
        nu = fd.fd2h(phi)
        true_nu = 2.26032812971008044434189923965e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_746_fd2h(self):
        phi = -12.0
        nu = fd.fd2h(phi)
        true_nu = 6.14420291551762144775711936943e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_747_fd2h(self):
        phi = -11.0
        nu = fd.fd2h(phi)
        true_nu = 0.0000167016310540609867424822560404
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_748_fd2h(self):
        phi = -10.0
        nu = fd.fd2h(phi)
        true_nu = 0.0000453994144844763352359751851868
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_749_fd2h(self):
        phi = -9.0
        nu = fd.fd2h(phi)
        true_nu = 0.000123405996800565410638757201782
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_750_fd2h(self):
        phi = -8.0
        nu = fd.fd2h(phi)
        true_nu = 0.000335434498302634621678420761615
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_751_fd2h(self):
        phi = -7.0
        nu = fd.fd2h(phi)
        true_nu = 0.000911674167582221941113989618814
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_752_fd2h(self):
        phi = -6.0
        nu = fd.fd2h(phi)
        true_nu = 0.00247721781344227553294761107734
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_753_fd2h(self):
        phi = -5.0
        nu = fd.fd2h(phi)
        true_nu = 0.00672663087752239812287104607256
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_754_fd2h(self):
        phi = -4.0
        nu = fd.fd2h(phi)
        true_nu = 0.0182324489699830256703316852357
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_755_fd2h(self):
        phi = -3.0
        nu = fd.fd2h(phi)
        true_nu = 0.0491807203388242266310615597651
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_756_fd2h(self):
        phi = -2.0
        nu = fd.fd2h(phi)
        true_nu = 0.131012484714423771270374507682
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_757_fd2h(self):
        phi = -1.0
        nu = fd.fd2h(phi)
        true_nu = 0.338647996403452179821413739727
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_758_fd2h(self):
        phi = 0.0
        nu = fd.fd2h(phi)
        true_nu = 0.822467033424113218236207583323
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_759_fd2h(self):
        phi = 1.0
        nu = fd.fd2h(phi)
        true_nu = 1.80628607044477425665100142692
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_760_fd2h(self):
        phi = 2.0
        nu = fd.fd2h(phi)
        true_nu = 3.51392158213380266520204065896
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_761_fd2h(self):
        phi = 3.0
        nu = fd.fd2h(phi)
        true_nu = 6.09575334650940220984135360688
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_762_fd2h(self):
        phi = 4.0
        nu = fd.fd2h(phi)
        true_nu = 9.62670161787824341080208348141
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_763_fd2h(self):
        phi = 5.0
        nu = fd.fd2h(phi)
        true_nu = 14.1382074359707040383495441206
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_764_fd2h(self):
        phi = 6.0
        nu = fd.fd2h(phi)
        true_nu = 19.6424568490347841609394675556
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_765_fd2h(self):
        phi = 7.0
        nu = fd.fd2h(phi)
        true_nu = 26.1440223926806442145313011770
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_766_fd2h(self):
        phi = 8.0
        nu = fd.fd2h(phi)
        true_nu = 33.6445986323499238018507367459
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_767_fd2h(self):
        phi = 9.0
        nu = fd.fd2h(phi)
        true_nu = 42.1448106608514258710617764094
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_768_fd2h(self):
        phi = 10.0
        nu = fd.fd2h(phi)
        true_nu = 51.6448886674337419601371791915
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_769_fd2h(self):
        phi = 11.0
        nu = fd.fd2h(phi)
        true_nu = 62.1449173652171723754856726844
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_770_fd2h(self):
        phi = 12.0
        nu = fd.fd2h(phi)
        true_nu = 73.6449279226453109188509674095
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_771_fd2h(self):
        phi = 13.0
        nu = fd.fd2h(phi)
        true_nu = 86.1449318065200967263919708247
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_772_fd2h(self):
        phi = 14.0
        nu = fd.fd2h(phi)
        true_nu = 99.6449332353196801928433210569
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_773_fd2h(self):
        phi = 15.0
        nu = fd.fd2h(phi)
        true_nu = 114.144933760945929328700868320
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_774_fd2h(self):
        phi = 16.0
        nu = fd.fd2h(phi)
        true_nu = 129.644933954313054883254529575
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_775_fd2h(self):
        phi = 17.0
        nu = fd.fd2h(phi)
        true_nu = 146.144934025448849677097848572
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_776_fd2h(self):
        phi = 18.0
        nu = fd.fd2h(phi)
        true_nu = 163.644934051618246749747857094
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_777_fd2h(self):
        phi = 19.0
        nu = fd.fd2h(phi)
        true_nu = 182.144934061245430006782979587
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_778_fd2h(self):
        phi = 20.0
        nu = fd.fd2h(phi)
        true_nu = 201.644934064787072815095945902
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_779_fd2h(self):
        phi = 21.0
        nu = fd.fd2h(phi)
        true_nu = 222.144934066089970393824962550
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_780_fd2h(self):
        phi = 22.0
        nu = fd.fd2h(phi)
        true_nu = 243.644934066569279627204975516
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_781_fd2h(self):
        phi = 23.0
        nu = fd.fd2h(phi)
        true_nu = 266.144934066745607640158028918
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_782_fd2h(self):
        phi = 24.0
        nu = fd.fd2h(phi)
        true_nu = 289.644934066810475091029980480
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_783_fd2h(self):
        phi = 25.0
        nu = fd.fd2h(phi)
        true_nu = 314.144934066834338492607499365
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_784_fd2h(self):
        phi = 26.0
        nu = fd.fd2h(phi)
        true_nu = 339.644934066843117347444358368
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_785_fd2h(self):
        phi = 27.0
        nu = fd.fd2h(phi)
        true_nu = 366.144934066846346907655876967
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_786_fd2h(self):
        phi = 28.0
        nu = fd.fd2h(phi)
        true_nu = 393.644934066847534996461721266
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_787_fd2h(self):
        phi = 29.0
        nu = fd.fd2h(phi)
        true_nu = 422.144934066847972069907677491
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_788_fd2h(self):
        phi = 30.0
        nu = fd.fd2h(phi)
        true_nu = 451.644934066848132860242726767
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_789_fd2h(self):
        phi = 31.0
        nu = fd.fd2h(phi)
        true_nu = 482.144934066848192011701330467
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_790_fd2h(self):
        phi = 32.0
        nu = fd.fd2h(phi)
        true_nu = 513.644934066848213772306866073
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_791_fd2h(self):
        phi = 33.0
        nu = fd.fd2h(phi)
        true_nu = 546.144934066848221777586270063
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_792_fd2h(self):
        phi = 34.0
        nu = fd.fd2h(phi)
        true_nu = 579.644934066848224722563983625
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_793_fd2h(self):
        phi = 35.0
        nu = fd.fd2h(phi)
        true_nu = 614.144934066848225805960739152
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_794_fd2h(self):
        phi = 36.0
        nu = fd.fd2h(phi)
        true_nu = 649.644934066848226204520132142
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_795_fd2h(self):
        phi = 37.0
        nu = fd.fd2h(phi)
        true_nu = 686.144934066848226351141938909
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_796_fd2h(self):
        phi = 38.0
        nu = fd.fd2h(phi)
        true_nu = 723.644934066848226405081087246
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_797_fd2h(self):
        phi = 39.0
        nu = fd.fd2h(phi)
        true_nu = 762.144934066848226424924190994
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_798_fd2h(self):
        phi = 40.0
        nu = fd.fd2h(phi)
        true_nu = 801.644934066848226432224060911
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_799_fd2h(self):
        phi = 41.0
        nu = fd.fd2h(phi)
        true_nu = 842.144934066848226434909532977
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_800_fd2h(self):
        phi = 42.0
        nu = fd.fd2h(phi)
        true_nu = 883.644934066848226435897462940
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_801_fd2h(self):
        phi = 43.0
        nu = fd.fd2h(phi)
        true_nu = 926.144934066848226436260902063
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_802_fd2h(self):
        phi = 44.0
        nu = fd.fd2h(phi)
        true_nu = 969.644934066848226436394603844
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_803_fd2h(self):
        phi = 45.0
        nu = fd.fd2h(phi)
        true_nu = 1014.14493406684822643644378998
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_804_fd2h(self):
        phi = 46.0
        nu = fd.fd2h(phi)
        true_nu = 1059.64493406684822643646188455
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_805_fd2h(self):
        phi = 47.0
        nu = fd.fd2h(phi)
        true_nu = 1106.14493406684822643646854117
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_806_fd2h(self):
        phi = 48.0
        nu = fd.fd2h(phi)
        true_nu = 1153.64493406684822643647099000
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_807_fd2h(self):
        phi = 49.0
        nu = fd.fd2h(phi)
        true_nu = 1202.14493406684822643647189088
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_808_fd2h(self):
        phi = 50.0
        nu = fd.fd2h(phi)
        true_nu = 1251.64493406684822643647222229
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd2h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd2h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_809_fd3h(self):
        phi = -50.0
        nu = fd.fd3h(phi)
        true_nu = 2.56396507159280597667950151729e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_810_fd3h(self):
        phi = -49.0
        nu = fd.fd3h(phi)
        true_nu = 6.96957966291441945168214836954e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_811_fd3h(self):
        phi = -48.0
        nu = fd.fd3h(phi)
        true_nu = 1.89452817496979842513991135321e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_812_fd3h(self):
        phi = -47.0
        nu = fd.fd3h(phi)
        true_nu = 5.14986151152408163985431703243e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_813_fd3h(self):
        phi = -46.0
        nu = fd.fd3h(phi)
        true_nu = 1.39987749658565430956184155512e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_814_fd3h(self):
        phi = -45.0
        nu = fd.fd3h(phi)
        true_nu = 3.80526156103752325005540036250e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_815_fd3h(self):
        phi = -44.0
        nu = fd.fd3h(phi)
        true_nu = 1.03437733539019994655570808451e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_816_fd3h(self):
        phi = -43.0
        nu = fd.fd3h(phi)
        true_nu = 2.81172911456106779131803759435e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_817_fd3h(self):
        phi = -42.0
        nu = fd.fd3h(phi)
        true_nu = 7.64307215866059162608792702933e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_818_fd3h(self):
        phi = -41.0
        nu = fd.fd3h(phi)
        true_nu = 2.07760241624883348912434074199e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_819_fd3h(self):
        phi = -40.0
        nu = fd.fd3h(phi)
        true_nu = 5.64750889485180948715554322372e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_820_fd3h(self):
        phi = -39.0
        nu = fd.fd3h(phi)
        true_nu = 1.53515208049364985118791563016e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_821_fd3h(self):
        phi = -38.0
        nu = fd.fd3h(phi)
        true_nu = 4.17297600432698589334509958944e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_822_fd3h(self):
        phi = -37.0
        nu = fd.fd3h(phi)
        true_nu = 1.13433248431576797677907495991e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_823_fd3h(self):
        phi = -36.0
        nu = fd.fd3h(phi)
        true_nu = 3.08343537954635694746189319251e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_824_fd3h(self):
        phi = -35.0
        nu = fd.fd3h(phi)
        true_nu = 8.38164636144858070287192999982e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_825_fd3h(self):
        phi = -34.0
        nu = fd.fd3h(phi)
        true_nu = 2.27836769968955471441922681418e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_826_fd3h(self):
        phi = -33.0
        nu = fd.fd3h(phi)
        true_nu = 6.19324551661414843433393629672e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_827_fd3h(self):
        phi = -32.0
        nu = fd.fd3h(phi)
        true_nu = 1.68349867469976677985845150833e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_828_fd3h(self):
        phi = -31.0
        nu = fd.fd3h(phi)
        true_nu = 4.57622385567124383521240373255e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_829_fd3h(self):
        phi = -30.0
        nu = fd.fd3h(phi)
        true_nu = 1.24394661498318005417889174633e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_830_fd3h(self):
        phi = -29.0
        nu = fd.fd3h(phi)
        true_nu = 3.38139747908182252078905863292e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_831_fd3h(self):
        phi = -28.0
        nu = fd.fd3h(phi)
        true_nu = 9.19159132218463250223101110827e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_832_fd3h(self):
        phi = -27.0
        nu = fd.fd3h(phi)
        true_nu = 2.49853356657110884130776722326e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_833_fd3h(self):
        phi = -26.0
        nu = fd.fd3h(phi)
        true_nu = 6.79171839180133589564643120774e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_834_fd3h(self):
        phi = -25.0
        nu = fd.fd3h(phi)
        true_nu = 1.84618046884160107006012930269e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_835_fd3h(self):
        phi = -24.0
        nu = fd.fd3h(phi)
        true_nu = 5.01843882048695449661957333231e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_836_fd3h(self):
        phi = -23.0
        nu = fd.fd3h(phi)
        true_nu = 1.36415310528067047809811953111e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_837_fd3h(self):
        phi = -22.0
        nu = fd.fd3h(phi)
        true_nu = 3.70815259720483973287716027874e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_838_fd3h(self):
        phi = -21.0
        nu = fd.fd3h(phi)
        true_nu = 1.00798038212810603644092693665e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_839_fd3h(self):
        phi = -20.0
        nu = fd.fd3h(phi)
        true_nu = 2.73997475555095892950721008740e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_840_fd3h(self):
        phi = -19.0
        nu = fd.fd3h(phi)
        true_nu = 7.44802358378762819526893759084e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_841_fd3h(self):
        phi = -18.0
        nu = fd.fd3h(phi)
        true_nu = 2.02458271312887282726943254355e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_842_fd3h(self):
        phi = -17.0
        nu = fd.fd3h(phi)
        true_nu = 5.50338637385109378678505167052e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_843_fd3h(self):
        phi = -16.0
        nu = fd.fd3h(phi)
        true_nu = 1.49597549869073717295064199685e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_844_fd3h(self):
        phi = -15.0
        nu = fd.fd3h(phi)
        true_nu = 4.06648287490721147332066158490e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_845_fd3h(self):
        phi = -14.0
        nu = fd.fd3h(phi)
        true_nu = 1.10538454774937270535100772949e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_846_fd3h(self):
        phi = -13.0
        nu = fd.fd3h(phi)
        true_nu = 3.00474597067236545166464787271e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_847_fd3h(self):
        phi = -12.0
        nu = fd.fd3h(phi)
        true_nu = 8.16774076341784913449765212107e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_848_fd3h(self):
        phi = -11.0
        nu = fd.fd3h(phi)
        true_nu = 0.0000222021798606580757514216832106
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_849_fd3h(self):
        phi = -10.0
        nu = fd.fd3h(phi)
        true_nu = 0.0000603514758980642543138566326155
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_850_fd3h(self):
        phi = -9.0
        nu = fd.fd3h(phi)
        true_nu = 0.000164050058039545758586893575299
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_851_fd3h(self):
        phi = -8.0
        nu = fd.fd3h(phi)
        true_nu = 0.000445917577853306079681917248518
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_852_fd3h(self):
        phi = -7.0
        nu = fd.fd3h(phi)
        true_nu = 0.00121200618444095114643567911378
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_853_fd3h(self):
        phi = -6.0
        nu = fd.fd3h(phi)
        true_nu = 0.00329366281014546159774755084881
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_854_fd3h(self):
        phi = -5.0
        nu = fd.fd3h(phi)
        true_nu = 0.00894638226041224674348411213158
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_855_fd3h(self):
        phi = -4.0
        nu = fd.fd3h(phi)
        true_nu = 0.0242694053348685870238157395699
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_856_fd3h(self):
        phi = -3.0
        nu = fd.fd3h(phi)
        true_nu = 0.0656117388063754437141550511200
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_857_fd3h(self):
        phi = -2.0
        nu = fd.fd3h(phi)
        true_nu = 0.175800988854012886371579301097
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_858_fd3h(self):
        phi = -1.0
        nu = fd.fd3h(phi)
        true_nu = 0.460848806290101658548012136555
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_859_fd3h(self):
        phi = 0.0
        nu = fd.fd3h(phi)
        true_nu = 1.15280383708836140326343256422
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_860_fd3h(self):
        phi = 1.0
        nu = fd.fd3h(phi)
        true_nu = 2.66168262473200422675229859352
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_861_fd3h(self):
        phi = 2.0
        nu = fd.fd3h(phi)
        true_nu = 5.53725367500834507775876653829
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_862_fd3h(self):
        phi = 3.0
        nu = fd.fd3h(phi)
        true_nu = 10.3537148647614519766918651630
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_863_fd3h(self):
        phi = 4.0
        nu = fd.fd3h(phi)
        true_nu = 17.6277025010449661350883026012
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_864_fd3h(self):
        phi = 5.0
        nu = fd.fd3h(phi)
        true_nu = 27.8024462157483804499474221879
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_865_fd3h(self):
        phi = 6.0
        nu = fd.fd3h(phi)
        true_nu = 41.2610026392260358368190166714
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_866_fd3h(self):
        phi = 7.0
        nu = fd.fd3h(phi)
        true_nu = 58.3422170416692295267379429025
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_867_fd3h(self):
        phi = 8.0
        nu = fd.fd3h(phi)
        true_nu = 79.3525936303318516767107109841
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_868_fd3h(self):
        phi = 9.0
        nu = fd.fd3h(phi)
        true_nu = 104.574241187725820201291663996
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_869_fd3h(self):
        phi = 10.0
        nu = fd.fd3h(phi)
        true_nu = 134.270159963139865130624947030
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_870_fd3h(self):
        phi = 11.0
        nu = fd.fd3h(phi)
        true_nu = 168.687863344419706788197891010
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_871_fd3h(self):
        phi = 12.0
        nu = fd.fd3h(phi)
        true_nu = 208.061958682070729279741986417
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_872_fd3h(self):
        phi = 13.0
        nu = fd.fd3h(phi)
        true_nu = 252.616059446827222540251261579
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_873_fd3h(self):
        phi = 14.0
        nu = fd.fd3h(phi)
        true_nu = 302.564251175685712037112499478
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_874_fd3h(self):
        phi = 15.0
        nu = fd.fd3h(phi)
        true_nu = 358.112247708526517420081699557
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_875_fd3h(self):
        phi = 16.0
        nu = fd.fd3h(phi)
        true_nu = 419.458324542063725981317966721
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_876_fd3h(self):
        phi = 17.0
        nu = fd.fd3h(phi)
        true_nu = 486.794086678056266198783204739
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_877_fd3h(self):
        phi = 18.0
        nu = fd.fd3h(phi)
        true_nu = 560.305110280068566213078895716
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_878_fd3h(self):
        phi = 19.0
        nu = fd.fd3h(phi)
        true_nu = 640.171485962780084048255487026
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_879_fd3h(self):
        phi = 20.0
        nu = fd.fd3h(phi)
        true_nu = 726.568283965175233401978262932
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_880_fd3h(self):
        phi = 21.0
        nu = fd.fd3h(phi)
        true_nu = 819.665956304119973435404450928
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_881_fd3h(self):
        phi = 22.0
        nu = fd.fd3h(phi)
        true_nu = 919.630687394137391882221175186
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_882_fd3h(self):
        phi = 23.0
        nu = fd.fd3h(phi)
        true_nu = 1026.62470202648950719805785680
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_883_fd3h(self):
        phi = 24.0
        nu = fd.fd3h(phi)
        true_nu = 1140.80653769852370232633309921
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_884_fd3h(self):
        phi = 25.0
        nu = fd.fd3h(phi)
        true_nu = 1262.33128686247492063234637295
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_885_fd3h(self):
        phi = 26.0
        nu = fd.fd3h(phi)
        true_nu = 1391.35081358276754097509772487
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_886_fd3h(self):
        phi = 27.0
        nu = fd.fd3h(phi)
        true_nu = 1528.01394825838910188971220769
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_887_fd3h(self):
        phi = 28.0
        nu = fd.fd3h(phi)
        true_nu = 1672.46666341707916557018573654
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_888_fd3h(self):
        phi = 29.0
        nu = fd.fd3h(phi)
        true_nu = 1824.85223307497897240627632223
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_889_fd3h(self):
        phi = 30.0
        nu = fd.fd3h(phi)
        true_nu = 1985.31137774603893269944070877
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_890_fd3h(self):
        phi = 31.0
        nu = fd.fd3h(phi)
        true_nu = 2153.98239685581647423768107000
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_891_fd3h(self):
        phi = 32.0
        nu = fd.fd3h(phi)
        true_nu = 2331.00129004651087533629455920
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_892_fd3h(self):
        phi = 33.0
        nu = fd.fd3h(phi)
        true_nu = 2516.50186864083298956717536547
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_893_fd3h(self):
        phi = 34.0
        nu = fd.fd3h(phi)
        true_nu = 2710.61585835148396322895886051
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_894_fd3h(self):
        phi = 35.0
        nu = fd.fd3h(phi)
        true_nu = 2913.47299417287240269705277939
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_895_fd3h(self):
        phi = 36.0
        nu = fd.fd3h(phi)
        true_nu = 3125.20110826624311413314071170
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_896_fd3h(self):
        phi = 37.0
        nu = fd.fd3h(phi)
        true_nu = 3345.92621154394726862172450689
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_897_fd3h(self):
        phi = 38.0
        nu = fd.fd3h(phi)
        true_nu = 3575.77256956947462898168595290
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_898_fd3h(self):
        phi = 39.0
        nu = fd.fd3h(phi)
        true_nu = 3814.86277331417573898927012405
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_899_fd3h(self):
        phi = 40.0
        nu = fd.fd3h(phi)
        true_nu = 4063.31780524699519909760550994
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_900_fd3h(self):
        phi = 41.0
        nu = fd.fd3h(phi)
        true_nu = 4321.25710117814208408481731482
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_901_fd3h(self):
        phi = 42.0
        nu = fd.fd3h(phi)
        true_nu = 4588.79860822992326884262944084
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_902_fd3h(self):
        phi = 43.0
        nu = fd.fd3h(phi)
        true_nu = 4866.05883926672481720335955592
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_903_fd3h(self):
        phi = 44.0
        nu = fd.fd3h(phi)
        true_nu = 5153.15292408033432721673742531
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_904_fd3h(self):
        phi = 45.0
        nu = fd.fd3h(phi)
        true_nu = 5450.19465759562068837180897464
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_905_fd3h(self):
        phi = 46.0
        nu = fd.fd3h(phi)
        true_nu = 5757.29654533433828706608404338
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_906_fd3h(self):
        phi = 47.0
        nu = fd.fd3h(phi)
        true_nu = 6074.56984635092766788449475689
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_907_fd3h(self):
        phi = 48.0
        nu = fd.fd3h(phi)
        true_nu = 6402.12461383316580560895352519
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_908_fd3h(self):
        phi = 49.0
        nu = fd.fd3h(phi)
        true_nu = 6740.06973354197537011392029914
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_909_fd3h(self):
        phi = 50.0
        nu = fd.fd3h(phi)
        true_nu = 7088.51296024829587255154259399
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd3h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd3h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_910_fd4h(self):
        phi = -50.0
        nu = fd.fd4h(phi)
        true_nu = 3.85749969592783556603459263115e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_911_fd4h(self):
        phi = -49.0
        nu = fd.fd4h(phi)
        true_nu = 1.04857713267269278743429234094e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_912_fd4h(self):
        phi = -48.0
        nu = fd.fd4h(phi)
        true_nu = 2.85032816548187021257013428290e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_913_fd4h(self):
        phi = -47.0
        nu = fd.fd4h(phi)
        true_nu = 7.74799525737437422585920303013e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_914_fd4h(self):
        phi = -46.0
        nu = fd.fd4h(phi)
        true_nu = 2.10612347151076247574989254234e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_915_fd4h(self):
        phi = -45.0
        nu = fd.fd4h(phi)
        true_nu = 5.72503716109878728891975822681e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_916_fd4h(self):
        phi = -44.0
        nu = fd.fd4h(phi)
        true_nu = 1.55622644822675930312752684112e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_917_fd4h(self):
        phi = -43.0
        nu = fd.fd4h(phi)
        true_nu = 4.23026207518216097315095753139e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_918_fd4h(self):
        phi = -42.0
        nu = fd.fd4h(phi)
        true_nu = 1.14990445285871196125023366045e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_919_fd4h(self):
        phi = -41.0
        nu = fd.fd4h(phi)
        true_nu = 3.12576437866997753557111580578e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_920_fd4h(self):
        phi = -40.0
        nu = fd.fd4h(phi)
        true_nu = 8.49670851058317798614634109610e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_921_fd4h(self):
        phi = -39.0
        nu = fd.fd4h(phi)
        true_nu = 2.30964483460315719391845137391e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_922_fd4h(self):
        phi = -38.0
        nu = fd.fd4h(phi)
        true_nu = 6.27826558409605923278254258919e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_923_fd4h(self):
        phi = -37.0
        nu = fd.fd4h(phi)
        true_nu = 1.70660952514881314065238451878e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_924_fd4h(self):
        phi = -36.0
        nu = fd.fd4h(phi)
        true_nu = 4.63904566048713864211987321895e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_925_fd4h(self):
        phi = -35.0
        nu = fd.fd4h(phi)
        true_nu = 1.26102335202939777774156084073e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_926_fd4h(self):
        phi = -34.0
        nu = fd.fd4h(phi)
        true_nu = 3.42781686308402519823491275745e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_927_fd4h(self):
        phi = -33.0
        nu = fd.fd4h(phi)
        true_nu = 9.31777229020678930206346282813e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_928_fd4h(self):
        phi = -32.0
        nu = fd.fd4h(phi)
        true_nu = 2.53283310981883113509695445961e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_929_fd4h(self):
        phi = -31.0
        nu = fd.fd4h(phi)
        true_nu = 6.88495421693992329016317281648e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_930_fd4h(self):
        phi = -30.0
        nu = fd.fd4h(phi)
        true_nu = 1.87152459376801302970625970398e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_931_fd4h(self):
        phi = -29.0
        nu = fd.fd4h(phi)
        true_nu = 5.08733129475368406473363010540e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_932_fd4h(self):
        phi = -28.0
        nu = fd.fd4h(phi)
        true_nu = 1.38288002138792107956041981951e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_933_fd4h(self):
        phi = -27.0
        nu = fd.fd4h(phi)
        true_nu = 3.75905763307728343237349112691e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_934_fd4h(self):
        phi = -26.0
        nu = fd.fd4h(phi)
        true_nu = 1.02181780561201237420746410036e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_935_fd4h(self):
        phi = -25.0
        nu = fd.fd4h(phi)
        true_nu = 2.77758877298798224431246279652e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_936_fd4h(self):
        phi = -24.0
        nu = fd.fd4h(phi)
        true_nu = 7.55026908852256640122181424970e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_937_fd4h(self):
        phi = -23.0
        nu = fd.fd4h(phi)
        true_nu = 2.05237592631405151739242151071e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_938_fd4h(self):
        phi = -22.0
        nu = fd.fd4h(phi)
        true_nu = 5.57893618554332130942555908922e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_939_fd4h(self):
        phi = -21.0
        nu = fd.fd4h(phi)
        true_nu = 1.51651208543864328901330306048e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_940_fd4h(self):
        phi = -20.0
        nu = fd.fd4h(phi)
        true_nu = 4.12230724381502709275761393778e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_941_fd4h(self):
        phi = -19.0
        nu = fd.fd4h(phi)
        true_nu = 1.12055928672267031129339819182e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_942_fd4h(self):
        phi = -18.0
        nu = fd.fd4h(phi)
        true_nu = 3.04599594314371863778602126113e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_943_fd4h(self):
        phi = -17.0
        nu = fd.fd4h(phi)
        true_nu = 8.27987539472262305634240078847e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_944_fd4h(self):
        phi = -16.0
        nu = fd.fd4h(phi)
        true_nu = 2.25070346272476947321711248093e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_945_fd4h(self):
        phi = -15.0
        nu = fd.fd4h(phi)
        true_nu = 6.11804617609596275026382582488e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_946_fd4h(self):
        phi = -14.0
        nu = fd.fd4h(phi)
        true_nu = 1.66305726534717568366176434784e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_947_fd4h(self):
        phi = -13.0
        nu = fd.fd4h(phi)
        true_nu = 4.52065753669070705893647933137e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_948_fd4h(self):
        phi = -12.0
        nu = fd.fd4h(phi)
        true_nu = 0.0000122884152688372404256783965735
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_949_fd4h(self):
        phi = -11.0
        nu = fd.fd4h(phi)
        true_nu = 0.0000334033318441340971479828759673
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_950_fd4h(self):
        phi = -10.0
        nu = fd.fd4h(phi)
        true_nu = 0.0000907993442434955332432527209022
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_951_fd4h(self):
        phi = -9.0
        nu = fd.fd4h(phi)
        true_nu = 0.000246815800817640029567962938703
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_952_fd4h(self):
        phi = -8.0
        nu = fd.fd4h(phi)
        true_nu = 0.000670897124807344134376473116589
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_953_fd4h(self):
        phi = -7.0
        nu = fd.fd4h(phi)
        true_nu = 0.00182355610507477338739624648246
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_954_fd4h(self):
        phi = -6.0
        nu = fd.fd4h(phi)
        true_nu = 0.00495596942721279808037006537815
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_955_fd4h(self):
        phi = -5.0
        nu = fd.fd4h(phi)
        true_nu = 0.0134645666109717548777791699858
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_956_fd4h(self):
        phi = -4.0
        nu = fd.fd4h(phi)
        true_nu = 0.0365478637632424012686148883495
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_957_fd4h(self):
        phi = -3.0
        nu = fd.fd4h(phi)
        true_nu = 0.0989634029095922634644110156418
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_958_fd4h(self):
        phi = -2.0
        nu = fd.fd4h(phi)
        true_nu = 0.266265458771300610164088926997
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_959_fd4h(self):
        phi = -1.0
        nu = fd.fd4h(phi)
        true_nu = 0.705129758595615518036110885560
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_960_fd4h(self):
        phi = 0.0
        nu = fd.fd4h(phi)
        true_nu = 1.80308535473939142809960724227
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_961_fd4h(self):
        phi = 1.0
        nu = fd.fd4h(phi)
        true_nu = 4.32833122562540172431427455219
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_962_fd4h(self):
        phi = 2.0
        nu = fd.fd4h(phi)
        true_nu = 9.51266839283087302272041626025
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_963_fd4h(self):
        phi = 3.0
        nu = fd.fd4h(phi)
        true_nu = 18.9685678039989508822989020155
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_964_fd4h(self):
        phi = 4.0
        nu = fd.fd4h(phi)
        true_nu = 34.5293537318823872263812695549
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_965_fd4h(self):
        phi = 5.0
        nu = fd.fd4h(phi)
        true_nu = 58.1294719017599027862685975031
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_966_fd4h(self):
        phi = 6.0
        nu = fd.fd4h(phi)
        true_nu = 91.7441647716059300357493520651
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_967_fd4h(self):
        phi = 7.0
        nu = fd.fd4h(phi)
        true_nu = 137.364233825313578217334541913
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_968_fd4h(self):
        phi = 8.0
        nu = fd.fd4h(phi)
        true_nu = 196.986282633363096994359685806
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_969_fd4h(self):
        phi = 9.0
        nu = fd.fd4h(phi)
        true_nu = 272.609060019068893496533040963
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_970_fd4h(self):
        phi = 10.0
        nu = fd.fd4h(phi)
        true_nu = 366.232105469642105558314879919
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_971_fd4h(self):
        phi = 11.0
        nu = fd.fd4h(phi)
        true_nu = 479.855249540659492403156948316
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_972_fd4h(self):
        phi = 12.0
        nu = fd.fd4h(phi)
        true_nu = 615.478429892772703312578389678
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_973_fd4h(self):
        phi = 13.0
        nu = fd.fd4h(phi)
        true_nu = 775.101623592044757372323186603
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_974_fd4h(self):
        phi = 14.0
        nu = fd.fd4h(phi)
        true_nu = 960.724822201474272235069974995
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_975_fd4h(self):
        phi = 15.0
        nu = fd.fd4h(phi)
        true_nu = 1174.34802261725141070376873003
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_976_fd4h(self):
        phi = 16.0
        nu = fd.fd4h(phi)
        true_nu = 1417.97122369754692557292756599
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_977_fd4h(self):
        phi = 17.0
        nu = fd.fd4h(phi)
        true_nu = 1693.59442502230511945395501290
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_978_fd4h(self):
        phi = 18.0
        nu = fd.fd4h(phi)
        true_nu = 2003.21762643699611114444413238
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_979_fd4h(self):
        phi = 19.0
        nu = fd.fd4h(phi)
        true_nu = 2348.84082788477153078651181278
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_980_fd4h(self):
        phi = 20.0
        nu = fd.fd4h(phi)
        true_nu = 2732.46402934471803136937830043
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_981_fd4h(self):
        phi = 21.0
        nu = fd.fd4h(phi)
        true_nu = 3156.08723080914202241728008029
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_982_fd4h(self):
        phi = 22.0
        nu = fd.fd4h(phi)
        true_nu = 3621.71043227521319015667393280
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_983_fd4h(self):
        phi = 23.0
        nu = fd.fd4h(phi)
        true_nu = 4131.33363374189032033702916948
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_984_fd4h(self):
        phi = 24.0
        nu = fd.fd4h(phi)
        true_nu = 4686.95683520879037164156115366
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_985_fd4h(self):
        phi = 25.0
        nu = fd.fd4h(phi)
        true_nu = 5290.58003667577243104468397149
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_986_fd4h(self):
        phi = 26.0
        nu = fd.fd4h(phi)
        true_nu = 5944.20323814278465954128837546
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_987_fd4h(self):
        phi = 27.0
        nu = fd.fd4h(phi)
        true_nu = 6649.82643960980798662714349628
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_988_fd4h(self):
        phi = 28.0
        nu = fd.fd4h(phi)
        true_nu = 7409.44964107683539665580997059
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_989_fd4h(self):
        phi = 29.0
        nu = fd.fd4h(phi)
        true_nu = 8225.07284254386430871519622170
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_990_fd4h(self):
        phi = 30.0
        nu = fd.fd4h(phi)
        true_nu = 9098.69604401089377334080428680
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_991_fd4h(self):
        phi = 31.0
        nu = fd.fd4h(phi)
        true_nu = 10032.3192454779234412441652431
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_992_fd4h(self):
        phi = 32.0
        nu = fd.fd4h(phi)
        true_nu = 11027.9424469449531839292323355
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_993_fd4h(self):
        phi = 33.0
        nu = fd.fd4h(phi)
        true_nu = 12087.5656484119829541249516912
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_994_fd4h(self):
        phi = 34.0
        nu = fd.fd4h(phi)
        true_nu = 13213.1888498790127344412744277
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_995_fd4h(self):
        phi = 35.0
        nu = fd.fd4h(phi)
        true_nu = 14406.8120513460425184807590804
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_996_fd4h(self):
        phi = 36.0
        nu = fd.fd4h(phi)
        true_nu = 15670.4352528130723038899184580
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_997_fd4h(self):
        phi = 37.0
        nu = fd.fd4h(phi)
        true_nu = 17006.0584542801020898029530082
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_998_fd4h(self):
        phi = 38.0
        nu = fd.fd4h(phi)
        true_nu = 18415.6816557471318759013528752
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_999_fd4h(self):
        phi = 39.0
        nu = fd.fd4h(phi)
        true_nu = 19901.3048572141616620679448313
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1000_fd4h(self):
        phi = 40.0
        nu = fd.fd4h(phi)
        true_nu = 21464.9280586811914482596232552
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1001_fd4h(self):
        phi = 41.0
        nu = fd.fd4h(phi)
        true_nu = 23108.5512601482212344605304747
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1002_fd4h(self):
        phi = 42.0
        nu = fd.fd4h(phi)
        true_nu = 24834.1744616152510206648327785
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1003_fd4h(self):
        phi = 43.0
        nu = fd.fd4h(phi)
        true_nu = 26643.7976630822808068703840639
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1004_fd4h(self):
        phi = 44.0
        nu = fd.fd4h(phi)
        true_nu = 28539.4208645493105930763948240
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1005_fd4h(self):
        phi = 45.0
        nu = fd.fd4h(phi)
        true_nu = 30523.0440660163403792825746154
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1006_fd4h(self):
        phi = 46.0
        nu = fd.fd4h(phi)
        true_nu = 32596.6672674833701654888165899
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1007_fd4h(self):
        phi = 47.0
        nu = fd.fd4h(phi)
        true_nu = 34762.2904689503999516950814403
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1008_fd4h(self):
        phi = 48.0
        nu = fd.fd4h(phi)
        true_nu = 37021.9136704174297379013547063
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1009_fd4h(self):
        phi = 49.0
        nu = fd.fd4h(phi)
        true_nu = 39377.5368718844595241076310682
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1010_fd4h(self):
        phi = 50.0
        nu = fd.fd4h(phi)
        true_nu = 41831.1600733514893103139085691
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd4h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd4h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1011_fd5h(self):
        phi = -50.0
        nu = fd.fd5h(phi)
        true_nu = 6.40991267898201494169886306879e-22
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1012_fd5h(self):
        phi = -49.0
        nu = fd.fd5h(phi)
        true_nu = 1.74239491572860486292061783671e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1013_fd5h(self):
        phi = -48.0
        nu = fd.fd5h(phi)
        true_nu = 4.73632043742449606285037500735e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1014_fd5h(self):
        phi = -47.0
        nu = fd.fd5h(phi)
        true_nu = 1.28746537788102040996402010717e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1015_fd5h(self):
        phi = -46.0
        nu = fd.fd5h(phi)
        true_nu = 3.49969374146413577390786134627e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1016_fd5h(self):
        phi = -45.0
        nu = fd.fd5h(phi)
        true_nu = 9.51315390259380812516257044969e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1017_fd5h(self):
        phi = -44.0
        nu = fd.fd5h(phi)
        true_nu = 2.58594333847549986640705533195e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1018_fd5h(self):
        phi = -43.0
        nu = fd.fd5h(phi)
        true_nu = 7.02932278640266947842650924022e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1019_fd5h(self):
        phi = -42.0
        nu = fd.fd5h(phi)
        true_nu = 1.91076803966514790661908522599e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1020_fd5h(self):
        phi = -41.0
        nu = fd.fd5h(phi)
        true_nu = 5.19400604062208372352835483227e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1021_fd5h(self):
        phi = -40.0
        nu = fd.fd5h(phi)
        true_nu = 1.41187722371295237231905278096e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1022_fd5h(self):
        phi = -39.0
        nu = fd.fd5h(phi)
        true_nu = 3.83788020123412463188722259571e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1023_fd5h(self):
        phi = -38.0
        nu = fd.fd5h(phi)
        true_nu = 1.04324400108174647623088850191e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1024_fd5h(self):
        phi = -37.0
        nu = fd.fd5h(phi)
        true_nu = 2.83583121078941996333614970850e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1025_fd5h(self):
        phi = -36.0
        nu = fd.fd5h(phi)
        true_nu = 7.70858844886589252669528085028e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1026_fd5h(self):
        phi = -35.0
        nu = fd.fd5h(phi)
        true_nu = 2.09541159036214529249502991093e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1027_fd5h(self):
        phi = -34.0
        nu = fd.fd5h(phi)
        true_nu = 5.69591924922388764892022142261e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1028_fd5h(self):
        phi = -33.0
        nu = fd.fd5h(phi)
        true_nu = 1.54831137915353774616455957136e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1029_fd5h(self):
        phi = -32.0
        nu = fd.fd5h(phi)
        true_nu = 4.20874668674942166076846323604e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1030_fd5h(self):
        phi = -31.0
        nu = fd.fd5h(phi)
        true_nu = 1.14405596391781443987782276196e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1031_fd5h(self):
        phi = -30.0
        nu = fd.fd5h(phi)
        true_nu = 3.10986653745797585730363352767e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1032_fd5h(self):
        phi = -29.0
        nu = fd.fd5h(phi)
        true_nu = 8.45349369770474636221258555798e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1033_fd5h(self):
        phi = -28.0
        nu = fd.fd5h(phi)
        true_nu = 2.29789783054629856213526127846e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1034_fd5h(self):
        phi = -27.0
        nu = fd.fd5h(phi)
        true_nu = 6.24633391642880979701896960083e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1035_fd5h(self):
        phi = -26.0
        nu = fd.fd5h(phi)
        true_nu = 1.69792959795110073164450120790e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1036_fd5h(self):
        phi = -25.0
        nu = fd.fd5h(phi)
        true_nu = 4.61545117210966829105293745096e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1037_fd5h(self):
        phi = -24.0
        nu = fd.fd5h(phi)
        true_nu = 1.25460970512592497952878598543e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1038_fd5h(self):
        phi = -23.0
        nu = fd.fd5h(phi)
        true_nu = 3.41038276323260940995208056010e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1039_fd5h(self):
        phi = -22.0
        nu = fd.fd5h(phi)
        true_nu = 9.27038149324066659096207703338e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1040_fd5h(self):
        phi = -21.0
        nu = fd.fd5h(phi)
        true_nu = 2.51995095548915472080557378006e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1041_fd5h(self):
        phi = -20.0
        nu = fd.fd5h(phi)
        true_nu = 6.84993689012533227138630467254e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1042_fd5h(self):
        phi = -19.0
        nu = fd.fd5h(phi)
        true_nu = 1.86200589686901318081384681698e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1043_fd5h(self):
        phi = -18.0
        nu = fd.fd5h(phi)
        true_nu = 5.06145678963567597492649100017e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1044_fd5h(self):
        phi = -17.0
        nu = fd.fd5h(phi)
        true_nu = 1.37584659849730225362070688900e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1045_fd5h(self):
        phi = -16.0
        nu = fd.fd5h(phi)
        true_nu = 3.73993878392725743802108063842e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1046_fd5h(self):
        phi = -15.0
        nu = fd.fd5h(phi)
        true_nu = 1.01662074621439526514114805918e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1047_fd5h(self):
        phi = -14.0
        nu = fd.fd5h(phi)
        true_nu = 2.76346157248074235285221571058e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1048_fd5h(self):
        phi = -13.0
        nu = fd.fd5h(phi)
        true_nu = 7.51186642745118815838901087653e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1049_fd5h(self):
        phi = -12.0
        nu = fd.fd5h(phi)
        true_nu = 0.0000204193629977995338680708383314
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1050_fd5h(self):
        phi = -11.0
        nu = fd.fd5h(phi)
        true_nu = 0.0000555055315903532616936944258281
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1051_fd5h(self):
        phi = -10.0
        nu = fd.fd5h(phi)
        true_nu = 0.000150879295186464421666651882943
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1052_fd5h(self):
        phi = -9.0
        nu = fd.fd5h(phi)
        true_nu = 0.000410129618569776771999482876429
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1053_fd5h(self):
        phi = -8.0
        nu = fd.fd5h(phi)
        true_nu = 0.00111482699596997194240739540122
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1054_fd5h(self):
        phi = -7.0
        nu = fd.fd5h(phi)
        true_nu = 0.00303025961120638561251351409151
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1055_fd5h(self):
        phi = -6.0
        nu = fd.fd5h(phi)
        true_nu = 0.00823595969841790550656610779383
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1056_fd5h(self):
        phi = -5.0
        nu = fd.fd5h(phi)
        true_nu = 0.0223792483585268202047846307426
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1057_fd5h(self):
        phi = -4.0
        nu = fd.fd5h(phi)
        true_nu = 0.0607711893745007465631442199357
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1058_fd5h(self):
        phi = -3.0
        nu = fd.fd5h(phi)
        true_nu = 0.164740393732205133160559689765
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1059_fd5h(self):
        phi = -2.0
        nu = fd.fd5h(phi)
        true_nu = 0.444554453458762989537800633655
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1060_fd5h(self):
        phi = -1.0
        nu = fd.fd5h(phi)
        true_nu = 1.18596817544346744299617311529
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1061_fd5h(self):
        phi = 0.0
        nu = fd.fd5h(phi)
        true_nu = 3.08258608283741860385459920620
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1062_fd5h(self):
        phi = 1.0
        nu = fd.fd5h(phi)
        true_nu = 7.62653535500559535189752215269
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1063_fd5h(self):
        phi = 2.0
        nu = fd.fd5h(phi)
        true_nu = 17.5294191873842618311380042119
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1064_fd5h(self):
        phi = 3.0
        nu = fd.fd5h(phi)
        true_nu = 36.9320654132932680955150169268
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1065_fd5h(self):
        phi = 4.0
        nu = fd.fd5h(phi)
        true_nu = 71.3480523238233553616374869428
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1066_fd5h(self):
        phi = 5.0
        nu = fd.fd5h(phi)
        true_nu = 127.489544913223225121436463623
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1067_fd5h(self):
        phi = 6.0
        nu = fd.fd5h(phi)
        true_nu = 213.098005918624084641038115037
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1068_fd5h(self):
        phi = 7.0
        nu = fd.fd5h(phi)
        true_nu = 336.814324923702770624413108518
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1069_fd5h(self):
        phi = 8.0
        nu = fd.fd5h(phi)
        true_nu = 508.084062021469329192258768063
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1070_fd5h(self):
        phi = 9.0
        nu = fd.fd5h(phi)
        true_nu = 737.087211031027469739936080845
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1071_fd5h(self):
        phi = 10.0
        nu = fd.fd5h(phi)
        true_nu = 1034.68425418153380384544887727
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1072_fd5h(self):
        phi = 11.0
        nu = fd.fd5h(phi)
        true_nu = 1412.37318771368968658689252318
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1073_fd5h(self):
        phi = 12.0
        nu = fd.fd5h(phi)
        true_nu = 1882.25420148514879258633414343
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1074_fd5h(self):
        phi = 13.0
        nu = fd.fd5h(phi)
        true_nu = 2456.99991597780890934080770741
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1075_fd5h(self):
        phi = 14.0
        nu = fd.fd5h(phi)
        true_nu = 3149.82980634700700526317287510
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1076_fd5h(self):
        phi = 15.0
        nu = fd.fd5h(phi)
        true_nu = 3974.48788194165672128451000277
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1077_fd5h(self):
        phi = 16.0
        nu = fd.fd5h(phi)
        true_nu = 4945.22296335338825078692212685
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1078_fd5h(self):
        phi = 17.0
        nu = fd.fd5h(phi)
        true_nu = 6076.77107621684254136217293246
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1079_fd5h(self):
        phi = 18.0
        nu = fd.fd5h(phi)
        true_nu = 7384.33960008593135533435010015
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1080_fd5h(self):
        phi = 19.0
        nu = fd.fd5h(phi)
        true_nu = 8883.59289359937046551155445768
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1081_fd5h(self):
        phi = 20.0
        nu = fd.fd5h(phi)
        true_nu = 10590.6391766143869803392555455
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1082_fd5h(self):
        phi = 21.0
        nu = fd.fd5h(phi)
        true_nu = 12522.0184937768199626615047318
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1083_fd5h(self):
        phi = 22.0
        nu = fd.fd5h(phi)
        true_nu = 14694.6916169665689065463108358
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1084_fd5h(self):
        phi = 23.0
        nu = fd.fd5h(phi)
        true_nu = 17126.0297693586837865664031932
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1085_fd5h(self):
        phi = 24.0
        nu = fd.fd5h(phi)
        true_nu = 19833.8050735769043146380331996
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1086_fd5h(self):
        phi = 25.0
        nu = fd.fd5h(phi)
        true_nu = 22836.1816420331284243573162934
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1087_fd5h(self):
        phi = 26.0
        nu = fd.fd5h(phi)
        true_nu = 26151.7072400590452398854030774
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1088_fd5h(self):
        phi = 27.0
        nu = fd.fd5h(phi)
        true_nu = 29799.3054625742444923462007806
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1089_fd5h(self):
        phi = 28.0
        nu = fd.fd5h(phi)
        true_nu = 33798.2683733315811282886838288
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1090_fd5h(self):
        phi = 29.0
        nu = fd.fd5h(phi)
        true_nu = 38168.2495626314139994936689744
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1091_fd5h(self):
        phi = 30.0
        nu = fd.fd5h(phi)
        true_nu = 42929.2575850999397812171360392
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1092_fd5h(self):
        phi = 31.0
        nu = fd.fd5h(phi)
        true_nu = 48101.6497439109585218554010906
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1093_fd5h(self):
        phi = 32.0
        nu = fd.fd5h(phi)
        true_nu = 53706.1261918708978981834738503
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1094_fd5h(self):
        phi = 33.0
        nu = fd.fd5h(phi)
        true_nu = 59763.7243232210248617815999825
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1095_fd5h(self):
        phi = 34.0
        nu = fd.fd5h(phi)
        true_nu = 66295.8134329466171213381730464
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1096_fd5h(self):
        phi = 35.0
        nu = fd.fd5h(phi)
        true_nu = 73324.0896229064114288653201193
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1097_fd5h(self):
        phi = 36.0
        nu = fd.fd5h(phi)
        true_nu = 80870.5709362757858348105178240
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1098_fd5h(self):
        phi = 37.0
        nu = fd.fd5h(phi)
        true_nu = 88957.5927036895086480253660267
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1099_fd5h(self):
        phi = 38.0
        nu = fd.fd5h(phi)
        true_nu = 97607.8030861197512863397400353
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1100_fd5h(self):
        phi = 39.0
        nu = fd.fd5h(phi)
        true_nu = 106844.158800969465170887998859
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1101_fd5h(self):
        phi = 40.0
        nu = fd.fd5h(phi)
        true_nu = 116689.921019130685082022189196
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1102_fd5h(self):
        phi = 41.0
        nu = fd.fd5h(phi)
        true_nu = 127168.651421877131324488234257
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1103_fd5h(self):
        phi = 42.0
        nu = fd.fd5h(phi)
        true_nu = 138304.208407451707941384166719
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1104_fd5h(self):
        phi = 43.0
        nu = fd.fd5h(phi)
        true_nu = 150120.743438089775047309057378
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1105_fd5h(self):
        phi = 44.0
        nu = fd.fd5h(phi)
        true_nu = 162642.697519003253651811092184
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1106_fd5h(self):
        phi = 45.0
        nu = fd.fd5h(phi)
        true_nu = 175894.797801551248062600890404
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1107_fd5h(self):
        phi = 46.0
        nu = fd.fd5h(phi)
        true_nu = 189902.054303450595824493048214
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1108_fd5h(self):
        phi = 47.0
        nu = fd.fd5h(phi)
        true_nu = 204689.756739443658182433296080
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1109_fd5h(self):
        phi = 48.0
        nu = fd.fd5h(phi)
        true_nu = 220283.471456348515744997826558
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1110_fd5h(self):
        phi = 49.0
        nu = fd.fd5h(phi)
        true_nu = 236709.038466875208928581037053
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1111_fd5h(self):
        phi = 50.0
        nu = fd.fd5h(phi)
        true_nu = 253992.568577006514392578142233
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd5h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd5h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1112_fd6h(self):
        phi = -50.0
        nu = fd.fd6h(phi)
        true_nu = 1.15724990877835066981039173963e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1113_fd6h(self):
        phi = -49.0
        nu = fd.fd6h(phi)
        true_nu = 3.14573139801807836230298010226e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1114_fd6h(self):
        phi = -48.0
        nu = fd.fd6h(phi)
        true_nu = 8.55098449644561063771116450846e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1115_fd6h(self):
        phi = -47.0
        nu = fd.fd6h(phi)
        true_nu = 2.32439857721231226775832370370e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1116_fd6h(self):
        phi = -46.0
        nu = fd.fd6h(phi)
        true_nu = 6.31837041453228742725383614833e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1117_fd6h(self):
        phi = -45.0
        nu = fd.fd6h(phi)
        true_nu = 1.71751114832963618667900022278e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1118_fd6h(self):
        phi = -44.0
        nu = fd.fd6h(phi)
        true_nu = 4.66867934468027790940528528046e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1119_fd6h(self):
        phi = -43.0
        nu = fd.fd6h(phi)
        true_nu = 1.26907862255464829196206393182e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1120_fd6h(self):
        phi = -42.0
        nu = fd.fd6h(phi)
        true_nu = 3.44971335857613588387466475484e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1121_fd6h(self):
        phi = -41.0
        nu = fd.fd6h(phi)
        true_nu = 9.37729313600993260762932269398e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1122_fd6h(self):
        phi = -40.0
        nu = fd.fd6h(phi)
        true_nu = 2.54901255317495339652072159927e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1123_fd6h(self):
        phi = -39.0
        nu = fd.fd6h(phi)
        true_nu = 6.92893450380947158675640967986e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1124_fd6h(self):
        phi = -38.0
        nu = fd.fd6h(phi)
        true_nu = 1.88347967522881777353007078405e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1125_fd6h(self):
        phi = -37.0
        nu = fd.fd6h(phi)
        true_nu = 5.11982857544643944926199172506e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1126_fd6h(self):
        phi = -36.0
        nu = fd.fd6h(phi)
        true_nu = 1.39171369814614161281166006576e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1127_fd6h(self):
        phi = -35.0
        nu = fd.fd6h(phi)
        true_nu = 3.78307005608819348230404761877e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1128_fd6h(self):
        phi = -34.0
        nu = fd.fd6h(phi)
        true_nu = 1.02834505892520766962605301639e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1129_fd6h(self):
        phi = -33.0
        nu = fd.fd6h(phi)
        true_nu = 2.79533168706203760456479308731e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1130_fd6h(self):
        phi = -32.0
        nu = fd.fd6h(phi)
        true_nu = 7.59849932945649941958170293620e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1131_fd6h(self):
        phi = -31.0
        nu = fd.fd6h(phi)
        true_nu = 2.06548626508198143104219272231e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1132_fd6h(self):
        phi = -30.0
        nu = fd.fd6h(phi)
        true_nu = 5.61457378130407192603413922268e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1133_fd6h(self):
        phi = -29.0
        nu = fd.fd6h(phi)
        true_nu = 1.52619938842612948280106019966e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1134_fd6h(self):
        phi = -28.0
        nu = fd.fd6h(phi)
        true_nu = 4.14864006416394252216440511464e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1135_fd6h(self):
        phi = -27.0
        nu = fd.fd6h(phi)
        true_nu = 1.12771728992331750328350476997e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1136_fd6h(self):
        phi = -26.0
        nu = fd.fd6h(phi)
        true_nu = 3.06545341683701597727351571465e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1137_fd6h(self):
        phi = -25.0
        nu = fd.fd6h(phi)
        true_nu = 8.33276631897117954486721339772e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1138_fd6h(self):
        phi = -24.0
        nu = fd.fd6h(phi)
        true_nu = 2.26508072656211428567674307510e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1139_fd6h(self):
        phi = -23.0
        nu = fd.fd6h(phi)
        true_nu = 6.15712777898164436726649038149e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1140_fd6h(self):
        phi = -22.0
        nu = fd.fd6h(phi)
        true_nu = 1.67368085569217563872870387553e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1141_fd6h(self):
        phi = -21.0
        nu = fd.fd6h(phi)
        true_nu = 4.54953625653153695188633085941e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1142_fd6h(self):
        phi = -20.0
        nu = fd.fd6h(phi)
        true_nu = 1.23669217330382141227099268341e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1143_fd6h(self):
        phi = -19.0
        nu = fd.fd6h(phi)
        true_nu = 3.36167786134518572829258761548e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1144_fd6h(self):
        phi = -18.0
        nu = fd.fd6h(phi)
        true_nu = 9.13798783812936647443621126118e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1145_fd6h(self):
        phi = -17.0
        nu = fd.fd6h(phi)
        true_nu = 2.48396262484394343006713518804e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1146_fd6h(self):
        phi = -16.0
        nu = fd.fd6h(phi)
        true_nu = 6.75211043566492711740041251920e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1147_fd6h(self):
        phi = -15.0
        nu = fd.fd6h(phi)
        true_nu = 1.83541388791987071746215072738e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1148_fd6h(self):
        phi = -14.0
        nu = fd.fd6h(phi)
        true_nu = 4.98917205533144588316890237046e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1149_fd6h(self):
        phi = -13.0
        nu = fd.fd6h(phi)
        true_nu = 0.0000135619745259787958543659261839
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1150_fd6h(self):
        phi = -12.0
        nu = fd.fd6h(phi)
        true_nu = 0.0000368652599632318991226694780875
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1151_fd6h(self):
        phi = -11.0
        nu = fd.fd6h(phi)
        true_nu = 0.000100210100136765574144857488041
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1152_fd6h(self):
        phi = -10.0
        nu = fd.fd6h(phi)
        true_nu = 0.000272398805649232167754923547503
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1153_fd6h(self):
        phi = -9.0
        nu = fd.fd6h(phi)
        true_nu = 0.000740453113416891950423981476487
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1154_fd6h(self):
        phi = -8.0
        nu = fd.fd6h(phi)
        true_nu = 0.00201273356952065049388319685149
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1155_fd6h(self):
        phi = -7.0
        nu = fd.fd6h(phi)
        true_nu = 0.00547098002620834811589217349031
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1156_fd6h(self):
        phi = -6.0
        nu = fd.fd6h(phi)
        true_nu = 0.0148702101076284003166736244497
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1157_fd6h(self):
        phi = -5.0
        nu = fd.fd6h(phi)
        true_nu = 0.0404106796321076236252221037883
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1158_fd6h(self):
        phi = -4.0
        nu = fd.fd6h(phi)
        true_nu = 0.109768487355853479181555937147
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1159_fd6h(self):
        phi = -3.0
        nu = fd.fd6h(phi)
        true_nu = 0.297801878470920452622005445237
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1160_fd6h(self):
        phi = -2.0
        nu = fd.fd6h(phi)
        true_nu = 0.805319493023208129186965350861
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1161_fd6h(self):
        phi = -1.0
        nu = fd.fd6h(phi)
        true_nu = 2.15983966101798607818152087307
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1162_fd6h(self):
        phi = 0.0
        nu = fd.fd6h(phi)
        true_nu = 5.68219697698347550545901940684
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1163_fd6h(self):
        phi = 1.0
        nu = fd.fd6h(phi)
        true_nu = 14.3893564934936442421537634406
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1164_fd6h(self):
        phi = 2.0
        nu = fd.fd6h(phi)
        true_nu = 34.2982832631224601194000554626
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1165_fd6h(self):
        phi = 3.0
        nu = fd.fd6h(phi)
        true_nu = 75.7298118803981443430512428679
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1166_fd6h(self):
        phi = 4.0
        nu = fd.fd6h(phi)
        true_nu = 154.211460675325966482412410876
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1167_fd6h(self):
        phi = 5.0
        nu = fd.fd6h(phi)
        true_nu = 290.944038287951826122723954208
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1168_fd6h(self):
        phi = 6.0
        nu = fd.fd6h(phi)
        true_nu = 513.002402963467777749622203187
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1169_fd6h(self):
        phi = 7.0
        nu = fd.fd6h(phi)
        true_nu = 853.414230800630028824247176137
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1170_fd6h(self):
        phi = 8.0
        nu = fd.fd6h(phi)
        true_nu = 1351.18972205525690616312786761
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1171_fd6h(self):
        phi = 9.0
        nu = fd.fd6h(phi)
        true_nu = 2051.33263174497255818176450033
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1172_fd6h(self):
        phi = 10.0
        nu = fd.fd6h(phi)
        true_nu = 3004.84434160962923272047483388
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1173_fd6h(self):
        phi = 11.0
        nu = fd.fd6h(phi)
        true_nu = 4268.72536000977301068483059945
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1174_fd6h(self):
        phi = 12.0
        nu = fd.fd6h(phi)
        true_nu = 5905.97587396714080833510226814
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1175_fd6h(self):
        phi = 13.0
        nu = fd.fd6h(phi)
        true_nu = 7985.59595228404322832363667394
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1176_fd6h(self):
        phi = 14.0
        nu = fd.fd6h(phi)
        true_nu = 10582.5856202715520403252522736
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1177_fd6h(self):
        phi = 15.0
        nu = fd.fd6h(phi)
        true_nu = 13777.9448872411059077099275588
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1178_fd6h(self):
        phi = 16.0
        nu = fd.fd6h(phi)
        true_nu = 17658.6737566181938106552401751
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1179_fd6h(self):
        phi = 17.0
        nu = fd.fd6h(phi)
        true_nu = 22317.7722296629830089481076453
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1180_fd6h(self):
        phi = 18.0
        nu = fd.fd6h(phi)
        true_nu = 27854.2403068390631688808119160
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1181_fd6h(self):
        phi = 19.0
        nu = fd.fd6h(phi)
        true_nu = 34373.0779883169794030970918070
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1182_fd6h(self):
        phi = 20.0
        nu = fd.fd6h(phi)
        true_nu = 41985.2852741594717530447780247
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1183_fd6h(self):
        phi = 21.0
        nu = fd.fd6h(phi)
        true_nu = 50807.8621643896209902073917673
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1184_fd6h(self):
        phi = 22.0
        nu = fd.fd6h(phi)
        true_nu = 60963.8086590159180559131726851
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1185_fd6h(self):
        phi = 23.0
        nu = fd.fd6h(phi)
        true_nu = 72582.1247580414865929147427438
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1186_fd6h(self):
        phi = 24.0
        nu = fd.fd6h(phi)
        true_nu = 85797.8104614674757251625952353
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1187_fd6h(self):
        phi = 25.0
        nu = fd.fd6h(phi)
        true_nu = 100751.865769294308191733506764
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1188_fd6h(self):
        phi = 26.0
        nu = fd.fd6h(phi)
        true_nu = 117591.290681522139509642807627
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1189_fd6h(self):
        phi = 27.0
        nu = fd.fd6h(phi)
        true_nu = 136469.085198151026890403190775
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1190_fd6h(self):
        phi = 28.0
        nu = fd.fd6h(phi)
        true_nu = 157544.249319180991380953974347
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1191_fd6h(self):
        phi = 29.0
        nu = fd.fd6h(phi)
        true_nu = 180981.783044612040724031433078
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1192_fd6h(self):
        phi = 30.0
        nu = fd.fd6h(phi)
        true_nu = 206952.686374444177768029060858
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1193_fd6h(self):
        phi = 31.0
        nu = fd.fd6h(phi)
        true_nu = 235633.959308677403560812264456
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1194_fd6h(self):
        phi = 32.0
        nu = fd.fd6h(phi)
        true_nu = 267208.601847311718487869184136
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1195_fd6h(self):
        phi = 33.0
        nu = fd.fd6h(phi)
        true_nu = 301865.613990347122691012981518
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1196_fd6h(self):
        phi = 34.0
        nu = fd.fd6h(phi)
        true_nu = 339799.995737783616222413803247
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1197_fd6h(self):
        phi = 35.0
        nu = fd.fd6h(phi)
        true_nu = 381212.747089621199101263973720
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1198_fd6h(self):
        phi = 36.0
        nu = fd.fd6h(phi)
        true_nu = 426310.868045859871334623954509
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1199_fd6h(self):
        phi = 37.0
        nu = fd.fd6h(phi)
        true_nu = 475307.358606499632925091144271
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1200_fd6h(self):
        phi = 38.0
        nu = fd.fd6h(phi)
        true_nu = 528421.218771540483873621072573
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1201_fd6h(self):
        phi = 39.0
        nu = fd.fd6h(phi)
        true_nu = 585877.448540982424180565259099
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1202_fd6h(self):
        phi = 40.0
        nu = fd.fd6h(phi)
        true_nu = 647907.047914825453846053020713
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1203_fd6h(self):
        phi = 41.0
        nu = fd.fd6h(phi)
        true_nu = 714747.016893069572870131930431
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1204_fd6h(self):
        phi = 42.0
        nu = fd.fd6h(phi)
        true_nu = 786640.355475714781252819489387
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1205_fd6h(self):
        phi = 43.0
        nu = fd.fd6h(phi)
        true_nu = 863836.063662761078994122135890
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1206_fd6h(self):
        phi = 44.0
        nu = fd.fd6h(phi)
        true_nu = 946589.141454208466094042238459
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1207_fd6h(self):
        phi = 45.0
        nu = fd.fd6h(phi)
        true_nu = 1.03516058885005694255258066843e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1208_fd6h(self):
        phi = 46.0
        nu = fd.fd6h(phi)
        true_nu = 1.12981740585030650836973774633e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1209_fd6h(self):
        phi = 47.0
        nu = fd.fd6h(phi)
        true_nu = 1.23083259245495716354551359010e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1210_fd6h(self):
        phi = 48.0
        nu = fd.fd6h(phi)
        true_nu = 1.33848514866400890807990824312e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1211_fd6h(self):
        phi = 49.0
        nu = fd.fd6h(phi)
        true_nu = 1.45306007447746174197292172134e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1212_fd6h(self):
        phi = 50.0
        nu = fd.fd6h(phi)
        true_nu = 1.57484836989531566522455403063e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd6h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd6h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1213_fd7h(self):
        phi = -50.0
        nu = fd.fd7h(phi)
        true_nu = 2.24346943764370522959462119730e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1214_fd7h(self):
        phi = -49.0
        nu = fd.fd7h(phi)
        true_nu = 6.09838220505011702022230373104e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1215_fd7h(self):
        phi = -48.0
        nu = fd.fd7h(phi)
        true_nu = 1.65771215309857362199773566183e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1216_fd7h(self):
        phi = -47.0
        nu = fd.fd7h(phi)
        true_nu = 4.50612882258357143487484186097e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1217_fd7h(self):
        phi = -46.0
        nu = fd.fd7h(phi)
        true_nu = 1.22489280951244752086832152643e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1218_fd7h(self):
        phi = -45.0
        nu = fd.fd7h(phi)
        true_nu = 3.32960386590783284381111182749e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1219_fd7h(self):
        phi = -44.0
        nu = fd.fd7h(phi)
        true_nu = 9.05080168466424953245581762300e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1220_fd7h(self):
        phi = -43.0
        nu = fd.fd7h(phi)
        true_nu = 2.46026297524093431747227590359e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1221_fd7h(self):
        phi = -42.0
        nu = fd.fd7h(phi)
        true_nu = 6.68768813882801767333672936110e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1222_fd7h(self):
        phi = -41.0
        nu = fd.fd7h(phi)
        true_nu = 1.81790211421772930336048721232e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1223_fd7h(self):
        phi = -40.0
        nu = fd.fd7h(phi)
        true_nu = 4.94157028299533330404447693968e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1224_fd7h(self):
        phi = -39.0
        nu = fd.fd7h(phi)
        true_nu = 1.34325807043194362184607877456e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1225_fd7h(self):
        phi = -38.0
        nu = fd.fd7h(phi)
        true_nu = 3.65135400378611267187368356462e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1226_fd7h(self):
        phi = -37.0
        nu = fd.fd7h(phi)
        true_nu = 9.92540923776296990910633302000e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1227_fd7h(self):
        phi = -36.0
        nu = fd.fd7h(phi)
        true_nu = 2.69800595710306241200044417467e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1228_fd7h(self):
        phi = -35.0
        nu = fd.fd7h(phi)
        true_nu = 7.33394056626750872809243765745e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1229_fd7h(self):
        phi = -34.0
        nu = fd.fd7h(phi)
        true_nu = 1.99357173722836082812470451567e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1230_fd7h(self):
        phi = -33.0
        nu = fd.fd7h(phi)
        true_nu = 5.41908982703738322734284061985e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1231_fd7h(self):
        phi = -32.0
        nu = fd.fd7h(phi)
        true_nu = 1.47306134036229840571537066404e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1232_fd7h(self):
        phi = -31.0
        nu = fd.fd7h(phi)
        true_nu = 4.00419587371235663145314286733e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1233_fd7h(self):
        phi = -30.0
        nu = fd.fd7h(phi)
        true_nu = 1.08845328811029605138114246308e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1234_fd7h(self):
        phi = -29.0
        nu = fd.fd7h(phi)
        true_nu = 2.95872279419669448731639426740e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1235_fd7h(self):
        phi = -28.0
        nu = fd.fd7h(phi)
        true_nu = 8.04264240691229073148405437947e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1236_fd7h(self):
        phi = -27.0
        nu = fd.fd7h(phi)
        true_nu = 2.18621687075026502536281093531e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1237_fd7h(self):
        phi = -26.0
        nu = fd.fd7h(phi)
        true_nu = 5.94275359283019438678831879376e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1238_fd7h(self):
        phi = -25.0
        nu = fd.fd7h(phi)
        true_nu = 1.61540791023937538465148781264e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1239_fd7h(self):
        phi = -24.0
        nu = fd.fd7h(phi)
        true_nu = 4.39113396794806355025510769688e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1240_fd7h(self):
        phi = -23.0
        nu = fd.fd7h(phi)
        true_nu = 1.19363396713682660605700459328e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1241_fd7h(self):
        phi = -22.0
        nu = fd.fd7h(phi)
        true_nu = 3.24463352267423257712313236595e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1242_fd7h(self):
        phi = -21.0
        nu = fd.fd7h(phi)
        true_nu = 8.81982834450759837483635183247e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1243_fd7h(self):
        phi = -20.0
        nu = fd.fd7h(phi)
        true_nu = 2.39747791176225491089100438154e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1244_fd7h(self):
        phi = -19.0
        nu = fd.fd7h(phi)
        true_nu = 6.51702064065523186530072230415e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1245_fd7h(self):
        phi = -18.0
        nu = fd.fd7h(phi)
        true_nu = 1.77150987756484802783487731662e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1246_fd7h(self):
        phi = -17.0
        nu = fd.fd7h(phi)
        true_nu = 4.81546310355098335861769988192e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1247_fd7h(self):
        phi = -16.0
        nu = fd.fd7h(phi)
        true_nu = 1.30897858088461275995324409014e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1248_fd7h(self):
        phi = -15.0
        nu = fd.fd7h(phi)
        true_nu = 3.55817265985367249568139202935e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1249_fd7h(self):
        phi = -14.0
        nu = fd.fd7h(phi)
        true_nu = 9.67211585912043943490801570404e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1250_fd7h(self):
        phi = -13.0
        nu = fd.fd7h(phi)
        true_nu = 0.0000262915351224280964236792821753
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1251_fd7h(self):
        phi = -12.0
        nu = fd.fd7h(phi)
        true_nu = 0.0000714677898985136935426852509580
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1252_fd7h(self):
        phi = -11.0
        nu = fd.fd7h(phi)
        true_nu = 0.000194269503959361798036830212154
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1253_fd7h(self):
        phi = -10.0
        nu = fd.fd7h(phi)
        true_nu = 0.000528078592682665068367727122663
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1254_fd7h(self):
        phi = -9.0
        nu = fd.fd7h(phi)
        true_nu = 0.00143546149372412830492287578803
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1255_fd7h(self):
        phi = -8.0
        nu = fd.fd7h(phi)
        true_nu = 0.00390195232886317986017502340784
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1256_fd7h(self):
        phi = -7.0
        nu = fd.fd7h(phi)
        true_nu = 0.0106063359647230755986699935991
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1257_fd7h(self):
        phi = -6.0
        nu = fd.fd7h(phi)
        true_nu = 0.0288290148824328073023984870580
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1258_fd7h(self):
        phi = -5.0
        nu = fd.fd7h(phi)
        true_nu = 0.0783506567150513110313642297682
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1259_fd7h(self):
        phi = -4.0
        nu = fd.fd7h(phi)
        true_nu = 0.212870597714748165947046128488
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1260_fd7h(self):
        phi = -3.0
        nu = fd.fd7h(phi)
        true_nu = 0.577845537508748185662714453145
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1261_fd7h(self):
        phi = -2.0
        nu = fd.fd7h(phi)
        true_nu = 1.56496626323607036080231375795
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1262_fd7h(self):
        phi = -1.0
        nu = fd.fd7h(phi)
        true_nu = 4.21326407192635907620576721812
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1263_fd7h(self):
        phi = 0.0
        nu = fd.fd7h(phi)
        true_nu = 11.1837167516933201006068243360
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1264_fd7h(self):
        phi = 1.0
        nu = fd.fd7h(phi)
        true_nu = 28.8313184159937554354489739653
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1265_fd7h(self):
        phi = 2.0
        nu = fd.fd7h(phi)
        true_nu = 70.7645563970973811925248734031
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1266_fd7h(self):
        phi = 3.0
        nu = fd.fd7h(phi)
        true_nu = 162.566440439895142344117981018
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1267_fd7h(self):
        phi = 4.0
        nu = fd.fd7h(phi)
        true_nu = 346.758061730937232796666485976
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1268_fd7h(self):
        phi = 5.0
        nu = fd.fd7h(phi)
        true_nu = 687.309406537756695824288483445
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1269_fd7h(self):
        phi = 6.0
        nu = fd.fd7h(phi)
        true_nu = 1273.52819240579041916847620999
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1270_fd7h(self):
        phi = 7.0
        nu = fd.fd7h(phi)
        true_nu = 2223.42343401084511036724299776
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1271_fd7h(self):
        phi = 8.0
        nu = fd.fd7h(phi)
        true_nu = 3686.67896661161164505543576287
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1272_fd7h(self):
        phi = 9.0
        nu = fd.fd7h(phi)
        true_nu = 5847.34110135846729815696620389
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1273_fd7h(self):
        phi = 10.0
        nu = fd.fd7h(phi)
        true_nu = 8926.29089605571892802721358220
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1274_fd7h(self):
        phi = 11.0
        nu = fd.fd7h(phi)
        true_nu = 13183.5480260051329787039496807
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1275_fd7h(self):
        phi = 12.0
        nu = fd.fd7h(phi)
        true_nu = 18920.4383948936691491231530333
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1276_fd7h(self):
        phi = 13.0
        nu = fd.fd7h(phi)
        true_nu = 26481.6483355572472690289483668
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1277_fd7h(self):
        phi = 14.0
        nu = fd.fd7h(phi)
        true_nu = 36257.1822919465790069278995652
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1278_fd7h(self):
        phi = 15.0
        nu = fd.fd7h(phi)
        true_nu = 48684.2369075854149991069893087
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1279_fd7h(self):
        phi = 16.0
        nu = fd.fd7h(phi)
        true_nu = 64249.0017001966536705095625248
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1280_fd7h(self):
        phi = 17.0
        nu = fd.fd7h(phi)
        true_nu = 83488.3945307826484335218944328
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1281_fd7h(self):
        phi = 18.0
        nu = fd.fd7h(phi)
        true_nu = 106991.738614267722616481686832
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1282_fd7h(self):
        phi = 19.0
        nu = fd.fd7h(phi)
        true_nu = 135402.386706349919052824861632
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1283_fd7h(self):
        phi = 20.0
        nu = fd.fd7h(phi)
        true_nu = 169419.297235024533878102886693
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1284_fd7h(self):
        phi = 21.0
        nu = fd.fd7h(phi)
        true_nu = 209798.566457997894227005470655
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1285_fd7h(self):
        phi = 22.0
        nu = fd.fd7h(phi)
        true_nu = 257354.920173173979948225879804
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1286_fd7h(self):
        phi = 23.0
        nu = fd.fd7h(phi)
        true_nu = 312963.168056596809313500036901
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1287_fd7h(self):
        phi = 24.0
        nu = fd.fd7h(phi)
        true_nu = 377559.623327745922163697813793
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1288_fd7h(self):
        phi = 25.0
        nu = fd.fd7h(phi)
        true_nu = 452143.490129115349417137968131
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1289_fd7h(self):
        phi = 26.0
        nu = fd.fd7h(phi)
        true_nu = 537778.220743017445149201789341
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1290_fd7h(self):
        phi = 27.0
        nu = fd.fd7h(phi)
        true_nu = 635592.844544022647707859018227
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1291_fd7h(self):
        phi = 28.0
        nu = fd.fd7h(phi)
        true_nu = 746783.270393043428478041249695
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1292_fd7h(self):
        phi = 29.0
        nu = fd.fd7h(phi)
        true_nu = 872613.564013076120712278856032
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1293_fd7h(self):
        phi = 30.0
        nu = fd.fd7h(phi)
        true_nu = 1.01441720174251448518077893817e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1294_fd7h(self):
        phi = 31.0
        nu = fd.fd7h(phi)
        true_nu = 1.17359830193614451138911941287e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1295_fd7h(self):
        phi = 32.0
        nu = fd.fd7h(phi)
        true_nu = 1.35163283517352358917799416654e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1296_fd7h(self):
        phi = 33.0
        nu = fd.fd7h(phi)
        true_nu = 1.55006981433708600516906192439e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1297_fd7h(self):
        phi = 34.0
        nu = fd.fd7h(phi)
        true_nu = 1.77053246553607495283957601257e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1298_fd7h(self):
        phi = 35.0
        nu = fd.fd7h(phi)
        true_nu = 2.01471938077569105970708291552e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1299_fd7h(self):
        phi = 36.0
        nu = fd.fd7h(phi)
        true_nu = 2.28440565320235071200772206048e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1300_fd7h(self):
        phi = 37.0
        nu = fd.fd7h(phi)
        true_nu = 2.58144399569456305588659227057e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1301_fd7h(self):
        phi = 38.0
        nu = fd.fd7h(phi)
        true_nu = 2.90776584351373717171959535703e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1302_fd7h(self):
        phi = 39.0
        nu = fd.fd7h(phi)
        true_nu = 3.26538244167943872799464247908e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1303_fd7h(self):
        phi = 40.0
        nu = fd.fd7h(phi)
        true_nu = 3.65638591768856441713722521720e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1304_fd7h(self):
        phi = 41.0
        nu = fd.fd7h(phi)
        true_nu = 4.08295034015702598540483913072e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1305_fd7h(self):
        phi = 42.0
        nu = fd.fd7h(phi)
        true_nu = 4.54733276392534788227808946786e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1306_fd7h(self):
        phi = 43.0
        nu = fd.fd7h(phi)
        true_nu = 5.05187426213566519561527935786e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1307_fd7h(self):
        phi = 44.0
        nu = fd.fd7h(phi)
        true_nu = 5.59900094575660001606166589807e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1308_fd7h(self):
        phi = 45.0
        nu = fd.fd7h(phi)
        true_nu = 6.19122497100408089974453344543e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1309_fd7h(self):
        phi = 46.0
        nu = fd.fd7h(phi)
        true_nu = 6.83114553508007837705196175796e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1310_fd7h(self):
        phi = 47.0
        nu = fd.fd7h(phi)
        true_nu = 7.52144986062722063811488429840e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1311_fd7h(self):
        phi = 48.0
        nu = fd.fd7h(phi)
        true_nu = 8.26491416927511818291547489122e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1312_fd7h(self):
        phi = 49.0
        nu = fd.fd7h(phi)
        true_nu = 9.06440464463378014880406377617e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1313_fd7h(self):
        phi = 50.0
        nu = fd.fd7h(phi)
        true_nu = 9.92287838507058571669917992031e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd7h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd7h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1314_fd8h(self):
        phi = -50.0
        nu = fd.fd8h(phi)
        true_nu = 4.62899963511340267924159485910e-21
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1315_fd8h(self):
        phi = -49.0
        nu = fd.fd8h(phi)
        true_nu = 1.25829255920723134492121265679e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1316_fd8h(self):
        phi = -48.0
        nu = fd.fd8h(phi)
        true_nu = 3.42039379857824425508461813533e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1317_fd8h(self):
        phi = -47.0
        nu = fd.fd8h(phi)
        true_nu = 9.29759430884924907103442040412e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1318_fd8h(self):
        phi = -46.0
        nu = fd.fd8h(phi)
        true_nu = 2.52734816581291497090236616360e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1319_fd8h(self):
        phi = -45.0
        nu = fd.fd8h(phi)
        true_nu = 6.87004459331854474672214640057e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1320_fd8h(self):
        phi = -44.0
        nu = fd.fd8h(phi)
        true_nu = 1.86747173787211116376665506361e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1321_fd8h(self):
        phi = -43.0
        nu = fd.fd8h(phi)
        true_nu = 5.07631449021859316788180907206e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1322_fd8h(self):
        phi = -42.0
        nu = fd.fd8h(phi)
        true_nu = 1.37988534343045435357465865664e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1323_fd8h(self):
        phi = -41.0
        nu = fd.fd8h(phi)
        true_nu = 3.75091725440397304323492413292e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1324_fd8h(self):
        phi = -40.0
        nu = fd.fd8h(phi)
        true_nu = 1.01960502126998135874365249380e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1325_fd8h(self):
        phi = -39.0
        nu = fd.fd8h(phi)
        true_nu = 2.77157380152378863570277498357e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1326_fd8h(self):
        phi = -38.0
        nu = fd.fd8h(phi)
        true_nu = 7.53391870091527110151089915077e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1327_fd8h(self):
        phi = -37.0
        nu = fd.fd8h(phi)
        true_nu = 2.04793143017857578516576432376e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1328_fd8h(self):
        phi = -36.0
        nu = fd.fd8h(phi)
        true_nu = 5.56685479258456649159803646321e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1329_fd8h(self):
        phi = -35.0
        nu = fd.fd8h(phi)
        true_nu = 1.51322802243527742273749206682e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1330_fd8h(self):
        phi = -34.0
        nu = fd.fd8h(phi)
        true_nu = 4.11338023570083089881537044387e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1331_fd8h(self):
        phi = -33.0
        nu = fd.fd8h(phi)
        true_nu = 1.11813267482481520461506808269e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1332_fd8h(self):
        phi = -32.0
        nu = fd.fd8h(phi)
        true_nu = 3.03939973178260097069084908597e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1333_fd8h(self):
        phi = -31.0
        nu = fd.fd8h(phi)
        true_nu = 8.26194506032793461215525264403e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1334_fd8h(self):
        phi = -30.0
        nu = fd.fd8h(phi)
        true_nu = 2.24582951252163533779672771130e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1335_fd8h(self):
        phi = -29.0
        nu = fd.fd8h(phi)
        true_nu = 6.10479755370456645796618313633e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1336_fd8h(self):
        phi = -28.0
        nu = fd.fd8h(phi)
        true_nu = 1.65945602566561286556239118034e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1337_fd8h(self):
        phi = -27.0
        nu = fd.fd8h(phi)
        true_nu = 4.51086915969353496027693400926e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1338_fd8h(self):
        phi = -26.0
        nu = fd.fd8h(phi)
        true_nu = 1.22618136673500216183963110029e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1339_fd8h(self):
        phi = -25.0
        nu = fd.fd8h(phi)
        true_nu = 3.33310652758991838033285300629e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1340_fd8h(self):
        phi = -24.0
        nu = fd.fd8h(phi)
        true_nu = 9.06032290625914587332742303840e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1341_fd8h(self):
        phi = -23.0
        nu = fd.fd8h(phi)
        true_nu = 2.46285111160055570992454805227e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1342_fd8h(self):
        phi = -22.0
        nu = fd.fd8h(phi)
        true_nu = 6.69472342282706104671903152512e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1343_fd8h(self):
        phi = -21.0
        nu = fd.fd8h(phi)
        true_nu = 1.81981450265573619772812246701e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1344_fd8h(self):
        phi = -20.0
        nu = fd.fd8h(phi)
        true_nu = 4.94676869353391221805787179460e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1345_fd8h(self):
        phi = -19.0
        nu = fd.fd8h(phi)
        true_nu = 1.34467114477350925037322152535e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1346_fd8h(self):
        phi = -18.0
        nu = fd.fd8h(phi)
        true_nu = 3.65519513699138870547912983598e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1347_fd8h(self):
        phi = -17.0
        nu = fd.fd8h(phi)
        true_nu = 9.93585051223008681667612574812e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1348_fd8h(self):
        phi = -16.0
        nu = fd.fd8h(phi)
        true_nu = 2.70084418376409472726691518972e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1349_fd8h(self):
        phi = -15.0
        nu = fd.fd8h(phi)
        true_nu = 7.34165562186164948179283816434e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1350_fd8h(self):
        phi = -14.0
        nu = fd.fd8h(phi)
        true_nu = 0.0000199566887399056779824142919435
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1351_fd8h(self):
        phi = -13.0
        nu = fd.fd8h(phi)
        true_nu = 0.0000542479019357296733360917526755
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1352_fd8h(self):
        phi = -12.0
        nu = fd.fd8h(phi)
        true_nu = 0.000147461068166390860949199238762
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1353_fd8h(self):
        phi = -11.0
        nu = fd.fd8h(phi)
        true_nu = 0.000400840609756248993413419038067
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1354_fd8h(self):
        phi = -10.0
        nu = fd.fd8h(phi)
        true_nu = 0.00108959676844366160512585211406
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1355_fd8h(self):
        phi = -9.0
        nu = fd.fd8h(phi)
        true_nu = 0.00296182387578112769301771439832
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1356_fd8h(self):
        phi = -8.0
        nu = fd.fd8h(phi)
        true_nu = 0.00805101867200747584858736962634
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1357_fd8h(self):
        phi = -7.0
        nu = fd.fd8h(phi)
        true_nu = 0.0218845436016423462392393714427
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1358_fd8h(self):
        phi = -6.0
        nu = fd.fd8h(phi)
        true_nu = 0.0594854455840390571292994614359
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1359_fd8h(self):
        phi = -5.0
        nu = fd.fd8h(phi)
        true_nu = 0.161676708195102294523180423369
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1360_fd8h(self):
        phi = -4.0
        nu = fd.fd8h(phi)
        true_nu = 0.439324340572652390220390446263
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1361_fd8h(self):
        phi = -3.0
        nu = fd.fd8h(phi)
        true_nu = 1.19304262361726325156776925122
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1362_fd8h(self):
        phi = -2.0
        nu = fd.fd8h(phi)
        true_nu = 3.23454735195516276792345415871
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1363_fd8h(self):
        phi = -1.0
        nu = fd.fd8h(phi)
        true_nu = 8.73213828890594144763998097971
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1364_fd8h(self):
        phi = 0.0
        nu = fd.fd8h(phi)
        true_nu = 23.3308744907258233424557234453
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1365_fd8h(self):
        phi = 1.0
        nu = fd.fd8h(phi)
        true_nu = 60.9694503721666512372017969010
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1366_fd8h(self):
        phi = 2.0
        nu = fd.fd8h(phi)
        true_nu = 153.187589122834016822385050001
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1367_fd8h(self):
        phi = 3.0
        nu = fd.fd8h(phi)
        true_nu = 363.818649290829130521605073013
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1368_fd8h(self):
        phi = 4.0
        nu = fd.fd8h(phi)
        true_nu = 808.172748717189836301847294127
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1369_fd8h(self):
        phi = 5.0
        nu = fd.fd8h(phi)
        true_nu = 1674.91658921164734074909154002
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1370_fd8h(self):
        phi = 6.0
        nu = fd.fd8h(phi)
        true_nu = 3249.22797409765850443132893497
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1371_fd8h(self):
        phi = 7.0
        nu = fd.fd8h(phi)
        true_nu = 5936.47445497044294149209793479
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1372_fd8h(self):
        phi = 8.0
        nu = fd.fd8h(phi)
        true_nu = 10286.0936264507821817207320907
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1373_fd8h(self):
        phi = 9.0
        nu = fd.fd8h(phi)
        true_nu = 17015.5488830961143062743050409
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1374_fd8h(self):
        phi = 10.0
        nu = fd.fd8h(phi)
        true_nu = 27034.3131151483522299879873450
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1375_fd8h(self):
        phi = 11.0
        nu = fd.fd8h(phi)
        true_nu = 41467.8627067151131485085254684
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1376_fd8h(self):
        phi = 12.0
        nu = fd.fd8h(phi)
        true_nu = 61681.6753273064229438122604441
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1377_fd8h(self):
        phi = 13.0
        nu = fd.fd8h(phi)
        true_nu = 89305.2291193163973120169958389
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1378_fd8h(self):
        phi = 14.0
        nu = fd.fd8h(phi)
        true_nu = 126256.002399104971363238317025
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1379_fd8h(self):
        phi = 15.0
        nu = fd.fd8h(phi)
        true_nu = 174763.473547030729574894336560
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1380_fd8h(self):
        phi = 16.0
        nu = fd.fd8h(phi)
        true_nu = 237393.120966996070983626899302
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1381_fd8h(self):
        phi = 17.0
        nu = fd.fd8h(phi)
        true_nu = 317070.423071564683649521338176
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1382_fd8h(self):
        phi = 18.0
        nu = fd.fd8h(phi)
        true_nu = 417104.858276486566296513738675
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1383_fd8h(self):
        phi = 19.0
        nu = fd.fd8h(phi)
        true_nu = 541213.904998683895902364304387
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1384_fd8h(self):
        phi = 20.0
        nu = fd.fd8h(phi)
        true_nu = 693547.041655510069734926067560
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1385_fd8h(self):
        phi = 21.0
        nu = fd.fd8h(phi)
        true_nu = 878709.746664477122142627820056
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1386_fd8h(self):
        phi = 22.0
        nu = fd.fd8h(phi)
        true_nu = 1.10178749844315544679461672125e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1387_fd8h(self):
        phi = 23.0
        nu = fd.fd8h(phi)
        true_nu = 1.36836977540913690655435556146e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1388_fd8h(self):
        phi = 24.0
        nu = fd.fd8h(phi)
        true_nu = 1.68457405598002126236051742670e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1389_fd8h(self):
        phi = 25.0
        nu = fd.fd8h(phi)
        true_nu = 2.05706981857341118069127051079e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1390_fd8h(self):
        phi = 26.0
        nu = fd.fd8h(phi)
        true_nu = 2.49310254160691039691302882541e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1391_fd8h(self):
        phi = 27.0
        nu = fd.fd8h(phi)
        true_nu = 3.00051770349812303961421693603e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1392_fd8h(self):
        phi = 28.0
        nu = fd.fd8h(phi)
        true_nu = 3.58778478266465338204155290796e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1393_fd8h(self):
        phi = 29.0
        nu = fd.fd8h(phi)
        true_nu = 4.26402125752410575065856698020e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1394_fd8h(self):
        phi = 30.0
        nu = fd.fd8h(phi)
        true_nu = 5.03901660649408449150616051518e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1395_fd8h(self):
        phi = 31.0
        nu = fd.fd8h(phi)
        true_nu = 5.92325630799219395782734722376e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1396_fd8h(self):
        phi = 32.0
        nu = fd.fd8h(phi)
        true_nu = 6.92794584043603850551464988287e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1397_fd8h(self):
        phi = 33.0
        nu = fd.fd8h(phi)
        true_nu = 8.06503468224322249143529118398e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1398_fd8h(self):
        phi = 34.0
        nu = fd.fd8h(phi)
        true_nu = 9.34724031183135027281506587848e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1399_fd8h(self):
        phi = 35.0
        nu = fd.fd8h(phi)
        true_nu = 1.07880722076180262070116800067e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1400_fd8h(self):
        phi = 36.0
        nu = fd.fd8h(phi)
        true_nu = 1.24018558480208546514313670604e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1401_fd8h(self):
        phi = 37.0
        nu = fd.fd8h(phi)
        true_nu = 1.42037567114574399634982127829e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1402_fd8h(self):
        phi = 38.0
        nu = fd.fd8h(phi)
        true_nu = 1.62098042763453865006428703939e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1403_fd8h(self):
        phi = 39.0
        nu = fd.fd8h(phi)
        true_nu = 1.84369160211022986202984091525e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1404_fd8h(self):
        phi = 40.0
        nu = fd.fd8h(phi)
        true_nu = 2.09029214241457806798987871294e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1405_fd8h(self):
        phi = 41.0
        nu = fd.fd8h(phi)
        true_nu = 2.36265859638934370368782893703e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1406_fd8h(self):
        phi = 42.0
        nu = fd.fd8h(phi)
        true_nu = 2.66276351187628720486713212088e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1407_fd8h(self):
        phi = 43.0
        nu = fd.fd8h(phi)
        true_nu = 2.99267783671716900727123322296e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1408_fd8h(self):
        phi = 44.0
        nu = fd.fd8h(phi)
        true_nu = 3.35457331875374954664357882965e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1409_fd8h(self):
        phi = 45.0
        nu = fd.fd8h(phi)
        true_nu = 3.75072490582778925872761612622e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1410_fd8h(self):
        phi = 46.0
        nu = fd.fd8h(phi)
        true_nu = 4.18351314578104857926679251825e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1411_fd8h(self):
        phi = 47.0
        nu = fd.fd8h(phi)
        true_nu = 4.65542658645528794400455549237e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1412_fd8h(self):
        phi = 48.0
        nu = fd.fd8h(phi)
        true_nu = 5.16906417569226778868435256501e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1413_fd8h(self):
        phi = 49.0
        nu = fd.fd8h(phi)
        true_nu = 5.72713766133374854904963126360e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1414_fd8h(self):
        phi = 50.0
        nu = fd.fd8h(phi)
        true_nu = 6.33247399122149066084383911957e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd8h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd8h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1415_fd9h(self):
        phi = -50.0
        nu = fd.fd9h(phi)
        true_nu = 1.00956124693966735331758384151e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1416_fd9h(self):
        phi = -49.0
        nu = fd.fd9h(phi)
        true_nu = 2.74427199227255265910006847204e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1417_fd9h(self):
        phi = -48.0
        nu = fd.fd9h(phi)
        true_nu = 7.45970468894358129899004539907e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1418_fd9h(self):
        phi = -47.0
        nu = fd.fd9h(phi)
        true_nu = 2.02775797016260714569385242176e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1419_fd9h(self):
        phi = -46.0
        nu = fd.fd9h(phi)
        true_nu = 5.51201764280601384390872949320e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1420_fd9h(self):
        phi = -45.0
        nu = fd.fd9h(phi)
        true_nu = 1.49832173965852477971594806064e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1421_fd9h(self):
        phi = -44.0
        nu = fd.fd9h(phi)
        true_nu = 4.07286075809891228961212082161e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1422_fd9h(self):
        phi = -43.0
        nu = fd.fd9h(phi)
        true_nu = 1.10711833885842044286769863225e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1423_fd9h(self):
        phi = -42.0
        nu = fd.fd9h(phi)
        true_nu = 3.00945966247260795303976270328e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1424_fd9h(self):
        phi = -41.0
        nu = fd.fd9h(phi)
        true_nu = 8.18055951397978186540470925275e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1425_fd9h(self):
        phi = -40.0
        nu = fd.fd9h(phi)
        true_nu = 2.22370662734789998702876786927e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1426_fd9h(self):
        phi = -39.0
        nu = fd.fd9h(phi)
        true_nu = 6.04466131694374629984984393412e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1427_fd9h(self):
        phi = -38.0
        nu = fd.fd9h(phi)
        true_nu = 1.64310930170375070348291171087e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1428_fd9h(self):
        phi = -37.0
        nu = fd.fd9h(phi)
        true_nu = 4.46643415699333646751955689306e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1429_fd9h(self):
        phi = -36.0
        nu = fd.fd9h(phi)
        true_nu = 1.21410268069637809162304645094e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1430_fd9h(self):
        phi = -35.0
        nu = fd.fd9h(phi)
        true_nu = 3.30027325482037897362255936392e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1431_fd9h(self):
        phi = -34.0
        nu = fd.fd9h(phi)
        true_nu = 8.97107281752762406631708111045e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1432_fd9h(self):
        phi = -33.0
        nu = fd.fd9h(phi)
        true_nu = 2.43859042216682270335182675595e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1433_fd9h(self):
        phi = -32.0
        nu = fd.fd9h(phi)
        true_nu = 6.62877603163034468072358718383e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1434_fd9h(self):
        phi = -31.0
        nu = fd.fd9h(phi)
        true_nu = 1.80188814317056185482708601041e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1435_fd9h(self):
        phi = -30.0
        nu = fd.fd9h(phi)
        true_nu = 4.89803979649634235919610022282e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1436_fd9h(self):
        phi = -29.0
        nu = fd.fd9h(phi)
        true_nu = 1.33142525738852000291432501801e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1437_fd9h(self):
        phi = -28.0
        nu = fd.fd9h(phi)
        true_nu = 3.61918908311058612607021845346e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1438_fd9h(self):
        phi = -27.0
        nu = fd.fd9h(phi)
        true_nu = 9.83797591837660120604653533526e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1439_fd9h(self):
        phi = -26.0
        nu = fd.fd9h(phi)
        true_nu = 2.67423911677388938491207065042e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1440_fd9h(self):
        phi = -25.0
        nu = fd.fd9h(phi)
        true_nu = 7.26933559607942006719335782393e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1441_fd9h(self):
        phi = -24.0
        nu = fd.fd9h(phi)
        true_nu = 1.97601028557827697504328542281e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1442_fd9h(self):
        phi = -23.0
        nu = fd.fd9h(phi)
        true_nu = 5.37135285212789968054765195468e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1443_fd9h(self):
        phi = -22.0
        nu = fd.fd9h(phi)
        true_nu = 1.46008508521240449552012071244e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1444_fd9h(self):
        phi = -21.0
        nu = fd.fd9h(phi)
        true_nu = 3.96892275509491956038556986037e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1445_fd9h(self):
        phi = -20.0
        nu = fd.fd9h(phi)
        true_nu = 1.07886506034215214849064629083e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1446_fd9h(self):
        phi = -19.0
        nu = fd.fd9h(phi)
        true_nu = 2.93265928865793362940581119384e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1447_fd9h(self):
        phi = -18.0
        nu = fd.fd9h(phi)
        true_nu = 7.97179445172462936202407965734e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1448_fd9h(self):
        phi = -17.0
        nu = fd.fd9h(phi)
        true_nu = 2.16695839858028825116475814336e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1449_fd9h(self):
        phi = -16.0
        nu = fd.fd9h(phi)
        true_nu = 5.89040362862842107447992464758e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1450_fd9h(self):
        phi = -15.0
        nu = fd.fd9h(phi)
        true_nu = 0.0000160117770775739301927653102739
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1451_fd9h(self):
        phi = -14.0
        nu = fd.fd9h(phi)
        true_nu = 0.0000435245221657771916594469393342
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1452_fd9h(self):
        phi = -13.0
        nu = fd.fd9h(phi)
        true_nu = 0.000118311913960212980277943541583
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1453_fd9h(self):
        phi = -12.0
        nu = fd.fd9h(phi)
        true_nu = 0.000321605098207324948286602535662
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1454_fd9h(self):
        phi = -11.0
        nu = fd.fd9h(phi)
        true_nu = 0.000874213090452239586235529443148
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1455_fd9h(self):
        phi = -10.0
        nu = fd.fd9h(phi)
        true_nu = 0.00237635605102621895029231209546
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1456_fd9h(self):
        phi = -9.0
        nu = fd.fd9h(phi)
        true_nu = 0.00645959433663459932472651228029
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1457_fd9h(self):
        phi = -8.0
        nu = fd.fd9h(phi)
        true_nu = 0.0175589156312568204448914749046
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1458_fd9h(self):
        phi = -7.0
        nu = fd.fd9h(phi)
        true_nu = 0.0477294734178761951360397954385
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1459_fd9h(self):
        phi = -6.0
        nu = fd.fd9h(phi)
        true_nu = 0.129737669722530291582921403650
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1460_fd9h(self):
        phi = -5.0
        nu = fd.fd9h(phi)
        true_nu = 0.352630389888596660776670267715
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1461_fd9h(self):
        phi = -4.0
        nu = fd.fd9h(phi)
        true_nu = 0.958304173823797922249170209471
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1462_fd9h(self):
        phi = -3.0
        nu = fd.fd9h(phi)
        true_nu = 2.60314166735125815572895647161
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1463_fd9h(self):
        phi = -2.0
        nu = fd.fd9h(phi)
        true_nu = 7.06294038379063354242248151362
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1464_fd9h(self):
        phi = -1.0
        nu = fd.fd9h(phi)
        true_nu = 19.1050680652288268477624070156
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1465_fd9h(self):
        phi = 0.0
        nu = fd.fd9h(phi)
        true_nu = 51.2905053032034983891639143110
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1466_fd9h(self):
        phi = 1.0
        nu = fd.fd9h(phi)
        true_nu = 135.419208460193110743191815888
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1467_fd9h(self):
        phi = 2.0
        nu = fd.fd9h(phi)
        true_nu = 346.603176159022425838378871371
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1468_fd9h(self):
        phi = 3.0
        nu = fd.fd9h(phi)
        true_nu = 846.253006254150889758163327725
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1469_fd9h(self):
        phi = 4.0
        nu = fd.fd9h(phi)
        true_nu = 1947.20938641251992211316111887
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1470_fd9h(self):
        phi = 5.0
        nu = fd.fd9h(phi)
        true_nu = 4200.34512673482423898297240974
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1471_fd9h(self):
        phi = 6.0
        nu = fd.fd9h(phi)
        true_nu = 8500.05785688319159184862178574
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1472_fd9h(self):
        phi = 7.0
        nu = fd.fd9h(phi)
        true_nu = 16206.0281310724689723601277399
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1473_fd9h(self):
        phi = 8.0
        nu = fd.fd9h(phi)
        true_nu = 29279.1898145693151132610738691
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1474_fd9h(self):
        phi = 9.0
        nu = fd.fd9h(phi)
        true_nu = 50430.4060071051079935877589186
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1475_fd9h(self):
        phi = 10.0
        nu = fd.fd9h(phi)
        true_nu = 83280.7334829104373016816842265
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1476_fd9h(self):
        phi = 11.0
        nu = fd.fd9h(phi)
        true_nu = 132532.419093242392474242768416
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1477_fd9h(self):
        phi = 12.0
        nu = fd.fd9h(phi)
        true_nu = 204149.946982895923612800476930
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1478_fd9h(self):
        phi = 13.0
        nu = fd.fd9h(phi)
        true_nu = 305550.577604251199253610638171
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1479_fd9h(self):
        phi = 14.0
        nu = fd.fd9h(phi)
        true_nu = 445803.907981293754392644238643
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1480_fd9h(self):
        phi = 15.0
        nu = fd.fd9h(phi)
        true_nu = 635840.049190115728997762082281
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1481_fd9h(self):
        phi = 16.0
        nu = fd.fd9h(phi)
        true_nu = 888666.068650890028772751894039
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1482_fd9h(self):
        phi = 17.0
        nu = fd.fd9h(phi)
        true_nu = 1.21959038596750461151818759488e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1483_fd9h(self):
        phi = 18.0
        nu = fd.fd9h(phi)
        true_nu = 1.64645484454482041026179900067e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1484_fd9h(self):
        phi = 19.0
        nu = fd.fd9h(phi)
        true_nu = 2.18987420896394502603897386380e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1485_fd9h(self):
        phi = 20.0
        nu = fd.fd9h(phi)
        true_nu = 2.87348286142502696609488650513e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1486_fd9h(self):
        phi = 21.0
        nu = fd.fd9h(phi)
        true_nu = 3.72418849042148763562761044024e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1487_fd9h(self):
        phi = 22.0
        nu = fd.fd9h(phi)
        true_nu = 4.77243258188530399371303038472e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1488_fd9h(self):
        phi = 23.0
        nu = fd.fd9h(phi)
        true_nu = 6.05245753786331437140846534360e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1489_fd9h(self):
        phi = 24.0
        nu = fd.fd9h(phi)
        true_nu = 7.60258026075077743568638626312e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1490_fd9h(self):
        phi = 25.0
        nu = fd.fd9h(phi)
        true_nu = 9.46547205253330167702280483123e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1491_fd9h(self):
        phi = 26.0
        nu = fd.fd9h(phi)
        true_nu = 1.16884446886190670253325937218e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1492_fd9h(self):
        phi = 27.0
        nu = fd.fd9h(phi)
        true_nu = 1.43237425348780084955339602735e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1493_fd9h(self):
        phi = 28.0
        nu = fd.fd9h(phi)
        true_nu = 1.74288405846036947046864656096e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1494_fd9h(self):
        phi = 29.0
        nu = fd.fd9h(phi)
        true_nu = 2.10667482994081982302721769065e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1495_fd9h(self):
        phi = 30.0
        nu = fd.fd9h(phi)
        true_nu = 2.53063191446586107258644925345e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1496_fd9h(self):
        phi = 31.0
        nu = fd.fd9h(phi)
        true_nu = 3.02225657160561329255218108250e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1497_fd9h(self):
        phi = 32.0
        nu = fd.fd9h(phi)
        true_nu = 3.58969803594204479298433090407e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1498_fd9h(self):
        phi = 33.0
        nu = fd.fd9h(phi)
        true_nu = 4.24178611907371827085154734853e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1499_fd9h(self):
        phi = 34.0
        nu = fd.fd9h(phi)
        true_nu = 4.98806434281089061500946588039e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1500_fd9h(self):
        phi = 35.0
        nu = fd.fd9h(phi)
        true_nu = 5.83882359514666542684487259225e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1501_fd9h(self):
        phi = 36.0
        nu = fd.fd9h(phi)
        true_nu = 6.80513630097892503404471048786e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1502_fd9h(self):
        phi = 37.0
        nu = fd.fd9h(phi)
        true_nu = 7.89889109991761098500720188418e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1503_fd9h(self):
        phi = 38.0
        nu = fd.fd9h(phi)
        true_nu = 9.13282802384556513187968255443e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1504_fd9h(self):
        phi = 39.0
        nu = fd.fd9h(phi)
        true_nu = 1.05205741672111908294674105489e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1505_fd9h(self):
        phi = 40.0
        nu = fd.fd9h(phi)
        true_nu = 1.20766798433199244274018528688e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1506_fd9h(self):
        phi = 41.0
        nu = fd.fd9h(phi)
        true_nu = 1.38166552201609238295684496035e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1507_fd9h(self):
        phi = 42.0
        nu = fd.fd9h(phi)
        true_nu = 1.57570074295572498984195959151e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1508_fd9h(self):
        phi = 43.0
        nu = fd.fd9h(phi)
        true_nu = 1.79152781436637013829246170528e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1509_fd9h(self):
        phi = 44.0
        nu = fd.fd9h(phi)
        true_nu = 2.03100816130577532347927016997e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1510_fd9h(self):
        phi = 45.0
        nu = fd.fd9h(phi)
        true_nu = 2.29611431608769783763908987110e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1511_fd9h(self):
        phi = 46.0
        nu = fd.fd9h(phi)
        true_nu = 2.58893381276520090784786062291e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1512_fd9h(self):
        phi = 47.0
        nu = fd.fd9h(phi)
        true_nu = 2.91167312616685059531991303820e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1513_fd9h(self):
        phi = 48.0
        nu = fd.fd9h(phi)
        true_nu = 3.26666165498656393334668032915e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1514_fd9h(self):
        phi = 49.0
        nu = fd.fd9h(phi)
        true_nu = 3.65635574844430502352679939522e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1515_fd9h(self):
        phi = 50.0
        nu = fd.fd9h(phi)
        true_nu = 4.08334277605038690366386705669e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd9h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd9h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1516_fd10h(self):
        phi = -50.0
        nu = fd.fd10h(phi)
        true_nu = 2.31449981755670133962080440469e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1517_fd10h(self):
        phi = -49.0
        nu = fd.fd10h(phi)
        true_nu = 6.29146279603615672460611482368e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1518_fd10h(self):
        phi = -48.0
        nu = fd.fd10h(phi)
        true_nu = 1.71019689928912212754234715065e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1519_fd10h(self):
        phi = -47.0
        nu = fd.fd10h(phi)
        true_nu = 4.64879715442462453551749159939e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1520_fd10h(self):
        phi = -46.0
        nu = fd.fd10h(phi)
        true_nu = 1.26367408290645748545139100787e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1521_fd10h(self):
        phi = -45.0
        nu = fd.fd10h(phi)
        true_nu = 3.43502229665927237336260957765e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1522_fd10h(self):
        phi = -44.0
        nu = fd.fd10h(phi)
        true_nu = 9.33735868936055581884462769658e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1523_fd10h(self):
        phi = -43.0
        nu = fd.fd10h(phi)
        true_nu = 2.53815724510929658394929287223e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1524_fd10h(self):
        phi = -42.0
        nu = fd.fd10h(phi)
        true_nu = 6.89942671715227176793527516994e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1525_fd10h(self):
        phi = -41.0
        nu = fd.fd10h(phi)
        true_nu = 1.87545862720198652166326083029e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1526_fd10h(self):
        phi = -40.0
        nu = fd.fd10h(phi)
        true_nu = 5.09802510634990679405667210421e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1527_fd10h(self):
        phi = -39.0
        nu = fd.fd10h(phi)
        true_nu = 1.38578690076189431810144026969e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1528_fd10h(self):
        phi = -38.0
        nu = fd.fd10h(phi)
        true_nu = 3.76695935045763555260310357903e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1529_fd10h(self):
        phi = -37.0
        nu = fd.fd10h(phi)
        true_nu = 1.02396571508928789394812407032e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1530_fd10h(self):
        phi = -36.0
        nu = fd.fd10h(phi)
        true_nu = 2.78342739629228325588686728165e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1531_fd10h(self):
        phi = -35.0
        nu = fd.fd10h(phi)
        true_nu = 7.56614011217638718822714288241e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1532_fd10h(self):
        phi = -34.0
        nu = fd.fd10h(phi)
        true_nu = 2.05669011785041550448547481651e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1533_fd10h(self):
        phi = -33.0
        nu = fd.fd10h(phi)
        true_nu = 5.59066337412407643004821753290e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1534_fd10h(self):
        phi = -32.0
        nu = fd.fd10h(phi)
        true_nu = 1.51969986589130078605996652085e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1535_fd10h(self):
        phi = -31.0
        nu = fd.fd10h(phi)
        true_nu = 4.13097253016396952807424676078e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1536_fd10h(self):
        phi = -30.0
        nu = fd.fd10h(phi)
        true_nu = 1.12291475626081931074413186122e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1537_fd10h(self):
        phi = -29.0
        nu = fd.fd10h(phi)
        true_nu = 3.05239877685229536067357715286e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1538_fd10h(self):
        phi = -28.0
        nu = fd.fd10h(phi)
        true_nu = 8.29728012832815396955352874339e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1539_fd10h(self):
        phi = -27.0
        nu = fd.fd10h(phi)
        true_nu = 2.25543457984683371692419574790e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1540_fd10h(self):
        phi = -26.0
        nu = fd.fd10h(phi)
        true_nu = 6.13090683367550023652371775705e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1541_fd10h(self):
        phi = -25.0
        nu = fd.fd10h(phi)
        true_nu = 1.66655326379532083076291885587e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1542_fd10h(self):
        phi = -24.0
        nu = fd.fd10h(phi)
        true_nu = 4.53016145313224511931883305998e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1543_fd10h(self):
        phi = -23.0
        nu = fd.fd10h(phi)
        true_nu = 1.23142555580225234571677978935e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1544_fd10h(self):
        phi = -22.0
        nu = fd.fd10h(phi)
        true_nu = 3.34736171142812014631092705588e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1545_fd10h(self):
        phi = -21.0
        nu = fd.fd10h(phi)
        true_nu = 9.09907251338648453108176395590e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1546_fd10h(self):
        phi = -20.0
        nu = fd.fd10h(phi)
        true_nu = 2.47338434684661275128682517201e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1547_fd10h(self):
        phi = -19.0
        nu = fd.fd10h(phi)
        true_nu = 6.72335572445613364979608694352e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1548_fd10h(self):
        phi = -18.0
        nu = fd.fd10h(phi)
        true_nu = 1.82759756893060488224722889177e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1549_fd10h(self):
        phi = -17.0
        nu = fd.fd10h(phi)
        true_nu = 4.96792525932862169411975172460e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1550_fd10h(self):
        phi = -16.0
        nu = fd.fd10h(phi)
        true_nu = 0.0000135042209425657835716963480469
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1551_fd10h(self):
        phi = -15.0
        nu = fd.fd10h(phi)
        true_nu = 0.0000367082782847636686507887509888
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1552_fd10h(self):
        phi = -14.0
        nu = fd.fd10h(phi)
        true_nu = 0.0000997834449959782206787179453948
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1553_fd10h(self):
        phi = -13.0
        nu = fd.fd10h(phi)
        true_nu = 0.000271239519258186492416985397544
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1554_fd10h(self):
        phi = -12.0
        nu = fd.fd10h(phi)
        true_nu = 0.000737305411615650647212806677622
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1555_fd10h(self):
        phi = -11.0
        nu = fd.fd10h(phi)
        true_nu = 0.00200420357180497859715194217815
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1556_fd10h(self):
        phi = -10.0
        nu = fd.fd10h(phi)
        true_nu = 0.00544798770685054348211194598316
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1557_fd10h(self):
        phi = -9.0
        nu = fd.fd10h(phi)
        true_nu = 0.0148091479344989052677934820473
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1558_fd10h(self):
        phi = -8.0
        nu = fd.fd10h(phi)
        true_nu = 0.0402553043510626643014872898113
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1559_fd10h(self):
        phi = -7.0
        nu = fd.fd10h(phi)
        true_nu = 0.109424276874989183092835025697
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1560_fd10h(self):
        phi = -6.0
        nu = fd.fd10h(phi)
        true_nu = 0.297438743307687792563027991783
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1561_fd10h(self):
        phi = -5.0
        nu = fd.fd10h(phi)
        true_nu = 0.808468565315963892467529167680
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1562_fd10h(self):
        phi = -4.0
        nu = fd.fd10h(phi)
        true_nu = 2.19724868233256871266712674590
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1563_fd10h(self):
        phi = -3.0
        nu = fd.fd10h(phi)
        true_nu = 5.96982068048816012492490855385
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1564_fd10h(self):
        phi = -2.0
        nu = fd.fd10h(phi)
        true_nu = 16.2062906961884117732450924558
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1565_fd10h(self):
        phi = -1.0
        nu = fd.fd10h(phi)
        true_nu = 43.8994842676530474793586976434
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1566_fd10h(self):
        phi = 0.0
        nu = fd.fd10h(phi)
        true_nu = 118.266130955692212491812709338
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1567_fd10h(self):
        phi = 1.0
        nu = fd.fd10h(phi)
        true_nu = 314.668054184308686462475851670
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1568_fd10h(self):
        phi = 2.0
        nu = fd.fd10h(phi)
        true_nu = 817.163121388398835231561758766
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1569_fd10h(self):
        phi = 3.0
        nu = fd.fd10h(phi)
        true_nu = 2041.05619416145356261265214585
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1570_fd10h(self):
        phi = 4.0
        nu = fd.fd10h(phi)
        true_nu = 4840.82031809616052336920258209
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1571_fd10h(self):
        phi = 5.0
        nu = fd.fd10h(phi)
        true_nu = 10821.4079074051804944636316554
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1572_fd10h(self):
        phi = 6.0
        nu = fd.fd10h(phi)
        true_nu = 22762.5893997726864094628066435
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1573_fd10h(self):
        phi = 7.0
        nu = fd.fd10h(phi)
        true_nu = 45160.5760142579404676683823446
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1574_fd10h(self):
        phi = 8.0
        nu = fd.fd10h(phi)
        true_nu = 84888.6204928642260949285980517
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1575_fd10h(self):
        phi = 9.0
        nu = fd.fd10h(phi)
        true_nu = 151977.238618432748493399548606
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1576_fd10h(self):
        phi = 10.0
        nu = fd.fd10h(phi)
        true_nu = 260514.290776968617075645607119
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1577_fd10h(self):
        phi = 11.0
        nu = fd.fd10h(phi)
        true_nu = 429665.011972298906291845674172
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1578_fd10h(self):
        phi = 12.0
        nu = fd.fd10h(phi)
        true_nu = 684812.022869142499198514958575
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1579_fd10h(self):
        phi = 13.0
        nu = fd.fd10h(phi)
        true_nu = 1.05881533385580365530235853314e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1580_fd10h(self):
        phi = 14.0
        nu = fd.fd10h(phi)
        true_nu = 1.59339234653877716399469293269e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1581_fd10h(self):
        phi = 15.0
        nu = fd.fd10h(phi)
        true_nu = 2.34061785429258606264686563316e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1582_fd10h(self):
        phi = 16.0
        nu = fd.fd10h(phi)
        true_nu = 3.36454404246205606344031568968e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1583_fd10h(self):
        phi = 17.0
        nu = fd.fd10h(phi)
        true_nu = 4.74294048843672821525693773823e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1584_fd10h(self):
        phi = 18.0
        nu = fd.fd10h(phi)
        true_nu = 6.56915416167823380010706873896e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1585_fd10h(self):
        phi = 19.0
        nu = fd.fd10h(phi)
        true_nu = 8.95408942373036499580622688350e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1586_fd10h(self):
        phi = 20.0
        nu = fd.fd10h(phi)
        true_nu = 1.20283080282227796658785699194e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1587_fd10h(self):
        phi = 21.0
        nu = fd.fd10h(phi)
        true_nu = 1.59442491208723642756159571819e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1588_fd10h(self):
        phi = 22.0
        nu = fd.fd10h(phi)
        true_nu = 2.08785692394837352808787897551e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1589_fd10h(self):
        phi = 23.0
        nu = fd.fd10h(phi)
        true_nu = 2.70346023139494235787282343581e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1590_fd10h(self):
        phi = 24.0
        nu = fd.fd10h(phi)
        true_nu = 3.46449396662499423630217784684e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1591_fd10h(self):
        phi = 25.0
        nu = fd.fd10h(phi)
        true_nu = 4.39741300104538120870918101117e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1592_fd10h(self):
        phi = 26.0
        nu = fd.fd10h(phi)
        true_nu = 5.53214994527175696470018648329e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1593_fd10h(self):
        phi = 27.0
        nu = fd.fd10h(phi)
        true_nu = 6.90240914912857717598778020866e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1594_fd10h(self):
        phi = 28.0
        nu = fd.fd10h(phi)
        true_nu = 8.54597270164909962067263905165e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1595_fd10h(self):
        phi = 29.0
        nu = fd.fd10h(phi)
        true_nu = 1.05050184310753842289642714587e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1596_fd10h(self):
        phi = 30.0
        nu = fd.fd10h(phi)
        true_nu = 1.28264499048582931000007379837e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1597_fd10h(self):
        phi = 31.0
        nu = fd.fd10h(phi)
        true_nu = 1.55622384296574905080362806751e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1598_fd10h(self):
        phi = 32.0
        nu = fd.fd10h(phi)
        true_nu = 1.87697770513414429047176247173e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1599_fd10h(self):
        phi = 33.0
        nu = fd.fd10h(phi)
        true_nu = 2.25122465549874189199213830065e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1600_fd10h(self):
        phi = 34.0
        nu = fd.fd10h(phi)
        true_nu = 2.68589934648814893620621200780e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1601_fd10h(self):
        phi = 35.0
        nu = fd.fd10h(phi)
        true_nu = 3.18859200445185272182056824914e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1602_fd10h(self):
        phi = 36.0
        nu = fd.fd10h(phi)
        true_nu = 3.76758862966022076541108907497e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1603_fd10h(self):
        phi = 37.0
        nu = fd.fd10h(phi)
        true_nu = 4.43191239630450080142448768992e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1604_fd10h(self):
        phi = 38.0
        nu = fd.fd10h(phi)
        true_nu = 5.19136625249682078217887269168e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1605_fd10h(self):
        phi = 39.0
        nu = fd.fd10h(phi)
        true_nu = 6.05657672027018887786395564287e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1606_fd10h(self):
        phi = 40.0
        nu = fd.fd10h(phi)
        true_nu = 7.03903889557849347654112743244e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1607_fd10h(self):
        phi = 41.0
        nu = fd.fd10h(phi)
        true_nu = 8.15116264829650318414348636747e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1608_fd10h(self):
        phi = 42.0
        nu = fd.fd10h(phi)
        true_nu = 9.40632002221986682447584850758e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1609_fd10h(self):
        phi = 43.0
        nu = fd.fd10h(phi)
        true_nu = 1.08188938350651134392147514667e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1610_fd10h(self):
        phi = 44.0
        nu = fd.fd10h(phi)
        true_nu = 1.24043274784696522879084558117e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1611_fd10h(self):
        phi = 45.0
        nu = fd.fd10h(phi)
        true_nu = 1.41791759179917728479769455769e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1612_fd10h(self):
        phi = 46.0
        nu = fd.fd10h(phi)
        true_nu = 1.61611578931106448147119284534e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1613_fd10h(self):
        phi = 47.0
        nu = fd.fd10h(phi)
        true_nu = 1.83692093172263181012768358587e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1614_fd10h(self):
        phi = 48.0
        nu = fd.fd10h(phi)
        true_nu = 2.08235378776597228387068229621e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1615_fd10h(self):
        phi = 49.0
        nu = fd.fd10h(phi)
        true_nu = 2.35456788356526693759087686947e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1616_fd10h(self):
        phi = 50.0
        nu = fd.fd10h(phi)
        true_nu = 2.65585520263678482796612757520e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd10h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd10h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1617_fd11h(self):
        phi = -50.0
        nu = fd.fd11h(phi)
        true_nu = 5.55258685816817044324672296080e-20
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1618_fd11h(self):
        phi = -49.0
        nu = fd.fd11h(phi)
        true_nu = 1.50934959574990396250504640272e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1619_fd11h(self):
        phi = -48.0
        nu = fd.fd11h(phi)
        true_nu = 4.10283757891896971444458957272e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1620_fd11h(self):
        phi = -47.0
        nu = fd.fd11h(phi)
        true_nu = 1.11526688358943393013166656765e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1621_fd11h(self):
        phi = -46.0
        nu = fd.fd11h(phi)
        true_nu = 3.03160970354330761415015394293e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1622_fd11h(self):
        phi = -45.0
        nu = fd.fd11h(phi)
        true_nu = 8.24076956812188628844032061379e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1623_fd11h(self):
        phi = -44.0
        nu = fd.fd11h(phi)
        true_nu = 2.24007341695440175928859224698e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1624_fd11h(self):
        phi = -43.0
        nu = fd.fd11h(phi)
        true_nu = 6.08915086372131243578657228540e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1625_fd11h(self):
        phi = -42.0
        nu = fd.fd11h(phi)
        true_nu = 1.65520281435993437418238397177e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1626_fd11h(self):
        phi = -41.0
        nu = fd.fd11h(phi)
        true_nu = 4.49930773268888002605028220827e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1627_fd11h(self):
        phi = -40.0
        nu = fd.fd11h(phi)
        true_nu = 1.22303864504134499292322947087e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1628_fd11h(self):
        phi = -39.0
        nu = fd.fd11h(phi)
        true_nu = 3.32456372431906046534159876214e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1629_fd11h(self):
        phi = -38.0
        nu = fd.fd11h(phi)
        true_nu = 9.03710115937062887229033820346e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1630_fd11h(self):
        phi = -37.0
        nu = fd.fd11h(phi)
        true_nu = 2.45653878634633505945172572555e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1631_fd11h(self):
        phi = -36.0
        nu = fd.fd11h(phi)
        true_nu = 6.67756474383007952103958355413e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1632_fd11h(self):
        phi = -35.0
        nu = fd.fd11h(phi)
        true_nu = 1.81515029015120844813717231513e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1633_fd11h(self):
        phi = -34.0
        nu = fd.fd11h(phi)
        true_nu = 4.93409004964019332990727007798e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1634_fd11h(self):
        phi = -33.0
        nu = fd.fd11h(phi)
        true_nu = 1.34122473219175255588158054695e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1635_fd11h(self):
        phi = -32.0
        nu = fd.fd11h(phi)
        true_nu = 3.64582681739669008452418822991e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1636_fd11h(self):
        phi = -31.0
        nu = fd.fd11h(phi)
        true_nu = 9.91038478743809397090019528769e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1637_fd11h(self):
        phi = -30.0
        nu = fd.fd11h(phi)
        true_nu = 2.69392188807299108275261888579e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1638_fd11h(self):
        phi = -29.0
        nu = fd.fd11h(phi)
        true_nu = 7.32283891563688059598914349304e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1639_fd11h(self):
        phi = -28.0
        nu = fd.fd11h(phi)
        true_nu = 1.99055399571083757598677849540e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1640_fd11h(self):
        phi = -27.0
        nu = fd.fd11h(phi)
        true_nu = 5.41088675510724302610191313428e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1641_fd11h(self):
        phi = -26.0
        nu = fd.fd11h(phi)
        true_nu = 1.47083151422572218718740386627e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1642_fd11h(self):
        phi = -25.0
        nu = fd.fd11h(phi)
        true_nu = 3.99813457784429451692830464732e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1643_fd11h(self):
        phi = -24.0
        nu = fd.fd11h(phi)
        true_nu = 1.08680565706850564006664212300e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1644_fd11h(self):
        phi = -23.0
        nu = fd.fd11h(phi)
        true_nu = 2.95424406867369431145629431680e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1645_fd11h(self):
        phi = -22.0
        nu = fd.fd11h(phi)
        true_nu = 8.03046796869297427385161444975e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1646_fd11h(self):
        phi = -21.0
        nu = fd.fd11h(phi)
        true_nu = 2.18290751532049333843309057850e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1647_fd11h(self):
        phi = -20.0
        nu = fd.fd11h(phi)
        true_nu = 5.93375783201696477284017865868e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1648_fd11h(self):
        phi = -19.0
        nu = fd.fd11h(phi)
        true_nu = 1.61296260886171030096892998441e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1649_fd11h(self):
        phi = -18.0
        nu = fd.fd11h(phi)
        true_nu = 4.38448694918631979002963776922e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1650_fd11h(self):
        phi = -17.0
        nu = fd.fd11h(phi)
        true_nu = 0.0000119182711976430361819973997453
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1651_fd11h(self):
        phi = -16.0
        nu = fd.fd11h(phi)
        true_nu = 0.0000323972199977373912849727231067
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1652_fd11h(self):
        phi = -15.0
        nu = fd.fd11h(phi)
        true_nu = 0.0000880647742242957334827447253627
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1653_fd11h(self):
        phi = -14.0
        nu = fd.fd11h(phi)
        true_nu = 0.000239384874111046524271437248384
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1654_fd11h(self):
        phi = -13.0
        nu = fd.fd11h(phi)
        true_nu = 0.000650715543031712027020860463728
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1655_fd11h(self):
        phi = -12.0
        nu = fd.fd11h(phi)
        true_nu = 0.00176882816021637675031213817972
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1656_fd11h(self):
        phi = -11.0
        nu = fd.fd11h(phi)
        true_nu = 0.00480817288473493654490050919506
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1657_fd11h(self):
        phi = -10.0
        nu = fd.fd11h(phi)
        true_nu = 0.0130699648365396608771155400846
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1658_fd11h(self):
        phi = -9.0
        nu = fd.fd11h(phi)
        true_nu = 0.0355278172928278612736078045792
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1659_fd11h(self):
        phi = -8.0
        nu = fd.fd11h(phi)
        true_nu = 0.0965743938967928194390638247302
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1660_fd11h(self):
        phi = -7.0
        nu = fd.fd11h(phi)
        true_nu = 0.262514748306838650156900414068
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1661_fd11h(self):
        phi = -6.0
        nu = fd.fd11h(phi)
        true_nu = 0.713576719509200558856956666904
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1662_fd11h(self):
        phi = -5.0
        nu = fd.fd11h(phi)
        true_nu = 1.93961140926070552793371548503
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1663_fd11h(self):
        phi = -4.0
        nu = fd.fd11h(phi)
        true_nu = 5.27173717643204330864969327176
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1664_fd11h(self):
        phi = -3.0
        nu = fd.fd11h(phi)
        true_nu = 14.3251077331683436095689950224
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1665_fd11h(self):
        phi = -2.0
        nu = fd.fd11h(phi)
        true_nu = 38.9033325432968816430871457151
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1666_fd11h(self):
        phi = -1.0
        nu = fd.fd11h(phi)
        true_nu = 105.487370142135507705829570829
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1667_fd11h(self):
        phi = 0.0
        nu = fd.fd11h(phi)
        true_nu = 284.903798991525380318206900025
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1668_fd11h(self):
        phi = 1.0
        nu = fd.fd11h(phi)
        true_nu = 762.407130148768539616596929940
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1669_fd11h(self):
        phi = 2.0
        nu = fd.fd11h(phi)
        true_nu = 2002.34212474102814506927369735
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1670_fd11h(self):
        phi = 3.0
        nu = fd.fd11h(phi)
        true_nu = 5094.80023573092281342555300408
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1671_fd11h(self):
        phi = 4.0
        nu = fd.fd11h(phi)
        true_nu = 12399.1113146343316810755089788
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1672_fd11h(self):
        phi = 5.0
        nu = fd.fd11h(phi)
        true_nu = 28605.5567188864958137997398272
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1673_fd11h(self):
        phi = 6.0
        nu = fd.fd11h(phi)
        true_nu = 62326.6343418810996434491138490
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1674_fd11h(self):
        phi = 7.0
        nu = fd.fd11h(phi)
        true_nu = 128314.347392955349602150913020
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1675_fd11h(self):
        phi = 8.0
        nu = fd.fd11h(phi)
        true_nu = 250387.049718493506248010804712
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1676_fd11h(self):
        phi = 9.0
        nu = fd.fd11h(phi)
        true_nu = 465139.656893138198843130886198
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1677_fd11h(self):
        phi = 10.0
        nu = fd.fd11h(phi)
        true_nu = 826503.886744092065068799839259
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1678_fd11h(self):
        phi = 11.0
        nu = fd.fd11h(phi)
        true_nu = 1.41121981401916539424597070660e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1679_fd11h(self):
        phi = 12.0
        nu = fd.fd11h(phi)
        true_nu = 2.32527582573205030442502144517e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1680_fd11h(self):
        phi = 13.0
        nu = fd.fd11h(phi)
        true_nu = 3.71137067234992976849445707845e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1681_fd11h(self):
        phi = 14.0
        nu = fd.fd11h(phi)
        true_nu = 5.75744849093217553505226462840e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1682_fd11h(self):
        phi = 15.0
        nu = fd.fd11h(phi)
        true_nu = 8.70635527938527830631703761131e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1683_fd11h(self):
        phi = 16.0
        nu = fd.fd11h(phi)
        true_nu = 1.28666632264412795259747747788e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1684_fd11h(self):
        phi = 17.0
        nu = fd.fd11h(phi)
        true_nu = 1.86247074809349094105174062135e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1685_fd11h(self):
        phi = 18.0
        nu = fd.fd11h(phi)
        true_nu = 2.64578783271198308158559597811e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1686_fd11h(self):
        phi = 19.0
        nu = fd.fd11h(phi)
        true_nu = 3.69492102836338795402092554607e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1687_fd11h(self):
        phi = 20.0
        nu = fd.fd11h(phi)
        true_nu = 5.08033083345546462859566542281e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1688_fd11h(self):
        phi = 21.0
        nu = fd.fd11h(phi)
        true_nu = 6.88636503102045524732180659954e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1689_fd11h(self):
        phi = 22.0
        nu = fd.fd11h(phi)
        true_nu = 9.21313033458658965148861940340e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1690_fd11h(self):
        phi = 23.0
        nu = fd.fd11h(phi)
        true_nu = 1.21785091344573328824856495150e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1691_fd11h(self):
        phi = 24.0
        nu = fd.fd11h(phi)
        true_nu = 1.59203249444410076518579963580e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1692_fd11h(self):
        phi = 25.0
        nu = fd.fd11h(phi)
        true_nu = 2.05986600631942011665257908002e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1693_fd11h(self):
        phi = 26.0
        nu = fd.fd11h(phi)
        true_nu = 2.63983288843808667264545805842e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1694_fd11h(self):
        phi = 27.0
        nu = fd.fd11h(phi)
        true_nu = 3.35315102151499275592419896811e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1695_fd11h(self):
        phi = 28.0
        nu = fd.fd11h(phi)
        true_nu = 4.22405418924402646763728453724e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1696_fd11h(self):
        phi = 29.0
        nu = fd.fd11h(phi)
        true_nu = 5.28008809208558497036419083827e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1697_fd11h(self):
        phi = 30.0
        nu = fd.fd11h(phi)
        true_nu = 6.55242322939037031525426746804e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1698_fd11h(self):
        phi = 31.0
        nu = fd.fd11h(phi)
        true_nu = 8.07618496018959311832686177683e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1699_fd11h(self):
        phi = 32.0
        nu = fd.fd11h(phi)
        true_nu = 9.89080104744723577716733164554e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1700_fd11h(self):
        phi = 33.0
        nu = fd.fd11h(phi)
        true_nu = 1.20403669853228484513704536306e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1701_fd11h(self):
        phi = 34.0
        nu = fd.fd11h(phi)
        true_nu = 1.45740294040093311879691442822e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1702_fd11h(self):
        phi = 35.0
        nu = fd.fd11h(phi)
        true_nu = 1.75463878419679168403316279539e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1703_fd11h(self):
        phi = 36.0
        nu = fd.fd11h(phi)
        true_nu = 2.10179151708630989024676619324e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1704_fd11h(self):
        phi = 37.0
        nu = fd.fd11h(phi)
        true_nu = 2.50553969541865704524391339852e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1705_fd11h(self):
        phi = 38.0
        nu = fd.fd11h(phi)
        true_nu = 2.97323900164361433780291321021e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1706_fd11h(self):
        phi = 39.0
        nu = fd.fd11h(phi)
        true_nu = 3.51297004957694234939305644106e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1707_fd11h(self):
        phi = 40.0
        nu = fd.fd11h(phi)
        true_nu = 4.13358816492703898112561973661e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1708_fd11h(self):
        phi = 41.0
        nu = fd.fd11h(phi)
        true_nu = 4.84477516763388032929055169748e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1709_fd11h(self):
        phi = 42.0
        nu = fd.fd11h(phi)
        true_nu = 5.65709318222274249847359944693e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1710_fd11h(self):
        phi = 43.0
        nu = fd.fd11h(phi)
        true_nu = 6.58204050204011428595509051614e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1711_fd11h(self):
        phi = 44.0
        nu = fd.fd11h(phi)
        true_nu = 7.63210953291668890535326648848e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1712_fd11h(self):
        phi = 45.0
        nu = fd.fd11h(phi)
        true_nu = 8.82084684149159933391535931029e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1713_fd11h(self):
        phi = 46.0
        nu = fd.fd11h(phi)
        true_nu = 1.01629153331324326699350617353e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1714_fd11h(self):
        phi = 47.0
        nu = fd.fd11h(phi)
        true_nu = 1.16741585840963778122746635396e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1715_fd11h(self):
        phi = 48.0
        nu = fd.fd11h(phi)
        true_nu = 1.33716673522985331731511461574e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1716_fd11h(self):
        phi = 49.0
        nu = fd.fd11h(phi)
        true_nu = 1.52738482907833787789108604485e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1717_fd11h(self):
        phi = 50.0
        nu = fd.fd11h(phi)
        true_nu = 1.74004948877341936262473968151e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd11h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd11h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1718_fd12h(self):
        phi = -50.0
        nu = fd.fd12h(phi)
        true_nu = 1.38869989053402080377248473536e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1719_fd12h(self):
        phi = -49.0
        nu = fd.fd12h(phi)
        true_nu = 3.77487767762169403476368435612e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1720_fd12h(self):
        phi = -48.0
        nu = fd.fd12h(phi)
        true_nu = 1.02611813957347327652541971529e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1721_fd12h(self):
        phi = -47.0
        nu = fd.fd12h(phi)
        true_nu = 2.78927829265477472131057937883e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1722_fd12h(self):
        phi = -46.0
        nu = fd.fd12h(phi)
        true_nu = 7.58204449743874491270896982539e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1723_fd12h(self):
        phi = -45.0
        nu = fd.fd12h(phi)
        true_nu = 2.06101337799556342401802665980e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1724_fd12h(self):
        phi = -44.0
        nu = fd.fd12h(phi)
        true_nu = 5.60241521361633349131018233152e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1725_fd12h(self):
        phi = -43.0
        nu = fd.fd12h(phi)
        true_nu = 1.52289434706557795037209222420e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1726_fd12h(self):
        phi = -42.0
        nu = fd.fd12h(phi)
        true_nu = 4.13965603029136306077975966799e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1727_fd12h(self):
        phi = -41.0
        nu = fd.fd12h(phi)
        true_nu = 1.12527517632119191301169612733e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1728_fd12h(self):
        phi = -40.0
        nu = fd.fd12h(phi)
        true_nu = 3.05881506380994407653552615309e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1729_fd12h(self):
        phi = -39.0
        nu = fd.fd12h(phi)
        true_nu = 8.31472140457136590935879995187e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1730_fd12h(self):
        phi = -38.0
        nu = fd.fd12h(phi)
        true_nu = 2.26017561027458133211615834851e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1731_fd12h(self):
        phi = -37.0
        nu = fd.fd12h(phi)
        true_nu = 6.14379429053572736778447014721e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1732_fd12h(self):
        phi = -36.0
        nu = fd.fd12h(phi)
        true_nu = 1.67005643777536995655847508400e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1733_fd12h(self):
        phi = -35.0
        nu = fd.fd12h(phi)
        true_nu = 4.53968406730583233529819049393e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1734_fd12h(self):
        phi = -34.0
        nu = fd.fd12h(phi)
        true_nu = 1.23401407071024931921462176828e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1735_fd12h(self):
        phi = -33.0
        nu = fd.fd12h(phi)
        true_nu = 3.35439802447444598012079365557e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1736_fd12h(self):
        phi = -32.0
        nu = fd.fd12h(phi)
        true_nu = 9.11819919534780561850342505870e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1737_fd12h(self):
        phi = -31.0
        nu = fd.fd12h(phi)
        true_nu = 2.47858351809838238344353418806e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1738_fd12h(self):
        phi = -30.0
        nu = fd.fd12h(phi)
        true_nu = 6.73748853756492079000209518450e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1739_fd12h(self):
        phi = -29.0
        nu = fd.fd12h(phi)
        true_nu = 1.83143926611138085591129196805e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1740_fd12h(self):
        phi = -28.0
        nu = fd.fd12h(phi)
        true_nu = 4.97836807699691927425458909962e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1741_fd12h(self):
        phi = -27.0
        nu = fd.fd12h(phi)
        true_nu = 1.35326074790812010119023607391e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1742_fd12h(self):
        phi = -26.0
        nu = fd.fd12h(phi)
        true_nu = 3.67854410020544697011189937481e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1743_fd12h(self):
        phi = -25.0
        nu = fd.fd12h(phi)
        true_nu = 9.99931958277300990636699107529e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1744_fd12h(self):
        phi = -24.0
        nu = fd.fd12h(phi)
        true_nu = 2.71809687188014872638783806947e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1745_fd12h(self):
        phi = -23.0
        nu = fd.fd12h(phi)
        true_nu = 7.38855333481943754656423160238e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1746_fd12h(self):
        phi = -22.0
        nu = fd.fd12h(phi)
        true_nu = 2.00841702686124897467205107904e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1747_fd12h(self):
        phi = -21.0
        nu = fd.fd12h(phi)
        true_nu = 5.45944350806423178138283912235e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1748_fd12h(self):
        phi = -20.0
        nu = fd.fd12h(phi)
        true_nu = 1.48403060813186464345234468751e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1749_fd12h(self):
        phi = -19.0
        nu = fd.fd12h(phi)
        true_nu = 4.03401343485025640931454858496e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1750_fd12h(self):
        phi = -18.0
        nu = fd.fd12h(phi)
        true_nu = 0.0000109655854148883608831693705561
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1751_fd12h(self):
        phi = -17.0
        nu = fd.fd12h(phi)
        true_nu = 0.0000298075515656124650454231622314
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1752_fd12h(self):
        phi = -16.0
        nu = fd.fd12h(phi)
        true_nu = 0.0000810253257266306317054532049112
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1753_fd12h(self):
        phi = -15.0
        nu = fd.fd12h(phi)
        true_nu = 0.000220249670234948285054134515301
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1754_fd12h(self):
        phi = -14.0
        nu = fd.fd12h(phi)
        true_nu = 0.000598700673865219005656867698215
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1755_fd12h(self):
        phi = -13.0
        nu = fd.fd12h(phi)
        true_nu = 0.00162743714428773713359255240952
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1756_fd12h(self):
        phi = -12.0
        nu = fd.fd12h(phi)
        true_nu = 0.00442383268204506927338091481092
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1757_fd12h(self):
        phi = -11.0
        nu = fd.fd12h(phi)
        true_nu = 0.0120252229999026062525853375506
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1758_fd12h(self):
        phi = -10.0
        nu = fd.fd12h(phi)
        true_nu = 0.0326879378350307736912424587844
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1759_fd12h(self):
        phi = -9.0
        nu = fd.fd12h(phi)
        true_nu = 0.0888549732743919763558369146974
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1760_fd12h(self):
        phi = -8.0
        nu = fd.fd12h(phi)
        true_nu = 0.241532459091878598110540958672
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1761_fd12h(self):
        phi = -7.0
        nu = fd.fd12h(phi)
        true_nu = 0.656550338099807951480788840896
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1762_fd12h(self):
        phi = -6.0
        nu = fd.fd12h(phi)
        true_nu = 1.78466701101761756168225893449
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1763_fd12h(self):
        phi = -5.0
        nu = fd.fd12h(phi)
        true_nu = 4.85106656535475492465985692655
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1764_fd12h(self):
        phi = -4.0
        nu = fd.fd12h(phi)
        true_nu = 13.1853750404661238004425657546
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1765_fd12h(self):
        phi = -3.0
        nu = fd.fd12h(phi)
        true_nu = 35.8327866053817191593716283444
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1766_fd12h(self):
        phi = -2.0
        nu = fd.fd12h(phi)
        true_nu = 97.3391801729945441882207416652
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1767_fd12h(self):
        phi = -1.0
        nu = fd.fd12h(phi)
        true_nu = 264.127579012570791679313594457
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1768_fd12h(self):
        phi = 0.0
        nu = fd.fd12h(phi)
        true_nu = 714.667550344437803522706513456
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1769_fd12h(self):
        phi = 1.0
        nu = fd.fd12h(phi)
        true_nu = 1920.62149110416286327540423093
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1770_fd12h(self):
        phi = 2.0
        nu = fd.fd12h(phi)
        true_nu = 5088.14241086489356725560140225
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1771_fd12h(self):
        phi = 3.0
        nu = fd.fd12h(phi)
        true_nu = 13140.9286770457404877085800083
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1772_fd12h(self):
        phi = 4.0
        nu = fd.fd12h(phi)
        true_nu = 32683.4302572783214144976325079
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1773_fd12h(self):
        phi = 5.0
        nu = fd.fd12h(phi)
        true_nu = 77515.0318479427964298720181118
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1774_fd12h(self):
        phi = 6.0
        nu = fd.fd12h(phi)
        true_nu = 174348.028942686080761337984164
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1775_fd12h(self):
        phi = 7.0
        nu = fd.fd12h(phi)
        true_nu = 371422.195243938379898912784870
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1776_fd12h(self):
        phi = 8.0
        nu = fd.fd12h(phi)
        true_nu = 750725.524064866082994438592031
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1777_fd12h(self):
        phi = 9.0
        nu = fd.fd12h(phi)
        true_nu = 1.44453725084123743044954927911e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1778_fd12h(self):
        phi = 10.0
        nu = fd.fd12h(phi)
        true_nu = 2.65701171616232435406017252120e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1779_fd12h(self):
        phi = 11.0
        nu = fd.fd12h(phi)
        true_nu = 4.69152253819438833135550590489e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1780_fd12h(self):
        phi = 12.0
        nu = fd.fd12h(phi)
        true_nu = 7.98448689894813175713732750369e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1781_fd12h(self):
        phi = 13.0
        nu = fd.fd12h(phi)
        true_nu = 1.31463898724303613293762560657e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1782_fd12h(self):
        phi = 14.0
        nu = fd.fd12h(phi)
        true_nu = 2.10107287682044464468590667984e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1783_fd12h(self):
        phi = 15.0
        nu = fd.fd12h(phi)
        true_nu = 3.26915974806194180200407409385e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1784_fd12h(self):
        phi = 16.0
        nu = fd.fd12h(phi)
        true_nu = 4.96506308401244518747281739319e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1785_fd12h(self):
        phi = 17.0
        nu = fd.fd12h(phi)
        true_nu = 7.37740289653505234011378040678e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1786_fd12h(self):
        phi = 18.0
        nu = fd.fd12h(phi)
        true_nu = 1.07460381615474288884471880014e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1787_fd12h(self):
        phi = 19.0
        nu = fd.fd12h(phi)
        true_nu = 1.53720012542685792250012470163e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1788_fd12h(self):
        phi = 20.0
        nu = fd.fd12h(phi)
        true_nu = 2.16286563844694367046480567182e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1789_fd12h(self):
        phi = 21.0
        nu = fd.fd12h(phi)
        true_nu = 2.99741540317248589672681545902e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1790_fd12h(self):
        phi = 22.0
        nu = fd.fd12h(phi)
        true_nu = 4.09652533806661401767729722889e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1791_fd12h(self):
        phi = 23.0
        nu = fd.fd12h(phi)
        true_nu = 5.52725847562337134230288642658e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1792_fd12h(self):
        phi = 24.0
        nu = fd.fd12h(phi)
        true_nu = 7.36974240589299230808031921725e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1793_fd12h(self):
        phi = 25.0
        nu = fd.fd12h(phi)
        true_nu = 9.71900512000718229044606018457e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1794_fd12h(self):
        phi = 26.0
        nu = fd.fd12h(phi)
        true_nu = 1.26869764537043983590312700983e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1795_fd12h(self):
        phi = 27.0
        nu = fd.fd12h(phi)
        true_nu = 1.64046623308551303821922779299e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1796_fd12h(self):
        phi = 28.0
        nu = fd.fd12h(phi)
        true_nu = 2.10244990069871822596718083373e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1797_fd12h(self):
        phi = 29.0
        nu = fd.fd12h(phi)
        true_nu = 2.67228945128109532023968798679e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1798_fd12h(self):
        phi = 30.0
        nu = fd.fd12h(phi)
        true_nu = 3.37029644977447190296173152449e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1799_fd12h(self):
        phi = 31.0
        nu = fd.fd12h(phi)
        true_nu = 4.21974696734399134724235063367e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1800_fd12h(self):
        phi = 32.0
        nu = fd.fd12h(phi)
        true_nu = 5.24719620573064094796109757727e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1801_fd12h(self):
        phi = 33.0
        nu = fd.fd12h(phi)
        true_nu = 6.48281472160378005244082768002e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1802_fd12h(self):
        phi = 34.0
        nu = fd.fd12h(phi)
        true_nu = 7.96074697091366819115224975287e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1803_fd12h(self):
        phi = 35.0
        nu = fd.fd12h(phi)
        true_nu = 9.71949289324399320843016053001e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1804_fd12h(self):
        phi = 36.0
        nu = fd.fd12h(phi)
        true_nu = 1.18023132561643993931939774139e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1805_fd12h(self):
        phi = 37.0
        nu = fd.fd12h(phi)
        true_nu = 1.42576594795830156096698524795e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1806_fd12h(self):
        phi = 38.0
        nu = fd.fd12h(phi)
        true_nu = 1.71396286600989834281133681909e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1807_fd12h(self):
        phi = 39.0
        nu = fd.fd12h(phi)
        true_nu = 2.05084445153549852555324471186e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1808_fd12h(self):
        phi = 40.0
        nu = fd.fd12h(phi)
        true_nu = 2.44309649683897724664103403827e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1809_fd12h(self):
        phi = 41.0
        nu = fd.fd12h(phi)
        true_nu = 2.89812170919906935334286450581e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1810_fd12h(self):
        phi = 42.0
        nu = fd.fd12h(phi)
        true_nu = 3.42409601330462221581903322336e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1811_fd12h(self):
        phi = 43.0
        nu = fd.fd12h(phi)
        true_nu = 4.03002773368984854019427789916e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1812_fd12h(self):
        phi = 44.0
        nu = fd.fd12h(phi)
        true_nu = 4.72581972916957918163008018284e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1813_fd12h(self):
        phi = 45.0
        nu = fd.fd12h(phi)
        true_nu = 5.52233455127451595739696906062e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1814_fd12h(self):
        phi = 46.0
        nu = fd.fd12h(phi)
        true_nu = 6.43146269868648445994682426991e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1815_fd12h(self):
        phi = 47.0
        nu = fd.fd12h(phi)
        true_nu = 7.46619403967368686998517972120e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1816_fd12h(self):
        phi = 48.0
        nu = fd.fd12h(phi)
        true_nu = 8.64069247452595476954352692250e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1817_fd12h(self):
        phi = 49.0
        nu = fd.fd12h(phi)
        true_nu = 9.97037390999000195505161840482e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1818_fd12h(self):
        phi = 50.0
        nu = fd.fd12h(phi)
        true_nu = 1.14719876177046772504097711479e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd12h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd12h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1819_fd13h(self):
        phi = -50.0
        nu = fd.fd13h(phi)
        true_nu = 3.60918145780931078811037377008e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1820_fd13h(self):
        phi = -49.0
        nu = fd.fd13h(phi)
        true_nu = 9.81077237237437575628283003275e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1821_fd13h(self):
        phi = -48.0
        nu = fd.fd13h(phi)
        true_nu = 2.66684442629733031438900421832e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1822_fd13h(self):
        phi = -47.0
        nu = fd.fd13h(phi)
        true_nu = 7.24923474333132054585598783074e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1823_fd13h(self):
        phi = -46.0
        nu = fd.fd13h(phi)
        true_nu = 1.97054630730314994919771469745e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1824_fd13h(self):
        phi = -45.0
        nu = fd.fd13h(phi)
        true_nu = 5.35650021927922608748705544004e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1825_fd13h(self):
        phi = -44.0
        nu = fd.fd13h(phi)
        true_nu = 1.45604772102036114353821084395e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1826_fd13h(self):
        phi = -43.0
        nu = fd.fd13h(phi)
        true_nu = 3.95794806141885308326589667311e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1827_fd13h(self):
        phi = -42.0
        nu = fd.fd13h(phi)
        true_nu = 1.07588182933395734322196678926e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1828_fd13h(self):
        phi = -41.0
        nu = fd.fd13h(phi)
        true_nu = 2.92455002624777201695793337414e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1829_fd13h(self):
        phi = -40.0
        nu = fd.fd13h(phi)
        true_nu = 7.94975119276874245418756477461e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1830_fd13h(self):
        phi = -39.0
        nu = fd.fd13h(phi)
        true_nu = 2.16096642080738930260989918986e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1831_fd13h(self):
        phi = -38.0
        nu = fd.fd13h(phi)
        true_nu = 5.87411575359090876800737506519e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1832_fd13h(self):
        phi = -37.0
        nu = fd.fd13h(phi)
        true_nu = 1.59675021112511778939631178778e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1833_fd13h(self):
        phi = -36.0
        nu = fd.fd13h(phi)
        true_nu = 4.34041708348955169423739843421e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1834_fd13h(self):
        phi = -35.0
        nu = fd.fd13h(phi)
        true_nu = 1.17984768859828549539871052095e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1835_fd13h(self):
        phi = -34.0
        nu = fd.fd13h(phi)
        true_nu = 3.20715853226612569480541007754e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1836_fd13h(self):
        phi = -33.0
        nu = fd.fd13h(phi)
        true_nu = 8.71796075924639183760402000652e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1837_fd13h(self):
        phi = -32.0
        nu = fd.fd13h(phi)
        true_nu = 2.36978743130784872073174231506e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1838_fd13h(self):
        phi = -31.0
        nu = fd.fd13h(phi)
        true_nu = 6.44175011183476230612427416182e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1839_fd13h(self):
        phi = -30.0
        nu = fd.fd13h(phi)
        true_nu = 1.75104922724744510897750049890e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1840_fd13h(self):
        phi = -29.0
        nu = fd.fd13h(phi)
        true_nu = 4.75984529516397907588005893772e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1841_fd13h(self):
        phi = -28.0
        nu = fd.fd13h(phi)
        true_nu = 1.29386009721204936655205748462e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1842_fd13h(self):
        phi = -27.0
        nu = fd.fd13h(phi)
        true_nu = 3.51707639081974448486854711803e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1843_fd13h(self):
        phi = -26.0
        nu = fd.fd13h(phi)
        true_nu = 9.56040484246746404954686147442e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1844_fd13h(self):
        phi = -25.0
        nu = fd.fd13h(phi)
        true_nu = 2.59878747559899081699428445243e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1845_fd13h(self):
        phi = -24.0
        nu = fd.fd13h(phi)
        true_nu = 7.06423677094675989775989066379e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1846_fd13h(self):
        phi = -23.0
        nu = fd.fd13h(phi)
        true_nu = 1.92025864463898988577199951030e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1847_fd13h(self):
        phi = -22.0
        nu = fd.fd13h(phi)
        true_nu = 5.21980417965847688126321553793e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1848_fd13h(self):
        phi = -21.0
        nu = fd.fd13h(phi)
        true_nu = 1.41888988496426413355355806447e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1849_fd13h(self):
        phi = -20.0
        nu = fd.fd13h(phi)
        true_nu = 3.85694259085494368809646962834e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1850_fd13h(self):
        phi = -19.0
        nu = fd.fd13h(phi)
        true_nu = 0.0000104842569579256190719710634641
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1851_fd13h(self):
        phi = -18.0
        nu = fd.fd13h(phi)
        true_nu = 0.0000284991651721088429699160301164
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1852_fd13h(self):
        phi = -17.0
        nu = fd.fd13h(phi)
        true_nu = 0.0000774687628023969503199559513164
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1853_fd13h(self):
        phi = -16.0
        nu = fd.fd13h(phi)
        true_nu = 0.000210581930116206539026180677196
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1854_fd13h(self):
        phi = -15.0
        nu = fd.fd13h(phi)
        true_nu = 0.000572421033425249413401805958789
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1855_fd13h(self):
        phi = -14.0
        nu = fd.fd13h(phi)
        true_nu = 0.00155600168886943659475789760160
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1856_fd13h(self):
        phi = -13.0
        nu = fd.fd13h(phi)
        true_nu = 0.00422965108252039094575683029517
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1857_fd13h(self):
        phi = -12.0
        nu = fd.fd13h(phi)
        true_nu = 0.0114973834316538544481682395411
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1858_fd13h(self):
        phi = -11.0
        nu = fd.fd13h(phi)
        true_nu = 0.0312531266343341501664501830377
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1859_fd13h(self):
        phi = -10.0
        nu = fd.fd13h(phi)
        true_nu = 0.0849547927442142553675519346799
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1860_fd13h(self):
        phi = -9.0
        nu = fd.fd13h(phi)
        true_nu = 0.230930969838656624405273475549
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1861_fd13h(self):
        phi = -8.0
        nu = fd.fd13h(phi)
        true_nu = 0.627734723603661167097991336958
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1862_fd13h(self):
        phi = -7.0
        nu = fd.fd13h(phi)
        true_nu = 1.70635445902159686122255814130
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1863_fd13h(self):
        phi = -6.0
        nu = fd.fd13h(phi)
        true_nu = 4.63831217644156354561080573065
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1864_fd13h(self):
        phi = -5.0
        nu = fd.fd13h(phi)
        true_nu = 12.6079431717955022320936639109
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1865_fd13h(self):
        phi = -4.0
        nu = fd.fd13h(phi)
        true_nu = 34.2697533791802475216549849411
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1866_fd13h(self):
        phi = -3.0
        nu = fd.fd13h(phi)
        true_nu = 93.1387030250703193985574888995
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1867_fd13h(self):
        phi = -2.0
        nu = fd.fd13h(phi)
        true_nu = 253.058602719728290391763975636
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1868_fd13h(self):
        phi = -1.0
        nu = fd.fd13h(phi)
        true_nu = 687.020599324359448024003301254
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1869_fd13h(self):
        phi = 0.0
        nu = fd.fd13h(phi)
        true_nu = 1861.36249481207316574496097672
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1870_fd13h(self):
        phi = 1.0
        nu = fd.fd13h(phi)
        true_nu = 5017.99304521024705041537813370
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1871_fd13h(self):
        phi = 2.0
        nu = fd.fd13h(phi)
        true_nu = 13381.9429741014306309784683968
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1872_fd13h(self):
        phi = 3.0
        nu = fd.fd13h(phi)
        true_nu = 34974.1859526465986349856719292
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1873_fd13h(self):
        phi = 4.0
        nu = fd.fd13h(phi)
        true_nu = 88576.2549921248856683342454658
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1874_fd13h(self):
        phi = 5.0
        nu = fd.fd13h(phi)
        true_nu = 215172.719205974850295176159325
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1875_fd13h(self):
        phi = 6.0
        nu = fd.fd13h(phi)
        true_nu = 497959.566724051481904733320214
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1876_fd13h(self):
        phi = 7.0
        nu = fd.fd13h(phi)
        true_nu = 1.09468196160105677034628011114e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1877_fd13h(self):
        phi = 8.0
        nu = fd.fd13h(phi)
        true_nu = 2.28664812332778016295007366278e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1878_fd13h(self):
        phi = 9.0
        nu = fd.fd13h(phi)
        true_nu = 4.54927580688853534191781525294e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1879_fd13h(self):
        phi = 10.0
        nu = fd.fd13h(phi)
        true_nu = 8.64948323913123805681330369600e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1880_fd13h(self):
        phi = 11.0
        nu = fd.fd13h(phi)
        true_nu = 1.57756514257505206459510350670e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1881_fd13h(self):
        phi = 12.0
        nu = fd.fd13h(phi)
        true_nu = 2.77062689287277210174001222799e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1882_fd13h(self):
        phi = 13.0
        nu = fd.fd13h(phi)
        true_nu = 4.70237298916888655371026372854e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1883_fd13h(self):
        phi = 14.0
        nu = fd.fd13h(phi)
        true_nu = 7.73800956842824028255483638318e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1884_fd13h(self):
        phi = 15.0
        nu = fd.fd13h(phi)
        true_nu = 1.23821953243503045803285086908e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1885_fd13h(self):
        phi = 16.0
        nu = fd.fd13h(phi)
        true_nu = 1.93181811408551317399916537482e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1886_fd13h(self):
        phi = 17.0
        nu = fd.fd13h(phi)
        true_nu = 2.94543772134982817253360111891e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1887_fd13h(self):
        phi = 18.0
        nu = fd.fd13h(phi)
        true_nu = 4.39791497912736148068894151116e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1888_fd13h(self):
        phi = 19.0
        nu = fd.fd13h(phi)
        true_nu = 6.44246771204158322352503264912e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1889_fd13h(self):
        phi = 20.0
        nu = fd.fd13h(phi)
        true_nu = 9.27407207258358035727722849802e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1890_fd13h(self):
        phi = 21.0
        nu = fd.fd13h(phi)
        true_nu = 1.31379193908392836236145358447e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1891_fd13h(self):
        phi = 22.0
        nu = fd.fd13h(phi)
        true_nu = 1.83390434338514860496720247714e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1892_fd13h(self):
        phi = 23.0
        nu = fd.fd13h(phi)
        true_nu = 2.52532111949920824694189568888e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1893_fd13h(self):
        phi = 24.0
        nu = fd.fd13h(phi)
        true_nu = 3.43391727034481250271205567929e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1894_fd13h(self):
        phi = 25.0
        nu = fd.fd13h(phi)
        true_nu = 4.61523676557020086091655162828e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1895_fd13h(self):
        phi = 26.0
        nu = fd.fd13h(phi)
        true_nu = 6.13601889288031132636274363967e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1896_fd13h(self):
        phi = 27.0
        nu = fd.fd13h(phi)
        true_nu = 8.07589052429131829536588445307e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1897_fd13h(self):
        phi = 28.0
        nu = fd.fd13h(phi)
        true_nu = 1.05292347401295299221379810809e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1898_fd13h(self):
        phi = 29.0
        nu = fd.fd13h(phi)
        true_nu = 1.36072464652505828526243956833e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1899_fd13h(self):
        phi = 30.0
        nu = fd.fd13h(phi)
        true_nu = 1.74401859794651209024140751479e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1900_fd13h(self):
        phi = 31.0
        nu = fd.fd13h(phi)
        true_nu = 2.21798413677548488402089880636e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1901_fd13h(self):
        phi = 32.0
        nu = fd.fd13h(phi)
        true_nu = 2.80022111757624615716514826972e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1902_fd13h(self):
        phi = 33.0
        nu = fd.fd13h(phi)
        true_nu = 3.51104187324359110740095505558e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1903_fd13h(self):
        phi = 34.0
        nu = fd.fd13h(phi)
        true_nu = 4.37378697947805244145923959405e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1904_fd13h(self):
        phi = 35.0
        nu = fd.fd13h(phi)
        true_nu = 5.41516653595855934854382731051e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1905_fd13h(self):
        phi = 36.0
        nu = fd.fd13h(phi)
        true_nu = 6.66562816738960806070571893228e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1906_fd13h(self):
        phi = 37.0
        nu = fd.fd13h(phi)
        true_nu = 8.15975296600342036864766658648e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1907_fd13h(self):
        phi = 38.0
        nu = fd.fd13h(phi)
        true_nu = 9.93668061522686126139932625338e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1908_fd13h(self):
        phi = 39.0
        nu = fd.fd13h(phi)
        true_nu = 1.20405649520899999936954615389e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1909_fd13h(self):
        phi = 40.0
        nu = fd.fd13h(phi)
        true_nu = 1.45210612435692213331671965237e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1910_fd13h(self):
        phi = 41.0
        nu = fd.fd13h(phi)
        true_nu = 1.74338464694330535818617729497e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1911_fd13h(self):
        phi = 42.0
        nu = fd.fd13h(phi)
        true_nu = 2.08411739213030141041136584416e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1912_fd13h(self):
        phi = 43.0
        nu = fd.fd13h(phi)
        true_nu = 2.48124634445637904960446127492e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1913_fd13h(self):
        phi = 44.0
        nu = fd.fd13h(phi)
        true_nu = 2.94249286664654132189469434450e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1914_fd13h(self):
        phi = 45.0
        nu = fd.fd13h(phi)
        true_nu = 3.47642425702626482593773741617e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1915_fd13h(self):
        phi = 46.0
        nu = fd.fd13h(phi)
        true_nu = 4.09252427915410829666999474024e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1916_fd13h(self):
        phi = 47.0
        nu = fd.fd13h(phi)
        true_nu = 4.80126780289922930212709659719e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1917_fd13h(self):
        phi = 48.0
        nu = fd.fd13h(phi)
        true_nu = 5.61419969778286588741507399716e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1918_fd13h(self):
        phi = 49.0
        nu = fd.fd13h(phi)
        true_nu = 6.54401812097780701705070547988e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1919_fd13h(self):
        phi = 50.0
        nu = fd.fd13h(phi)
        true_nu = 7.60466234391757983075997714853e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd13h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd13h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1920_fd14h(self):
        phi = -50.0
        nu = fd.fd14h(phi)
        true_nu = 9.72089923373814562640740047140e-19
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1921_fd14h(self):
        phi = -49.0
        nu = fd.fd14h(phi)
        true_nu = 2.64241437433518582433458446096e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1922_fd14h(self):
        phi = -48.0
        nu = fd.fd14h(phi)
        true_nu = 7.18282697701431293567797799415e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1923_fd14h(self):
        phi = -47.0
        nu = fd.fd14h(phi)
        true_nu = 1.95249480485834230491743511190e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1924_fd14h(self):
        phi = -46.0
        nu = fd.fd14h(phi)
        true_nu = 5.30743114820712143889649720014e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1925_fd14h(self):
        phi = -45.0
        nu = fd.fd14h(phi)
        true_nu = 1.44270936459689439681277998149e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1926_fd14h(self):
        phi = -44.0
        nu = fd.fd14h(phi)
        true_nu = 3.92169064953143344391831963181e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1927_fd14h(self):
        phi = -43.0
        nu = fd.fd14h(phi)
        true_nu = 1.06602604294590456526134533224e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1928_fd14h(self):
        phi = -42.0
        nu = fd.fd14h(phi)
        true_nu = 2.89775922120395414255233986570e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1929_fd14h(self):
        phi = -41.0
        nu = fd.fd14h(phi)
        true_nu = 7.87692623424834339112996159331e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1930_fd14h(self):
        phi = -40.0
        nu = fd.fd14h(phi)
        true_nu = 2.14117054466696085361040131886e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1931_fd14h(self):
        phi = -39.0
        nu = fd.fd14h(phi)
        true_nu = 5.82030498319995613681371538311e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1932_fd14h(self):
        phi = -38.0
        nu = fd.fd14h(phi)
        true_nu = 1.58212292719220693267531451434e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1933_fd14h(self):
        phi = -37.0
        nu = fd.fd14h(phi)
        true_nu = 4.30065600337500915888263310691e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1934_fd14h(self):
        phi = -36.0
        nu = fd.fd14h(phi)
        true_nu = 1.16903950644275897065015670905e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1935_fd14h(self):
        phi = -35.0
        nu = fd.fd14h(phi)
        true_nu = 3.17777884711408264253540001332e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1936_fd14h(self):
        phi = -34.0
        nu = fd.fd14h(phi)
        true_nu = 8.63809849497174529233403145228e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1937_fd14h(self):
        phi = -33.0
        nu = fd.fd14h(phi)
        true_nu = 2.34807861713211222881670765644e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1938_fd14h(self):
        phi = -32.0
        nu = fd.fd14h(phi)
        true_nu = 6.38273943674346424870266661785e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1939_fd14h(self):
        phi = -31.0
        nu = fd.fd14h(phi)
        true_nu = 1.73500846266886790172011907770e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1940_fd14h(self):
        phi = -30.0
        nu = fd.fd14h(phi)
        true_nu = 4.71624197629544627693952303487e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1941_fd14h(self):
        phi = -29.0
        nu = fd.fd14h(phi)
        true_nu = 1.28200748627796787296540536376e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1942_fd14h(self):
        phi = -28.0
        nu = fd.fd14h(phi)
        true_nu = 3.48485765389785290436107752500e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1943_fd14h(self):
        phi = -27.0
        nu = fd.fd14h(phi)
        true_nu = 9.47282523535691025695666771056e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1944_fd14h(self):
        phi = -26.0
        nu = fd.fd14h(phi)
        true_nu = 2.57498087014386426894751362482e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1945_fd14h(self):
        phi = -25.0
        nu = fd.fd14h(phi)
        true_nu = 6.99952370794148665708321123748e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1946_fd14h(self):
        phi = -24.0
        nu = fd.fd14h(phi)
        true_nu = 1.90266781031638468765027544365e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1947_fd14h(self):
        phi = -23.0
        nu = fd.fd14h(phi)
        true_nu = 5.17198733437567949788721392606e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1948_fd14h(self):
        phi = -22.0
        nu = fd.fd14h(phi)
        true_nu = 1.40589191880440619268037562468e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1949_fd14h(self):
        phi = -21.0
        nu = fd.fd14h(phi)
        true_nu = 3.82161045565628161892514554233e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1950_fd14h(self):
        phi = -20.0
        nu = fd.fd14h(phi)
        true_nu = 0.0000103882142570066919785540128954
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1951_fd14h(self):
        phi = -19.0
        nu = fd.fd14h(phi)
        true_nu = 0.0000282380940445698116333660836830
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1952_fd14h(self):
        phi = -18.0
        nu = fd.fd14h(phi)
        true_nu = 0.0000767590979087850867488002631125
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1953_fd14h(self):
        phi = -17.0
        nu = fd.fd14h(phi)
        true_nu = 0.000208652860993029827454934116547
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1954_fd14h(self):
        phi = -16.0
        nu = fd.fd14h(phi)
        true_nu = 0.000567177280335740178996411555697
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1955_fd14h(self):
        phi = -15.0
        nu = fd.fd14h(phi)
        true_nu = 0.00154174769348691997339101541401
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1956_fd14h(self):
        phi = -14.0
        nu = fd.fd14h(phi)
        true_nu = 0.00419090473066925736680818540538
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1957_fd14h(self):
        phi = -13.0
        nu = fd.fd14h(phi)
        true_nu = 0.0113920601105993324330229213160
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1958_fd14h(self):
        phi = -12.0
        nu = fd.fd14h(phi)
        true_nu = 0.0309668295175447419587821004265
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1959_fd14h(self):
        phi = -11.0
        nu = fd.fd14h(phi)
        true_nu = 0.0841765664910763939365838847187
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1960_fd14h(self):
        phi = -10.0
        nu = fd.fd14h(phi)
        true_nu = 0.228815605424033592628354723373
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1961_fd14h(self):
        phi = -9.0
        nu = fd.fd14h(phi)
        true_nu = 0.621985112758082495744850836068
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1962_fd14h(self):
        phi = -8.0
        nu = fd.fd14h(phi)
        true_nu = 1.69072942912140607016623468872
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1963_fd14h(self):
        phi = -7.0
        nu = fd.fd14h(phi)
        true_nu = 4.59586873625552494799573866553
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1964_fd14h(self):
        phi = -6.0
        nu = fd.fd14h(phi)
        true_nu = 12.4927900179141368383296622317
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1965_fd14h(self):
        phi = -5.0
        nu = fd.fd14h(phi)
        true_nu = 33.9583592991019159736156428408
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1966_fd14h(self):
        phi = -4.0
        nu = fd.fd14h(phi)
        true_nu = 92.3042202899393871770216842580
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1967_fd14h(self):
        phi = -3.0
        nu = fd.fd14h(phi)
        true_nu = 250.878118472339849328037542931
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1968_fd14h(self):
        phi = -2.0
        nu = fd.fd14h(phi)
        true_nu = 681.731117258312948962054808135
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1969_fd14h(self):
        phi = -1.0
        nu = fd.fd14h(phi)
        true_nu = 1851.48488698096750105388846130
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1970_fd14h(self):
        phi = 0.0
        nu = fd.fd14h(phi)
        true_nu = 5021.01432933734541210553787082
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1971_fd14h(self):
        phi = 1.0
        nu = fd.fd14h(phi)
        true_nu = 13567.1145986895771182507593372
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1972_fd14h(self):
        phi = 2.0
        nu = fd.fd14h(phi)
        true_nu = 36361.9986181421675835272998326
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1973_fd14h(self):
        phi = 3.0
        nu = fd.fd14h(phi)
        true_nu = 95928.0284440768129180596169607
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1974_fd14h(self):
        phi = 4.0
        nu = fd.fd14h(phi)
        true_nu = 246605.083832826147675894910161
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1975_fd14h(self):
        phi = 5.0
        nu = fd.fd14h(phi)
        true_nu = 611526.414107404231877643312805
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1976_fd14h(self):
        phi = 6.0
        nu = fd.fd14h(phi)
        true_nu = 1.45151114238570026817063481729e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1977_fd14h(self):
        phi = 7.0
        nu = fd.fd14h(phi)
        true_nu = 3.28371003743275468098171323111e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1978_fd14h(self):
        phi = 8.0
        nu = fd.fd14h(phi)
        true_nu = 7.07275838731787863025971712665e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1979_fd14h(self):
        phi = 9.0
        nu = fd.fd14h(phi)
        true_nu = 1.45221833527432457744083835311e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1980_fd14h(self):
        phi = 10.0
        nu = fd.fd14h(phi)
        true_nu = 2.84988359016829944683844515779e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1981_fd14h(self):
        phi = 11.0
        nu = fd.fd14h(phi)
        true_nu = 5.36281510455979666830755525428e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1982_fd14h(self):
        phi = 12.0
        nu = fd.fd14h(phi)
        true_nu = 9.71030777463890680138993651352e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1983_fd14h(self):
        phi = 13.0
        nu = fd.fd14h(phi)
        true_nu = 1.69754558997851217961511691430e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1984_fd14h(self):
        phi = 14.0
        nu = fd.fd14h(phi)
        true_nu = 2.87436482266961724331622855229e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1985_fd14h(self):
        phi = 15.0
        nu = fd.fd14h(phi)
        true_nu = 4.72783060363184964498460549282e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1986_fd14h(self):
        phi = 16.0
        nu = fd.fd14h(phi)
        true_nu = 7.57401642760876272621259712904e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1987_fd14h(self):
        phi = 17.0
        nu = fd.fd14h(phi)
        true_nu = 1.18456899738401254090929706088e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1988_fd14h(self):
        phi = 18.0
        nu = fd.fd14h(phi)
        true_nu = 1.81250414285664414886692951611e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1989_fd14h(self):
        phi = 19.0
        nu = fd.fd14h(phi)
        true_nu = 2.71829585122031702965621237232e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1990_fd14h(self):
        phi = 20.0
        nu = fd.fd14h(phi)
        true_nu = 4.00256798111892428484721266991e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1991_fd14h(self):
        phi = 21.0
        nu = fd.fd14h(phi)
        true_nu = 5.79497084145115635552578800494e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1992_fd14h(self):
        phi = 22.0
        nu = fd.fd14h(phi)
        true_nu = 8.26059182549061192431744725063e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1993_fd14h(self):
        phi = 23.0
        nu = fd.fd14h(phi)
        true_nu = 1.16073835954735924210693269120e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1994_fd14h(self):
        phi = 24.0
        nu = fd.fd14h(phi)
        true_nu = 1.60947131376545885466018614879e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1995_fd14h(self):
        phi = 25.0
        nu = fd.fd14h(phi)
        true_nu = 2.20431400478294619100191799155e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1996_fd14h(self):
        phi = 26.0
        nu = fd.fd14h(phi)
        true_nu = 2.98455374473263229183450037523e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1997_fd14h(self):
        phi = 27.0
        nu = fd.fd14h(phi)
        true_nu = 3.99796739694641053374129322006e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1998_fd14h(self):
        phi = 28.0
        nu = fd.fd14h(phi)
        true_nu = 5.30223802964788376781264381242e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_1999_fd14h(self):
        phi = 29.0
        nu = fd.fd14h(phi)
        true_nu = 6.96654287669176114647844343829e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2000_fd14h(self):
        phi = 30.0
        nu = fd.fd14h(phi)
        true_nu = 9.07332596135002464063296515296e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2001_fd14h(self):
        phi = 31.0
        nu = fd.fd14h(phi)
        true_nu = 1.17202692431448652478192777051e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2002_fd14h(self):
        phi = 32.0
        nu = fd.fd14h(phi)
        true_nu = 1.50224766517283888917555076776e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2003_fd14h(self):
        phi = 33.0
        nu = fd.fd14h(phi)
        true_nu = 1.91148858758090920133067919336e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2004_fd14h(self):
        phi = 34.0
        nu = fd.fd14h(phi)
        true_nu = 2.41549232791251068529411217376e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2005_fd14h(self):
        phi = 35.0
        nu = fd.fd14h(phi)
        true_nu = 3.03254178194642164246831320497e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2006_fd14h(self):
        phi = 36.0
        nu = fd.fd14h(phi)
        true_nu = 3.78377903507306391815710059867e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2007_fd14h(self):
        phi = 37.0
        nu = fd.fd14h(phi)
        true_nu = 4.69355351920585833726183963833e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2008_fd14h(self):
        phi = 38.0
        nu = fd.fd14h(phi)
        true_nu = 5.78980113519725710912820641372e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2009_fd14h(self):
        phi = 39.0
        nu = fd.fd14h(phi)
        true_nu = 7.10445612995945320154354907353e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2010_fd14h(self):
        phi = 40.0
        nu = fd.fd14h(phi)
        true_nu = 8.67389756788976668388485596549e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2011_fd14h(self):
        phi = 41.0
        nu = fd.fd14h(phi)
        true_nu = 1.05394322866007080394173341472e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2012_fd14h(self):
        phi = 42.0
        nu = fd.fd14h(phi)
        true_nu = 1.27478162773547184467435995496e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2013_fd14h(self):
        phi = 43.0
        nu = fd.fd14h(phi)
        true_nu = 1.53518164810035870304034792640e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2014_fd14h(self):
        phi = 44.0
        nu = fd.fd14h(phi)
        true_nu = 1.84108150406325450806244261266e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2015_fd14h(self):
        phi = 45.0
        nu = fd.fd14h(phi)
        true_nu = 2.19914581025090372422225456639e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2016_fd14h(self):
        phi = 46.0
        nu = fd.fd14h(phi)
        true_nu = 2.61683513073361696726542354230e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2017_fd14h(self):
        phi = 47.0
        nu = fd.fd14h(phi)
        true_nu = 3.10248041642108351692184366947e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2018_fd14h(self):
        phi = 48.0
        nu = fd.fd14h(phi)
        true_nu = 3.66536255500865152654094986331e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2019_fd14h(self):
        phi = 49.0
        nu = fd.fd14h(phi)
        true_nu = 4.31579726279407592964206547727e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2020_fd14h(self):
        phi = 50.0
        nu = fd.fd14h(phi)
        true_nu = 5.06522555272473404337981119439e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd14h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd14h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2021_fd15h(self):
        phi = -50.0
        nu = fd.fd15h(phi)
        true_nu = 2.70688609335698309108278176964e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2022_fd15h(self):
        phi = -49.0
        nu = fd.fd15h(phi)
        true_nu = 7.35807927928078181721213318021e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2023_fd15h(self):
        phi = -48.0
        nu = fd.fd15h(phi)
        true_nu = 2.00013331972299773579176103726e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2024_fd15h(self):
        phi = -47.0
        nu = fd.fd15h(phi)
        true_nu = 5.43692605749849040939204905093e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2025_fd15h(self):
        phi = -46.0
        nu = fd.fd15h(phi)
        true_nu = 1.47790973047736246189832901104e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2026_fd15h(self):
        phi = -45.0
        nu = fd.fd15h(phi)
        true_nu = 4.01737516445941956561560922044e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2027_fd15h(self):
        phi = -44.0
        nu = fd.fd15h(phi)
        true_nu = 1.09203579076527085765389283924e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2028_fd15h(self):
        phi = -43.0
        nu = fd.fd15h(phi)
        true_nu = 2.96846104606413981245115676269e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2029_fd15h(self):
        phi = -42.0
        nu = fd.fd15h(phi)
        true_nu = 8.06911372000468007417756544802e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2030_fd15h(self):
        phi = -41.0
        nu = fd.fd15h(phi)
        true_nu = 2.19341251968582901272791875764e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2031_fd15h(self):
        phi = -40.0
        nu = fd.fd15h(phi)
        true_nu = 5.96231339457655684071063853621e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2032_fd15h(self):
        phi = -39.0
        nu = fd.fd15h(phi)
        true_nu = 1.62072481560554197700912189032e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2033_fd15h(self):
        phi = -38.0
        nu = fd.fd15h(phi)
        true_nu = 4.40558681519318157638752701125e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2034_fd15h(self):
        phi = -37.0
        nu = fd.fd15h(phi)
        true_nu = 1.19756265834383834232949261564e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2035_fd15h(self):
        phi = -36.0
        nu = fd.fd15h(phi)
        true_nu = 3.25531281261716377276367474717e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2036_fd15h(self):
        phi = -35.0
        nu = fd.fd15h(phi)
        true_nu = 8.84885766448714123090113584254e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2037_fd15h(self):
        phi = -34.0
        nu = fd.fd15h(phi)
        true_nu = 2.40536889919959428249118925572e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2038_fd15h(self):
        phi = -33.0
        nu = fd.fd15h(phi)
        true_nu = 6.53847056943479396234316992414e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2039_fd15h(self):
        phi = -32.0
        nu = fd.fd15h(phi)
        true_nu = 1.77734057348088660272043922340e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2040_fd15h(self):
        phi = -31.0
        nu = fd.fd15h(phi)
        true_nu = 4.83131258387607218898288583067e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2041_fd15h(self):
        phi = -30.0
        nu = fd.fd15h(phi)
        true_nu = 1.31328692043558417117873720779e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2042_fd15h(self):
        phi = -29.0
        nu = fd.fd15h(phi)
        true_nu = 3.56988397137298681509271257733e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2043_fd15h(self):
        phi = -28.0
        nu = fd.fd15h(phi)
        true_nu = 9.70395072909038878224287413228e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2044_fd15h(self):
        phi = -27.0
        nu = fd.fd15h(phi)
        true_nu = 2.63780729311482205786477418212e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2045_fd15h(self):
        phi = -26.0
        nu = fd.fd15h(phi)
        true_nu = 7.17030363185069922447092225116e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2046_fd15h(self):
        phi = -25.0
        nu = fd.fd15h(phi)
        true_nu = 1.94909060669931788061729578428e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2047_fd15h(self):
        phi = -24.0
        nu = fd.fd15h(phi)
        true_nu = 5.29817757821062238731743748639e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2048_fd15h(self):
        phi = -23.0
        nu = fd.fd15h(phi)
        true_nu = 1.44019398347965063307602904394e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2049_fd15h(self):
        phi = -22.0
        nu = fd.fd15h(phi)
        true_nu = 3.91485313474687401216981326377e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2050_fd15h(self):
        phi = -21.0
        nu = fd.fd15h(phi)
        true_nu = 0.0000106416741372542689900474083476
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2051_fd15h(self):
        phi = -20.0
        nu = fd.fd15h(phi)
        true_nu = 0.0000289270694315767648572981620408
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2052_fd15h(self):
        phi = -19.0
        nu = fd.fd15h(phi)
        true_nu = 0.0000786319271856590259737740046644
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2053_fd15h(self):
        phi = -18.0
        nu = fd.fd15h(phi)
        true_nu = 0.000213743738799807938533945678826
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2054_fd15h(self):
        phi = -17.0
        nu = fd.fd15h(phi)
        true_nu = 0.000581015721084416684250946222861
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2055_fd15h(self):
        phi = -16.0
        nu = fd.fd15h(phi)
        true_nu = 0.00157936447636247465323338570986
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2056_fd15h(self):
        phi = -15.0
        nu = fd.fd15h(phi)
        true_nu = 0.00429315775431684743248022731236
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2057_fd15h(self):
        phi = -14.0
        nu = fd.fd15h(phi)
        true_nu = 0.0116700126933244033719701124553
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2058_fd15h(self):
        phi = -13.0
        nu = fd.fd15h(phi)
        true_nu = 0.0317223833169564317430628658935
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2059_fd15h(self):
        phi = -12.0
        nu = fd.fd15h(phi)
        true_nu = 0.0862303772008319657113067057397
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2060_fd15h(self):
        phi = -11.0
        nu = fd.fd15h(phi)
        true_nu = 0.234398460570850864743021903867
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2061_fd15h(self):
        phi = -10.0
        nu = fd.fd15h(phi)
        true_nu = 0.637161025481871703340520235754
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2062_fd15h(self):
        phi = -9.0
        nu = fd.fd15h(phi)
        true_nu = 1.73198286417452903064207197972
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2063_fd15h(self):
        phi = -8.0
        nu = fd.fd15h(phi)
        true_nu = 4.70801478935348161930435877996
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2064_fd15h(self):
        phi = -7.0
        nu = fd.fd15h(phi)
        true_nu = 12.7976906749499891115682312509
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2065_fd15h(self):
        phi = -6.0
        nu = fd.fd15h(phi)
        true_nu = 34.7875794657275800954352343793
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2066_fd15h(self):
        phi = -5.0
        nu = fd.fd15h(phi)
        true_nu = 94.5613329590952311091725887716
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2067_fd15h(self):
        phi = -4.0
        nu = fd.fd15h(phi)
        true_nu = 257.036139392335661095685229195
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2068_fd15h(self):
        phi = -3.0
        nu = fd.fd15h(phi)
        true_nu = 698.636058501250645798382114693
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2069_fd15h(self):
        phi = -2.0
        nu = fd.fd15h(phi)
        true_nu = 1898.64350750803069005075536108
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2070_fd15h(self):
        phi = -1.0
        nu = fd.fd15h(phi)
        true_nu = 5157.78327415922094413966381608
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2071_fd15h(self):
        phi = 0.0
        nu = fd.fd15h(phi)
        true_nu = 13996.7836281144022350710321944
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2072_fd15h(self):
        phi = 1.0
        nu = fd.fd15h(phi)
        true_nu = 37883.5612899737621971509584474
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2073_fd15h(self):
        phi = 2.0
        nu = fd.fd15h(phi)
        true_nu = 101915.357549983810223815796888
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2074_fd15h(self):
        phi = 3.0
        nu = fd.fd15h(phi)
        true_nu = 270839.892813916389906335764579
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2075_fd15h(self):
        phi = 4.0
        nu = fd.fd15h(phi)
        true_nu = 704786.411814175754889585661989
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2076_fd15h(self):
        phi = 5.0
        nu = fd.fd15h(phi)
        true_nu = 1.77857352127051444857547233533e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2077_fd15h(self):
        phi = 6.0
        nu = fd.fd15h(phi)
        true_nu = 4.31680539439484872666294832852e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2078_fd15h(self):
        phi = 7.0
        nu = fd.fd15h(phi)
        true_nu = 1.00227218972349492919761148299e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2079_fd15h(self):
        phi = 8.0
        nu = fd.fd15h(phi)
        true_nu = 2.22092341259978053930285548776e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2080_fd15h(self):
        phi = 9.0
        nu = fd.fd15h(phi)
        true_nu = 4.69751283916379314088144429297e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2081_fd15h(self):
        phi = 10.0
        nu = fd.fd15h(phi)
        true_nu = 9.50075819114644908768542177323e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2082_fd15h(self):
        phi = 11.0
        nu = fd.fd15h(phi)
        true_nu = 1.84233550667990526509503586641e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2083_fd15h(self):
        phi = 12.0
        nu = fd.fd15h(phi)
        true_nu = 3.43586999478636930454611562870e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2084_fd15h(self):
        phi = 13.0
        nu = fd.fd15h(phi)
        true_nu = 6.18206140121750942564833005464e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2085_fd15h(self):
        phi = 14.0
        nu = fd.fd15h(phi)
        true_nu = 1.07642465911399295302659278857e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2086_fd15h(self):
        phi = 15.0
        nu = fd.fd15h(phi)
        true_nu = 1.81897321439896779529416877851e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2087_fd15h(self):
        phi = 16.0
        nu = fd.fd15h(phi)
        true_nu = 2.99086214253471905836611479565e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2088_fd15h(self):
        phi = 17.0
        nu = fd.fd15h(phi)
        true_nu = 4.79647324354614284863807262675e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2089_fd15h(self):
        phi = 18.0
        nu = fd.fd15h(phi)
        true_nu = 7.51844761046311256250643053576e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2090_fd15h(self):
        phi = 19.0
        nu = fd.fd15h(phi)
        true_nu = 1.15410176657279927693380509892e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2091_fd15h(self):
        phi = 20.0
        nu = fd.fd15h(phi)
        true_nu = 1.73784947863699531414376083342e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2092_fd15h(self):
        phi = 21.0
        nu = fd.fd15h(phi)
        true_nu = 2.57096890801987909298539039752e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2093_fd15h(self):
        phi = 22.0
        nu = fd.fd15h(phi)
        true_nu = 3.74191049581479489976048153992e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2094_fd15h(self):
        phi = 23.0
        nu = fd.fd15h(phi)
        true_nu = 5.36458250801262027181601420554e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2095_fd15h(self):
        phi = 24.0
        nu = fd.fd15h(phi)
        true_nu = 7.58410659844273196873367882241e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2096_fd15h(self):
        phi = 25.0
        nu = fd.fd15h(phi)
        true_nu = 1.05835461198729281490534379558e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2097_fd15h(self):
        phi = 26.0
        nu = fd.fd15h(phi)
        true_nu = 1.45917201832091766028414719303e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2098_fd15h(self):
        phi = 27.0
        nu = fd.fd15h(phi)
        true_nu = 1.98922240523124716390028587273e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2099_fd15h(self):
        phi = 28.0
        nu = fd.fd15h(phi)
        true_nu = 2.68337842133213555015623067241e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2100_fd15h(self):
        phi = 29.0
        nu = fd.fd15h(phi)
        true_nu = 3.58420843691206536561182076108e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2101_fd15h(self):
        phi = 30.0
        nu = fd.fd15h(phi)
        true_nu = 4.74332066785219180258226902619e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2102_fd15h(self):
        phi = 31.0
        nu = fd.fd15h(phi)
        true_nu = 6.22288407827974517613457530685e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2103_fd15h(self):
        phi = 32.0
        nu = fd.fd15h(phi)
        true_nu = 8.09734215365848804235959894690e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2104_fd15h(self):
        phi = 33.0
        nu = fd.fd15h(phi)
        true_nu = 1.04553364883153870767256824354e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2105_fd15h(self):
        phi = 34.0
        nu = fd.fd15h(phi)
        true_nu = 1.34018579983041800554620535223e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2106_fd15h(self):
        phi = 35.0
        nu = fd.fd15h(phi)
        true_nu = 1.70606444517690373665038537945e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2107_fd15h(self):
        phi = 36.0
        nu = fd.fd15h(phi)
        true_nu = 2.15768439043637741075767386085e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2108_fd15h(self):
        phi = 37.0
        nu = fd.fd15h(phi)
        true_nu = 2.71199645365836699112081617045e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2109_fd15h(self):
        phi = 38.0
        nu = fd.fd15h(phi)
        true_nu = 3.38871323128675456197837765013e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2110_fd15h(self):
        phi = 39.0
        nu = fd.fd15h(phi)
        true_nu = 4.21066788188262723130788509697e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2111_fd15h(self):
        phi = 40.0
        nu = fd.fd15h(phi)
        true_nu = 5.20420825827579219430452503323e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2112_fd15h(self):
        phi = 41.0
        nu = fd.fd15h(phi)
        true_nu = 6.39962881505349103064538114638e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2113_fd15h(self):
        phi = 42.0
        nu = fd.fd15h(phi)
        true_nu = 7.83164281588178153012888393925e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2114_fd15h(self):
        phi = 43.0
        nu = fd.fd15h(phi)
        true_nu = 9.53989746401941478720385731434e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2115_fd15h(self):
        phi = 44.0
        nu = fd.fd15h(phi)
        true_nu = 1.15695346795094820210322902182e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2116_fd15h(self):
        phi = 45.0
        nu = fd.fd15h(phi)
        true_nu = 1.39718003479049135091248454381e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2117_fd15h(self):
        phi = 46.0
        nu = fd.fd15h(phi)
        true_nu = 1.68047049679849305367488964248e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2118_fd15h(self):
        phi = 47.0
        nu = fd.fd15h(phi)
        true_nu = 2.01337387297361708135962817216e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2119_fd15h(self):
        phi = 48.0
        nu = fd.fd15h(phi)
        true_nu = 2.40326441588903284015175524840e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2120_fd15h(self):
        phi = 49.0
        nu = fd.fd15h(phi)
        true_nu = 2.85842495705161513856851892225e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2121_fd15h(self):
        phi = 50.0
        nu = fd.fd15h(phi)
        true_nu = 3.38813666815443586601309334793e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd15h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd15h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2122_fd16h(self):
        phi = -50.0
        nu = fd.fd16h(phi)
        true_nu = 7.77671938699051650112592330668e-18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2123_fd16h(self):
        phi = -49.0
        nu = fd.fd16h(phi)
        true_nu = 2.11393149946814865946766973343e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2124_fd16h(self):
        phi = -48.0
        nu = fd.fd16h(phi)
        true_nu = 5.74626158161145034854239839018e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2125_fd16h(self):
        phi = -47.0
        nu = fd.fd16h(phi)
        true_nu = 1.56199584388667384393395990821e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2126_fd16h(self):
        phi = -46.0
        nu = fd.fd16h(phi)
        true_nu = 4.24594491856569715111728508906e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2127_fd16h(self):
        phi = -45.0
        nu = fd.fd16h(phi)
        true_nu = 1.15416749167751551745028851304e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2128_fd16h(self):
        phi = -44.0
        nu = fd.fd16h(phi)
        true_nu = 3.13735251962514675513513250535e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2129_fd16h(self):
        phi = -43.0
        nu = fd.fd16h(phi)
        true_nu = 8.52820834356723652209428575911e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2130_fd16h(self):
        phi = -42.0
        nu = fd.fd16h(phi)
        true_nu = 2.31820737696316331404447513180e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2131_fd16h(self):
        phi = -41.0
        nu = fd.fd16h(phi)
        true_nu = 6.30154098739867471292320475546e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2132_fd16h(self):
        phi = -40.0
        nu = fd.fd16h(phi)
        true_nu = 1.71293643573356868290253425977e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2133_fd16h(self):
        phi = -39.0
        nu = fd.fd16h(phi)
        true_nu = 4.65624398655996490955599447321e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2134_fd16h(self):
        phi = -38.0
        nu = fd.fd16h(phi)
        true_nu = 1.26569834175376554621785307963e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2135_fd16h(self):
        phi = -37.0
        nu = fd.fd16h(phi)
        true_nu = 3.44052480270000732767950808707e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2136_fd16h(self):
        phi = -36.0
        nu = fd.fd16h(phi)
        true_nu = 9.35231605154207176943815027345e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2137_fd16h(self):
        phi = -35.0
        nu = fd.fd16h(phi)
        true_nu = 2.54222307769126611715898667769e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2138_fd16h(self):
        phi = -34.0
        nu = fd.fd16h(phi)
        true_nu = 6.91047879597739625699989679154e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2139_fd16h(self):
        phi = -33.0
        nu = fd.fd16h(phi)
        true_nu = 1.87846289370568980014622696417e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2140_fd16h(self):
        phi = -32.0
        nu = fd.fd16h(phi)
        true_nu = 5.10619154939477152526224092498e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2141_fd16h(self):
        phi = -31.0
        nu = fd.fd16h(phi)
        true_nu = 1.38800677013509441469995332058e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2142_fd16h(self):
        phi = -30.0
        nu = fd.fd16h(phi)
        true_nu = 3.77299358103635771112684099018e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2143_fd16h(self):
        phi = -29.0
        nu = fd.fd16h(phi)
        true_nu = 1.02560598902237480790332468546e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2144_fd16h(self):
        phi = -28.0
        nu = fd.fd16h(phi)
        true_nu = 2.78788612311828608844200807720e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2145_fd16h(self):
        phi = -27.0
        nu = fd.fd16h(phi)
        true_nu = 7.57826018828555602501534029801e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2146_fd16h(self):
        phi = -26.0
        nu = fd.fd16h(phi)
        true_nu = 2.05998469611511197110568452757e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2147_fd16h(self):
        phi = -25.0
        nu = fd.fd16h(phi)
        true_nu = 5.59961896635334121471709603877e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2148_fd16h(self):
        phi = -24.0
        nu = fd.fd16h(phi)
        true_nu = 1.52213424825321998179173598313e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2149_fd16h(self):
        phi = -23.0
        nu = fd.fd16h(phi)
        true_nu = 4.13758986750137288442667407627e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2150_fd16h(self):
        phi = -22.0
        nu = fd.fd16h(phi)
        true_nu = 0.0000112471353504413771830828089373
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2151_fd16h(self):
        phi = -21.0
        nu = fd.fd16h(phi)
        true_nu = 0.0000305728836452955304392306900176
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2152_fd16h(self):
        phi = -20.0
        nu = fd.fd16h(phi)
        true_nu = 0.0000831057140563880937260004409285
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2153_fd16h(self):
        phi = -19.0
        nu = fd.fd16h(phi)
        true_nu = 0.000225904752359030560139945926810
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2154_fd16h(self):
        phi = -18.0
        nu = fd.fd16h(phi)
        true_nu = 0.000614072783288546936264097259122
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2155_fd16h(self):
        phi = -17.0
        nu = fd.fd16h(phi)
        true_nu = 0.00166922288807920890833270938810
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2156_fd16h(self):
        phi = -16.0
        nu = fd.fd16h(phi)
        true_nu = 0.00453741824368322446312365219048
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2157_fd16h(self):
        phi = -15.0
        nu = fd.fd16h(phi)
        true_nu = 0.0123339815552644877578141979507
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2158_fd16h(self):
        phi = -14.0
        nu = fd.fd16h(phi)
        true_nu = 0.0335272378998049574210770733248
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2159_fd16h(self):
        phi = -13.0
        nu = fd.fd16h(phi)
        true_nu = 0.0911364812871353731118417746887
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2160_fd16h(self):
        phi = -12.0
        nu = fd.fd16h(phi)
        true_nu = 0.247734639113275438996942619217
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2161_fd16h(self):
        phi = -11.0
        nu = fd.fd16h(phi)
        true_nu = 0.673412553895653295710928111114
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2162_fd16h(self):
        phi = -10.0
        nu = fd.fd16h(phi)
        true_nu = 1.83052500570773313415797802666
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2163_fd16h(self):
        phi = -9.0
        nu = fd.fd16h(phi)
        true_nu = 4.97588210141786465900127090907
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2164_fd16h(self):
        phi = -8.0
        nu = fd.fd16h(phi)
        true_nu = 13.5258442949615986833045117298
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2165_fd16h(self):
        phi = -7.0
        nu = fd.fd16h(phi)
        true_nu = 36.7670153698246211715860583528
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2166_fd16h(self):
        phi = -6.0
        nu = fd.fd16h(phi)
        true_nu = 99.9428039376570719883573901372
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2167_fd16h(self):
        phi = -5.0
        nu = fd.fd16h(phi)
        true_nu = 271.670448384971683213147798796
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2168_fd16h(self):
        phi = -4.0
        nu = fd.fd16h(phi)
        true_nu = 738.460154880772100196403494305
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2169_fd16h(self):
        phi = -3.0
        nu = fd.fd16h(phi)
        true_nu = 2007.21964672064572399909573977
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2170_fd16h(self):
        phi = -2.0
        nu = fd.fd16h(phi)
        true_nu = 5455.28129049920821948849994655
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2171_fd16h(self):
        phi = -1.0
        nu = fd.fd16h(phi)
        true_nu = 14822.3407146038229544812346532
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2172_fd16h(self):
        phi = 0.0
        nu = fd.fd16h(phi)
        true_nu = 40243.1620768775269365570118443
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2173_fd16h(self):
        phi = 1.0
        nu = fd.fd16h(phi)
        true_nu = 109054.053296106923526467164638
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2174_fd16h(self):
        phi = 2.0
        nu = fd.fd16h(phi)
        true_nu = 294200.488504444732770931666953
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2175_fd16h(self):
        phi = 3.0
        nu = fd.fd16h(phi)
        true_nu = 786266.126824085315169400594510
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2176_fd16h(self):
        phi = 4.0
        nu = fd.fd16h(phi)
        true_nu = 2.06622671994019534297877185733e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2177_fd16h(self):
        phi = 5.0
        nu = fd.fd16h(phi)
        true_nu = 5.29154527278831041813183926864e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2178_fd16h(self):
        phi = 6.0
        nu = fd.fd16h(phi)
        true_nu = 1.30954591956168623664091146637e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2179_fd16h(self):
        phi = 7.0
        nu = fd.fd16h(phi)
        true_nu = 3.11229043338433097662159683964e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2180_fd16h(self):
        phi = 8.0
        nu = fd.fd16h(phi)
        true_nu = 7.07888052283636992786182649051e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2181_fd16h(self):
        phi = 9.0
        nu = fd.fd16h(phi)
        true_nu = 1.53946435810725486381410788663e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2182_fd16h(self):
        phi = 10.0
        nu = fd.fd16h(phi)
        true_nu = 3.20395613391440660462798385463e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2183_fd16h(self):
        phi = 11.0
        nu = fd.fd16h(phi)
        true_nu = 6.39442779911364881918245212418e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2184_fd16h(self):
        phi = 12.0
        nu = fd.fd16h(phi)
        true_nu = 1.22704760324312301978797580347e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2185_fd16h(self):
        phi = 13.0
        nu = fd.fd16h(phi)
        true_nu = 2.27045361825388585650428026111e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2186_fd16h(self):
        phi = 14.0
        nu = fd.fd16h(phi)
        true_nu = 4.06260362988837894906138982479e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2187_fd16h(self):
        phi = 15.0
        nu = fd.fd16h(phi)
        true_nu = 7.04908412146824070286859710244e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2188_fd16h(self):
        phi = 16.0
        nu = fd.fd16h(phi)
        true_nu = 1.18908267517486413526717258249e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2189_fd16h(self):
        phi = 17.0
        nu = fd.fd16h(phi)
        true_nu = 1.95463191843999180476153398378e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2190_fd16h(self):
        phi = 18.0
        nu = fd.fd16h(phi)
        true_nu = 3.13776419736286444415460400770e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2191_fd16h(self):
        phi = 19.0
        nu = fd.fd16h(phi)
        true_nu = 4.92852530296697196348718829667e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2192_fd16h(self):
        phi = 20.0
        nu = fd.fd16h(phi)
        true_nu = 7.58770863078873764981615270985e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2193_fd16h(self):
        phi = 21.0
        nu = fd.fd16h(phi)
        true_nu = 1.14678216805225332634195188892e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2194_fd16h(self):
        phi = 22.0
        nu = fd.fd16h(phi)
        true_nu = 1.70388069707747161902485731094e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2195_fd16h(self):
        phi = 23.0
        nu = fd.fd16h(phi)
        true_nu = 2.49192917613008278844823172549e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2196_fd16h(self):
        phi = 24.0
        nu = fd.fd16h(phi)
        true_nu = 3.59142216151001044017039862026e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2197_fd16h(self):
        phi = 25.0
        nu = fd.fd16h(phi)
        true_nu = 5.10598175047414540783573971488e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2198_fd16h(self):
        phi = 26.0
        nu = fd.fd16h(phi)
        true_nu = 7.16768848712950589785187021217e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2199_fd16h(self):
        phi = 27.0
        nu = fd.fd16h(phi)
        true_nu = 9.94335957802437573048894274422e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2200_fd16h(self):
        phi = 28.0
        nu = fd.fd16h(phi)
        true_nu = 1.36418962086748364182767532667e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2201_fd16h(self):
        phi = 29.0
        nu = fd.fd16h(phi)
        true_nu = 1.85228318322641088303688793410e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2202_fd16h(self):
        phi = 30.0
        nu = fd.fd16h(phi)
        true_nu = 2.49062237849521201944101707065e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2203_fd16h(self):
        phi = 31.0
        nu = fd.fd16h(phi)
        true_nu = 3.31840414686327121884986553137e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2204_fd16h(self):
        phi = 32.0
        nu = fd.fd16h(phi)
        true_nu = 4.38332156315759058762209423548e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2205_fd16h(self):
        phi = 33.0
        nu = fd.fd16h(phi)
        true_nu = 5.74305249701926392378829478056e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2206_fd16h(self):
        phi = 34.0
        nu = fd.fd16h(phi)
        true_nu = 7.46695083711593930511102805690e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2207_fd16h(self):
        phi = 35.0
        nu = fd.fd16h(phi)
        true_nu = 9.63796036123401208740119456080e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2208_fd16h(self):
        phi = 36.0
        nu = fd.fd16h(phi)
        true_nu = 1.23547726243342898884108127258e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2209_fd16h(self):
        phi = 37.0
        nu = fd.fd16h(phi)
        true_nu = 1.57342515672148711326225430356e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2210_fd16h(self):
        phi = 38.0
        nu = fd.fd16h(phi)
        true_nu = 1.99141489193049787322563918633e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2211_fd16h(self):
        phi = 39.0
        nu = fd.fd16h(phi)
        true_nu = 2.50561358803134904798140643620e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2212_fd16h(self):
        phi = 40.0
        nu = fd.fd16h(phi)
        true_nu = 3.13491780169759077274814487524e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2213_fd16h(self):
        phi = 41.0
        nu = fd.fd16h(phi)
        true_nu = 3.90132818029835039287097191371e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2214_fd16h(self):
        phi = 42.0
        nu = fd.fd16h(phi)
        true_nu = 4.83036427623383946172955457353e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2215_fd16h(self):
        phi = 43.0
        nu = fd.fd16h(phi)
        true_nu = 5.95152267488582703992809020808e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2216_fd16h(self):
        phi = 44.0
        nu = fd.fd16h(phi)
        true_nu = 7.29878175073545345329929589610e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2217_fd16h(self):
        phi = 45.0
        nu = fd.fd16h(phi)
        true_nu = 8.91115653151275866725445549663e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2218_fd16h(self):
        phi = 46.0
        nu = fd.fd16h(phi)
        true_nu = 1.08333073195862994350115733548e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2219_fd16h(self):
        phi = 47.0
        nu = fd.fd16h(phi)
        true_nu = 1.31162058931772293772336836498e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2220_fd16h(self):
        phi = 48.0
        nu = fd.fd16h(phi)
        true_nu = 1.58178632873902161506093643764e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2221_fd16h(self):
        phi = 49.0
        nu = fd.fd16h(phi)
        true_nu = 1.90041233364935698629075049523e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2222_fd16h(self):
        phi = 50.0
        nu = fd.fd16h(phi)
        true_nu = 2.27495263443529568920383764422e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd16h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd16h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2223_fd17h(self):
        phi = -50.0
        nu = fd.fd17h(phi)
        true_nu = 2.30085317935343562742036511708e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2224_fd17h(self):
        phi = -49.0
        nu = fd.fd17h(phi)
        true_nu = 6.25436738738866454463031773183e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2225_fd17h(self):
        phi = -48.0
        nu = fd.fd17h(phi)
        true_nu = 1.70011332176454807542300022791e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2226_fd17h(self):
        phi = -47.0
        nu = fd.fd17h(phi)
        true_nu = 4.62138714887371684798326641888e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2227_fd17h(self):
        phi = -46.0
        nu = fd.fd17h(phi)
        true_nu = 1.25622327090575809261359792927e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2228_fd17h(self):
        phi = -45.0
        nu = fd.fd17h(phi)
        true_nu = 3.41476888979050663077340283454e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2229_fd17h(self):
        phi = -44.0
        nu = fd.fd17h(phi)
        true_nu = 9.28230422150480229005908663519e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2230_fd17h(self):
        phi = -43.0
        nu = fd.fd17h(phi)
        true_nu = 2.52319188915451884058422030787e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2231_fd17h(self):
        phi = -42.0
        nu = fd.fd17h(phi)
        true_nu = 6.85874666200397806305637680545e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2232_fd17h(self):
        phi = -41.0
        nu = fd.fd17h(phi)
        true_nu = 1.86440064173295466082275515298e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2233_fd17h(self):
        phi = -40.0
        nu = fd.fd17h(phi)
        true_nu = 5.06796638539007331463377786175e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2234_fd17h(self):
        phi = -39.0
        nu = fd.fd17h(phi)
        true_nu = 1.37761609326471068047972504339e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2235_fd17h(self):
        phi = -38.0
        nu = fd.fd17h(phi)
        true_nu = 3.74474879291420434009174613731e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2236_fd17h(self):
        phi = -37.0
        nu = fd.fd17h(phi)
        true_nu = 1.01792825959226259110002870259e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2237_fd17h(self):
        phi = -36.0
        nu = fd.fd17h(phi)
        true_nu = 2.76701589072458920773551455174e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2238_fd17h(self):
        phi = -35.0
        nu = fd.fd17h(phi)
        true_nu = 7.52152901481407005281555841372e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2239_fd17h(self):
        phi = -34.0
        nu = fd.fd17h(phi)
        true_nu = 2.04456356431965514495704183883e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2240_fd17h(self):
        phi = -33.0
        nu = fd.fd17h(phi)
        true_nu = 5.55769998401957490375126027620e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2241_fd17h(self):
        phi = -32.0
        nu = fd.fd17h(phi)
        true_nu = 1.51073948745875363873531714691e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2242_fd17h(self):
        phi = -31.0
        nu = fd.fd17h(phi)
        true_nu = 4.10661569629466155587606704502e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2243_fd17h(self):
        phi = -30.0
        nu = fd.fd17h(phi)
        true_nu = 1.11629388237024668976631165591e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2244_fd17h(self):
        phi = -29.0
        nu = fd.fd17h(phi)
        true_nu = 3.03440137566703985880643974969e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2245_fd17h(self):
        phi = -28.0
        nu = fd.fd17h(phi)
        true_nu = 8.24835811972683834147498127605e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2246_fd17h(self):
        phi = -27.0
        nu = fd.fd17h(phi)
        true_nu = 2.24213619914760456922573769927e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2247_fd17h(self):
        phi = -26.0
        nu = fd.fd17h(phi)
        true_nu = 6.09475808707313734540736399497e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2248_fd17h(self):
        phi = -25.0
        nu = fd.fd17h(phi)
        true_nu = 1.65672701569445197487012396512e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2249_fd17h(self):
        phi = -24.0
        nu = fd.fd17h(phi)
        true_nu = 4.50345094147926382641876783433e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2250_fd17h(self):
        phi = -23.0
        nu = fd.fd17h(phi)
        true_nu = 0.0000122416488595787653108211256525
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2251_fd17h(self):
        phi = -22.0
        nu = fd.fd17h(phi)
        true_nu = 0.0000332762516453612485961386955355
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2252_fd17h(self):
        phi = -21.0
        nu = fd.fd17h(phi)
        true_nu = 0.0000904542301667560103660863186151
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2253_fd17h(self):
        phi = -20.0
        nu = fd.fd17h(phi)
        true_nu = 0.000245880090169102421872507236857
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2254_fd17h(self):
        phi = -19.0
        nu = fd.fd17h(phi)
        true_nu = 0.000668371381083273473247156337229
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2255_fd17h(self):
        phi = -18.0
        nu = fd.fd17h(phi)
        true_nu = 0.00181682177983658184665409510023
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2256_fd17h(self):
        phi = -17.0
        nu = fd.fd17h(phi)
        true_nu = 0.00493863362949990993299924883041
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2257_fd17h(self):
        phi = -16.0
        nu = fd.fd17h(phi)
        true_nu = 0.0134245980511674684022530045334
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2258_fd17h(self):
        phi = -15.0
        nu = fd.fd17h(phi)
        true_nu = 0.0364918409271099798121038053326
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2259_fd17h(self):
        phi = -14.0
        nu = fd.fd17h(phi)
        true_nu = 0.0991951080071728535465478574121
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2260_fd17h(self):
        phi = -13.0
        nu = fd.fd17h(phi)
        true_nu = 0.269640259035857083736865843674
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2261_fd17h(self):
        phi = -12.0
        nu = fd.fd17h(phi)
        true_nu = 0.732958212426641763915893873330
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2262_fd17h(self):
        phi = -11.0
        nu = fd.fd17h(phi)
        true_nu = 1.99238696080896379095078803116
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2263_fd17h(self):
        phi = -10.0
        nu = fd.fd17h(phi)
        true_nu = 5.41586905617236226100074662777
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2264_fd17h(self):
        phi = -9.0
        nu = fd.fd17h(phi)
        true_nu = 14.7218568546246418103181556564
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2265_fd17h(self):
        phi = -8.0
        nu = fd.fd17h(phi)
        true_nu = 40.0181442495222794718824484017
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2266_fd17h(self):
        phi = -7.0
        nu = fd.fd17h(phi)
        true_nu = 108.780507726951731951545531778
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2267_fd17h(self):
        phi = -6.0
        nu = fd.fd17h(phi)
        true_nu = 295.695437617217856822032167681
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2268_fd17h(self):
        phi = -5.0
        nu = fd.fd17h(phi)
        true_nu = 803.778807696472359188039455017
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2269_fd17h(self):
        phi = -4.0
        nu = fd.fd17h(phi)
        true_nu = 2184.86240971387659472460332235
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2270_fd17h(self):
        phi = -3.0
        nu = fd.fd17h(phi)
        true_nu = 5938.81401465016544050942989153
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2271_fd17h(self):
        phi = -2.0
        nu = fd.fd17h(phi)
        true_nu = 16141.4702107032991229142396574
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2272_fd17h(self):
        phi = -1.0
        nu = fd.fd17h(phi)
        true_nu = 43863.1178495533611310808854783
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2273_fd17h(self):
        phi = 0.0
        nu = fd.fd17h(phi)
        true_nu = 119131.005967529971558683646834
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2274_fd17h(self):
        phi = 1.0
        nu = fd.fd17h(phi)
        true_nu = 323113.856134700064172358069615
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2275_fd17h(self):
        phi = 2.0
        nu = fd.fd17h(phi)
        true_nu = 873482.619781045743656690219000
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2276_fd17h(self):
        phi = 3.0
        nu = fd.fd17h(phi)
        true_nu = 2.34454234994908560346994378131e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2277_fd17h(self):
        phi = 4.0
        nu = fd.fd17h(phi)
        true_nu = 6.20963742874162683278648547289e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2278_fd17h(self):
        phi = 5.0
        nu = fd.fd17h(phi)
        true_nu = 1.60984390138240463232980248012e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2279_fd17h(self):
        phi = 6.0
        nu = fd.fd17h(phi)
        true_nu = 4.05150030748309479398122783905e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2280_fd17h(self):
        phi = 7.0
        nu = fd.fd17h(phi)
        true_nu = 9.83121519746614005686468483057e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2281_fd17h(self):
        phi = 8.0
        nu = fd.fd17h(phi)
        true_nu = 2.29006823165293213436889057165e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2282_fd17h(self):
        phi = 9.0
        nu = fd.fd17h(phi)
        true_nu = 5.11086834099962318426308354788e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2283_fd17h(self):
        phi = 10.0
        nu = fd.fd17h(phi)
        true_nu = 1.09283463125764265156277579932e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2284_fd17h(self):
        phi = 11.0
        nu = fd.fd17h(phi)
        true_nu = 2.24190712780819376215073219337e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2285_fd17h(self):
        phi = 12.0
        nu = fd.fd17h(phi)
        true_nu = 4.42198919865499781954838419195e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2286_fd17h(self):
        phi = 13.0
        nu = fd.fd17h(phi)
        true_nu = 8.40730631871827671648047113000e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2287_fd17h(self):
        phi = 14.0
        nu = fd.fd17h(phi)
        true_nu = 1.54486621531324270113627512616e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2288_fd17h(self):
        phi = 15.0
        nu = fd.fd17h(phi)
        true_nu = 2.75079813024941810602659359501e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2289_fd17h(self):
        phi = 16.0
        nu = fd.fd17h(phi)
        true_nu = 4.75821064576517069120975023248e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2290_fd17h(self):
        phi = 17.0
        nu = fd.fd17h(phi)
        true_nu = 8.01408425855404598102018693517e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2291_fd17h(self):
        phi = 18.0
        nu = fd.fd17h(phi)
        true_nu = 1.31708977301890270849920128711e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2292_fd17h(self):
        phi = 19.0
        nu = fd.fd17h(phi)
        true_nu = 2.11627254427598644103353745747e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2293_fd17h(self):
        phi = 20.0
        nu = fd.fd17h(phi)
        true_nu = 3.33033054377301262768825871583e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2294_fd17h(self):
        phi = 21.0
        nu = fd.fd17h(phi)
        true_nu = 5.14107857423797416532355226234e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2295_fd17h(self):
        phi = 22.0
        nu = fd.fd17h(phi)
        true_nu = 7.79645450435169705314918801010e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2296_fd17h(self):
        phi = 23.0
        nu = fd.fd17h(phi)
        true_nu = 1.16300230033489088635128860004e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2297_fd17h(self):
        phi = 24.0
        nu = fd.fd17h(phi)
        true_nu = 1.70849957379782096651710725817e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2298_fd17h(self):
        phi = 25.0
        nu = fd.fd17h(phi)
        true_nu = 2.47435494767624620134412194107e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2299_fd17h(self):
        phi = 26.0
        nu = fd.fd17h(phi)
        true_nu = 3.53623164308974652472101865454e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2300_fd17h(self):
        phi = 27.0
        nu = fd.fd17h(phi)
        true_nu = 4.99150204240684536772032331390e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2301_fd17h(self):
        phi = 28.0
        nu = fd.fd17h(phi)
        true_nu = 6.96433382657080431028396917714e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2302_fd17h(self):
        phi = 29.0
        nu = fd.fd17h(phi)
        true_nu = 9.61171781415249688038801376675e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2303_fd17h(self):
        phi = 30.0
        nu = fd.fd17h(phi)
        true_nu = 1.31305686066446753438994205314e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2304_fd17h(self):
        phi = 31.0
        nu = fd.fd17h(phi)
        true_nu = 1.77660417600741636105111567594e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2305_fd17h(self):
        phi = 32.0
        nu = fd.fd17h(phi)
        true_nu = 2.38212245239820606260358372566e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2306_fd17h(self):
        phi = 33.0
        nu = fd.fd17h(phi)
        true_nu = 3.16683712279515596254861181961e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2307_fd17h(self):
        phi = 34.0
        nu = fd.fd17h(phi)
        true_nu = 4.17618691656697347365264498908e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2308_fd17h(self):
        phi = 35.0
        nu = fd.fd17h(phi)
        true_nu = 5.46531363393028952862804832306e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2309_fd17h(self):
        phi = 36.0
        nu = fd.fd17h(phi)
        true_nu = 7.10076686948526214318331561236e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2310_fd17h(self):
        phi = 37.0
        nu = fd.fd17h(phi)
        true_nu = 9.16244715140572429717033496072e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2311_fd17h(self):
        phi = 38.0
        nu = fd.fd17h(phi)
        true_nu = 1.17458127442044165130116207395e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2312_fd17h(self):
        phi = 39.0
        nu = fd.fd17h(phi)
        true_nu = 1.49643772233880139998862120659e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2313_fd17h(self):
        phi = 40.0
        nu = fd.fd17h(phi)
        true_nu = 1.89525268708800203788650699704e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2314_fd17h(self):
        phi = 41.0
        nu = fd.fd17h(phi)
        true_nu = 2.38686889619452310883215850871e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2315_fd17h(self):
        phi = 42.0
        nu = fd.fd17h(phi)
        true_nu = 2.98988841186050935847280195476e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2316_fd17h(self):
        phi = 43.0
        nu = fd.fd17h(phi)
        true_nu = 3.72606980922818947979704056857e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2317_fd17h(self):
        phi = 44.0
        nu = fd.fd17h(phi)
        true_nu = 4.62077106107301123905126344618e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2318_fd17h(self):
        phi = 45.0
        nu = fd.fd17h(phi)
        true_nu = 5.70344212822706737691382593624e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2319_fd17h(self):
        phi = 46.0
        nu = fd.fd17h(phi)
        true_nu = 7.00817149949903540162884507609e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2320_fd17h(self):
        phi = 47.0
        nu = fd.fd17h(phi)
        true_nu = 8.57429117809435437071072797414e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2321_fd17h(self):
        phi = 48.0
        nu = fd.fd17h(phi)
        true_nu = 1.04470448736524363306325384550e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2322_fd17h(self):
        phi = 49.0
        nu = fd.fd17h(phi)
        true_nu = 1.26783244301079047054229211087e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2323_fd17h(self):
        phi = 50.0
        nu = fd.fd17h(phi)
        true_nu = 1.53274797997505738666179155151e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd17h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd17h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2324_fd18h(self):
        phi = -50.0
        nu = fd.fd18h(phi)
        true_nu = 6.99904744829146485101333229431e-17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2325_fd18h(self):
        phi = -49.0
        nu = fd.fd18h(phi)
        true_nu = 1.90253834952133379352090373419e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2326_fd18h(self):
        phi = -48.0
        nu = fd.fd18h(phi)
        true_nu = 5.17163542345030531368816574885e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2327_fd18h(self):
        phi = -47.0
        nu = fd.fd18h(phi)
        true_nu = 1.40579625949800645954056923580e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2328_fd18h(self):
        phi = -46.0
        nu = fd.fd18h(phi)
        true_nu = 3.82135042670912743600559587818e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2329_fd18h(self):
        phi = -45.0
        nu = fd.fd18h(phi)
        true_nu = 1.03875074250976396570528869927e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2330_fd18h(self):
        phi = -44.0
        nu = fd.fd18h(phi)
        true_nu = 2.82361726766263207962183381477e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2331_fd18h(self):
        phi = -43.0
        nu = fd.fd18h(phi)
        true_nu = 7.67538750921051286988644257874e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2332_fd18h(self):
        phi = -42.0
        nu = fd.fd18h(phi)
        true_nu = 2.08638663926684698264119907628e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2333_fd18h(self):
        phi = -41.0
        nu = fd.fd18h(phi)
        true_nu = 5.67138688865880724163954024628e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2334_fd18h(self):
        phi = -40.0
        nu = fd.fd18h(phi)
        true_nu = 1.54164279216021181461867677590e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2335_fd18h(self):
        phi = -39.0
        nu = fd.fd18h(phi)
        true_nu = 4.19061958790396841864765500091e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2336_fd18h(self):
        phi = -38.0
        nu = fd.fd18h(phi)
        true_nu = 1.13912850757838899163098843233e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2337_fd18h(self):
        phi = -37.0
        nu = fd.fd18h(phi)
        true_nu = 3.09647232243000659516958799905e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2338_fd18h(self):
        phi = -36.0
        nu = fd.fd18h(phi)
        true_nu = 8.41708444638786459440093871656e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2339_fd18h(self):
        phi = -35.0
        nu = fd.fd18h(phi)
        true_nu = 2.28800076992213950685188801008e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2340_fd18h(self):
        phi = -34.0
        nu = fd.fd18h(phi)
        true_nu = 6.21943091637965664170960934576e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2341_fd18h(self):
        phi = -33.0
        nu = fd.fd18h(phi)
        true_nu = 1.69061660433512082782339164531e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2342_fd18h(self):
        phi = -32.0
        nu = fd.fd18h(phi)
        true_nu = 4.59557239445529442957106526630e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2343_fd18h(self):
        phi = -31.0
        nu = fd.fd18h(phi)
        true_nu = 1.24920609312158501522569411481e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2344_fd18h(self):
        phi = -30.0
        nu = fd.fd18h(phi)
        true_nu = 3.39569422293272225032300704419e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2345_fd18h(self):
        phi = -29.0
        nu = fd.fd18h(phi)
        true_nu = 9.23045390120137556401942394417e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2346_fd18h(self):
        phi = -28.0
        nu = fd.fd18h(phi)
        true_nu = 2.50909751080645917382672299522e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2347_fd18h(self):
        phi = -27.0
        nu = fd.fd18h(phi)
        true_nu = 6.82043416945701294126630898129e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2348_fd18h(self):
        phi = -26.0
        nu = fd.fd18h(phi)
        true_nu = 1.85398622650361002417156925454e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2349_fd18h(self):
        phi = -25.0
        nu = fd.fd18h(phi)
        true_nu = 5.03965706971807544331812362330e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2350_fd18h(self):
        phi = -24.0
        nu = fd.fd18h(phi)
        true_nu = 0.0000136992082342794848786474445058
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2351_fd18h(self):
        phi = -23.0
        nu = fd.fd18h(phi)
        true_nu = 0.0000372383088075160877473661365367
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2352_fd18h(self):
        phi = -22.0
        nu = fd.fd18h(phi)
        true_nu = 0.000101224218153999969035124531552
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2353_fd18h(self):
        phi = -21.0
        nu = fd.fd18h(phi)
        true_nu = 0.000275155952807863522648311754870
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2354_fd18h(self):
        phi = -20.0
        nu = fd.fd18h(phi)
        true_nu = 0.000747951426508998354073115300603
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2355_fd18h(self):
        phi = -19.0
        nu = fd.fd18h(phi)
        true_nu = 0.00203314277124239934308917184833
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2356_fd18h(self):
        phi = -18.0
        nu = fd.fd18h(phi)
        true_nu = 0.00552665504967912051663021295815
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2357_fd18h(self):
        phi = -17.0
        nu = fd.fd18h(phi)
        true_nu = 0.0150230059933202464745499941407
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2358_fd18h(self):
        phi = -16.0
        nu = fd.fd18h(phi)
        true_nu = 0.0408367641976368838170566984009
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2359_fd18h(self):
        phi = -15.0
        nu = fd.fd18h(phi)
        true_nu = 0.111005834030541465864328458694
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2360_fd18h(self):
        phi = -14.0
        nu = fd.fd18h(phi)
        true_nu = 0.301745141343273663512759412766
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2361_fd18h(self):
        phi = -13.0
        nu = fd.fd18h(phi)
        true_nu = 0.820228333394751640389522384770
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2362_fd18h(self):
        phi = -12.0
        nu = fd.fd18h(phi)
        true_nu = 2.22961176539760914138173198671
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2363_fd18h(self):
        phi = -11.0
        nu = fd.fd18h(phi)
        true_nu = 6.06071308391259794104037040740
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2364_fd18h(self):
        phi = -10.0
        nu = fd.fd18h(phi)
        true_nu = 16.4747257817897630358996603633
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2365_fd18h(self):
        phi = -9.0
        nu = fd.fd18h(phi)
        true_nu = 44.7829443098617532740493286824
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2366_fd18h(self):
        phi = -8.0
        nu = fd.fd18h(phi)
        true_nu = 121.732638533842947845888976889
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2367_fd18h(self):
        phi = -7.0
        nu = fd.fd18h(phi)
        true_nu = 330.903432992092560192366363054
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2368_fd18h(self):
        phi = -6.0
        nu = fd.fd18h(phi)
        true_nu = 899.487412607016761317661167219
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2369_fd18h(self):
        phi = -5.0
        nu = fd.fd18h(phi)
        true_nu = 2445.05012030720548000959494178
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2370_fd18h(self):
        phi = -4.0
        nu = fd.fd18h(phi)
        true_nu = 6646.26019809489903599463634194
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2371_fd18h(self):
        phi = -3.0
        nu = fd.fd18h(phi)
        true_nu = 18065.8537178160001648897168545
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2372_fd18h(self):
        phi = -2.0
        nu = fd.fd18h(phi)
        true_nu = 49103.9920948638467766306198545
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2373_fd18h(self):
        phi = -1.0
        nu = fd.fd18h(phi)
        true_nu = 133448.432031065514556676756604
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2374_fd18h(self):
        phi = 0.0
        nu = fd.fd18h(phi)
        true_nu = 362531.456517260785739160823367
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2375_fd18h(self):
        phi = 1.0
        nu = fd.fd18h(phi)
        true_nu = 983900.091215314222064025786580
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2376_fd18h(self):
        phi = 2.0
        nu = fd.fd18h(phi)
        true_nu = 2.66384739778870884649940259893e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2377_fd18h(self):
        phi = 3.0
        nu = fd.fd18h(phi)
        true_nu = 7.17360924967333597469253816115e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2378_fd18h(self):
        phi = 4.0
        nu = fd.fd18h(phi)
        true_nu = 1.91173678328690379417461380520e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2379_fd18h(self):
        phi = 5.0
        nu = fd.fd18h(phi)
        true_nu = 5.00626601745878788428020424532e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2380_fd18h(self):
        phi = 6.0
        nu = fd.fd18h(phi)
        true_nu = 1.27813982409523594748612052755e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2381_fd18h(self):
        phi = 7.0
        nu = fd.fd18h(phi)
        true_nu = 3.15896817592395328964859962390e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2382_fd18h(self):
        phi = 8.0
        nu = fd.fd18h(phi)
        true_nu = 7.51931085009012380946046086785e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2383_fd18h(self):
        phi = 9.0
        nu = fd.fd18h(phi)
        true_nu = 1.71882349435273156433024507727e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2384_fd18h(self):
        phi = 10.0
        nu = fd.fd18h(phi)
        true_nu = 3.76995675191450967997053209628e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2385_fd18h(self):
        phi = 11.0
        nu = fd.fd18h(phi)
        true_nu = 7.93916153933063677162773670579e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2386_fd18h(self):
        phi = 12.0
        nu = fd.fd18h(phi)
        true_nu = 1.60785870497158276388989524075e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2387_fd18h(self):
        phi = 13.0
        nu = fd.fd18h(phi)
        true_nu = 3.13830003173595831620448813667e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2388_fd18h(self):
        phi = 14.0
        nu = fd.fd18h(phi)
        true_nu = 5.91779064279090446806714805315e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2389_fd18h(self):
        phi = 15.0
        nu = fd.fd18h(phi)
        true_nu = 1.08071553801200525885426161336e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2390_fd18h(self):
        phi = 16.0
        nu = fd.fd18h(phi)
        true_nu = 1.91597733969472920363029744559e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2391_fd18h(self):
        phi = 17.0
        nu = fd.fd18h(phi)
        true_nu = 3.30507666506228767608867683697e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2392_fd18h(self):
        phi = 18.0
        nu = fd.fd18h(phi)
        true_nu = 5.55905539874262969141301609495e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2393_fd18h(self):
        phi = 19.0
        nu = fd.fd18h(phi)
        true_nu = 9.13463820834898826198453056298e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2394_fd18h(self):
        phi = 20.0
        nu = fd.fd18h(phi)
        true_nu = 1.46900161157408841172362332831e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2395_fd18h(self):
        phi = 21.0
        nu = fd.fd18h(phi)
        true_nu = 2.31576248773468755819060076346e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2396_fd18h(self):
        phi = 22.0
        nu = fd.fd18h(phi)
        true_nu = 3.58378775497788222869868317168e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2397_fd18h(self):
        phi = 23.0
        nu = fd.fd18h(phi)
        true_nu = 5.45184727941041438692082744933e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2398_fd18h(self):
        phi = 24.0
        nu = fd.fd18h(phi)
        true_nu = 8.16246334108792861837295064680e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2399_fd18h(self):
        phi = 25.0
        nu = fd.fd18h(phi)
        true_nu = 1.20406436927184345503943921307e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2400_fd18h(self):
        phi = 26.0
        nu = fd.fd18h(phi)
        true_nu = 1.75170285405235541552299532101e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2401_fd18h(self):
        phi = 27.0
        nu = fd.fd18h(phi)
        true_nu = 2.51562528638488971466600117322e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2402_fd18h(self):
        phi = 28.0
        nu = fd.fd18h(phi)
        true_nu = 3.56914307174285818394430420322e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2403_fd18h(self):
        phi = 29.0
        nu = fd.fd18h(phi)
        true_nu = 5.00657822780825930117050784184e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2404_fd18h(self):
        phi = 30.0
        nu = fd.fd18h(phi)
        true_nu = 6.94825477689393424857146891275e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2405_fd18h(self):
        phi = 31.0
        nu = fd.fd18h(phi)
        true_nu = 9.54644653819094723194171680080e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2406_fd18h(self):
        phi = 32.0
        nu = fd.fd18h(phi)
        true_nu = 1.29924233285970614678636843929e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2407_fd18h(self):
        phi = 33.0
        nu = fd.fd18h(phi)
        true_nu = 1.75247529117736496637612347600e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2408_fd18h(self):
        phi = 34.0
        nu = fd.fd18h(phi)
        true_nu = 2.34390324364657452333366823429e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2409_fd18h(self):
        phi = 35.0
        nu = fd.fd18h(phi)
        true_nu = 3.10992406132913079077282096862e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2410_fd18h(self):
        phi = 36.0
        nu = fd.fd18h(phi)
        true_nu = 4.09509205304491448205123820768e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2411_fd18h(self):
        phi = 37.0
        nu = fd.fd18h(phi)
        true_nu = 5.35364228393982955624646680717e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2412_fd18h(self):
        phi = 38.0
        nu = fd.fd18h(phi)
        true_nu = 6.95124600878130571197792282642e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2413_fd18h(self):
        phi = 39.0
        nu = fd.fd18h(phi)
        true_nu = 8.96702452753051920272376437180e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2414_fd18h(self):
        phi = 40.0
        nu = fd.fd18h(phi)
        true_nu = 1.14958511293816230485604684714e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2415_fd18h(self):
        phi = 41.0
        nu = fd.fd18h(phi)
        true_nu = 1.46509732825506144610317657068e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2416_fd18h(self):
        phi = 42.0
        nu = fd.fd18h(phi)
        true_nu = 1.85669898542688040396324302619e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2417_fd18h(self):
        phi = 43.0
        nu = fd.fd18h(phi)
        true_nu = 2.34032209123169880401712670839e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2418_fd18h(self):
        phi = 44.0
        nu = fd.fd18h(phi)
        true_nu = 2.93475105696551617570564819212e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2419_fd18h(self):
        phi = 45.0
        nu = fd.fd18h(phi)
        true_nu = 3.66205063908877488033254640891e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2420_fd18h(self):
        phi = 46.0
        nu = fd.fd18h(phi)
        true_nu = 4.54804620870846578140198559043e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2421_fd18h(self):
        phi = 47.0
        nu = fd.fd18h(phi)
        true_nu = 5.62286135874828148402856268178e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2422_fd18h(self):
        phi = 48.0
        nu = fd.fd18h(phi)
        true_nu = 6.92151820964499564433567143732e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2423_fd18h(self):
        phi = 49.0
        nu = fd.fd18h(phi)
        true_nu = 8.48460614254312052393596382046e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2424_fd18h(self):
        phi = 50.0
        nu = fd.fd18h(phi)
        true_nu = 1.03590250736048086387655337385e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd18h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd18h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2425_fd19h(self):
        phi = -50.0
        nu = fd.fd19h(phi)
        true_nu = 2.18581052038576384604934715235e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2426_fd19h(self):
        phi = -49.0
        nu = fd.fd19h(phi)
        true_nu = 5.94164901801923131739880399635e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2427_fd19h(self):
        phi = -48.0
        nu = fd.fd19h(phi)
        true_nu = 1.61510765567632067165185180598e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2428_fd19h(self):
        phi = -47.0
        nu = fd.fd19h(phi)
        true_nu = 4.39031779143003100558411484260e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2429_fd19h(self):
        phi = -46.0
        nu = fd.fd19h(phi)
        true_nu = 1.19341210736047018798292671100e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2430_fd19h(self):
        phi = -45.0
        nu = fd.fd19h(phi)
        true_nu = 3.24403044530098129923479681647e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2431_fd19h(self):
        phi = -44.0
        nu = fd.fd19h(phi)
        true_nu = 8.81818901042956217555660611673e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2432_fd19h(self):
        phi = -43.0
        nu = fd.fd19h(phi)
        true_nu = 2.39703229469679289855535939578e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2433_fd19h(self):
        phi = -42.0
        nu = fd.fd19h(phi)
        true_nu = 6.51580932890377915990614489813e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2434_fd19h(self):
        phi = -41.0
        nu = fd.fd19h(phi)
        true_nu = 1.77118060964630692778352889460e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2435_fd19h(self):
        phi = -40.0
        nu = fd.fd19h(phi)
        true_nu = 4.81456806612056964891621314401e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2436_fd19h(self):
        phi = -39.0
        nu = fd.fd19h(phi)
        true_nu = 1.30873528860147514646617522362e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2437_fd19h(self):
        phi = -38.0
        nu = fd.fd19h(phi)
        true_nu = 3.55751135326849412316427421488e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2438_fd19h(self):
        phi = -37.0
        nu = fd.fd19h(phi)
        true_nu = 9.67031846612649461602008257630e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2439_fd19h(self):
        phi = -36.0
        nu = fd.fd19h(phi)
        true_nu = 2.62866509618835974776977455706e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2440_fd19h(self):
        phi = -35.0
        nu = fd.fd19h(phi)
        true_nu = 7.14545256407336655328583714312e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2441_fd19h(self):
        phi = -34.0
        nu = fd.fd19h(phi)
        true_nu = 1.94233538610367239000796695834e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2442_fd19h(self):
        phi = -33.0
        nu = fd.fd19h(phi)
        true_nu = 5.27981498481859617554949103671e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2443_fd19h(self):
        phi = -32.0
        nu = fd.fd19h(phi)
        true_nu = 1.43520251308581596934944959790e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2444_fd19h(self):
        phi = -31.0
        nu = fd.fd19h(phi)
        true_nu = 3.90128491147992857082155538503e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2445_fd19h(self):
        phi = -30.0
        nu = fd.fd19h(phi)
        true_nu = 1.06047918825173442380357896203e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2446_fd19h(self):
        phi = -29.0
        nu = fd.fd19h(phi)
        true_nu = 2.88268130688368837220549394022e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2447_fd19h(self):
        phi = -28.0
        nu = fd.fd19h(phi)
        true_nu = 7.83594021374050016577128788746e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2448_fd19h(self):
        phi = -27.0
        nu = fd.fd19h(phi)
        true_nu = 2.13002938919022710528377363537e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2449_fd19h(self):
        phi = -26.0
        nu = fd.fd19h(phi)
        true_nu = 5.79002018271950090532535863184e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2450_fd19h(self):
        phi = -25.0
        nu = fd.fd19h(phi)
        true_nu = 0.0000157389066490974446989069368702
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2451_fd19h(self):
        phi = -24.0
        nu = fd.fd19h(phi)
        true_nu = 0.0000427827839440541216376732883840
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2452_fd19h(self):
        phi = -23.0
        nu = fd.fd19h(phi)
        true_nu = 0.000116295664166006511368756379873
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2453_fd19h(self):
        phi = -22.0
        nu = fd.fd19h(phi)
        true_nu = 0.000316124390630992754253620441363
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2454_fd19h(self):
        phi = -21.0
        nu = fd.fd19h(phi)
        true_nu = 0.000859315186584632037243570758941
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2455_fd19h(self):
        phi = -20.0
        nu = fd.fd19h(phi)
        true_nu = 0.00233586085660979763056991186024
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2456_fd19h(self):
        phi = -19.0
        nu = fd.fd19h(phi)
        true_nu = 0.00634952812031566382008280121518
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2457_fd19h(self):
        phi = -18.0
        nu = fd.fd19h(phi)
        true_nu = 0.0172598069086290457965519420538
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2458_fd19h(self):
        phi = -17.0
        nu = fd.fd19h(phi)
        true_nu = 0.0469170194815903929193935634712
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2459_fd19h(self):
        phi = -16.0
        nu = fd.fd19h(phi)
        true_nu = 0.127533681496001510623599045077
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2460_fd19h(self):
        phi = -15.0
        nu = fd.fd19h(phi)
        true_nu = 0.346672488880774497553274381100
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2461_fd19h(self):
        phi = -14.0
        nu = fd.fd19h(phi)
        true_nu = 0.942353526609240383265830816661
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2462_fd19h(self):
        phi = -13.0
        nu = fd.fd19h(phi)
        true_nu = 2.56158246483884763958543118922
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2463_fd19h(self):
        phi = -12.0
        nu = fd.fd19h(phi)
        true_nu = 6.96310304759605709037655353754
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2464_fd19h(self):
        phi = -11.0
        nu = fd.fd19h(phi)
        true_nu = 18.9276763459796819801953196213
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2465_fd19h(self):
        phi = -10.0
        nu = fd.fd19h(phi)
        true_nu = 51.4507576466266290711406597192
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2466_fd19h(self):
        phi = -9.0
        nu = fd.fd19h(phi)
        true_nu = 139.857652037375362123273100756
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2467_fd19h(self):
        phi = -8.0
        nu = fd.fd19h(phi)
        true_nu = 380.172458435963949273109566047
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2468_fd19h(self):
        phi = -7.0
        nu = fd.fd19h(phi)
        true_nu = 1033.41547411635718409250281798
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2469_fd19h(self):
        phi = -6.0
        nu = fd.fd19h(phi)
        true_nu = 2809.11146528529961500888345923
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2470_fd19h(self):
        phi = -5.0
        nu = fd.fd19h(phi)
        true_nu = 7635.93419483750646637278157536
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2471_fd19h(self):
        phi = -4.0
        nu = fd.fd19h(phi)
        true_nu = 20756.4552783569734116141659722
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2472_fd19h(self):
        phi = -3.0
        nu = fd.fd19h(phi)
        true_nu = 56420.6702043653332227845918616
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2473_fd19h(self):
        phi = -2.0
        nu = fd.fd19h(phi)
        true_nu = 153358.245822800227965113995620
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2474_fd19h(self):
        phi = -1.0
        nu = fd.fd19h(phi)
        true_nu = 416804.453566915204510144116783
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2475_fd19h(self):
        phi = 0.0
        nu = fd.fd19h(phi)
        true_nu = 1.13250640741475118782008693704e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2476_fd19h(self):
        phi = 1.0
        nu = fd.fd19h(phi)
        true_nu = 3.07498631374914182705044411939e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2477_fd19h(self):
        phi = 2.0
        nu = fd.fd19h(phi)
        true_nu = 8.33458513740198240126415050052e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2478_fd19h(self):
        phi = 3.0
        nu = fd.fd19h(phi)
        true_nu = 2.25000978552951322360687296169e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2479_fd19h(self):
        phi = 4.0
        nu = fd.fd19h(phi)
        true_nu = 6.02517009675097954301749461401e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2480_fd19h(self):
        phi = 5.0
        nu = fd.fd19h(phi)
        true_nu = 1.59076889487447755239521592237e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2481_fd19h(self):
        phi = 6.0
        nu = fd.fd19h(phi)
        true_nu = 4.11093043078852298140371374189e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2482_fd19h(self):
        phi = 7.0
        nu = fd.fd19h(phi)
        true_nu = 1.03248370239070775995296036500e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2483_fd19h(self):
        phi = 8.0
        nu = fd.fd19h(phi)
        true_nu = 2.50590648893080899735846505928e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2484_fd19h(self):
        phi = 9.0
        nu = fd.fd19h(phi)
        true_nu = 5.85586473583071910756115486795e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2485_fd19h(self):
        phi = 10.0
        nu = fd.fd19h(phi)
        true_nu = 1.31532391521317754923379156485e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2486_fd19h(self):
        phi = 11.0
        nu = fd.fd19h(phi)
        true_nu = 2.83960293046587754932687084693e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2487_fd19h(self):
        phi = 12.0
        nu = fd.fd19h(phi)
        true_nu = 5.89822000371636460866370692593e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2488_fd19h(self):
        phi = 13.0
        nu = fd.fd19h(phi)
        true_nu = 1.18080949848842489038723650975e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2489_fd19h(self):
        phi = 14.0
        nu = fd.fd19h(phi)
        true_nu = 2.28324526669502309194022197621e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2490_fd19h(self):
        phi = 15.0
        nu = fd.fd19h(phi)
        true_nu = 4.27387933091956613727870031682e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2491_fd19h(self):
        phi = 16.0
        nu = fd.fd19h(phi)
        true_nu = 7.76202710202709452607289778433e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2492_fd19h(self):
        phi = 17.0
        nu = fd.fd19h(phi)
        true_nu = 1.37076787999131314421374472574e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2493_fd19h(self):
        phi = 18.0
        nu = fd.fd19h(phi)
        true_nu = 2.35878065705949609398154161567e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2494_fd19h(self):
        phi = 19.0
        nu = fd.fd19h(phi)
        true_nu = 3.96261648277572980725333566095e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2495_fd19h(self):
        phi = 20.0
        nu = fd.fd19h(phi)
        true_nu = 6.51054723016305721131774970231e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2496_fd19h(self):
        phi = 21.0
        nu = fd.fd19h(phi)
        true_nu = 1.04785031802299182682718946234e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2497_fd19h(self):
        phi = 22.0
        nu = fd.fd19h(phi)
        true_nu = 1.65451638430782552676504316046e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2498_fd19h(self):
        phi = 23.0
        nu = fd.fd19h(phi)
        true_nu = 2.56637103065351184182868504808e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2499_fd19h(self):
        phi = 24.0
        nu = fd.fd19h(phi)
        true_nu = 3.91541931072020543227136005999e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2500_fd19h(self):
        phi = 25.0
        nu = fd.fd19h(phi)
        true_nu = 5.88211703450616615208010103335e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2501_fd19h(self):
        phi = 26.0
        nu = fd.fd19h(phi)
        true_nu = 8.71020567562455992022332271887e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2502_fd19h(self):
        phi = 27.0
        nu = fd.fd19h(phi)
        true_nu = 1.27252501710751856292736923955e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2503_fd19h(self):
        phi = 28.0
        nu = fd.fd19h(phi)
        true_nu = 1.83576088739524072836493897381e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2504_fd19h(self):
        phi = 29.0
        nu = fd.fd19h(phi)
        true_nu = 2.61706727477374792111681866056e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2505_fd19h(self):
        phi = 30.0
        nu = fd.fd19h(phi)
        true_nu = 3.68953297223271656301725945602e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2506_fd19h(self):
        phi = 31.0
        nu = fd.fd19h(phi)
        true_nu = 5.14717406182964369358257551914e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2507_fd19h(self):
        phi = 32.0
        nu = fd.fd19h(phi)
        true_nu = 7.10996558510753001022085594432e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2508_fd19h(self):
        phi = 33.0
        nu = fd.fd19h(phi)
        true_nu = 9.72986579269511195466905123410e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2509_fd19h(self):
        phi = 34.0
        nu = fd.fd19h(phi)
        true_nu = 1.31979884226301093710787752486e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2510_fd19h(self):
        phi = 35.0
        nu = fd.fd19h(phi)
        true_nu = 1.77530968436221496802214184753e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2511_fd19h(self):
        phi = 36.0
        nu = fd.fd19h(phi)
        true_nu = 2.36916137956354799933392353835e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2512_fd19h(self):
        phi = 37.0
        nu = fd.fd19h(phi)
        true_nu = 3.13793619381237270675743373973e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2513_fd19h(self):
        phi = 38.0
        nu = fd.fd19h(phi)
        true_nu = 4.12652735494145005153117317433e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2514_fd19h(self):
        phi = 39.0
        nu = fd.fd19h(phi)
        true_nu = 5.38973325836515023063136305829e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2515_fd19h(self):
        phi = 40.0
        nu = fd.fd19h(phi)
        true_nu = 6.99410389599769666780738934359e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2516_fd19h(self):
        phi = 41.0
        nu = fd.fd19h(phi)
        true_nu = 9.02007135089731441488991297260e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2517_fd19h(self):
        phi = 42.0
        nu = fd.fd19h(phi)
        true_nu = 1.15643992511533176246154967693e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2518_fd19h(self):
        phi = 43.0
        nu = fd.fd19h(phi)
        true_nu = 1.47429893314099389069160492707e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2519_fd19h(self):
        phi = 44.0
        nu = fd.fd19h(phi)
        true_nu = 1.86940867171422634817250253462e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2520_fd19h(self):
        phi = 45.0
        nu = fd.fd19h(phi)
        true_nu = 2.35819292334510071045316403409e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2521_fd19h(self):
        phi = 46.0
        nu = fd.fd19h(phi)
        true_nu = 2.96008899549096595670378063393e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2522_fd19h(self):
        phi = 47.0
        nu = fd.fd19h(phi)
        true_nu = 3.69801663641646391098739496179e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2523_fd19h(self):
        phi = 48.0
        nu = fd.fd19h(phi)
        true_nu = 4.59890738829396644845677508163e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2524_fd19h(self):
        phi = 49.0
        nu = fd.fd19h(phi)
        true_nu = 5.69430061883096722671258516772e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2525_fd19h(self):
        phi = 50.0
        nu = fd.fd19h(phi)
        true_nu = 7.02101296381633334468840757600e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd19h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd19h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2526_fd20h(self):
        phi = -50.0
        nu = fd.fd20h(phi)
        true_nu = 6.99904744829146485101333295346e-16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2527_fd20h(self):
        phi = -49.0
        nu = fd.fd20h(phi)
        true_nu = 1.90253834952133379352090422124e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2528_fd20h(self):
        phi = -48.0
        nu = fd.fd20h(phi)
        true_nu = 5.17163542345030531368816934769e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2529_fd20h(self):
        phi = -47.0
        nu = fd.fd20h(phi)
        true_nu = 1.40579625949800645954057189500e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2530_fd20h(self):
        phi = -46.0
        nu = fd.fd20h(phi)
        true_nu = 3.82135042670912743600561552720e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2531_fd20h(self):
        phi = -45.0
        nu = fd.fd20h(phi)
        true_nu = 1.03875074250976396570530321803e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2532_fd20h(self):
        phi = -44.0
        nu = fd.fd20h(phi)
        true_nu = 2.82361726766263207962194109474e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2533_fd20h(self):
        phi = -43.0
        nu = fd.fd20h(phi)
        true_nu = 7.67538750921051286988723527651e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2534_fd20h(self):
        phi = -42.0
        nu = fd.fd20h(phi)
        true_nu = 2.08638663926684698264178480511e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2535_fd20h(self):
        phi = -41.0
        nu = fd.fd20h(phi)
        true_nu = 5.67138688865880724164386822946e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2536_fd20h(self):
        phi = -40.0
        nu = fd.fd20h(phi)
        true_nu = 1.54164279216021181462187474695e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2537_fd20h(self):
        phi = -39.0
        nu = fd.fd20h(phi)
        true_nu = 4.19061958790396841867128498843e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2538_fd20h(self):
        phi = -38.0
        nu = fd.fd20h(phi)
        true_nu = 1.13912850757838899164844876267e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2539_fd20h(self):
        phi = -37.0
        nu = fd.fd20h(phi)
        true_nu = 3.09647232243000659529860335940e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2540_fd20h(self):
        phi = -36.0
        nu = fd.fd20h(phi)
        true_nu = 8.41708444638786459535424045179e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2541_fd20h(self):
        phi = -35.0
        nu = fd.fd20h(phi)
        true_nu = 2.28800076992213950755628801016e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2542_fd20h(self):
        phi = -34.0
        nu = fd.fd20h(phi)
        true_nu = 6.21943091637965664691446046245e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2543_fd20h(self):
        phi = -33.0
        nu = fd.fd20h(phi)
        true_nu = 1.69061660433512083166928533409e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2544_fd20h(self):
        phi = -32.0
        nu = fd.fd20h(phi)
        true_nu = 4.59557239445529445798858948321e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2545_fd20h(self):
        phi = -31.0
        nu = fd.fd20h(phi)
        true_nu = 1.24920609312158503622356217796e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2546_fd20h(self):
        phi = -30.0
        nu = fd.fd20h(phi)
        true_nu = 3.39569422293272240547743212071e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2547_fd20h(self):
        phi = -29.0
        nu = fd.fd20h(phi)
        true_nu = 9.23045390120137671046417483168e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2548_fd20h(self):
        phi = -28.0
        nu = fd.fd20h(phi)
        true_nu = 2.50909751080646002094118085809e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2549_fd20h(self):
        phi = -27.0
        nu = fd.fd20h(phi)
        true_nu = 6.82043416945701920064256033783e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2550_fd20h(self):
        phi = -26.0
        nu = fd.fd20h(phi)
        true_nu = 0.0000185398622650361464925979579838
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2551_fd20h(self):
        phi = -25.0
        nu = fd.fd20h(phi)
        true_nu = 0.0000503965706971810961835449269213
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2552_fd20h(self):
        phi = -24.0
        nu = fd.fd20h(phi)
        true_nu = 0.000136992082342797373999083643676
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2553_fd20h(self):
        phi = -23.0
        nu = fd.fd20h(phi)
        true_nu = 0.000372383088075179536411291736755
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2554_fd20h(self):
        phi = -22.0
        nu = fd.fd20h(phi)
        true_nu = 0.00101224218154013756228814201573
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2555_fd20h(self):
        phi = -21.0
        nu = fd.fd20h(phi)
        true_nu = 0.00275155952807965396995930420279
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2556_fd20h(self):
        phi = -20.0
        nu = fd.fd20h(phi)
        true_nu = 0.00747951426509751109342688904160
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2557_fd20h(self):
        phi = -19.0
        nu = fd.fd20h(phi)
        true_nu = 0.0203314277124796149400436138484
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2558_fd20h(self):
        phi = -18.0
        nu = fd.fd20h(phi)
        true_nu = 0.0552665504972021956176411824852
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2559_fd20h(self):
        phi = -17.0
        nu = fd.fd20h(phi)
        true_nu = 0.150230059936239296244731474972
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2560_fd20h(self):
        phi = -16.0
        nu = fd.fd20h(phi)
        true_nu = 0.408367641998808156444480160362
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2561_fd20h(self):
        phi = -15.0
        nu = fd.fd20h(phi)
        true_nu = 1.11005834047122003944966578442
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2562_fd20h(self):
        phi = -14.0
        nu = fd.fd20h(phi)
        true_nu = 3.01745141465788188052063529708
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2563_fd20h(self):
        phi = -13.0
        nu = fd.fd20h(phi)
        true_nu = 8.20228334300018305237159046894
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2564_fd20h(self):
        phi = -12.0
        nu = fd.fd20h(phi)
        true_nu = 22.2961177208667471173286698058
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2565_fd20h(self):
        phi = -11.0
        nu = fd.fd20h(phi)
        true_nu = 60.6071313333846662442139801970
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2566_fd20h(self):
        phi = -10.0
        nu = fd.fd20h(phi)
        true_nu = 164.747261470000371369687156570
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2567_fd20h(self):
        phi = -9.0
        nu = fd.fd20h(phi)
        true_nu = 447.829470084160890404175833319
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2568_fd20h(self):
        phi = -8.0
        nu = fd.fd20h(phi)
        true_nu = 1217.32658473514556838594231646
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2569_fd20h(self):
        phi = -7.0
        nu = fd.fd20h(phi)
        true_nu = 3309.03580325481128987154786392
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2570_fd20h(self):
        phi = -6.0
        nu = fd.fd20h(phi)
        true_nu = 8994.88501222256653280112179737
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2571_fd20h(self):
        phi = -5.0
        nu = fd.fd20h(phi)
        true_nu = 24450.5816335453246971728831552
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2572_fd20h(self):
        phi = -4.0
        nu = fd.fd20h(phi)
        true_nu = 66463.1961273598065654258225241
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2573_fd20h(self):
        phi = -3.0
        nu = fd.fd20h(phi)
        true_nu = 180662.924177009038586945272309
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2574_fd20h(self):
        phi = -2.0
        nu = fd.fd20h(phi)
        true_nu = 491072.273275895510272199417674
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2575_fd20h(self):
        phi = -1.0
        nu = fd.fd20h(phi)
        true_nu = 1.33472212342151734608279239492e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2576_fd20h(self):
        phi = 0.0
        nu = fd.fd20h(phi)
        true_nu = 3.62704781032576286463808894162e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2577_fd20h(self):
        phi = 1.0
        nu = fd.fd20h(phi)
        true_nu = 9.85138109033360026034379553649e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2578_fd20h(self):
        phi = 2.0
        nu = fd.fd20h(phi)
        true_nu = 2.67232395417208112392134784642e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2579_fd20h(self):
        phi = 3.0
        nu = fd.fd20h(phi)
        true_nu = 7.22753609541082868617466890716e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2580_fd20h(self):
        phi = 4.0
        nu = fd.fd20h(phi)
        true_nu = 1.94265140926689097683349547555e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2581_fd20h(self):
        phi = 5.0
        nu = fd.fd20h(phi)
        true_nu = 5.16284914634810263796547426608e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2582_fd20h(self):
        phi = 6.0
        nu = fd.fd20h(phi)
        true_nu = 1.34780878290348735066124717207e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2583_fd20h(self):
        phi = 7.0
        nu = fd.fd20h(phi)
        true_nu = 3.43252309566254961024960432813e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2584_fd20h(self):
        phi = 8.0
        nu = fd.fd20h(phi)
        true_nu = 8.47680181652393253242016960471e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2585_fd20h(self):
        phi = 9.0
        nu = fd.fd20h(phi)
        true_nu = 2.02117156321345143957914451028e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2586_fd20h(self):
        phi = 10.0
        nu = fd.fd20h(phi)
        true_nu = 4.64156853994102605225576005078e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2587_fd20h(self):
        phi = 11.0
        nu = fd.fd20h(phi)
        true_nu = 1.02582592685101788384814632679e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2588_fd20h(self):
        phi = 12.0
        nu = fd.fd20h(phi)
        true_nu = 2.18287249340167111383326034425e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2589_fd20h(self):
        phi = 13.0
        nu = fd.fd20h(phi)
        true_nu = 4.47805636505367892929926192260e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2590_fd20h(self):
        phi = 14.0
        nu = fd.fd20h(phi)
        true_nu = 8.87223911041215394046238732881e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2591_fd20h(self):
        phi = 15.0
        nu = fd.fd20h(phi)
        true_nu = 1.70115413236390449198213938659e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2592_fd20h(self):
        phi = 16.0
        nu = fd.fd20h(phi)
        true_nu = 3.16330590194080719782014431069e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2593_fd20h(self):
        phi = 17.0
        nu = fd.fd20h(phi)
        true_nu = 5.71658517688815616654181163946e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2594_fd20h(self):
        phi = 18.0
        nu = fd.fd20h(phi)
        true_nu = 1.00601515926321332886353604580e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2595_fd20h(self):
        phi = 19.0
        nu = fd.fd20h(phi)
        true_nu = 1.72730145106472501155177176015e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2596_fd20h(self):
        phi = 20.0
        nu = fd.fd20h(phi)
        true_nu = 2.89863401278743436991605571654e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2597_fd20h(self):
        phi = 21.0
        nu = fd.fd20h(phi)
        true_nu = 4.76197354053453307570555212077e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2598_fd20h(self):
        phi = 22.0
        nu = fd.fd20h(phi)
        true_nu = 7.67004309844032920129061884849e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2599_fd20h(self):
        phi = 23.0
        nu = fd.fd20h(phi)
        true_nu = 1.21288569978104580658780421041e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2600_fd20h(self):
        phi = 24.0
        nu = fd.fd20h(phi)
        true_nu = 1.88536791500124494871336548817e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2601_fd20h(self):
        phi = 25.0
        nu = fd.fd20h(phi)
        true_nu = 2.88418049599759635500087038525e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2602_fd20h(self):
        phi = 26.0
        nu = fd.fd20h(phi)
        true_nu = 4.34662206114228390589073357310e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2603_fd20h(self):
        phi = 27.0
        nu = fd.fd20h(phi)
        true_nu = 6.45949459662016049825023154475e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2604_fd20h(self):
        phi = 28.0
        nu = fd.fd20h(phi)
        true_nu = 9.47417206045892854887984872567e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2605_fd20h(self):
        phi = 29.0
        nu = fd.fd20h(phi)
        true_nu = 1.37254655480265183622167923055e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2606_fd20h(self):
        phi = 30.0
        nu = fd.fd20h(phi)
        true_nu = 1.96550554324856857301655723646e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2607_fd20h(self):
        phi = 31.0
        nu = fd.fd20h(phi)
        true_nu = 2.78403818747387704123683757834e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2608_fd20h(self):
        phi = 32.0
        nu = fd.fd20h(phi)
        true_nu = 3.90300198731378448433392300258e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2609_fd20h(self):
        phi = 33.0
        nu = fd.fd20h(phi)
        true_nu = 5.41867146097411375287635867172e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2610_fd20h(self):
        phi = 34.0
        nu = fd.fd20h(phi)
        true_nu = 7.45394182995176381269229088745e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2611_fd20h(self):
        phi = 35.0
        nu = fd.fd20h(phi)
        true_nu = 1.01645852150278181162647253016e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2612_fd20h(self):
        phi = 36.0
        nu = fd.fd20h(phi)
        true_nu = 1.37467317519171062690429586653e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2613_fd20h(self):
        phi = 37.0
        nu = fd.fd20h(phi)
        true_nu = 1.84457700067539369010354367532e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2614_fd20h(self):
        phi = 38.0
        nu = fd.fd20h(phi)
        true_nu = 2.45668850867299688745299989098e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2615_fd20h(self):
        phi = 39.0
        nu = fd.fd20h(phi)
        true_nu = 3.24874790232559739210470160876e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2616_fd20h(self):
        phi = 40.0
        nu = fd.fd20h(phi)
        true_nu = 4.26717464810025665046693177606e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2617_fd20h(self):
        phi = 41.0
        nu = fd.fd20h(phi)
        true_nu = 5.56877097467226361547100349522e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2618_fd20h(self):
        phi = 42.0
        nu = fd.fd20h(phi)
        true_nu = 7.22270504111358136982755622970e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2619_fd20h(self):
        phi = 43.0
        nu = fd.fd20h(phi)
        true_nu = 9.31281113132572357526557617313e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2620_fd20h(self):
        phi = 44.0
        nu = fd.fd20h(phi)
        true_nu = 1.19402481310902341508627294132e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2621_fd20h(self):
        phi = 45.0
        nu = fd.fd20h(phi)
        true_nu = 1.52265617418848442248688573032e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2622_fd20h(self):
        phi = 46.0
        nu = fd.fd20h(phi)
        true_nu = 1.93172003966063147198956286439e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2623_fd20h(self):
        phi = 47.0
        nu = fd.fd20h(phi)
        true_nu = 2.43855396817929009209943728764e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2624_fd20h(self):
        phi = 48.0
        nu = fd.fd20h(phi)
        true_nu = 3.06374752544541370399710324942e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2625_fd20h(self):
        phi = 49.0
        nu = fd.fd20h(phi)
        true_nu = 3.83166497851599541272919713023e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2626_fd20h(self):
        phi = 50.0
        nu = fd.fd20h(phi)
        true_nu = 4.77103853789446136951170579724e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd20h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd20h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2627_fd21h(self):
        phi = -50.0
        nu = fd.fd21h(phi)
        true_nu = 2.29510104640505203835181466281e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2628_fd21h(self):
        phi = -49.0
        nu = fd.fd21h(phi)
        true_nu = 6.23873146892019288326874532550e-15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2629_fd21h(self):
        phi = -48.0
        nu = fd.fd21h(phi)
        true_nu = 1.69586303846013670523444523075e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2630_fd21h(self):
        phi = -47.0
        nu = fd.fd21h(phi)
        true_nu = 4.60983368100153255586332675067e-14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2631_fd21h(self):
        phi = -46.0
        nu = fd.fd21h(phi)
        true_nu = 1.25308271272849369738207760260e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2632_fd21h(self):
        phi = -45.0
        nu = fd.fd21h(phi)
        true_nu = 3.40623196756603036419657032222e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2633_fd21h(self):
        phi = -44.0
        nu = fd.fd21h(phi)
        true_nu = 9.25909846095104028433468517455e-13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2634_fd21h(self):
        phi = -43.0
        nu = fd.fd21h(phi)
        true_nu = 2.51688390943163254348331116980e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2635_fd21h(self):
        phi = -42.0
        nu = fd.fd21h(phi)
        true_nu = 6.84159979534896811790281028283e-12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2636_fd21h(self):
        phi = -41.0
        nu = fd.fd21h(phi)
        true_nu = 1.85973964012862227417370887645e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2637_fd21h(self):
        phi = -40.0
        nu = fd.fd21h(phi)
        true_nu = 5.05529646942659813136943899326e-11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2638_fd21h(self):
        phi = -39.0
        nu = fd.fd21h(phi)
        true_nu = 1.37417205303154890379496311181e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2639_fd21h(self):
        phi = -38.0
        nu = fd.fd21h(phi)
        true_nu = 3.73538692093191882936297350245e-10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2640_fd21h(self):
        phi = -37.0
        nu = fd.fd21h(phi)
        true_nu = 1.01538343894328193471202369035e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2641_fd21h(self):
        phi = -36.0
        nu = fd.fd21h(phi)
        true_nu = 2.76009835099777773537930704468e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2642_fd21h(self):
        phi = -35.0
        nu = fd.fd21h(phi)
        true_nu = 7.50272519227703488258343374157e-9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2643_fd21h(self):
        phi = -34.0
        nu = fd.fd21h(phi)
        true_nu = 2.03945215540885601071522334226e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2644_fd21h(self):
        phi = -33.0
        nu = fd.fd21h(phi)
        true_nu = 5.54380573405952599324450732007e-8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2645_fd21h(self):
        phi = -32.0
        nu = fd.fd21h(phi)
        true_nu = 1.50696263874010677440614368967e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2646_fd21h(self):
        phi = -31.0
        nu = fd.fd21h(phi)
        true_nu = 4.09634915705392504805076129271e-7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2647_fd21h(self):
        phi = -30.0
        nu = fd.fd21h(phi)
        true_nu = 1.11350314766432118096968892681e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2648_fd21h(self):
        phi = -29.0
        nu = fd.fd21h(phi)
        true_nu = 3.02681537222787305664394113068e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2649_fd21h(self):
        phi = -28.0
        nu = fd.fd21h(phi)
        true_nu = 8.22773722442752713827913151133e-6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2650_fd21h(self):
        phi = -27.0
        nu = fd.fd21h(phi)
        true_nu = 0.0000223653085864973991192060679819
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2651_fd21h(self):
        phi = -26.0
        nu = fd.fd21h(phi)
        true_nu = 0.0000607952119185548667486551705266
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2652_fd21h(self):
        phi = -25.0
        nu = fd.fd21h(phi)
        true_nu = 0.000165258519815523961761136801402
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2653_fd21h(self):
        phi = -24.0
        nu = fd.fd21h(phi)
        true_nu = 0.000449219231412574132450718467355
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2654_fd21h(self):
        phi = -23.0
        nu = fd.fd21h(phi)
        true_nu = 0.00122110447374311163418070938299
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2655_fd21h(self):
        phi = -22.0
        nu = fd.fd21h(phi)
        true_nu = 0.00331930610162574360576210535341
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2656_fd21h(self):
        phi = -21.0
        nu = fd.fd21h(phi)
        true_nu = 0.00902280945914099856957770121988
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2657_fd21h(self):
        phi = -20.0
        nu = fd.fd21h(phi)
        true_nu = 0.0245265389944203293905851529566
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2658_fd21h(self):
        phi = -19.0
        nu = fd.fd21h(phi)
        true_nu = 0.0666700452634434406881090177877
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2659_fd21h(self):
        phi = -18.0
        nu = fd.fd21h(phi)
        true_nu = 0.181227972541557951693957097026
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2660_fd21h(self):
        phi = -17.0
        nu = fd.fd21h(phi)
        true_nu = 0.492628704563740680574862864110
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2661_fd21h(self):
        phi = -16.0
        nu = fd.fd21h(phi)
        true_nu = 1.33910365576004630581458723388
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2662_fd21h(self):
        phi = -15.0
        nu = fd.fd21h(phi)
        true_nu = 3.64006113363258809444553938875
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2663_fd21h(self):
        phi = -14.0
        nu = fd.fd21h(phi)
        true_nu = 9.89471203223778998810062163840
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2664_fd21h(self):
        phi = -13.0
        nu = fd.fd21h(phi)
        true_nu = 26.8966159017984787199587907412
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2665_fd21h(self):
        phi = -12.0
        nu = fd.fd21h(phi)
        true_nu = 73.1125821548591501937192935889
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2666_fd21h(self):
        phi = -11.0
        nu = fd.fd21h(phi)
        true_nu = 198.740602778833102795527455880
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2667_fd21h(self):
        phi = -10.0
        nu = fd.fd21h(phi)
        true_nu = 540.232963757776469168966788214
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2668_fd21h(self):
        phi = -9.0
        nu = fd.fd21h(phi)
        true_nu = 1468.50540896433083426539584446
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2669_fd21h(self):
        phi = -8.0
        nu = fd.fd21h(phi)
        true_nu = 3991.81127592297253547757481847
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2670_fd21h(self):
        phi = -7.0
        nu = fd.fd21h(phi)
        true_nu = 10850.8658944803118484904163552
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2671_fd21h(self):
        phi = -6.0
        nu = fd.fd21h(phi)
        true_nu = 29495.6956276752185435019420750
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2672_fd21h(self):
        phi = -5.0
        nu = fd.fd21h(phi)
        true_nu = 80177.4955466839442442063544156
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2673_fd21h(self):
        phi = -4.0
        nu = fd.fd21h(phi)
        true_nu = 217944.158187450721029706745395
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2674_fd21h(self):
        phi = -3.0
        nu = fd.fd21h(phi)
        true_nu = 592427.211498220991863769693481
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2675_fd21h(self):
        phi = -2.0
        nu = fd.fd21h(phi)
        true_nu = 1.61033663968283481691576909766e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2676_fd21h(self):
        phi = -1.0
        nu = fd.fd21h(phi)
        true_nu = 4.37699899793898474957084362725e6
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2677_fd21h(self):
        phi = 0.0
        nu = fd.fd21h(phi)
        true_nu = 1.18953520671253301513368412094e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2678_fd21h(self):
        phi = 1.0
        nu = fd.fd21h(phi)
        true_nu = 3.23163416627579029713080381061e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2679_fd21h(self):
        phi = 2.0
        nu = fd.fd21h(phi)
        true_nu = 8.77139634776827702051513936699e7
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2680_fd21h(self):
        phi = 3.0
        nu = fd.fd21h(phi)
        true_nu = 2.37554869329380734317688274174e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2681_fd21h(self):
        phi = 4.0
        nu = fd.fd21h(phi)
        true_nu = 6.40338450122658312755380487306e8
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2682_fd21h(self):
        phi = 5.0
        nu = fd.fd21h(phi)
        true_nu = 1.71071421787788872690774838852e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2683_fd21h(self):
        phi = 6.0
        nu = fd.fd21h(phi)
        true_nu = 4.50360918600586328118532740129e9
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2684_fd21h(self):
        phi = 7.0
        nu = fd.fd21h(phi)
        true_nu = 1.16071610043499022869341591774e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2685_fd21h(self):
        phi = 8.0
        nu = fd.fd21h(phi)
        true_nu = 2.91077397624789150079271673607e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2686_fd21h(self):
        phi = 9.0
        nu = fd.fd21h(phi)
        true_nu = 7.06820738676905281667993388001e10
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2687_fd21h(self):
        phi = 10.0
        nu = fd.fd21h(phi)
        true_nu = 1.65680057795603854321422377757e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2688_fd21h(self):
        phi = 11.0
        nu = fd.fd21h(phi)
        true_nu = 3.74324621461980415145402488180e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2689_fd21h(self):
        phi = 12.0
        nu = fd.fd21h(phi)
        true_nu = 8.15043227867186854663882386998e11
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2690_fd21h(self):
        phi = 13.0
        nu = fd.fd21h(phi)
        true_nu = 1.71166666802374442634504145095e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2691_fd21h(self):
        phi = 14.0
        nu = fd.fd21h(phi)
        true_nu = 3.47203120540443300551867124825e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2692_fd21h(self):
        phi = 15.0
        nu = fd.fd21h(phi)
        true_nu = 6.81468727845783914446225180511e12
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2693_fd21h(self):
        phi = 16.0
        nu = fd.fd21h(phi)
        true_nu = 1.29672826810292763670520343168e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2694_fd21h(self):
        phi = 17.0
        nu = fd.fd21h(phi)
        true_nu = 2.39691265330346171360729409007e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2695_fd21h(self):
        phi = 18.0
        nu = fd.fd21h(phi)
        true_nu = 4.31218758599877518635875896987e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2696_fd21h(self):
        phi = 19.0
        nu = fd.fd21h(phi)
        true_nu = 7.56466918400289514880907025544e13
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2697_fd21h(self):
        phi = 20.0
        nu = fd.fd21h(phi)
        true_nu = 1.29624111368554767523855968383e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2698_fd21h(self):
        phi = 21.0
        nu = fd.fd21h(phi)
        true_nu = 2.17314847895151235499190450229e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2699_fd21h(self):
        phi = 22.0
        nu = fd.fd21h(phi)
        true_nu = 3.56986404300623005016625565887e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2700_fd21h(self):
        phi = 23.0
        nu = fd.fd21h(phi)
        true_nu = 5.75402436770174953255893666829e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2701_fd21h(self):
        phi = 24.0
        nu = fd.fd21h(phi)
        true_nu = 9.11169996710825386879407493022e14
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2702_fd21h(self):
        phi = 25.0
        nu = fd.fd21h(phi)
        true_nu = 1.41918490149469174177077666244e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2703_fd21h(self):
        phi = 26.0
        nu = fd.fd21h(phi)
        true_nu = 2.17646840863928361748314768204e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2704_fd21h(self):
        phi = 27.0
        nu = fd.fd21h(phi)
        true_nu = 3.28975001860287597268199361340e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2705_fd21h(self):
        phi = 28.0
        nu = fd.fd21h(phi)
        true_nu = 4.90522259894225632291155743312e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2706_fd21h(self):
        phi = 29.0
        nu = fd.fd21h(phi)
        true_nu = 7.22097816244403324638430448250e15
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2707_fd21h(self):
        phi = 30.0
        nu = fd.fd21h(phi)
        true_nu = 1.05027266656935012776871822514e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2708_fd21h(self):
        phi = 31.0
        nu = fd.fd21h(phi)
        true_nu = 1.51035073118291028491780436375e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2709_fd21h(self):
        phi = 32.0
        nu = fd.fd21h(phi)
        true_nu = 2.14882233004560373610809366753e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2710_fd21h(self):
        phi = 33.0
        nu = fd.fd21h(phi)
        true_nu = 3.02639680977325870860194881356e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2711_fd21h(self):
        phi = 34.0
        nu = fd.fd21h(phi)
        true_nu = 4.22172655010045073634587494606e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2712_fd21h(self):
        phi = 35.0
        nu = fd.fd21h(phi)
        true_nu = 5.83595185184369038668491782712e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2713_fd21h(self):
        phi = 36.0
        nu = fd.fd21h(phi)
        true_nu = 7.99821549223811609783669383680e16
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2714_fd21h(self):
        phi = 37.0
        nu = fd.fd21h(phi)
        true_nu = 1.08723171888537518919089295772e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2715_fd21h(self):
        phi = 38.0
        nu = fd.fd21h(phi)
        true_nu = 1.46647020100660389646258241440e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2716_fd21h(self):
        phi = 39.0
        nu = fd.fd21h(phi)
        true_nu = 1.96340030859610179883086077542e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2717_fd21h(self):
        phi = 40.0
        nu = fd.fd21h(phi)
        true_nu = 2.61023879941820121755027326724e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2718_fd21h(self):
        phi = 41.0
        nu = fd.fd21h(phi)
        true_nu = 3.44689901141524704090917021394e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2719_fd21h(self):
        phi = 42.0
        nu = fd.fd21h(phi)
        true_nu = 4.52257412620280819518562067036e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2720_fd21h(self):
        phi = 43.0
        nu = fd.fd21h(phi)
        true_nu = 5.89759602475489531105793937052e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2721_fd21h(self):
        phi = 44.0
        nu = fd.fd21h(phi)
        true_nu = 7.64560938509164324266966733257e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2722_fd21h(self):
        phi = 45.0
        nu = fd.fd21h(phi)
        true_nu = 9.85610523295818992580298407615e17
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2723_fd21h(self):
        phi = 46.0
        nu = fd.fd21h(phi)
        true_nu = 1.26373631166621487598027742656e18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2724_fd21h(self):
        phi = 47.0
        nu = fd.fd21h(phi)
        true_nu = 1.61198564608043429849624833255e18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2725_fd21h(self):
        phi = 48.0
        nu = fd.fd21h(phi)
        true_nu = 2.04601814858546418962772382570e18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2726_fd21h(self):
        phi = 49.0
        nu = fd.fd21h(phi)
        true_nu = 2.58455763875384334545392720457e18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_2727_fd21h(self):
        phi = 50.0
        nu = fd.fd21h(phi)
        true_nu = 3.24991042788515674600524917629e18
        self.assert_rtol(nu, true_nu, RTOL)
        vphi = numpy.zeros(2); vphi.fill(phi)
        vnu = fd.fd21h(vphi)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(RTOL)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); fd.fd21h(vphi, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

if __name__ == "__main__":
    unittest.main()
