# Copyright (c) 2015, Scott J Maddox. All rights reserved.
# Use of this source code is governed by the BSD-3-Clause
# license that can be found in the LICENSE file.

# This file was generated by `scripts/gen_test_scfd.py`.
# Do not edit this file directly, or your changes will be lost.
'''
Tests the `scfd` module.
'''
# Make sure we import the local package
import os
import sys
sys.path.insert(0,
    os.path.abspath(os.path.join(os.path.dirname(__file__), '../..')))
from fdint import scfd
import unittest
import numpy
import warnings

class Test_SCFD(unittest.TestCase):

    def assert_rtol(self, a, b, rtol):
        assert rtol >= 0
        rerr = abs(a-b)/a
        if rerr > rtol:
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(rtol, rerr))

    def assert_all_rtol(self, a, b, rtol):
        a = numpy.array(a)
        b = numpy.array(b)
        rtol = numpy.array(rtol)
        for rtol_ in rtol:
            assert rtol_ >= 0
        rerr = abs(a-b)/a
        if (rerr > rtol).all():
            self.fail('Outside of relative tolerance of {}: {}'
                      ''.format(rtol, rerr))

    def test_nonparabolic_1(self):
        phi = -50.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.92874984796e-22
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_2(self):
        phi = -49.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.24288566336e-22
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_3(self):
        phi = -48.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.42516408274e-21
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_4(self):
        phi = -47.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.87399762869e-21
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_5(self):
        phi = -46.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.05306173576e-20
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_6(self):
        phi = -45.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.86251858055e-20
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_7(self):
        phi = -44.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.78113224113e-20
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_8(self):
        phi = -43.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.11513103759e-19
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_9(self):
        phi = -42.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.74952226429e-19
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_10(self):
        phi = -41.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.56288218933e-18
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_11(self):
        phi = -40.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.24835425529e-18
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_12(self):
        phi = -39.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.1548224173e-17
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_13(self):
        phi = -38.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.13913279205e-17
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_14(self):
        phi = -37.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.53304762574e-17
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_15(self):
        phi = -36.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.31952283024e-16
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_16(self):
        phi = -35.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.30511676015e-16
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_17(self):
        phi = -34.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.71390843154e-15
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_18(self):
        phi = -33.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.6588861451e-15
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_19(self):
        phi = -32.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.26641655491e-14
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_20(self):
        phi = -31.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.44247710847e-14
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_21(self):
        phi = -30.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.35762296884e-14
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_22(self):
        phi = -29.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.54366564738e-13
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_23(self):
        phi = -28.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.91440010694e-13
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_24(self):
        phi = -27.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.87952881654e-12
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_25(self):
        phi = -26.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.10908902805e-12
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_26(self):
        phi = -25.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.38879438649e-11
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_27(self):
        phi = -24.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.77513454423e-11
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_28(self):
        phi = -23.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.02618796313e-10
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_29(self):
        phi = -22.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.78946809259e-10
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_30(self):
        phi = -21.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.58256042588e-10
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_31(self):
        phi = -20.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.06115362094e-09
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_32(self):
        phi = -19.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.60279642644e-09
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_33(self):
        phi = -18.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.52299796627e-08
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_34(self):
        phi = -17.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.13993765819e-08
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_35(self):
        phi = -16.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.12535170242e-07
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_36(self):
        phi = -15.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.05902287418e-07
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_37(self):
        phi = -14.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.31528474643e-07
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_38(self):
        phi = -13.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.26032760065e-06
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_39(self):
        phi = -12.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.14419900626e-06
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_40(self):
        phi = -11.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.67016021686e-05
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_41(self):
        phi = -10.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.53992010526e-05
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_42(self):
        phi = -9.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000123404419837
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_43(self):
        phi = -8.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000335422847974
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_44(self):
        phi = -7.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000911588121597
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_45(self):
        phi = -6.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00247658279586
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_46(self):
        phi = -5.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00672195431451
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_47(self):
        phi = -4.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0181982035084
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_48(self):
        phi = -3.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0489337056965
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_49(self):
        phi = -2.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.12929851332
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_50(self):
        phi = -1.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.327795159261
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_51(self):
        phi = 0.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.765147024625
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_52(self):
        phi = 1.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.57564077615
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_53(self):
        phi = 2.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.8237212774
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_54(self):
        phi = 3.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.48754742135
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_55(self):
        phi = 4.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.51156759275
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_56(self):
        phi = 5.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.84420889524
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_57(self):
        phi = 6.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 11.4465997826
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_58(self):
        phi = 7.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 14.2905131953
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_59(self):
        phi = 8.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 17.3550201204
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_60(self):
        phi = 9.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 20.6240182116
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_61(self):
        phi = 10.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 24.0846569646
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_62(self):
        phi = 11.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 27.7263594133
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_63(self):
        phi = 12.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 31.540203287
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_64(self):
        phi = 13.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 35.5185155886
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_65(self):
        phi = 14.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 39.6545962515
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_66(self):
        phi = 15.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 43.9425224877
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_67(self):
        phi = 16.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 48.3770055247
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_68(self):
        phi = 17.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 52.9532826565
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_69(self):
        phi = 18.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 57.667033928
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_70(self):
        phi = 19.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 62.5143165249
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_71(self):
        phi = 20.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 67.4915122217
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_72(self):
        phi = 21.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 72.5952846738
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_73(self):
        phi = 22.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 77.8225442718
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_74(self):
        phi = 23.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 83.1704188979
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_75(self):
        phi = 24.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 88.6362293577
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_76(self):
        phi = 25.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 94.2174685579
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_77(self):
        phi = 26.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 99.9117837223
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_78(self):
        phi = 27.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 105.716961094
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_79(self):
        phi = 28.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 111.630912691
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_80(self):
        phi = 29.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 117.651664775
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_81(self):
        phi = 30.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 123.77734775
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_82(self):
        phi = 31.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 130.006187281
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_83(self):
        phi = 32.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 136.336496435
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_84(self):
        phi = 33.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 142.766668709
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_85(self):
        phi = 34.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 149.295171817
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_86(self):
        phi = 35.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 155.920542121
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_87(self):
        phi = 36.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 162.641379646
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_88(self):
        phi = 37.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 169.456343578
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_89(self):
        phi = 38.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 176.364148199
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_90(self):
        phi = 39.0
        alpha = 0.0
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 183.363559209
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_91(self):
        phi = 40.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 190.453390376
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_92(self):
        phi = 41.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 197.632500489
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_93(self):
        phi = 42.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 204.899790578
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_94(self):
        phi = 43.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 212.254201357
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_95(self):
        phi = 44.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 219.694710898
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_96(self):
        phi = 45.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 227.220332472
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_97(self):
        phi = 46.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 234.830112575
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_98(self):
        phi = 47.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 242.523129103
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_99(self):
        phi = 48.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 250.298489656
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_100(self):
        phi = 49.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 258.155329983
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_101(self):
        phi = 50.0
        alpha = 0.0
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 266.092812521
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_102(self):
        phi = -50.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.20864706206e-22
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_103(self):
        phi = -49.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.00372517428e-22
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_104(self):
        phi = -48.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.63198170443e-21
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_105(self):
        phi = -47.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.43618621153e-21
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_106(self):
        phi = -46.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.20588043665e-20
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_107(self):
        phi = -45.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.27792287823e-20
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_108(self):
        phi = -44.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.91031819499e-20
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_109(self):
        phi = -43.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.42207560352e-19
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_110(self):
        phi = -42.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.58388410021e-19
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_111(self):
        phi = -41.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.78968525103e-18
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_112(self):
        phi = -40.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.86486889653e-18
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_113(self):
        phi = -39.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.32240847193e-17
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_114(self):
        phi = -38.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.59467891904e-17
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_115(self):
        phi = -37.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.77135038477e-17
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_116(self):
        phi = -36.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.65612841904e-16
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_117(self):
        phi = -35.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.22010561554e-16
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_118(self):
        phi = -34.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.96262818943e-15
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_119(self):
        phi = -33.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.33497654334e-15
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_120(self):
        phi = -32.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.4501969793e-14
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_121(self):
        phi = -31.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.94204409652e-14
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_122(self):
        phi = -30.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.07155868346e-13
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_123(self):
        phi = -29.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.91279849737e-13
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_124(self):
        phi = -28.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.91780722535e-13
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_125(self):
        phi = -27.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.15228315019e-12
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_126(self):
        phi = -26.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.85051217686e-12
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_127(self):
        phi = -25.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.59033409375e-11
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_128(self):
        phi = -24.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.32297626818e-11
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_129(self):
        phi = -23.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.17510678344e-10
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_130(self):
        phi = -22.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.19427141574e-10
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_131(self):
        phi = -21.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.68292994319e-10
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_132(self):
        phi = -20.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.36026506722e-09
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_133(self):
        phi = -19.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.41586563505e-09
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_134(self):
        phi = -18.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.7440130914e-08
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_135(self):
        phi = -17.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.74071905392e-08
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_136(self):
        phi = -16.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.28866101548e-07
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_137(self):
        phi = -15.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.50294359736e-07
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_138(self):
        phi = -14.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.52198627113e-07
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_139(self):
        phi = -13.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.58834300176e-06
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_140(self):
        phi = -12.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.03583670773e-06
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_141(self):
        phi = -11.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.91253202758e-05
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_142(self):
        phi = -10.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.19875170283e-05
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_143(self):
        phi = -9.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000141313076251
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_144(self):
        phi = -8.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000384101826574
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_145(self):
        phi = -7.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00104389803239
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_146(self):
        phi = -6.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00283614042915
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_147(self):
        phi = -5.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00769861073715
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_148(self):
        phi = -4.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.02084772211
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_149(self):
        phi = -3.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0560972103338
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_150(self):
        phi = -2.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.148496703474
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_151(self):
        phi = -1.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.37814921154
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_152(self):
        phi = 0.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.891260994302
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_153(self):
        phi = 1.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.86749878339
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_154(self):
        phi = 2.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.43309077641
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_155(self):
        phi = 3.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.63242857159
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_156(self):
        phi = 4.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.47184565105
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_157(self):
        phi = 5.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 11.9553513357
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_158(self):
        phi = 6.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 16.0944900087
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_159(self):
        phi = 7.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 20.9077713923
        rtol = 7e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_160(self):
        phi = 8.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 26.4184324441
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_161(self):
        phi = 9.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 32.6526969373
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_162(self):
        phi = 10.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 39.6386756954
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_163(self):
        phi = 11.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 47.4057044789
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_164(self):
        phi = 12.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 55.9839434379
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_165(self):
        phi = 13.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 65.4041282119
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_166(self):
        phi = 14.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 75.697409721
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_167(self):
        phi = 15.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 86.8952472147
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_168(self):
        phi = 16.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 99.0293344072
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_169(self):
        phi = 17.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 112.131546908
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_170(self):
        phi = 18.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 126.233903831
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_171(self):
        phi = 19.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 141.368539145
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_172(self):
        phi = 20.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 157.567679877
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_173(self):
        phi = 21.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 174.863629277
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_174(self):
        phi = 22.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 193.288753623
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_175(self):
        phi = 23.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 212.875471759
        rtol = 7e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_176(self):
        phi = 24.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 233.656246703
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_177(self):
        phi = 25.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 255.663578854
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_178(self):
        phi = 26.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 278.930000451
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_179(self):
        phi = 27.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 303.488071002
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_180(self):
        phi = 28.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 329.370373504
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_181(self):
        phi = 29.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 356.60951128
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_182(self):
        phi = 30.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 385.238105328
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_183(self):
        phi = 31.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 415.288792079
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_184(self):
        phi = 32.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 446.794221499
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_185(self):
        phi = 33.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 479.787055459
        rtol = 7e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_186(self):
        phi = 34.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 514.29996635
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_187(self):
        phi = 35.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 550.365635881
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_188(self):
        phi = 36.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 588.016754045
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_189(self):
        phi = 37.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 627.286018223
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_190(self):
        phi = 38.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 668.206132395
        rtol = 1e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_191(self):
        phi = 39.0
        alpha = 0.0375
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 710.809806463
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_192(self):
        phi = 40.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 755.129755647
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_193(self):
        phi = 41.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 801.19869996
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_194(self):
        phi = 42.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 849.049363742
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_195(self):
        phi = 43.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 898.714475249
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_196(self):
        phi = 44.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 950.226766287
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_197(self):
        phi = 45.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1003.61897189
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_198(self):
        phi = 46.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1058.92383003
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_199(self):
        phi = 47.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1116.17408135
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_200(self):
        phi = 48.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1175.40246895
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_201(self):
        phi = 49.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1236.64173817
        rtol = 7e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_202(self):
        phi = 50.0
        alpha = 0.0375
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1299.9246364
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_203(self):
        phi = -50.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.50505939245e-22
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_204(self):
        phi = -49.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.8094574257e-22
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_205(self):
        phi = -48.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.8510024382e-21
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_206(self):
        phi = -47.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.03154629218e-21
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_207(self):
        phi = -46.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.36771608551e-20
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_208(self):
        phi = -45.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.71783778173e-20
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_209(self):
        phi = -44.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.01061308832e-19
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_210(self):
        phi = -43.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.74713119359e-19
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_211(self):
        phi = -42.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.46747680393e-19
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_212(self):
        phi = -41.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.02987065006e-18
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_213(self):
        phi = -40.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.51776050217e-18
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_214(self):
        phi = -39.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.49988281068e-17
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_215(self):
        phi = -38.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.0771041891e-17
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_216(self):
        phi = -37.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.108271823e-16
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_217(self):
        phi = -36.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.01259515745e-16
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_218(self):
        phi = -35.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.18908267299e-16
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_219(self):
        phi = -34.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.22602346217e-15
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_220(self):
        phi = -33.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.05095912695e-15
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_221(self):
        phi = -32.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.64482122395e-14
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_222(self):
        phi = -31.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.47108764414e-14
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_223(self):
        phi = -30.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.21536762965e-13
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_224(self):
        phi = -29.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.30371174258e-13
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_225(self):
        phi = -28.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.98041959631e-13
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_226(self):
        phi = -27.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.44113114006e-12
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_227(self):
        phi = -26.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.6356824189e-12
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_228(self):
        phi = -25.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.80376549387e-11
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_229(self):
        phi = -24.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.90314296474e-11
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_230(self):
        phi = -23.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.33281244231e-10
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_231(self):
        phi = -22.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.62295984248e-10
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_232(self):
        phi = -21.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.84822590359e-10
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_233(self):
        phi = -20.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.67702535054e-09
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_234(self):
        phi = -19.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.27690935666e-09
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_235(self):
        phi = -18.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.97806904122e-08
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_236(self):
        phi = -17.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.37694908632e-08
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_237(self):
        phi = -16.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.46160626698e-07
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_238(self):
        phi = -15.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.97305751641e-07
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_239(self):
        phi = -14.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.07998882808e-06
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_240(self):
        phi = -13.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.93571269878e-06
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_241(self):
        phi = -12.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.98008482135e-06
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_242(self):
        phi = -11.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.1692048172e-05
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_243(self):
        phi = -10.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.89645728934e-05
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_244(self):
        phi = -9.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000160278429695
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_245(self):
        phi = -8.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000435653149741
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_246(self):
        phi = -7.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00118401537325
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_247(self):
        phi = -6.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00321691781512
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_248(self):
        phi = -5.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00873292597804
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_249(self):
        phi = -4.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0236538083852
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_250(self):
        phi = -3.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0636851016419
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_251(self):
        phi = -2.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.168839809398
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_252(self):
        phi = -1.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.431555614469
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_253(self):
        phi = 0.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.02529648397
        rtol = 2e-10
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_254(self):
        phi = 1.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.17889488386
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_255(self):
        phi = 2.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.08713877701
        rtol = 3e-10
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_256(self):
        phi = 3.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.87077011898
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_257(self):
        phi = 4.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 10.6110964577
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_258(self):
        phi = 5.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 15.3831296835
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_259(self):
        phi = 6.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 21.2660125591
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_260(self):
        phi = 7.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 28.3435183242
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_261(self):
        phi = 8.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 36.7026281193
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_262(self):
        phi = 9.0
        alpha = 0.075
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 46.432314197
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_263(self):
        phi = 10.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 57.622764121
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_264(self):
        phi = 11.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 70.3649212213
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_265(self):
        phi = 12.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 84.750214468
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_266(self):
        phi = 13.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 100.870396531
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_267(self):
        phi = 14.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 118.817443577
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_268(self):
        phi = 15.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 138.683491019
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_269(self):
        phi = 16.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 160.560790867
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_270(self):
        phi = 17.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 184.541682488
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_271(self):
        phi = 18.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 210.718571994
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_272(self):
        phi = 19.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 239.18391735
        rtol = 7e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_273(self):
        phi = 20.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 270.030217395
        rtol = 1e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_274(self):
        phi = 21.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 303.350003595
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_275(self):
        phi = 22.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 339.235833746
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_276(self):
        phi = 23.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 377.780287117
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_277(self):
        phi = 24.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 419.075960631
        rtol = 7e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_278(self):
        phi = 25.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 463.215465858
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_279(self):
        phi = 26.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 510.291426599
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_280(self):
        phi = 27.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 560.396476944
        rtol = 1e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_281(self):
        phi = 28.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 613.623259692
        rtol = 4e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_282(self):
        phi = 29.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 670.064425054
        rtol = 8e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_283(self):
        phi = 30.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 729.812629586
        rtol = 2e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_284(self):
        phi = 31.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 792.960535301
        rtol = 4e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_285(self):
        phi = 32.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 859.600808927
        rtol = 9e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_286(self):
        phi = 33.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 929.826121286
        rtol = 2e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_287(self):
        phi = 34.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1003.72914677
        rtol = 3e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_288(self):
        phi = 35.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1081.40256288
        rtol = 6e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_289(self):
        phi = 36.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1162.93904986
        rtol = 1e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_290(self):
        phi = 37.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1248.4312904
        rtol = 2e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_291(self):
        phi = 38.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1337.97196927
        rtol = 3e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_292(self):
        phi = 39.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1431.65377318
        rtol = 4e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_293(self):
        phi = 40.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1529.56939049
        rtol = 7e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_294(self):
        phi = 41.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1631.81151107
        rtol = 1e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_295(self):
        phi = 42.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1738.47282616
        rtol = 2e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_296(self):
        phi = 43.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1849.64602816
        rtol = 2e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_297(self):
        phi = 44.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1965.42381058
        rtol = 3e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_298(self):
        phi = 45.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2085.89886788
        rtol = 5e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_299(self):
        phi = 46.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2211.16389543
        rtol = 6e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_300(self):
        phi = 47.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2341.31158937
        rtol = 9e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_301(self):
        phi = 48.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2476.43464656
        rtol = 1e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_302(self):
        phi = 49.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2616.62576454
        rtol = 2e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_303(self):
        phi = 50.0
        alpha = 0.075
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2761.97764142
        rtol = 2e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_304(self):
        phi = -50.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.81695489721e-22
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_305(self):
        phi = -49.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.65727730866e-22
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_306(self):
        phi = -48.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.08146377636e-21
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_307(self):
        phi = -47.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.65800515988e-21
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_308(self):
        phi = -46.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.53800526114e-20
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_309(self):
        phi = -45.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.18073175344e-20
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_310(self):
        phi = -44.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.1364407155e-19
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_311(self):
        phi = -43.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.08916614607e-19
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_312(self):
        phi = -42.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.39722419996e-19
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_313(self):
        phi = -41.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.28260219523e-18
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_314(self):
        phi = -40.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.20475606888e-18
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_315(self):
        phi = -39.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.68662756721e-17
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_316(self):
        phi = -38.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.58472906732e-17
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_317(self):
        phi = -37.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.24625857121e-16
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_318(self):
        phi = -36.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.38768202768e-16
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_319(self):
        phi = -35.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.20867449644e-16
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_320(self):
        phi = -34.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.50317725479e-15
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_321(self):
        phi = -33.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.8043412451e-15
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_322(self):
        phi = -32.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.84961171612e-14
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_323(self):
        phi = -31.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.02776591763e-14
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_324(self):
        phi = -30.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.36668847316e-13
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_325(self):
        phi = -29.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.71504444176e-13
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_326(self):
        phi = -28.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.0098537798e-12
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_327(self):
        phi = -27.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.74506717902e-12
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_328(self):
        phi = -26.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.46186623062e-12
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_329(self):
        phi = -25.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.0283455381e-11
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_330(self):
        phi = -24.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.51361481803e-11
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_331(self):
        phi = -23.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.49875589687e-10
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_332(self):
        phi = -22.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.07404091954e-10
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_333(self):
        phi = -21.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.10743913984e-09
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_334(self):
        phi = -20.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.0103316888e-09
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_335(self):
        phi = -19.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.18292991872e-09
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_336(self):
        phi = -18.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.22435096383e-08
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_337(self):
        phi = -17.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.04641275834e-08
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_338(self):
        phi = -16.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.64358535828e-07
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_339(self):
        phi = -15.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.4677279576e-07
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_340(self):
        phi = -14.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.2144541835e-06
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_341(self):
        phi = -13.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.30122734441e-06
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_342(self):
        phi = -12.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.97365600105e-06
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_343(self):
        phi = -11.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.43928499293e-05
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_344(self):
        phi = -10.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.63060783133e-05
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_345(self):
        phi = -9.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000180234452463
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_346(self):
        phi = -8.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000489897337555
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_347(self):
        phi = -7.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00133145228187
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_348(self):
        phi = -6.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00361758891525
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_349(self):
        phi = -5.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00982129629324
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_350(self):
        phi = -4.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0266066722552
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_351(self):
        phi = -3.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0716708108023
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_352(self):
        phi = -2.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.190255923883
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_353(self):
        phi = -1.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.487821113367
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_354(self):
        phi = 0.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.16674266025
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_355(self):
        phi = 1.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.50852378088
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_356(self):
        phi = 2.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.78271160848
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_357(self):
        phi = 3.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.19549529233
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_358(self):
        phi = 4.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 12.914675984
        rtol = 6e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_359(self):
        phi = 5.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 19.0995295199
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_360(self):
        phi = 6.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 26.9112398236
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_361(self):
        phi = 7.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 36.5140860924
        rtol = 9e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_362(self):
        phi = 8.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 48.0745898375
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_363(self):
        phi = 9.0
        alpha = 0.1125
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 61.7606630952
        rtol = 2e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_364(self):
        phi = 10.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 77.7410517355
        rtol = 3e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_365(self):
        phi = 11.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 96.185006978
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_366(self):
        phi = 12.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 117.262095389
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_367(self):
        phi = 13.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 141.142087528
        rtol = 4e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_368(self):
        phi = 14.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 167.994890808
        rtol = 7e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_369(self):
        phi = 15.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 197.990507601
        rtol = 2e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_370(self):
        phi = 16.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 231.299008147
        rtol = 3e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_371(self):
        phi = 17.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 268.090512449
        rtol = 8e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_372(self):
        phi = 18.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 308.535177788
        rtol = 2e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_373(self):
        phi = 19.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 352.803189908
        rtol = 4e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_374(self):
        phi = 20.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 401.064756627
        rtol = 1e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_375(self):
        phi = 21.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 453.490103125
        rtol = 2e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_376(self):
        phi = 22.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 510.249468411
        rtol = 5e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_377(self):
        phi = 23.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 571.513102624
        rtol = 1e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_378(self):
        phi = 24.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 637.451264955
        rtol = 2e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_379(self):
        phi = 25.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 708.234222018
        rtol = 4e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_380(self):
        phi = 26.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 784.03224657
        rtol = 7e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_381(self):
        phi = 27.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 865.01561648
        rtol = 1e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_382(self):
        phi = 28.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 951.354613909
        rtol = 2e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_383(self):
        phi = 29.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1043.21952464
        rtol = 4e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_384(self):
        phi = 30.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1140.78063753
        rtol = 6e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_385(self):
        phi = 31.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1244.20824407
        rtol = 1e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_386(self):
        phi = 32.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1353.67263799
        rtol = 2e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_387(self):
        phi = 33.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1469.34411496
        rtol = 2e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_388(self):
        phi = 34.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1591.39297236
        rtol = 3e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_389(self):
        phi = 35.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1719.989509
        rtol = 5e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_390(self):
        phi = 36.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1855.30402498
        rtol = 7e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_391(self):
        phi = 37.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1997.50682151
        rtol = 1e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_392(self):
        phi = 38.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2146.7682008
        rtol = 1e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_393(self):
        phi = 39.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2303.25846591
        rtol = 2e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_394(self):
        phi = 40.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2467.14792069
        rtol = 3e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_395(self):
        phi = 41.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2638.60686964
        rtol = 4e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_396(self):
        phi = 42.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2817.80561789
        rtol = 5e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_397(self):
        phi = 43.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3004.9144711
        rtol = 7e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_398(self):
        phi = 44.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3200.10373543
        rtol = 9e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_399(self):
        phi = 45.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3403.54371746
        rtol = 1e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_400(self):
        phi = 46.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3615.40472416
        rtol = 1e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_401(self):
        phi = 47.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3835.85706287
        rtol = 2e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_402(self):
        phi = 48.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4065.07104122
        rtol = 2e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_403(self):
        phi = 49.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4303.21696715
        rtol = 3e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_404(self):
        phi = 50.0
        alpha = 0.1125
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4550.46514885
        rtol = 4e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_405(self):
        phi = -50.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.1434921979e-22
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_406(self):
        phi = -49.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.54489771946e-22
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_407(self):
        phi = -48.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.32274401969e-21
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_408(self):
        phi = -47.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.31387286087e-21
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_409(self):
        phi = -46.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.71628858649e-20
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_410(self):
        phi = -45.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.66535607705e-20
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_411(self):
        phi = -44.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.26817526475e-19
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_412(self):
        phi = -43.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.44725777748e-19
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_413(self):
        phi = -42.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.37061817454e-19
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_414(self):
        phi = -41.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.54719811053e-18
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_415(self):
        phi = -40.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.92400233734e-18
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_416(self):
        phi = -39.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.88213897338e-17
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_417(self):
        phi = -38.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.11618416997e-17
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_418(self):
        phi = -37.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.39072304603e-16
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_419(self):
        phi = -36.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.78037718444e-16
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_420(self):
        phi = -35.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.02761306052e-15
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_421(self):
        phi = -34.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.79334190909e-15
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_422(self):
        phi = -33.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.59309055216e-15
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_423(self):
        phi = -32.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.06401600698e-14
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_424(self):
        phi = -31.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.61057720542e-14
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_425(self):
        phi = -30.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.52511300646e-13
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_426(self):
        phi = -29.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.14568697182e-13
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_427(self):
        phi = -28.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.1269145562e-12
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_428(self):
        phi = -27.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.06327136034e-12
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_429(self):
        phi = -26.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 8.32683487444e-12
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_430(self):
        phi = -25.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.26346839277e-11
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_431(self):
        phi = -24.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.15274500132e-11
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_432(self):
        phi = -23.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.67248949319e-10
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_433(self):
        phi = -22.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.54629779741e-10
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_434(self):
        phi = -21.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.23581186878e-09
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_435(self):
        phi = -20.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.35928494506e-09
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_436(self):
        phi = -19.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.13148321366e-09
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_437(self):
        phi = -18.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.48219448192e-08
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_438(self):
        phi = -17.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6.74730410517e-08
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_439(self):
        phi = -16.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.83410737726e-07
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_440(self):
        phi = -15.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4.98562048342e-07
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_441(self):
        phi = -14.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.35523195567e-06
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_442(self):
        phi = -13.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3.68390091544e-06
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_443(self):
        phi = -12.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.00138699584e-05
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_444(self):
        phi = -11.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.72204397724e-05
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_445(self):
        phi = -10.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 7.39922285305e-05
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_446(self):
        phi = -9.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000201127309881
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_447(self):
        phi = -8.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.000546688053964
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_448(self):
        phi = -7.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00148581098867
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_449(self):
        phi = -6.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.00403707257596
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_450(self):
        phi = -5.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0109607835132
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_451(self):
        phi = -4.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0296983321829
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_452(self):
        phi = -3.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.0800326801439
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_453(self):
        phi = -2.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.212686453342
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_454(self):
        phi = -1.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 0.546788385513
        rtol = 6e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_455(self):
        phi = 0.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1.31518461906
        rtol = 5e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_456(self):
        phi = 1.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2.8553303413
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_457(self):
        phi = 2.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5.51728104044
        rtol = 4e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_458(self):
        phi = 3.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 9.60099836353
        rtol = 8e-09
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_459(self):
        phi = 4.0
        alpha = 0.15
        nu = scfd.nonparabolic(phi, alpha)
        true_nu = 15.3711566133
        rtol = 2e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_460(self):
        phi = 5.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 23.0830562122
        rtol = 3e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_461(self):
        phi = 6.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 32.9925443129
        rtol = 5e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_462(self):
        phi = 7.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 45.3575589991
        rtol = 9e-08
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_463(self):
        phi = 8.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 60.4376489452
        rtol = 2e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_464(self):
        phi = 9.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 78.493369888
        rtol = 4e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_465(self):
        phi = 10.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 99.7858763513
        rtol = 9e-07
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_466(self):
        phi = 11.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 124.576679972
        rtol = 2e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_467(self):
        phi = 12.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 153.12751091
        rtol = 4e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_468(self):
        phi = 13.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 185.700237808
        rtol = 9e-06
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_469(self):
        phi = 14.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 222.556820371
        rtol = 2e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_470(self):
        phi = 15.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 263.959280327
        rtol = 5e-05
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_471(self):
        phi = 16.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 310.169683005
        rtol = 1e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_472(self):
        phi = 17.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 361.450125223
        rtol = 2e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_473(self):
        phi = 18.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 418.062727088
        rtol = 5e-04
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_474(self):
        phi = 19.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 480.26962627
        rtol = 1e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_475(self):
        phi = 20.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 548.332973925
        rtol = 2e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_476(self):
        phi = 21.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 622.514931713
        rtol = 4e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_477(self):
        phi = 22.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 703.077669585
        rtol = 7e-03
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_478(self):
        phi = 23.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 790.283364119
        rtol = 1e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_479(self):
        phi = 24.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 884.394197236
        rtol = 2e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_480(self):
        phi = 25.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 985.672355215
        rtol = 4e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_481(self):
        phi = 26.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1094.38002791
        rtol = 6e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_482(self):
        phi = 27.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1210.77940815
        rtol = 9e-02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_483(self):
        phi = 28.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1335.13269123
        rtol = 1e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_484(self):
        phi = 29.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1467.70207453
        rtol = 2e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_485(self):
        phi = 30.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1608.74975717
        rtol = 3e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_486(self):
        phi = 31.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1758.53793977
        rtol = 5e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_487(self):
        phi = 32.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 1917.32882424
        rtol = 7e-01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_488(self):
        phi = 33.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2085.38461355
        rtol = 1e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_489(self):
        phi = 34.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2262.96751166
        rtol = 1e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_490(self):
        phi = 35.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2450.33972331
        rtol = 2e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_491(self):
        phi = 36.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2647.76345396
        rtol = 3e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_492(self):
        phi = 37.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 2855.5009097
        rtol = 4e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_493(self):
        phi = 38.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3073.81429717
        rtol = 5e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_494(self):
        phi = 39.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3302.96582346
        rtol = 7e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_495(self):
        phi = 40.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3543.21769612
        rtol = 9e+00
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_496(self):
        phi = 41.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 3794.83212305
        rtol = 1e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_497(self):
        phi = 42.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4058.0713125
        rtol = 2e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_498(self):
        phi = 43.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4333.19747299
        rtol = 2e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_499(self):
        phi = 44.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4620.47281332
        rtol = 2e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_500(self):
        phi = 45.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 4920.15954254
        rtol = 3e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_501(self):
        phi = 46.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5232.51986989
        rtol = 4e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_502(self):
        phi = 47.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5557.81600481
        rtol = 5e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_503(self):
        phi = 48.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 5896.31015691
        rtol = 6e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_504(self):
        phi = 49.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6248.26453595
        rtol = 8e+01
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

    def test_nonparabolic_505(self):
        phi = 50.0
        alpha = 0.15
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            nu = scfd.nonparabolic(phi, alpha)
        true_nu = 6613.94135185
        rtol = 1e+02
        self.assert_rtol(nu, true_nu, rtol)
        vphi = numpy.zeros(2); vphi.fill(phi)
        valpha = numpy.zeros(2); valpha.fill(alpha)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = scfd.nonparabolic(vphi, valpha)
        vtrue_nu = numpy.zeros(2); vtrue_nu.fill(true_nu)
        vrtol = numpy.zeros(2); vrtol.fill(rtol)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            vnu = numpy.zeros(2); scfd.nonparabolic(vphi, valpha, vnu)
        self.assert_all_rtol(vnu, vtrue_nu, vrtol)

if __name__ == "__main__":
    unittest.main()
